#
# spec file for package kernel-vanilla
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%define srcversion 6.9-rc7-next-20240510
%define patchversion 6.9.0-rc7-next-20240510
%define git_commit 7a0beef82c33552b9d2fd7787c1fdf2613251a91
%define variant -vanilla%{nil}
%define compress_modules xz
%define compress_vmlinux gz
%define livepatch %{nil}
%define livepatch_rt %{nil}
%define sb_efi_only 0
%define split_base 0
%define split_optional 0
%define supported_modules_check 0
%define build_flavor vanilla

%include %_sourcedir/kernel-spec-macros

%(chmod +x %_sourcedir/{guards,apply-patches,check-for-config-changes,group-source-files.pl,split-modules,modversions,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,log.sh,try-disable-staging-driver,compress-vmlinux.sh,mkspec-dtb,check-module-license,klp-symbols,splitflist,mergedep,moddep,modflist,kernel-subpackage-build})

Name:           kernel-vanilla
Version:        6.9~rc7.next.20240510
%if 0%{?is_kotd}
Release:        1.1.g7a0beef
%else
Release:        1.1
%endif
Summary:        The Standard Kernel - without any SUSE patches
License:        GPL-2.0-only
Group:          System/Kernel
URL:            https://www.kernel.org/
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150300
BuildRequires:  bash-sh
%endif
BuildRequires:  bc
BuildRequires:  bison
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  flex
# Cannot test %%CONFIG_GCC_PLUGINS here because the buildservice parser
# does not expand %%(...)
%if "%build_flavor" == "syzkaller"
# Needed by scripts/gcc-plugin.sh
BuildRequires:  gcc-c++
BuildRequires:  gcc-devel
%endif
BuildRequires:  hmaccalc
BuildRequires:  libopenssl-devel
BuildRequires:  modutils
BuildRequires:  python3-base
# Used to sign the kernel in the buildservice
BuildRequires:  openssl
BuildRequires:  pesign-obs-integration
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
# pahole for CONFIG_DEBUG_INFO_BTF
BuildRequires:  dwarves >= 1.22
%endif
# for objtool
BuildRequires:  libelf-devel
# required for 50-check-kernel-build-id rpm check
BuildRequires:  elfutils
%ifarch %arm
BuildRequires:  u-boot-tools
%endif
# Do not install p-b and dracut for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader dracut distribution-release suse-kernel-rpm-scriptlets
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools udev insserv
%if ! 0%{?is_kotd} || ! %{?is_kotd_qa}%{!?is_kotd_qa:0}
ExclusiveArch:  alpha alpha alpha aarch64 aarch64 aarch64 aarch64 armv6hl armv6hl armv7hl armv7hl armv7hl armv7hl %ix86 %ix86 %ix86 %ix86 ia64 ia64 ia64 mips mips mips mips64 mips64 mips64 parisc parisc parisc ppc ppc ppc ppc64 ppc64 ppc64 ppc64 ppc64le ppc64le ppc64le ppc64le riscv64 riscv64 riscv64 s390 s390 s390 s390x s390x sparc sparc sparc sparc64 sparc64 sparc64 x86_64 x86_64 x86_64 x86_64
%else
ExclusiveArch:  do_not_build
%endif

%ifarch %ix86 x86_64
%define image vmlinuz
%endif
%ifarch ppc ppc64 ppc64le
%define image vmlinux
%endif
%ifarch s390 s390x
%define image image
%endif
%ifarch %arm
%define image zImage
%endif
%ifarch aarch64 riscv64
%define image Image
%endif

%ifarch %ix86 x86_64
%define install_vdso 1
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150500
%define separate_vdso 1
%endif
%else
%define install_vdso 0
%endif

%define build_default	("%build_flavor" == "default")
%define build_vanilla	("%build_flavor" == "vanilla")
%define vanilla_only    %{lua: if (rpm.expand("%variant") == "-vanilla") then print(1) else print(0) end}

%if ! %build_vanilla
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%else
%define src_install_dir /usr/src/linux-%kernelrelease-vanilla
%endif
%define obj_install_dir /usr/src/linux-%kernelrelease%variant-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %my_builddir/linux-%srcversion/linux-obj
%define modules_dir %kernel_module_directory/%kernelrelease-%build_flavor

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

%if 0%{?_project:1} && ( %(echo %_project | grep -Ex -f %_sourcedir/release-projects | grep -v ^PTF | grep -vc openSUSE) || %(echo %_project | grep -Ec "^(Devel:)?Kernel:") )
	%define klp_symbols 1
%endif

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_MODULE_SIG CONFIG_MODULE_SIG_HASH CONFIG_KMSG_IDS CONFIG_SUSE_KERNEL_SUPPORTED CONFIG_EFI_STUB CONFIG_LIVEPATCH_IPA_CLONES CONFIG_DEBUG_INFO_BTF_MODULES CONFIG_PREEMPT_DYNAMIC
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_extra ("%CONFIG_MODULES" == "y" && "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y")

%if "%CONFIG_MODULES" != "y"
	%define klp_symbols 0
%endif

%global certs %( space="" ; for f in %_sourcedir/*.crt; do                                              \
    if ! test -e "$f"; then                                                                             \
        continue                                                                                        \
    fi                                                                                                  \
    h=$(openssl x509 -inform PEM -fingerprint -noout -in "$f")                                          \
    if [ -z "$h" ] ; then                                                                               \
        echo Cannot parse "$f" >&2                                                                      \
        confinue                                                                                        \
    fi                                                                                                  \
    cert=$(echo "$h" | sed -rn 's/^SHA1 Fingerprint=//; T; s/://g; s/(.{8}).*/\\1/p')                   \
    echo Found signing certificate "$f" "($cert)" >&2                                                   \
    cat "$f" >>%_sourcedir/.kernel_signing_key.pem                                                      \
    mkdir -p %_sourcedir/.kernel_signing_certs                                                          \
    openssl x509 -inform PEM -in "$f" -outform DER -out %_sourcedir/.kernel_signing_certs/"$cert".crt   \
    echo -n "$space$cert" ; space=" "                                                                   \
done )

Source0:        linux-%srcversion.tar.xz
Source3:        kernel-source.rpmlintrc
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source19:       kernel-binary-conflicts
Source20:       obsolete-kmps
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source35:       group-source-files.pl
Source36:       README.PATCH-POLICY.SUSE
Source37:       README.SUSE
Source38:       README.KSYMS
Source40:       source-timestamp
Source46:       split-modules
Source47:       modversions
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source57:       kernel-cert-subpackage
Source58:       constraints.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-flavors
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source67:       log.sh
Source68:       host-memcpy-hack.h
Source69:       try-disable-staging-driver
Source70:       kernel-obs-build.spec.in
Source71:       kernel-obs-qa.spec.in
Source72:       compress-vmlinux.sh
Source73:       dtb.spec.in.in
Source74:       mkspec-dtb
Source75:       release-projects
Source76:       check-module-license
Source77:       klp-symbols
Source78:       modules.fips
Source79:       splitflist
Source80:       mergedep
Source81:       moddep
Source82:       modflist
Source83:       kernel-subpackage-build
Source84:       kernel-subpackage-spec
Source85:       kernel-default-base.spec.txt
Source86:       old_changelog.txt
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source113:      patches.kabi.tar.bz2
Source114:      patches.drm.tar.bz2
Source120:      kabi.tar.bz2
Source121:      sysctl.tar.bz2
# These files are found in the kernel-source package:
NoSource:       0
NoSource:       3
NoSource:       14
NoSource:       16
NoSource:       17
NoSource:       19
NoSource:       20
NoSource:       21
NoSource:       23
NoSource:       33
NoSource:       35
NoSource:       36
NoSource:       37
NoSource:       38
NoSource:       40
NoSource:       46
NoSource:       47
NoSource:       48
NoSource:       49
NoSource:       50
NoSource:       51
NoSource:       52
NoSource:       53
NoSource:       54
NoSource:       55
NoSource:       56
NoSource:       57
NoSource:       58
NoSource:       60
NoSource:       61
NoSource:       62
NoSource:       63
NoSource:       64
NoSource:       65
NoSource:       67
NoSource:       68
NoSource:       69
NoSource:       70
NoSource:       71
NoSource:       72
NoSource:       73
NoSource:       74
NoSource:       75
NoSource:       76
NoSource:       77
NoSource:       78
NoSource:       79
NoSource:       80
NoSource:       81
NoSource:       82
NoSource:       83
NoSource:       84
NoSource:       85
NoSource:       86
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       113
NoSource:       114
NoSource:       120
NoSource:       121

%ifarch %ix86
# Only i386/default supports i586, mark other flavors' packages as i686
%if ! %build_default
BuildArch:      i686
%endif
%endif
# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356 boo#1175882)
%define _binary_payload w9.bzdio
# Do not recompute the build-id of vmlinux in find-debuginfo.sh (bsc#964063)
%undefine _unique_build_ids
%define _no_recompute_build_ids 1
# prevent usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
%undefine _unique_debug_names

%if "%{compress_modules}" == "zstd"
BuildRequires:  zstd
# Make sure kmod supports zstd compressed modules
Requires(post): kmod-zstd
%endif
Provides:       %name = %version-%source_rel
# bnc#901925
Provides:       %name-%version-%source_rel
Provides:       %{name}_%_target_cpu = %version-%source_rel
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
# In SLE11, kernel-$flavor complemented kernel-$flavor-base. With SLE12,
# kernel-$flavor itself contains all the needed files and kernel-$flavor-base
# is a subset that can replace kernel-$flavor in some scenarios. We need to
# obsolete the -base subpackage from SLE11, so that the base files are not
# owned by multiple packages now. The dependency is not correct wrt openSUSE
# 11.2 - 11.4, but we primarily care about the supported upgrade path.
Obsoletes:      %name-base < 3.1
%if ("%build_flavor" != "kvmsmall") && ("%build_flavor" != "azure")
Recommends: kernel-firmware
%endif
# The following is copied to the -base subpackage as well
# BEGIN COMMON DEPS
Requires(pre):  suse-kernel-rpm-scriptlets
Requires(post): suse-kernel-rpm-scriptlets
Requires:       suse-kernel-rpm-scriptlets
Requires(preun): suse-kernel-rpm-scriptlets
Requires(postun): suse-kernel-rpm-scriptlets
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2 and /usr/lib/modprobe.d/*.conf
Requires(post): suse-module-tools
Requires:       suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for dracut.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
Requires(post): dracut
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release

%if %{usrmerged}
# make sure we have a post-usrmerge system
Conflicts:      filesystem < 16
%endif

Obsoletes:      microcode_ctl < 1.18

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/kernel-binary-conflicts')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Conflicts: ' .. package .. ' < '.. version .. '\n')
		end
	end
	fd:close()
}

%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-%git_commit
Provides:       kernel-srchash-%git_commit
# END COMMON DEPS
Provides:       %name-srchash-%git_commit
%obsolete_rebuilds %name

%define kmp_target_cpu %_target_cpu
%ifarch %ix86
# KMPs are always built as i586, because rpm does not allow to build
# subpackages for different architectures. Therefore, we change the
# /usr/src/linux-obj/<arch> symlink to i586.
%define kmp_target_cpu i586
%endif

%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt = %version-%release
Provides:       kernel-preempt_%_target_cpu = %version-%source_rel
%endif
%endif

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/obsolete-kmps')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Obsoletes: ' .. package .. '-kmp-' .. rpm.expand('%build_flavor') .. ' <= '.. version .. '\n')
			print('Provides: ' .. package .. '-kmp = ' .. version .. '.1\n')
			print('Provides: ' .. package .. '-kmp-' .. rpm.expand('%build_flavor') .. ' = '.. version .. '.1\n')
		end
	end
	fd:close()
}

%description
The standard kernel - without any SUSE patches


%source_timestamp

%pre
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-pre --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%post
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-post --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%preun
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-preun --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%postun
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-postun --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%posttrans
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-posttrans --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%files -f kernel-main.files

%if "%CONFIG_MODULES" == "y" && %split_base
%package base
Summary:        The Standard Kernel - without any SUSE patches - base modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
Conflicts:      %name = %version-%source_rel
Requires(pre):  suse-kernel-rpm-scriptlets
Requires(post): suse-kernel-rpm-scriptlets
Requires:       suse-kernel-rpm-scriptlets
Requires(preun): suse-kernel-rpm-scriptlets
Requires(postun): suse-kernel-rpm-scriptlets
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2 and /usr/lib/modprobe.d/*.conf
Requires(post): suse-module-tools
Requires:       suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for dracut.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
Requires(post): dracut
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release

%if %{usrmerged}
# make sure we have a post-usrmerge system
Conflicts:      filesystem < 16
%endif

Obsoletes:      microcode_ctl < 1.18

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/kernel-binary-conflicts')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Conflicts: ' .. package .. ' < '.. version .. '\n')
		end
	end
	fd:close()
}

%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-%git_commit
Provides:       kernel-srchash-%git_commit

%obsolete_rebuilds %name-base
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description base
The standard kernel - without any SUSE patches

This package contains only the base modules, required in all installs.


%source_timestamp
%pre base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-pre --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-post --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-preun --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-postun --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-posttrans --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files base -f kernel-base.files
%endif

%package extra
Summary:        The Standard Kernel - without any SUSE patches - Unsupported kernel modules
Group:          System/Kernel
URL:            https://www.kernel.org/
Provides:       %name-extra_%_target_cpu = %version-%source_rel
Provides:       kernel-extra = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %{name}_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): dracut
%obsolete_rebuilds %name-extra
Supplements:    packageand(product(SLED):%{name}_%_target_cpu)
Supplements:    packageand(product(sle-we):%{name}_%_target_cpu)
Supplements:    packageand(product(Leap):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-extra = %version-%release
Provides:       kernel-preempt-extra_%_target_cpu = %version-%source_rel
%endif
%endif

%description extra
The standard kernel - without any SUSE patches

This package contains additional modules not supported by SUSE.


%source_timestamp

%pre extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%if %split_extra

%files extra -f kernel-extra.files
%endif

%if %split_extra && %split_optional
%package optional
Summary:        The Standard Kernel - without any SUSE patches - Optional kernel modules
Group:          System/Kernel
URL:            https://www.kernel.org/
Provides:       %name-optional_%_target_cpu = %version-%source_rel
Provides:       kernel-optional = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %name-extra_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): dracut
%obsolete_rebuilds %name-optional
Supplements:    packageand(product(Leap):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-optional = %version-%release
Provides:       kernel-preempt-optional_%_target_cpu = %version-%source_rel
%endif
%endif

%description optional
The standard kernel - without any SUSE patches

This package contains optional modules only for openSUSE Leap.


%source_timestamp

%pre optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files optional -f kernel-optional.files
%endif

%if "%CONFIG_KMSG_IDS" == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
/usr/share/man/man9/*
%endif

%if 0%{?separate_vdso}
%package vdso
Summary:        vdso binaries for debugging purposes
Group:          System/Kernel

%description vdso
This package includes the vdso binaries. They can be used for debugging. The
actual binary linked to the programs is loaded from the in-memory image, not
from this package.


%source_timestamp
%files vdso
%modules_dir/vdso/
%endif

%package devel
Summary:        Development files necessary for building kernel modules
Group:          Development/Sources
Provides:       %name-devel = %version-%source_rel
Provides:       multiversion(kernel)
%if ! %build_vanilla && ! %vanilla_only
Requires:       kernel-devel%variant = %version-%source_rel
Recommends:     make
Recommends:     gcc
Recommends:     perl
# for objtool
Requires:	libelf-devel
Supplements:    packageand(%name:kernel-devel%variant)
%else
Requires:       kernel-source-vanilla = %version-%source_rel
Supplements:    packageand(%name:kernel-source-vanilla)
%endif
%if "%CONFIG_DEBUG_INFO_BTF_MODULES" == "y"
Requires:       dwarves >= 1.22
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-devel = %version-%release
%endif
%endif
%obsolete_rebuilds %name-devel
PreReq:         coreutils

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp

%if "%CONFIG_MODULES" == "y"

%pre devel

# handle update from an older kernel-source with linux-obj as symlink
if [ -h /usr/src/linux-obj ]; then
    rm -vf /usr/src/linux-obj
fi

%post devel
%relink_function

relink ../../linux-%{kernelrelease}%{variant}-obj/"%cpu_arch_flavor" /usr/src/linux-obj/"%cpu_arch_flavor"

%files devel -f kernel-devel.files
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%exclude %obj_install_dir/%cpu_arch_flavor/Symbols.list
%if "%kmp_target_cpu" != "%cpu_arch"
%obj_install_dir/%kmp_target_cpu
/usr/src/linux-obj/%kmp_target_cpu
%endif

%if "%livepatch" != "" && "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y" && (("%variant" == "" && %build_default) || ("%variant" == "-rt" && 0%livepatch_rt))
%if "%livepatch" == "kgraft"
%define patch_package %{livepatch}-patch
%else
%define patch_package kernel-%{livepatch}
%endif
%package %{livepatch}
Summary:        Metapackage to pull in matching %patch_package package
Group:          System/Kernel
Requires:       %{patch_package}-%(echo %{version}-%{source_rel} | sed 'y/\./_/')-%{build_flavor}
Provides:       multiversion(kernel)
%if "%variant" != "-rt"
Provides:	kernel-default-kgraft = %version
Provides:	kernel-xen-kgraft = %version
%if "%livepatch" != "kgraft"
Obsoletes:	kernel-default-kgraft < %version
Obsoletes:	kernel-xen-kgraft < %version
%endif
%endif

%description %{livepatch}
This is a metapackage that pulls in the matching %patch_package package for a
given kernel version. The advantage of the metapackage is that its name is
static, unlike the %{patch_package}-<kernel-version>-flavor package names.

%files %{livepatch}
# rpmlint complains about empty packages, so lets own something
%dir %modules_dir
%endif

%if 0%{?klp_symbols} && "%livepatch" != ""
%package %{livepatch}-devel
Summary:	Kernel symbols file used during kGraft patch development
Group:		System/Kernel
Provides:	klp-symbols = %version

%description %{livepatch}-devel
This package brings a file named Symbols.list, which contains a list of all
kernel symbols and its respective kernel object . This list is to be used by
the klp-convert tool, which helps livepatch developers by enabling automatic
symbol resolution.

%files %{livepatch}-devel -f livepatch-files
%endif

%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
%endif # %CONFIG_SUSE_KERNEL_SUPPORTED
%endif # %CONFIG_MODULES

%prep
if ! [ -e %{S:0} ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 108 -a 109 -a 110 -a 111 -a 113 -a 114 -a 120 -a 121

mkdir -p %kernel_build_dir

# Generate a list of modules with their support status marking
# The first marker is supposed to be either "+external", "-" or "-!optional",
# where "+external" is for an externally supported module, "-" is for an
# unsuppored module, "-!optional" is for Leap-only unsupported module.
# There can be an optional arch-specific second marker with "+arch" (e.g.
# +arm64), which enforces the module to be supported on the specific arch.
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '{
    t = "";
    for (i = 1; i < NF; i++) {
	if ($i == "+external") {
		t = " external";
	} else if ($i == "+'%cpu_arch'") {
		t = "";
	} else if ($i ~ "^-") {
		t = " no";
	}
    }
    print $(NF) t;
}' >%kernel_build_dir/Module.supported
subpackages=(
	base
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	
%endif
)
for package in "${subpackages[@]}"; do
	%_sourcedir/guards --default=0 "$package" \
		<%_sourcedir/supported.conf | sed 's,.*/,,; s,\.ko$,,' | \
		sort -u >%kernel_build_dir/Module."$package"
done
%if %split_extra && %split_optional
# Module.optional is in a special form, containing guard markers for
# both extra and optional modules, which is processed by split-modules
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '{
    t = "";
    for (i = 1; i < NF; i++) {
	if ($i == "+'%cpu_arch'") {
		t = "";
	} else if ($i ~ "^-") {
		t = $i
	}
    }
    if (t != "") {print t,$(NF);}
}' >%kernel_build_dir/Module.optional
%endif

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla} && ! %vanilla_only
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

cd %kernel_build_dir

# Override the timestamp 'uname -v' reports with the source timestamp and
# the commit hash.
date=$(head -n 1 %_sourcedir/source-timestamp)
commit=$(sed -n 's/GIT Revision: //p' %_sourcedir/source-timestamp)
cat > .kernel-binary.spec.buildenv <<EOF
export KBUILD_BUILD_TIMESTAMP="$(LANG=C date -d "$date") (${commit:0:7})"
export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_BUILD_USER=geeko
export KBUILD_BUILD_HOST=buildhost
export HOST_EXTRACFLAGS="-include %_sourcedir/host-memcpy-hack.h"
EOF
source .kernel-binary.spec.buildenv

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

config_base="default"
%ifarch %ix86
config_base="pae"
%endif
if ! [ -f %my_builddir/config/%cpu_arch/$config_base ] ; then
    config_base=%variant
    config_base=${config_base#-}
fi
if ! grep -q CONFIG_MMU= "%my_builddir/config/%cpu_arch_flavor"; then
cp "%my_builddir/config/%cpu_arch/$config_base" .config
../scripts/kconfig/merge_config.sh -m .config \
                                   %my_builddir/config/%cpu_arch_flavor
else
cp %my_builddir/config/%cpu_arch_flavor .config
fi
if test -e %my_builddir/config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	../scripts/kconfig/merge_config.sh -m .config %my_builddir/config.addon/%cpu_arch_flavor
fi

CONFIG_SUSE_KERNEL_RELEASED="--disable CONFIG_SUSE_KERNEL_RELEASED"
%if 0%{?_project:1}
if echo %_project | grep -Eqx -f %_sourcedir/release-projects; then
	CONFIG_SUSE_KERNEL_RELEASED="--enable CONFIG_SUSE_KERNEL_RELEASED"
fi
%endif

DEBUG_INFO_TYPE="$(grep "CONFIG_DEBUG_INFO_DWARF.*=y" .config)"
DEBUG_INFO_TYPE="${DEBUG_INFO_TYPE%%=y}"
DEBUG_INFO_TYPE="${DEBUG_INFO_TYPE##CONFIG_DEBUG_INFO_}"
echo "Kernel debuginfo type: ${DEBUG_INFO_TYPE}"

../scripts/config \
	--set-str CONFIG_LOCALVERSION -%source_rel-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
	$CONFIG_SUSE_KERNEL_RELEASED \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO
%else
	--disable CONFIG_DEBUG_INFO \
	--disable CONFIG_DEBUG_INFO_"${DEBUG_INFO_TYPE}" \
	--enable  CONFIG_DEBUG_INFO_NONE
%endif

if [ %CONFIG_MODULE_SIG = "y" ]; then
	if [ -n "%certs" ] ; then
		ln -s %_sourcedir/.kernel_signing_key.pem .
	else
		if ! [ -f .kernel.genkey ] ; then
			cat > .kernel.genkey <<EOF
[ req ]
default_bits = 4096
distinguished_name = req_distinguished_name
prompt = no
string_mask = utf8only
x509_extensions = myexts

[ req_distinguished_name ]
CN = Build time autogenerated kernel key

[ myexts ]
basicConstraints=critical,CA:FALSE
keyUsage=digitalSignature
subjectKeyIdentifier=hash
authorityKeyIdentifier=keyid
extendedKeyUsage=codeSigning
EOF
		fi
		openssl req -new -nodes -utf8 -%CONFIG_MODULE_SIG_HASH -days 36500 \
			-batch -x509 -config .kernel.genkey \
			-outform PEM -out .kernel_signing_key.pem \
			-keyout .kernel_signing_key.pem
	fi
	../scripts/config --set-str CONFIG_MODULE_SIG_KEY ".kernel_signing_key.pem"
fi

case %cpu_arch in
    x86_64 | i386)
        MAKE_ARGS="$MAKE_ARGS ARCH=x86"
        ;;
    ppc*)
        MAKE_ARGS="$MAKE_ARGS ARCH=powerpc"
        ;;
    s390x)
        MAKE_ARGS="$MAKE_ARGS ARCH=s390"
        ;;
    arm64)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm64"
        ;;
    armv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm"
        ;;
    riscv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=riscv"
        ;;
    *)
        MAKE_ARGS="$MAKE_ARGS ARCH=%cpu_arch"
        ;;
esac

makeoutputsync=
if make --output-sync --help >/dev/null 2>&1 ; then
        makeoutputsync=--output-sync
else
        echo make does not support --output-sync flag. Build messages may be mangled. 1>&2
fi
MAKE_ARGS="$MAKE_ARGS $makeoutputsync %{?_smp_mflags}"
echo export MAKE_ARGS=\""$MAKE_ARGS"\" >> .kernel-binary.spec.buildenv

KERN_DIRS="-C .. O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS $KERN_DIRS
else
    cp .config .config.orig
    if test -f ../scripts/kconfig/Makefile && \
       grep -q syncconfig ../scripts/kconfig/Makefile; then
        syncconfig="syncconfig"
    else
        syncconfig="silentoldconfig"
    fi
    make $syncconfig $MAKE_ARGS $KERN_DIRS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d ! -name 'Module.base' ! -name 'Module.*-kmp' ! -name 'Module.optional' -printf '%%P\n' \
	> %my_builddir/obj-files

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

%if "%CONFIG_KMSG_IDS" == "y"
    chmod +x ../scripts/kmsg-doc
    MAKE_ARGS="$MAKE_ARGS D=2"
%endif

mkdir -p %_topdir/OTHER
log=%_topdir/OTHER/make-stderr.log
while true; do
    make all $MAKE_ARGS 2> >(tee "$log")
    if test "${PIPESTATUS[0]}" -eq 0; then
        break
    fi
    # In the linux-next and vanilla branches, we try harder to build a
    # package.
    if test 0%vanilla_only -gt 0 &&
			%_sourcedir/try-disable-staging-driver "$log"; then
        echo "Retrying make"
    else
        exit 1
    fi
done

# Generate list of symbols that are used to create kernel livepatches
%if 0%{?klp_symbols}
	%_sourcedir/klp-symbols . Symbols.list
%endif

%install

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux*'

# %kernel_module_directory/%kernelrelease-%build_flavor/source points to the source
# directory installed by kernel-devel. The kernel-%build_flavor-devel package
# has a correct dependency on kernel-devel, but the brp check does not see
# kernel-devel during build.
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir
source .kernel-binary.spec.buildenv

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor

    cp vmlinux %buildroot/$vmlinux
    # make sure that find-debuginfo.sh picks it up. In the filelist, we
    # mark the file 0644 again
    chmod +x %buildroot/$vmlinux
    if test $1 == "--compressed"; then
        # avoid using the gzip -n option to make kdump happy (bnc#880848#c20)
        ts="$(head -n1 %_sourcedir/source-timestamp)"
        touch -d "$ts" %buildroot/$vmlinux
        touch %buildroot/$vmlinux.%{compress_vmlinux}
%if 0%{?__debug_package:1}
        # compress the vmlinux image after find-debuginfo.sh has processed it
%global __debug_install_post %__debug_install_post \
%_sourcedir/compress-vmlinux.sh %buildroot/boot/vmlinux-%kernelrelease-%build_flavor
%else
        %_sourcedir/compress-vmlinux.sh %buildroot/$vmlinux
%endif
        ghost_vmlinux=true
    else
        ghost_vmlinux=false
    fi
}

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
    cp -p arch/x86/boot/bzImage %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch ppc ppc64 ppc64le
    add_vmlinux
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    image=image
    if test ! -f arch/s390/boot/$image; then
        image=bzImage
    fi
    cp -p arch/s390/boot/$image %buildroot/boot/%image-%kernelrelease-%build_flavor
%if "%CONFIG_KMSG_IDS" == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
    s390x_vmlinux=arch/s390/boot/compressed/vmlinux
    if [ ! -f "$s390x_vmlinux" ]; then
        s390x_vmlinux=arch/s390/boot/vmlinux
    fi
    objcopy -R .rodata.compressed "$s390x_vmlinux" %buildroot/boot/zdebug-%kernelrelease-%build_flavor
%endif
%endif
%ifarch %arm
    add_vmlinux --compressed
    cp -p arch/arm/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch aarch64
    add_vmlinux --compressed
    cp -p arch/arm64/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch riscv64
    add_vmlinux --compressed
    cp -p arch/riscv/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif

# sign the modules, firmware and possibly the kernel in the buildservice
BRP_PESIGN_FILES=""
%if "%CONFIG_EFI_STUB" == "y"
%if %{usrmerged}
BRP_PESIGN_FILES="%modules_dir/%image"
%else
BRP_PESIGN_FILES="/boot/%image-%kernelrelease-%build_flavor"
%endif
%endif
%if ! %sb_efi_only
%ifarch s390x ppc64 ppc64le
%if %{usrmerged}
BRP_PESIGN_FILES="%modules_dir/%image"
%else
BRP_PESIGN_FILES="/boot/%image-%kernelrelease-%build_flavor"
%endif
%endif
%endif
%if "%CONFIG_MODULE_SIG" == "y"
BRP_PESIGN_FILES="$BRP_PESIGN_FILES *.ko"
%endif
%ifarch %ix86
# XXX: do not sign on x86, as the repackaging changes kernel-pae
# from i686 to i586
BRP_PESIGN_FILES=""
%endif
export BRP_PESIGN_FILES
%if "%{compress_modules}" != "none"
export BRP_PESIGN_COMPRESS_MODULE=%{compress_modules}
%endif
# Do not sign vanilla kernels released in official projects
%if %build_vanilla && ! %vanilla_only
BRP_PESIGN_FILES=""
%endif

if test -x /usr/lib/rpm/pesign/gen-hmac; then
	$_ -r %buildroot /boot/%image-%kernelrelease-%build_flavor
fi

# Package the compiled-in certificates as DER files in /etc/uefi/certs
# and have mokutil enroll them when the kernel is installed
echo Signing certificates "%certs"
if test %CONFIG_MODULE_SIG = "y" -a -d %_sourcedir/.kernel_signing_certs ; then
    for f in %_sourcedir/.kernel_signing_certs/*.crt; do
            mkdir -p %buildroot/etc/uefi/certs
            cp -v $f %buildroot/etc/uefi/certs
    done
fi

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor
sysctl_file=%buildroot/boot/sysctl.conf-%kernelrelease-%build_flavor
for file in %my_builddir/sysctl/{defaults,%cpu_arch/arch-defaults,%cpu_arch_flavor}; do
	if [ -f "$file" ]; then
		cat "$file"
	fi
done | sed '1i # Generated file - do not edit.' >$sysctl_file
if [ ! -s $sysctl_file ]; then
	rm $sysctl_file
fi

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
rm -rf %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/vdso/.build-id
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1
# Also reserve some space for the kdump initrd
cp %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%if 0%{?suse_version} >= 1500
# Use same permissions as dracut
chmod 0600 %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%endif

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    install -m 755 -D -t %rpm_install_dir/%cpu_arch_flavor/scripts/mod/ scripts/mod/ksym-provides

    gzip -n -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

%ifarch s390 s390x
    expoline=arch/s390/lib/expoline/expoline.o
    if test -f arch/s390/lib/expoline/expoline.o ; then
	install -m 644 -D -t %rpm_install_dir/%cpu_arch_flavor/$(dirname $expoline) $expoline
    fi
%endif

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-devel + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # List of symbols that are used to generate kernel livepatches
    %if 0%{?klp_symbols}
        cp Symbols.list %rpm_install_dir/%cpu_arch/%build_flavor
        echo %obj_install_dir/%cpu_arch/%build_flavor/Symbols.list > %my_builddir/livepatch-files.no_dir

        %if "%CONFIG_LIVEPATCH_IPA_CLONES" == "y"
            find %kernel_build_dir -name "*.ipa-clones" ! -size 0 | sed -e 's|^%kernel_build_dir/||' | sort > ipa-clones.list
            cp ipa-clones.list %rpm_install_dir/%cpu_arch/%build_flavor
            echo %obj_install_dir/%cpu_arch/%build_flavor/ipa-clones.list >> %my_builddir/livepatch-files.no_dir
            tar -C %kernel_build_dir \
%if ! 0%{?suse_version} || 0%{?suse_version} >= 1500
		    --verbatim-files-from \
%endif
		    -T ipa-clones.list -cf- | tar -C %rpm_install_dir/%cpu_arch/%build_flavor -xvf-
            cat ipa-clones.list | sed -e 's|^|%obj_install_dir/%cpu_arch/%build_flavor/|' >> %my_builddir/livepatch-files.no_dir
        %endif
    %endif

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -n -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%kmp_target_cpu ]; then
        ln -sf %cpu_arch %rpm_install_dir/%kmp_target_cpu
        ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%kmp_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir \
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	-e \
%endif
%if ! %supported_modules_check
	-i \
%endif
	%nil
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

    # The modules.dep file is sorted randomly which produces strange file
    # checksums. As the file is not included in the resulting RPM, it's
    # pointless to rely on its contents. Replacing by zeros to make the
    # checksums always the same for several builds of the same package.
    test -s %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep && \
    dd if=/dev/zero of=%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep ibs=$(stat -c%s %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep) count=1

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers || res=$?
    fi
    if [ $res -ne 0 ]; then
	# %ignore_kabi_badness is defined in the Kernel:* projects in the
	# OBS to be able to build the KOTD in spite of kabi errors
	if [ 0%{?ignore_kabi_badness} -eq 0 -a \
	     ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    # Check the license in each module
    if ! sh %_sourcedir/check-module-license %buildroot; then
	echo "Please fix the missing licenses!"
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	exit 1
%endif
    fi

    # These files are required for building external modules
    for FILE in arch/powerpc/lib/crtsavres.o arch/arm64/kernel/ftrace-mod.o \
		arch/*/kernel/macros.s scripts/module.lds
    do
	    if [ -f %kernel_build_dir/$FILE ]; then
		echo $FILE >> %my_builddir/obj-files
	    fi
    done

    tar --exclude=\*.ipa-clones --exclude=.config.old --exclude=.kernel-binary.spec.buildenv \
        --exclude=.kernel_signing_key.pem --exclude=.kernel.genkey \
        -cf - -T %my_builddir/obj-files | \
	tar -xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done

    # Recreate the generated Makefile with correct path
    #
    # Linux 5.13 no longer has mkmakefile
    if [ -f ../scripts/mkmakefile ] ; then
        sh ../scripts/mkmakefile ../../../%{basename:%src_install_dir} \
            %rpm_install_dir/%cpu_arch_flavor \
            $(echo %srcversion | sed -r 's/^([0-9]+)\.([0-9]+).*/\1 \2/')
    else
       echo include ../../../%{basename:%src_install_dir}/Makefile > %rpm_install_dir/%cpu_arch_flavor/Makefile
    fi
fi

# CONFIG_GDB_SCRIPTS
if [ -e vmlinux-gdb.py ]; then
    DEST=%rpm_install_dir/%cpu_arch_flavor/
    install -m 755 -d "$DEST"
    # set sys.path to our devel.rpm scripts
    sed 's@\(sys\.path\.insert(0, \).*@\1"%obj_install_dir/%cpu_arch_flavor/scripts/gdb/")@' vmlinux-gdb.py > "$DEST/vmlinux-gdb.py"

    DEST=%rpm_install_dir/%cpu_arch_flavor/scripts/gdb/linux
    install -m 755 -d "$DEST"
    pushd scripts/gdb/linux/
    for file in *.py; do
	if test -L "$file"; then
	    # relink against our devel.rpm sources, not of buildroot's
	    ln -s "%src_install_dir/scripts/gdb/linux/$file" "$DEST/$file"
	else
	    cp -p "$file" "$DEST"
	fi
    done
    popd

    DEST=%{buildroot}%{_datadir}/gdb/auto-load%modules_dir
    install -m 755 -d "$DEST"
    ln -s %obj_install_dir/%cpu_arch_flavor/vmlinux-gdb.py "$DEST/vmlinux-gdb.py"
fi

rm -rf %{buildroot}/lib/firmware

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|(/usr)?/lib/(modules|firmware)|/usr/share|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
if [ -f %my_builddir/livepatch-files.no_dir ] ; then
    cat %my_builddir/livepatch-files.no_dir | add_dirs_to_filelist > %my_builddir/livepatch-files
fi

# does not exist for non-modularized kernels
%if %{usrmerged}
        mkdir -p %{buildroot}%modules_dir
%endif
shopt -s nullglob dotglob
> %my_builddir/kernel-devel.files
{
    echo "%modules_dir/build"
    echo "%modules_dir/source"
    cd %buildroot
    for file in boot/symtypes*; do
%if %{usrmerged}
        l="${file##*/}"
        l="%modules_dir/${l//-%kernelrelease-%build_flavor}"
        mv "$file" "%{buildroot}$l"
        ln -s "..$l" $file
        echo "$l"
        echo "%%ghost /$file"
%else
        echo "/$file"
%endif
    done
    if test -d .%{_datadir}/gdb/; then
	find .%obj_install_dir/%cpu_arch_flavor/scripts/gdb/linux/ -name '*.py' -type l | sed -e 's/^[.]//'
	echo "%{_datadir}/gdb/auto-load%modules_dir/vmlinux-gdb.py"
    fi
} | add_dirs_to_filelist >%my_builddir/kernel-devel.files
( cd %buildroot ; find .%obj_install_dir/%cpu_arch_flavor -type f ; ) | \
sed -e 's/^[.]//' | grep -v -e '[.]ipa-clones$' -e '/Symbols[.]list$' -e '/ipa-clones[.]list$'| \
add_dirs_to_filelist >> %my_builddir/kernel-devel.files

{   echo %ghost /boot/%image
    echo %ghost /boot/initrd
    cd %buildroot
    for f in boot/*; do
        l="${f##*/}"
        l="%modules_dir/${l//-%kernelrelease-%build_flavor}"
        if test -L "$f"; then
            echo "%%ghost /$f"
            continue
        elif test ! -f "$f"; then
            continue
        fi
        case "$f" in
        boot/initrd-*)
            echo "%%ghost /$f"
            continue
            ;;
        boot/vmlinux-*.%{compress_vmlinux})
            ;;
        boot/vmlinux-*)
            if $ghost_vmlinux; then
                # fall through to mark next echo as %ghost
                echo -n "%%ghost "
            fi
            ;;
%if %{usrmerged}
        boot/vmlinuz-*)
            echo -n "%%attr(0644, root, root) "
            ;;
%endif
        boot/symtypes*)
%if %{usrmerged}
            echo "%exclude $l"
%endif
            continue
            ;;
        esac
%if %{usrmerged}
        mv "$f" "./$l"
        ln -s "..$l" $f
        # the find in the CONFIG_MODULES condition below also finds the files
        # but there's sort -u later, so this is ok
        echo "$l" # note: must be first after case statement above
        echo "%%ghost /$f"
%else
        echo "%%attr(0644, root, root) /$f"
%endif
    done

    if [ %CONFIG_MODULES = y ]; then
	MODULES=%{lua: print(rpm.expand('%kernel_module_directory'):sub(2))}/%kernelrelease-%build_flavor
	find "$MODULES" \
%if 0%{?separate_vdso}
	    -path "$MODULES/vdso" -prune -o \
%endif
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \
	     ! -path '*/modules.builtin.modinfo' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune \
	       -o \( -type f \
%if %{usrmerged}
		! -path '*/symtypes*' ! -path '*/vmlinu*' \
%endif
		\) -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    if test %CONFIG_MODULE_SIG = "y" -a -d etc/uefi/certs; then
        find etc/uefi/certs -type f -printf '/%%p\n'
    fi
    if test -d lib/firmware/%kernelrelease-%build_flavor; then
        echo "%%dir /lib/firmware/%kernelrelease-%build_flavor"
        cat %my_builddir/base-firmware
    fi
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u | add_dirs_to_filelist >%my_builddir/kernel-base.files

{
    add_dirs_to_filelist %my_builddir/kernel-base.files
    if [ %CONFIG_MODULES = y ]; then
        add_dirs_to_filelist %my_builddir/main-modules
    fi
    if test -d %buildroot/lib/firmware/%kernelrelease-%build_flavor; then
	echo "/lib/firmware/%kernelrelease-%build_flavor"
    fi
} > %my_builddir/kernel-main.files

%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files
%if %split_extra && %split_optional
    add_dirs_to_filelist %my_builddir/optional-modules > %my_builddir/kernel-optional.files
%endif

%if 0%{?sle_version} >= 150000
    # By default, loading unsupported modules is disabled on SLE through
    # /etc/modprobe.d/10-unsupported-modules.conf from the suse-module-tools
    # package.
    # modules in kernel-$flavor-extra don't have the supported flag set,
    # yet loading them should be possible if the package is installed.
    # CAUTION PACKAGERS: The file content below must not change between
    # kernel versions, otherwise file conflicts might arise with
    # multiversion(kernel).

    modprobe_d_dir=/etc/modprobe.d
    %if 0%{?sle_version} > 150300
    modprobe_d_dir=/lib/modprobe.d
    %endif
    %if %{usrmerged}
    modprobe_d_dir=/usr/lib/modprobe.d
    %endif

    mkdir -p %buildroot$modprobe_d_dir
    cat >%buildroot$modprobe_d_dir/20-kernel-%{build_flavor}-extra.conf <<EOF
# This file overrides the default from 10-unsupported-modules.conf.
# This is necessary to load kernel modules from the
# kernel-%{build_flavor}-extra package.
#
# WARNING: loading unsupported modules may compromise SLE support.
# Please read the comments in 10-unsupported-modules.conf.
allow_unsupported_modules 1
EOF
    echo "%%dir $modprobe_d_dir" >> %my_builddir/kernel-extra.files
    echo "%%config(noreplace) $modprobe_d_dir/20-kernel-%{build_flavor}-extra.conf" >> %my_builddir/kernel-extra.files
%endif
%endif
for f in %my_builddir/*-kmp-modules; do
	f2=${f%%-modules}.files
	add_dirs_to_filelist "$f" >"$f2"
done

if [ %CONFIG_MODULES = y ]; then
  install -m 644 %_sourcedir/modules.fips %{buildroot}%modules_dir/modules.fips
  echo %modules_dir/modules.fips >> %my_builddir/kernel-base.files
  echo %modules_dir/modules.fips >> %my_builddir/kernel-main.files
fi

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes %buildroot%modules_dir

%changelog
* Fri May 10 2024 kbuild@suse.de
- Automatically updated to 6.9-rc7-next-20240510
- commit 7a0beef
* Thu May  9 2024 kbuild@suse.de
- Automatically updated to 6.9-rc7-next-20240509
- commit 87dd744
* Wed May  8 2024 kbuild@suse.de
- Automatically updated to 6.9-rc7-next-20240508
- commit 61df743
* Tue May  7 2024 kbuild@suse.de
- Automatically updated to 6.9-rc7-next-20240507
- commit ea106ee
* Mon May  6 2024 kbuild@suse.de
- Automatically updated to 6.9-rc7-next-20240506
- commit 072fe09
* Sun May  5 2024 mkubecek@suse.cz
- update to 6.9-rc7
- update configs
  - DRM_PANEL_ILITEK_ILI9341=n (x86_64)
- commit 8586ec6
* Fri May  3 2024 kbuild@suse.de
- Automatically updated to 6.9-rc6-next-20240503
- commit 7a821bd
* Thu May  2 2024 kbuild@suse.de
- Automatically updated to 6.9-rc6-next-20240502
- commit 00b7617
* Tue Apr 30 2024 kbuild@suse.de
- Automatically updated to 6.9-rc6-next-20240430
- commit e36f493
* Mon Apr 29 2024 kbuild@suse.de
- Automatically updated to 6.9-rc6-next-20240429
- commit a89a14b
* Sun Apr 28 2024 mkubecek@suse.cz
- update to 6.9-rc6
- update configs
  - CPU_MITIGATIONS=y (x86)
  - NTFS_FS=m (except s390x/zfcpdump)
  - ERRATA_THEAD_MAE=y (riscv64)
- commit fb7fd8b
* Fri Apr 26 2024 kbuild@suse.de
- Automatically updated to 6.9-rc5-next-20240426
- commit 18e836b
* Thu Apr 25 2024 kbuild@suse.de
- Automatically updated to 6.9-rc5-next-20240424
- commit 14b4be8
* Tue Apr 23 2024 kbuild@suse.de
- Automatically updated to 6.9-rc5-next-20240423
- commit e179b62
* Mon Apr 22 2024 kbuild@suse.de
- Automatically updated to 6.9-rc5-next-20240422
- commit 45549ab
* Fri Apr 19 2024 jslaby@suse.cz
- Update config files. Disable N_GSM (bsc#1223134).
- commit 8eb8a7d
* Fri Apr 19 2024 kbuild@suse.de
- Automatically updated to 6.9-rc4-next-20240419
- commit e3ca7f8
* Thu Apr 18 2024 kbuild@suse.de
- Automatically updated to 6.9-rc4-next-20240418
- commit da5acc1
* Wed Apr 17 2024 kbuild@suse.de
- Automatically updated to 6.9-rc4-next-20240417
- commit 087b30a
* Wed Apr 17 2024 macpaul.lin@mediatek.com
- Update config files: re-enable arm64 regulator modules for MediaTek boards (bsc#1222818).
  This re-enable some regulator modules, pinctrl and RTC drivers for
  MediaTek boards which has been disabled when merging config file from
  master to stable (kernel 6.5.9->6.6) branch.
  This re-applies commit b197b3604a7b (Update config files: enable arm64
  regulator modules for MediaTek boards.)
  [js] set also KEYBOARD_MTK_PMIC=m, POWER_RESET_MT6323=n, LEDS_MT6323=n,
    and MFD_MT6397=m -- the same as commit b197b3604a7b.
- commit 43e68cf
* Tue Apr 16 2024 kbuild@suse.de
- Automatically updated to 6.9-rc4-next-20240416
- commit b879d9c
* Mon Apr 15 2024 kbuild@suse.de
- Automatically updated to 6.9-rc4-next-20240415
- commit f972cdb
* Mon Apr 15 2024 duwe@suse.de
- Update arm* configs to 6.9-rc4. Mostly new SoC and component support enabled as modules.
- Re-enable arm in config.conf
- commit 45425cd
* Sun Apr 14 2024 mkubecek@suse.cz
- update to 6.9-rc4
- update configs
  - MITIGATION_SPECTRE_BHI=y (x86 only)
- commit d8d7202
* Fri Apr 12 2024 kbuild@suse.de
- Automatically updated to 6.9-rc3-next-20240412
- commit 72763b8
* Thu Apr 11 2024 kbuild@suse.de
- Automatically updated to 6.9-rc3-next-20240411
- commit 963d418
* Wed Apr 10 2024 kbuild@suse.de
- Automatically updated to 6.9-rc3-next-20240410
- commit daaf4aa
* Tue Apr  9 2024 kbuild@suse.de
- Automatically updated to 6.9-rc3-next-20240409
- commit 24cf628
* Mon Apr  8 2024 kbuild@suse.de
- Automatically updated to 6.9-rc3-next-20240408
- commit 83edeef
* Fri Apr  5 2024 kbuild@suse.de
- Automatically updated to 6.9-rc2-next-20240405
- commit 8fb3754
* Thu Apr  4 2024 kbuild@suse.de
- Automatically updated to 6.9-rc2-next-20240404
- commit 7e2839b
* Wed Apr  3 2024 kbuild@suse.de
- Automatically updated to 6.9-rc2-next-20240403
- commit a177ec9
* Tue Apr  2 2024 kbuild@suse.de
- Automatically updated to 6.9-rc2-next-20240402
- commit 7551ae5
* Mon Apr  1 2024 mkubecek@suse.cz
- update to 6.9-rc2
- refresh
  - patches.suse/0003-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mode.patch
- update configs
- commit e5b2a1e
* Thu Mar 28 2024 kbuild@suse.de
- Automatically updated to 6.9-rc1-next-20240328
- commit 40d4c87
* Tue Mar 26 2024 kbuild@suse.de
- Automatically updated to 6.9-rc1-next-20240326
- commit 05df362
* Mon Mar 25 2024 kbuild@suse.de
- Automatically updated to 6.9-rc1-next-20240325
- commit bcb89d9
* Mon Mar 25 2024 mkubecek@suse.cz
- update to 6.9-rc1
- drop 19 patches (14 mainline, 5 stable)
  - patches.kernel.org/*
  - patches.suse/Bluetooth-btmtk-Add-MODULE_FIRMWARE-for-MT7922.patch
  - patches.suse/btrfs-fix-race-when-detecting-delalloc-ranges-during.patch
  - patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch
  - patches.suse/net-mdio-add-2.5g-and-5g-related-PMA-speed-constants.patch
  - patches.suse/net-phy-realtek-add-5Gbps-support-to-rtl822x_config_.patch
  - patches.suse/net-phy-realtek-add-support-for-RTL8126A-integrated-.patch
  - patches.suse/net-phy-realtek-use-generic-MDIO-constants.patch
  - patches.suse/r8169-add-support-for-RTL8126A.patch
  - patches.suse/wifi-ath11k-do-not-dump-SRNG-statistics-during-resum.patch
  - patches.suse/wifi-ath11k-fix-warning-on-DMA-ring-capabilities-eve.patch
  - patches.suse/wifi-ath11k-rearrange-IRQ-enable-disable-in-reset-pa.patch
  - patches.suse/wifi-ath11k-remove-MHI-LOOPBACK-channels.patch
  - patches.suse/wifi-ath11k-thermal-don-t-try-to-register-multiple-t.patch
  - patches.suse/wifi-brcmfmac-Fix-use-after-free-bug-in-brcmf_cfg802.patch
- refresh
  - patches.suse/0001-security-lockdown-expose-a-hook-to-lock-the-kernel-down.patch
  - patches.suse/Restore-kABI-for-NVidia-vGPU-driver.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/bus-mhi-host-add-mhi_power_down_no_destroy.patch
  - patches.suse/drivers-firmware-skip-simpledrm-if-nvidia-drm.modese.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- disable ARM architectures (need config update)
- new config options
  - Processor type and features
  - X86_FRED=y
  - Mitigations for speculative execution vulnerabilities
  - MITIGATION_PAGE_TABLE_ISOLATION=y
  - MITIGATION_RETPOLINE=y
  - MITIGATION_RETHUNK=y
  - MITIGATION_UNRET_ENTRY=y
  - MITIGATION_CALL_DEPTH_TRACKING=y
  - MITIGATION_IBPB_ENTRY=y
  - MITIGATION_IBRS_ENTRY=y
  - MITIGATION_SRSO=y
  - MITIGATION_SLS=y
  - MITIGATION_GDS_FORCE=n
  - Power management and ACPI options
  - HIBERNATION_COMP_LZO=y
  - HIBERNATION_COMP_LZ4=n
  - General architecture-dependent options
  - PAGE_SIZE_4KB=y
  - File systems
  - FUSE_PASSTHROUGH=y
  - Cryptographic API
  - CRYPTO_DEV_QAT_ERROR_INJECTION=n
  - Network device support
  - OCTEON_EP_VF=m
  - QCA83XX_PHY=m
  - QCA808X_PHY=m
  - CAN_ESD_402_PCI=m
  - Input device support
  - TOUCHSCREEN_GOODIX_BERLIN_I2C=m
  - TOUCHSCREEN_GOODIX_BERLIN_SPI=m
  - Hardware Monitoring support
  - SENSORS_ASUS_ROG_RYUJIN=m
  - SENSORS_CHIPCAP2=m
  - SENSORS_LTC4282=m
  - SENSORS_NZXT_KRAKEN3=m
  - SENSORS_MPQ8785=m
  - SENSORS_PT5161L=m
  - SENSORS_SURFACE_FAN=m
  - Graphics support
  - MAX6959=n
  - SEG_LED_GPIO=n
  - DRM_I915_DP_TUNNEL=y
  - BACKLIGHT_KTD2801=m
  - Sound card support
  - SND_SOC_AMD_SOUNDWIRE=m
  - SND_SOC_SOF_AMD_SOUNDWIRE=m
  - SND_SOC_WCD939X_SDW=n
  - USB support
  - USB_DEFAULT_AUTHORIZATION_MODE=1
  - TYPEC_MUX_IT5205=m
  - Industrial I/O support
  - AD9467=n
  - ADI_AXI_ADC=n
  - PAC1934=n
  - TI_ADS1298=n
  - ADMFM2000=n
  - Reliability, Availability and Serviceability (RAS) features
  - AMD_ATL=m
  - RAS_FMPM=m
  - Misc drivers
  - MTD_UBI_NVMEM=m
  - DM_VDO=m
  - PTP_1588_CLOCK_FC3W=m
  - GPIO_CROS_EC=m
  - W1_MASTER_UART=m
  - CROS_EC_WATCHDOG=m
  - QCOM_PBS=m
  - RESET_GPIO=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - DRM_PANEL_BOE_TH101MB31UIG002_28A=n
  - DRM_PANEL_HIMAX_HX83112A=n
  - DRM_PANEL_NOVATEK_NT36672E=n
  - LEDS_NCP5623=m
  - i386
  - QCA807X_PHY=m
  - PINCTRL_AW9523=m
  - DRM_XE=m
  - DRM_XE_* copied from x86_64
  - SND_SOC_FRAMER=m
  - AF8133J=n
  - ppc64le
  - NET_DSA_REALTEK_MDIO=y
  - NET_DSA_REALTEK_SMI=y
  - QCA807X_PHY=m
  - PINCTRL_AW9523=m
  - s390x
  - DRM_DEBUG_MM=n
  - DEBUG_VIRTUAL=n
  - riscv64
  - RISCV_PROBE_UNALIGNED_ACCESS=y
  - HIBERNATION=y
  - HIBERNATION_SNAPSHOT_DEV=y
  - PM_STD_PARTITION=""
  - ACPI_CPPC_CPUFREQ=m
  - ACPI_CPPC_CPUFREQ_FIE=y
  - ACPI_PROCESSOR=y
  - ACPI_THERMAL=m
  - RANDOMIZE_KSTACK_OFFSET=y
  - RANDOMIZE_KSTACK_OFFSET_DEFAULT=y
  - NET_DSA_REALTEK_MDIO=y
  - NET_DSA_REALTEK_SMI=y
  - SND_SOC_FRAMER=m
  - MMC_DW_HI3798MV200=m
  - AF8133J=n
  - STARFIVE_JH8100_INTC=y
  - STARFIVE_STARLINK_PMU=y
  - ANDES_CUSTOM_PMU=y
  - CRYPTO_*_RISCV64=m
- commit 9214575
* Fri Mar 22 2024 kbuild@suse.de
- Automatically updated to 6.8-next-20240322
- commit 2afe32b
* Thu Mar 21 2024 kbuild@suse.de
- Automatically updated to 6.8-next-20240321
- commit f1b2509
* Wed Mar 20 2024 kbuild@suse.de
- Automatically updated to 6.8-next-20240320
- commit 41fc058
* Tue Mar 19 2024 kbuild@suse.de
- Automatically updated to 6.8-next-20240319
- commit 644b7ef
* Mon Mar 18 2024 kbuild@suse.de
- Automatically updated to 6.8-next-20240318
- commit 16d1fa4
* Fri Mar 15 2024 kbuild@suse.de
- Automatically updated to 6.8-next-20240315
- commit ed4bf22
* Thu Mar 14 2024 kbuild@suse.de
- Automatically updated to 6.8-next-20240314
- commit 9bcfcac
* Wed Mar 13 2024 kbuild@suse.de
- Automatically updated to 6.8-next-20240313
- commit fc27d6a
* Wed Mar 13 2024 jslaby@suse.cz
- x86/rfds: Mitigate Register File Data Sampling (RFDS)
  (bsc#1213456 CVE-2023-28746).
- Update config files. Set MITIGATION_RFDS=y.
- commit 8a210d0
* Sun Mar 10 2024 mkubecek@suse.cz
- Update to 6.8 final
- update configs
- commit e436778
* Sun Mar 10 2024 mkubecek@suse.cz
- config: update and reenable armv6hl configs
- option values mirrored from armv7hl
- commit 3949f96
* Sun Mar 10 2024 mkubecek@suse.cz
- config: update and reenable armv7hl configs
- option values mirrored from arm64 or other architectures
- commit 55963ae
* Sun Mar 10 2024 mkubecek@suse.cz
- config: update and reenable arm64 configs
- most options mirrored from other architectures except
  - ARM64_ERRATUM_3117295=y
  - TEE_STMM_EFI=m
  - PINCTRL_SM4450=m
  - PINCTRL_SM8650=m
  - PINCTRL_X1E80100=m
  - PINCTRL_SM8650_LPASS_LPI=m
  - GPIO_NPCM_SGPIO=y
  - GPIO_RTD=m
  - VIDEO_STM32_DCMIPP=m
  - DRM_POWERVR=m
  - SND_SOC_X1E80100=m
  - RTC_DRV_MA35D1=m
  - COMMON_CLK_MT7988=m
  - CLK_X1E80100_GCC=m
  - SC_CAMCC_8280XP=m
  - QDU_ECPRICC_1000=m
  - SM_DISPCC_8650=m
  - SM_GCC_8650=m
  - SM_GPUCC_8650=m
  - SM_TCSRCC_8650=m
  - COMMON_CLK_STM32MP=y
  - INTERCONNECT_QCOM_SM6115=m
  - INTERCONNECT_QCOM_SM8650=m
  - INTERCONNECT_QCOM_X1E80100=m
  - KASAN_EXTRA_INFO=n (arm64/debug only)
- commit a64dd34
* Fri Mar  8 2024 kbuild@suse.de
- Automatically updated to 6.8-rc7-next-20240308
- commit 7728d4d
* Thu Mar  7 2024 msuchanek@suse.de
- group-source-files.pl: Quote filenames (boo#1221077).
  The kernel source now contains a file with a space in the name.
  Add quotes in group-source-files.pl to avoid splitting the filename.
  Also use -print0 / -0 when updating timestamps.
- commit a005e42
* Thu Mar  7 2024 kbuild@suse.de
- Automatically updated to 6.8-rc7-next-20240307
- commit 17d5714
* Wed Mar  6 2024 msuchanek@suse.de
- kernel-binary: Fix i386 build
  Fixes: 89eaf4cdce05 ("rpm templates: Move macro definitions below buildrequires")
- commit f7c6351
* Wed Mar  6 2024 kbuild@suse.de
- Automatically updated to 6.8-rc7-next-20240306
- commit 2251ba2
* Wed Mar  6 2024 msuchanek@suse.de
- kernel-binary: vdso: fix filelist for non-usrmerged kernel
  Fixes: a6ad8af207e6 ("rpm templates: Always define usrmerged")
- commit fb3f221
* Tue Mar  5 2024 kbuild@suse.de
- Automatically updated to 6.8-rc7-next-20240305
- commit 65785c7
* Mon Mar  4 2024 petr.pavlu@suse.com
- doc/README.SUSE: Update information about module support status
  (jsc#PED-5759)
  Following the code change in SLE15-SP6 to have externally supported
  modules no longer taint the kernel, update the respective documentation
  in README.SUSE:
  * Describe that support status can be obtained at runtime for each
  module from /sys/module/$MODULE/supported and for the entire system
  from /sys/kernel/supported. This provides a way how to now check that
  the kernel has any externally supported modules loaded.
  * Remove a mention that externally supported modules taint the kernel,
  but keep the information about bit 16 (X) and add a note that it is
  still tracked per module and can be read from
  /sys/module/$MODULE/taint. This per-module information also appears in
  Oopses.
- commit 9ed8107
* Mon Mar  4 2024 kbuild@suse.de
- Automatically updated to 6.8-rc7-next-20240304
- commit 868b5d8
* Sun Mar  3 2024 mkubecek@suse.cz
- Update to 6.8-rc7
- eliminate 1 mainline patch
  - patches.rpmify/net-ethernet-adi-move-PHYLIB-from-vendor-to-driver-s.patch (943d4bd67950)
- update riscv64 configs
  - RISCV_ISA_V=y
  - RISCV_ISA_V_DEFAULT_ENABLE=y
  - RISCV_ISA_V_UCOPY_THRESHOLD=768
  - RISCV_ISA_V_PREEMPTIVE=y
  - RISCV_ISA_ZBB=y
- commit 856dfa7
* Fri Mar  1 2024 kbuild@suse.de
- Automatically updated to 6.8-rc6-next-20240301
- commit 31c8e3b
* Thu Feb 29 2024 kbuild@suse.de
- Automatically updated to 6.8-rc6-next-20240229
- commit 557127a
* Wed Feb 28 2024 kbuild@suse.de
- Automatically updated to 6.8-rc6-next-20240228
- commit c3e2c1b
* Tue Feb 27 2024 kbuild@suse.de
- Automatically updated to 6.8-rc6-next-20240227
- commit 778174b
* Mon Feb 26 2024 kbuild@suse.de
- Automatically updated to 6.8-rc5-next-20240226
- commit 76d0731
* Mon Feb 26 2024 mkubecek@suse.cz
- net: ethernet: adi: move PHYLIB from vendor to driver symbol.
  Fix config dependencies.
- restore config options from before 6.8-rc6:
  - NET_VENDOR_ADI=y
  - ADIN1110=m
- commit 053790d
* Mon Feb 26 2024 mkubecek@suse.cz
- Update to 6.8-rc6
- update configs
  - DRM_NOUVEAU_GSP_DEFAULT=n
  - disable NET_VENDOR_ADI (mainline commit a9f80df4f514 would force many
    other config options to "Y")
- commit 598b821
* Fri Feb 23 2024 kbuild@suse.de
- Automatically updated to 6.8-rc5-next-20240223
- commit f6f0e4d
* Thu Feb 22 2024 msuchanek@suse.de
- rpm templates: Always define usrmerged
  usrmerged is now defined in kernel-spec-macros and not the distribution.
  Only check if it's defined in kernel-spec-macros, not everywhere where
  it's used.
- commit a6ad8af
* Wed Feb 21 2024 msuchanek@suse.de
- rpm templates: Move macro definitions below buildrequires
  Many of the rpm macros defined in the kernel packages depend directly or
  indirectly on script execution. OBS cannot execute scripts which means
  values of these macros cannot be used in tags that are required for OBS
  to see such as package name, buildrequires or buildarch.
  Accumulate macro definitions that are not directly expanded by mkspec
  below buildrequires and buildarch to make this distinction clear.
- commit 89eaf4c
* Wed Feb 21 2024 kbuild@suse.de
- Automatically updated to 6.8-rc5-next-20240221
- commit 3a97471
* Wed Feb 21 2024 jslaby@suse.cz
- rpm/check-for-config-changes: add GCC_ASM_GOTO_OUTPUT_WORKAROUND to IGNORED_CONFIGS_RE
  Introduced by commit 68fb3ca0e408 ("update workarounds for gcc "asm
  goto" issue").
- commit be1bdab
* Tue Feb 20 2024 mkubecek@suse.cz
- Update to 6.8-rc5
- update configs
  - HDC3020=n
- commit 974f1ef
* Tue Feb 20 2024 kbuild@suse.de
- Automatically updated to 6.8-rc5-next-20240220
- commit c24be6d
* Mon Feb 19 2024 mkoutny@suse.com
- Update config files.
  Disable CONFIG_RT_GROUP_SCHED on all archs (bsc#950955 bsc#1153228).
- commit db8fd6b
* Mon Feb 19 2024 msuchanek@suse.de
- compute-PATCHVERSION: Do not produce output when awk fails
  compute-PATCHVERSION uses awk to produce a shell script that is
  subsequently executed to update shell variables which are then printed
  as the patchversion.
  Some versions of awk, most notably bysybox-gawk do not understand the
  awk program and fail to run. This results in no script generated as
  output, and printing the initial values of the shell variables as
  the patchversion.
  When the awk program fails to run produce 'exit 1' as the shell script
  to run instead. That prevents printing the stale values, generates no
  output, and generates invalid rpm spec file down the line. Then the
  problem is flagged early and should be easier to diagnose.
- commit 8ef8383
* Mon Feb 19 2024 kbuild@suse.de
- Automatically updated to 6.8-rc5-next-20240219
- commit 5838072
* Fri Feb 16 2024 kbuild@suse.de
- Automatically updated to 6.8-rc4-next-20240216
- commit 242ab33
* Thu Feb 15 2024 kbuild@suse.de
- Automatically updated to 6.8-rc4-next-20240215
- commit 10427cf
* Wed Feb 14 2024 msuchanek@suse.de
- kernel-binary: Move build script to the end
  All other spec templates have the build script at the end, only
  kernel-binary has it in the middle. Align with the other templates.
- commit 98cbdd0
* Wed Feb 14 2024 msuchanek@suse.de
- rpm templates: Aggregate subpackage descriptions
  While in some cases the package tags, description, scriptlets and
  filelist are located together in other cases they are all across the
  spec file. Aggregate the information related to a subpackage in one
  place.
- commit 8eeb08c
* Wed Feb 14 2024 msuchanek@suse.de
- rpm templates: sort rpm tags
  The rpm tags in kernel spec files are sorted at random.
  Make the order of rpm tags somewhat more consistent across rpm spec
  templates.
- commit 8875c35
* Wed Feb 14 2024 kbuild@suse.de
- Automatically updated to 6.8-rc4-next-20240214
- commit 898e48a
* Tue Feb 13 2024 kbuild@suse.de
- Automatically updated to 6.8-rc4-next-20240213
- commit 5566bb5
* Mon Feb 12 2024 tiwai@suse.de
- Update config files: disable broken ATOMISP drivers (bsc#1210639)
  It's been broken over a year, better to disable it before hitting another victim
- commit 736d8a7
* Mon Feb 12 2024 vbabka@suse.cz
- Update config files. Enable CONFIG_READ_ONLY_THP_FOR_FS (bsc#1219593).
- commit cb89f09
* Mon Feb 12 2024 kbuild@suse.de
- Automatically updated to 6.8-rc4-next-20240212
- commit 63de5a8
* Fri Feb  9 2024 kbuild@suse.de
- Automatically updated to 6.8-rc3-next-20240209
- commit 8594c93
* Thu Feb  8 2024 msuchanek@suse.de
- kernel-binary: certs: Avoid trailing space
- commit bc7dc31
* Thu Feb  8 2024 kbuild@suse.de
- Automatically updated to 6.8-rc3-next-20240208
- commit 329cb5b
* Wed Feb  7 2024 jslaby@suse.cz
- rpm/kernel-binary.spec.in: install scripts/gdb when enabled in config
  (bsc#1219653)
  They are put into -devel subpackage. And a proper link to
  /usr/share/gdb/auto-load/ is created.
- commit 1dccf2a
* Wed Feb  7 2024 kbuild@suse.de
- Automatically updated to 6.8-rc3-next-20240207
- commit 8f88ce7
* Tue Feb  6 2024 kbuild@suse.de
- Automatically updated to 6.8-rc3-next-20240206
- commit 42d5744
* Tue Feb  6 2024 jslaby@suse.cz
- rpm/mkspec: sort entries in _multibuild
  Otherwise it creates unnecessary diffs when tar-up-ing. It's of course
  due to readdir() using "random" order as served by the underlying
  filesystem.
  See for example:
  https://build.opensuse.org/request/show/1144457/changes
- commit d1155de
* Mon Feb  5 2024 kbuild@suse.de
- Automatically updated to 6.8-rc3-next-20240205
- commit a5da8fe
* Sun Feb  4 2024 mkubecek@suse.cz
- Update to 6.8-rc3
- eliminate 1 patch
  - patches.suse/mm-huge_memory-don-t-force-huge-page-alignment-on-32.patch
- refresh configs
- commit 9ffdecb
* Fri Feb  2 2024 mkubecek@suse.cz
- config: add missing USELIB=n to arm configs
  ARM configs were not refreshed properly after commit 077d05a10ddb ("Update
  config files: disable CONFIG_USELIB (bsc#1219222)") because they are
  disabled at the moment. Add missing lines for (now disabled) CONFIG_USELIB
  option.
- commit b271fea
* Fri Feb  2 2024 kbuild@suse.de
- Automatically updated to 6.8-rc2-next-20240202
- commit 59c848d
* Fri Feb  2 2024 tiwai@suse.de
- Update config files: disable CONFIG_USELIB (bsc#1219222)
  It's only for the old libc5. Let's reduce the possible attack surfaces.
- commit 7d16d19
* Thu Feb  1 2024 kbuild@suse.de
- Automatically updated to 6.8-rc2-next-20240201
- commit d6a2751
* Wed Jan 31 2024 msuchanek@suse.de
- kernel-source: Fix description typo
- commit 8abff35
* Wed Jan 31 2024 kbuild@suse.de
- Automatically updated to 6.8-rc2-next-20240131
- commit a9d7eaf
* Tue Jan 30 2024 kbuild@suse.de
- Automatically updated to 6.8-rc2-next-20240130
- commit 9208163
* Tue Jan 30 2024 jslaby@suse.cz
- rpm/constraints.in: set jobs for riscv to 8
  The same workers are used for x86 and riscv and the riscv builds take
  ages. So align the riscv jobs count to x86.
- commit b2c82b9
* Tue Jan 30 2024 jslaby@suse.cz
- Update config files. (bsc#1219328)
  Synchronize PSTORE_CONSOLE, PSTORE_PMSG, and PSTORE_FTRACE with
  SLE15-SP6.
- commit 51a3f0c
* Mon Jan 29 2024 kbuild@suse.de
- Automatically updated to 6.8-rc1-next-20240129
- commit b7aa79a
* Mon Jan 29 2024 mkubecek@suse.cz
- Update to 6.8-rc2
- eliminate 1 patch
  - patches.suse/futex-Avoid-reusing-outdated-pi_state.patch (e626cb02ee83)
- refresh configs
- commit 87d7644
* Fri Jan 26 2024 msuchanek@suse.de
- mkspec: Use variant in constraints template
  Constraints are not applied consistently with kernel package variants.
  Add variant to the constraints template as appropriate, and expand it
  in mkspec.
- commit cc68ab9
* Fri Jan 26 2024 jslaby@suse.cz
- rpm/constraints.in: add static multibuild packages
  Commit 841012b049a5 (rpm/mkspec: use kernel-source: prefix for
  constraints on multibuild) added "kernel-source:" prefix to the
  dynamically generated kernels. But there are also static ones like
  kernel-docs. Those fail to build as the constraints are still not
  applied.
  So add the prefix also to the static ones.
  Note kernel-docs-rt is given kernel-source-rt prefix. I am not sure it
  will ever be multibuilt...
- commit c2e0681
* Thu Jan 25 2024 msuchanek@suse.de
- Revert "Limit kernel-source build to architectures for which the kernel binary"
  This reverts commit 08a9e44c00758b5f3f3b641830ab6affff041132.
  The fix for bsc#1108281 directly causes bsc#1218768, revert.
- commit 2943b8a
* Thu Jan 25 2024 msuchanek@suse.de
- mkspec: Include constraints for both multibuild and plain package always
  There is no need to check for multibuild flag, the constraints can be
  always generated for both cases.
- commit 308ea09
* Thu Jan 25 2024 kbuild@suse.de
- Automatically updated to 6.8-rc1-next-20240125
- commit 2e98f41
* Thu Jan 25 2024 jslaby@suse.cz
- rpm/mkspec: use kernel-source: prefix for constraints on multibuild
  Otherwise the constraints are not applied with multibuild enabled.
- commit 841012b
* Wed Jan 24 2024 jslaby@suse.cz
- rpm/kernel-source.rpmlintrc: add action-ebpf
  Upstream commit a79d8ba734bd (selftests: tc-testing: remove buildebpf
  plugin) added this precompiled binary blob. Adapt rpmlintrc for
  kernel-source.
- commit b5ccb33
* Wed Jan 24 2024 kbuild@suse.de
- Automatically updated to 6.8-rc1-next-20240124
- commit 442bd1a
* Tue Jan 23 2024 tiwai@suse.de
- scripts/tar-up.sh: don't add spurious entry from kernel-sources.changes.old
  The previous change added the manual entry from kernel-sources.change.old
  to old_changelog.txt unnecessarily.  Let's fix it.
- commit fb033e8
* Tue Jan 23 2024 kbuild@suse.de
- Automatically updated to 6.8-rc1-next-20240123
- commit 82b2081
* Tue Jan 23 2024 jslaby@suse.cz
- rpm/kernel-docs.spec.in: fix build with 6.8
  Since upstream commit f061c9f7d058 (Documentation: Document each netlink
  family), the build needs python yaml.
- commit 6a7ece3
* Mon Jan 22 2024 mkubecek@suse.cz
- Update to 6.8-rc1
- drop 3 patches (all mainline)
  - patches.rpmify/media-solo6x10-replace-max-a-min-b-c-by-clamp-b-a-c.patch (31e97d7c9ae3)
  - patches.suse/0001-bsc-1204315-Disable-sysfb-before-creating-simple-fra.patch
  (3310288f6135)
  - patches.suse/keys-dns-Fix-size-check-of-V1-server-list-header.patch
- disable (conflict)
  - patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch
- refresh
  - patches.suse/0001-security-lockdown-expose-a-hook-to-lock-the-kernel-down.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/btrfs-provide-super_operations-get_inode_dev
  - patches.suse/genksyms-add-override-flag.diff
  - patches.suse/vfs-add-super_operations-get_inode_dev
- fix patch metadata
  - patches.suse/btrfs-provide-super_operations-get_inode_dev
- disable ARM architectures (need config update)
- new config options
  - Virtualization
  - CONFIG_KVM_SW_PROTECTED_VM=y
  - CONFIG_KVM_HYPERV=y
  - Enable the block layer
  - CONFIG_BLK_DEV_WRITE_MOUNTED=y
  - Memory Management options
  - CONFIG_ZSWAP_SHRINKER_DEFAULT_ON=n
  - CONFIG_TRANSPARENT_HUGEPAGE_NEVER=n
  - File systems
  - CONFIG_BCACHEFS_SIX_OPTIMISTIC_SPIN=y
  - CONFIG_EROFS_FS_ONDEMAND=n
  - CONFIG_NFSD_LEGACY_CLIENT_TRACKING=n
  - Cryptographic API
  - CONFIG_CRYPTO_DEV_QAT_420XX=m
  - CONFIG_CRYPTO_DEV_IAA_CRYPTO=m
  - CONFIG_CRYPTO_DEV_IAA_CRYPTO_STATS=n
  - Library routines
  - CONFIG_STACKDEPOT_MAX_FRAMES=64
  - Misc devices
  - CONFIG_NSM=m
  - CONFIG_INTEL_MEI_VSC_HW=m
  - CONFIG_INTEL_MEI_VSC=m
  - Network device support
  - CONFIG_ICE_HWMON=y
  - CONFIG_DP83TG720_PHY=m
  - CONFIG_FRAMER=m
  - Pin controllers
  - CONFIG_PINCTRL_INTEL_PLATFORM=m
  - CONFIG_PINCTRL_METEORPOINT=m
  - Hardware Monitoring support
  - CONFIG_SENSORS_GIGABYTE_WATERFORCE=m
  - CONFIG_SENSORS_LTC4286=n
  - CONFIG_SENSORS_MP2856=m
  - CONFIG_SENSORS_MP5990=m
  - Multimedia support
  - CONFIG_VIDEO_ALVIUM_CSI2=m
  - CONFIG_VIDEO_GC0308=m
  - CONFIG_VIDEO_GC2145=m
  - CONFIG_VIDEO_OV64A40=m
  - CONFIG_VIDEO_THP7312=m
  - CONFIG_VIDEO_TW9900=m
  - Graphics support
  - CONFIG_DRM_I915_DEBUG_WAKEREF=n
  - CONFIG_DRM_XE=m
  - CONFIG_DRM_XE_DISPLAY=y
  - CONFIG_DRM_XE_FORCE_PROBE=""
  - CONFIG_DRM_XE_WERROR=n
  - CONFIG_DRM_XE_DEBUG=n
  - CONFIG_DRM_XE_DEBUG_VM=n
  - CONFIG_DRM_XE_DEBUG_SRIOV=n
  - CONFIG_DRM_XE_DEBUG_MEM=n
  - CONFIG_DRM_XE_SIMPLE_ERROR_CAPTURE=n
  - CONFIG_DRM_XE_LARGE_GUC_BUFFER=n
  - CONFIG_DRM_XE_USERPTR_INVAL_INJECT=n
  - CONFIG_DRM_XE_JOB_TIMEOUT_MAX=10000
  - CONFIG_DRM_XE_JOB_TIMEOUT_MIN=1
  - CONFIG_DRM_XE_TIMESLICE_MAX=10000000
  - CONFIG_DRM_XE_TIMESLICE_MIN=1
  - CONFIG_DRM_XE_PREEMPT_TIMEOUT=640000
  - CONFIG_DRM_XE_PREEMPT_TIMEOUT_MAX=10000000
  - CONFIG_DRM_XE_PREEMPT_TIMEOUT_MIN=1
  - CONFIG_DRM_XE_ENABLE_SCHEDTIMEOUT_LIMIT=y
  - CONFIG_BACKLIGHT_MP3309C=m
  - Real Time Clock
  - CONFIG_RTC_DRV_MAX31335=m
  - CONFIG_RTC_DRV_TPS6594=m
  - VFIO Non-Privileged userspace driver framework
  - CONFIG_VFIO_DEBUGFS=n
  - CONFIG_VIRTIO_VFIO_PCI=m
  - X86 Platform Specific Device Drivers
  - CONFIG_AMD_WBRF=y
  - CONFIG_SILICOM_PLATFORM=m
  - Industrial I/O support
  - CONFIG_AD7091R8=n
  - CONFIG_MAX34408=n
  - CONFIG_AOSONG_AGS02MA=n
  - CONFIG_MCP4821=n
  - CONFIG_BMI323_I2C=m
  - CONFIG_BMI323_SPI=m
  - CONFIG_ISL76682=n
  - CONFIG_LTR390=n
  - CONFIG_VEML6075=n
  - CONFIG_HSC030PA=n
  - CONFIG_MLX90635=m
  - CONFIG_MCP9600=m
  - Misc drivers
  - CONFIG_MTD_UBI_FAULT_INJECTION=n
  - CONFIG_ZRAM_TRACK_ENTRY_ACTIME=n
  - CONFIG_JOYSTICK_SEESAW=m
  - CONFIG_W1_MASTER_AMD_AXI=m
  - CONFIG_THERMAL_DEBUGFS=n
  - CONFIG_REGULATOR_NETLINK_EVENTS=y
  - CONFIG_SND_AMD_ASOC_ACP70=m
  - CONFIG_HID_MCP2200=m
  - CONFIG_TYPEC_MUX_WCD939X_USBSS=m
  - CONFIG_QCOM_PMIC_PDCHARGER_ULOG=m
  - CONFIG_DWC_PCIE_PMU=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - PINCTRL_TPS6594=n
  - DRM_PANEL_ILITEK_ILI9805=n
  - DRM_PANEL_SYNAPTICS_R63353=n
  - LEDS_MAX5970=m
  - i386
  - FRAMER_PEF2256=m
  - PINCTRL_PEF2256=n
  - s390x
  - DRM_DP_AUX_CHARDEV=y
  - DRM_DP_CEC=y
  - DRM_PANEL_RASPBERRYPI_TOUCHSCREEN=n
  - MEDIA_CEC_RC=n
  - s390x/zfcpdump
  - HW_RANDOM_VIRTIO=n
  - HW_RANDOM_S390=y
  - riscv64
  - PARAVIRT=y
  - PARAVIRT_TIME_ACCOUNTING=n
  - POLARFIRE_SOC_AUTO_UPDATE=m
  - FRAMER_PEF2256=m
  - SERIAL_EARLYCON_RISCV_SBI=y
  - HVC_RISCV_SBI=y
  - PINCTRL_PEF2256=n
  - DRM_PANEL_RASPBERRYPI_TOUCHSCREEN=m
  - DRM_PANEL_*=n (except above)
  - LEDS_SUN50I_A100=m
  - VIDEO_STARFIVE_CAMSS=m
- commit b883272
* Mon Jan 22 2024 kbuild@suse.de
- Automatically updated to 6.8-rc1-next-20240122
- commit 6816a1e
* Sun Jan 21 2024 colyli@suse.de
- Update config files, enable CONFIG_IMA_DISABLE_HTABLE in all archs for
  Tumbleweed as SLE15-SP6 kernel does (bsc#1218400).
- commit b2c4d85
* Fri Jan 19 2024 kbuild@suse.de
- Automatically updated to 6.7-next-20240119
- commit 3bdeeb6
* Thu Jan 18 2024 kbuild@suse.de
- Automatically updated to 6.7-next-20240118
- commit d0c76c5
* Wed Jan 17 2024 kbuild@suse.de
- Automatically updated to 6.7-next-20240117
- commit b081df0
* Fri Jan 12 2024 kbuild@suse.de
- Automatically updated to 6.7-next-20240112
- commit 6cc0533
* Thu Jan 11 2024 kbuild@suse.de
- Automatically updated to 6.7-next-20240111
- commit 8eef0ba
* Thu Jan 11 2024 tiwai@suse.de
- Store the old kernel changelog entries in kernel-docs package (bsc#1218713)
  The old entries are found in kernel-docs/old_changelog.txt in docdir.
  rpm/old_changelog.txt can be an optional file that stores the similar
  info like rpm/kernel-sources.changes.old.  It can specify the commit
  range that have been truncated.  scripts/tar-up.sh expands from the
  git log accordingly.
- commit c9a2566
* Wed Jan 10 2024 kbuild@suse.de
- Automatically updated to 6.7-next-20240110
- commit a325369
* Tue Jan  9 2024 kbuild@suse.de
- Automatically updated to 6.7-next-20240109
- commit f92854b
* Mon Jan  8 2024 msuchanek@suse.de
- Limit kernel-source build to architectures for which the kernel binary
  is built (bsc#1108281).
- commit 08a9e44
* Mon Jan  8 2024 kbuild@suse.de
- Automatically updated to 6.7-next-20240108
- commit 3ba5873
* Sun Jan  7 2024 mkubecek@suse.cz
- Update to 6.7
- refresh configs (only headers)
- commit 660bb81
* Fri Jan  5 2024 kbuild@suse.de
- Automatically updated to 6.7-rc8-next-20240105
- commit eb658fa
* Fri Jan  5 2024 petr.pavlu@suse.com
- Delete doc/config-options.changes (jsc#PED-5021)
  Following on adedbd2a5c6 ("kernel-source: Remove config-options.changes
  (jsc#PED-5021)"), remove the now unused file from the tree.
- commit b9e9083
* Thu Jan  4 2024 msuchanek@suse.de
- config: ppc64le: CONFIG_MEM_SOFT_DIRTY=y (bsc#1218286 ltc#204519).
- commit a296839
* Thu Jan  4 2024 kbuild@suse.de
- Automatically updated to 6.7-rc8-next-20240104
- commit a111ae3
* Wed Jan  3 2024 msuchanek@suse.de
- mkspec: Add multibuild support (JSC-SLE#5501, boo#1211226, bsc#1218184)
  When MULTIBUILD option in config.sh is enabled generate a _multibuild
  file listing all spec files.
- commit f734347
* Wed Jan  3 2024 msuchanek@suse.de
- Build in the correct KOTD repository with multibuild
  (JSC-SLE#5501, boo#1211226, bsc#1218184)
  With multibuild setting repository flags is no longer supported for
  individual spec files - see
  https://github.com/openSUSE/open-build-service/issues/3574
  Add ExclusiveArch conditional that depends on a macro set up by
  bs-upload-kernel instead. With that each package should build only in
  one repository - either standard or QA.
  Note: bs-upload-kernel does not interpret rpm conditionals, and only
  uses the first ExclusiveArch line to determine the architectures to
  enable.
- commit aa5424d
* Wed Jan  3 2024 kbuild@suse.de
- Automatically updated to 6.7-rc8-next-20240103
- commit c811388
* Wed Jan  3 2024 msuchanek@suse.de
- rpm/config.sh: Enable multibuild.
- commit f33249f
* Tue Jan  2 2024 kbuild@suse.de
- Automatically updated to 6.7-rc8-next-20240102
- commit 3329a30
* Mon Jan  1 2024 mkubecek@suse.cz
- Update to 6.7-rc8
- update configs
  - s390x/zfcpdump:
  - KEXEC_FILE=y
- commit 1990dea
* Sun Dec 24 2023 mkubecek@suse.cz
- Update to 6.7-rc7
- refresh configs
- commit 9a59ccc
* Fri Dec 22 2023 kbuild@suse.de
- Automatically updated to 6.7-rc6-next-20231222
- commit 7066387
* Thu Dec 21 2023 kbuild@suse.de
- Automatically updated to 6.7-rc6-next-20231221
- commit 8b952e2
* Wed Dec 20 2023 kbuild@suse.de
- Automatically updated to 6.7-rc6-next-20231220
- commit ea44110
* Tue Dec 19 2023 kbuild@suse.de
- Automatically updated to 6.7-rc6-next-20231219
- commit 9828b08
* Mon Dec 18 2023 kbuild@suse.de
- Automatically updated to 6.7-rc5-next-20231218
- commit f76d54a
* Mon Dec 18 2023 mkubecek@suse.cz
- Update to 6.7-rc6
- refresh configs
- commit afff72b
* Sat Dec 16 2023 dmueller@suse.com
- config: update riscv64
- sync few options with arm
- config.conf: reenable armv6hl/armv7hl
- Update config files.
- commit f0b16bf
* Sat Dec 16 2023 dmueller@suse.com
- config.conf: Reenable arm64
- Update config files for arm64. Take settings from x86_64, enable
  everthing that can be enabled as modules.
- commit 945067c
* Fri Dec 15 2023 kbuild@suse.de
- Automatically updated to 6.7-rc5-next-20231215
- commit 0088f56
* Thu Dec 14 2023 kbuild@suse.de
- Automatically updated to 6.7-rc5-next-20231214
- commit 91add7b
* Wed Dec 13 2023 kbuild@suse.de
- Automatically updated to 6.7-rc5-next-20231213
- commit 52cde3c
* Tue Dec 12 2023 kbuild@suse.de
- Automatically updated to 6.7-rc5-next-20231212
- commit f2bc3ed
* Mon Dec 11 2023 kbuild@suse.de
- Automatically updated to 6.7-rc4-next-20231211
- commit 9a59470
* Mon Dec 11 2023 mkubecek@suse.cz
- Update to 6.7-rc5
- refresh configs
- commit 101cb8f
* Fri Dec  8 2023 kbuild@suse.de
- Automatically updated to 6.7-rc4-next-20231208
- commit 22a5bb8
* Fri Dec  8 2023 petr.pavlu@suse.com
- kernel-source: Remove config-options.changes (jsc#PED-5021)
  The file doc/config-options.changes was used in the past to document
  kernel config changes. It was introduced in 2010 but haven't received
  any updates on any branch since 2015. The file is renamed by tar-up.sh
  to config-options.changes.txt and shipped in the kernel-source RPM
  package under /usr/share/doc. As its content now only contains outdated
  information, retaining it can lead to confusion for users encountering
  this file.
  Config changes are nowadays described in associated Git commit messages,
  which get automatically collected and are incorporated into changelogs
  of kernel RPM packages.
  Drop then this obsolete file, starting with its packaging logic.
  For branch maintainers: Upon merging this commit on your branch, please
  correspondingly delete the file doc/config-options.changes.
- commit adedbd2
* Fri Dec  8 2023 petr.pavlu@suse.com
- doc/README.SUSE: Simplify the list of references (jsc#PED-5021)
  Reduce indentation in the list of references, make the style consistent
  with README.md.
- commit 70e3c33
* Thu Dec  7 2023 petr.pavlu@suse.com
- doc/README.SUSE: Add how to update the config for module signing
  (jsc#PED-5021)
  Configuration files for SUSE kernels include settings to integrate with
  signing support provided by the Open Build Service. This creates
  problems if someone tries to use such a configuration file to build
  a "standalone" kernel as described in doc/README.SUSE:
  * Default configuration files available in the kernel-source repository
  unset CONFIG_MODULE_SIG_ALL to leave module signing to
  pesign-obs-integration. In case of a "standalone" build, this
  integration is not available and the modules don't get signed.
  * The kernel spec file overrides CONFIG_MODULE_SIG_KEY to
  ".kernel_signing_key.pem" which is a file populated by certificates
  provided by OBS but otherwise not available. The value ends up in
  /boot/config-$VERSION-$RELEASE-$FLAVOR and /proc/config.gz. If someone
  decides to use one of these files as their base configuration then the
  build fails with an error because the specified module signing key is
  missing.
  Add information on how to enable module signing and where to find the
  relevant upstream documentation.
- commit a699dc3
* Thu Dec  7 2023 kbuild@suse.de
- Automatically updated to 6.7-rc4-next-20231207
- commit 7bbbedc
* Wed Dec  6 2023 petr.pavlu@suse.com
- doc/README.SUSE: Remove how to build modules using kernel-source
  (jsc#PED-5021)
  Remove the first method how to build kernel modules from the readme. It
  describes a process consisting of the kernel-source installation,
  configuring this kernel and then performing an ad-hoc module build.
  This method is not ideal as no modversion data is involved in the
  process. It results in a module with no symbol CRCs which can be wrongly
  loaded on an incompatible kernel.
  Removing the method also simplifies the readme because only two main
  methods how to build the modules are then described, either doing an
  ad-hoc build using kernel-devel, or creating a proper Kernel Module
  Package.
- commit 9285bb8
* Wed Dec  6 2023 kbuild@suse.de
- Automatically updated to 6.7-rc4-next-20231206
- commit 0a1d7e6
* Tue Dec  5 2023 kbuild@suse.de
- Automatically updated to 6.7-rc4-next-20231205
- commit 8e27d01
* Mon Dec  4 2023 kbuild@suse.de
- Automatically updated to 6.7-rc4-next-20231204
- commit 5164e1d
* Sun Dec  3 2023 mkubecek@suse.cz
- Update to 6.7-rc4
- update configs
  - BCACHEFS_ERASURE_CODING=n
- commit 95032af
* Fri Dec  1 2023 msuchanek@suse.de
- kernel-binary: suse-module-tools is also required when installed
  Requires(pre) adds dependency for the specific sciptlet.
  However, suse-module-tools also ships modprobe.d files which may be
  needed at posttrans time or any time the kernel is on the system for
  generating ramdisk. Add plain Requires as well.
- commit 8c12816
* Fri Dec  1 2023 msuchanek@suse.de
- rpm: Use run_if_exists for all external scriptlets
  With that the scriptlets do not need to be installed for build.
- commit 25edd65
* Fri Dec  1 2023 kbuild@suse.de
- Automatically updated to 6.7-rc3-next-20231201
- commit 389b0b7
* Thu Nov 30 2023 kbuild@suse.de
- Automatically updated to 6.7-rc3-next-20231130
- commit 7154ceb
* Thu Nov 30 2023 jslaby@suse.cz
- README.SUSE: fix patches.addon use
  It's series, not series.conf in there.
  And make it more precise on when the patches are applied.
- commit cb8969c
* Wed Nov 29 2023 bwiedemann@suse.de
- Do not store build host name in initrd
  Without this patch, kernel-obs-build stored the build host name
  in its .build.initrd.kvm
  This patch allows for reproducible builds of kernel-obs-build and thus
  avoids re-publishing the kernel-obs-build.rpm when nothing changed.
  Note that this has no influence on the /etc/hosts file
  that is used during other OBS builds.
  https://bugzilla.opensuse.org/show_bug.cgi?id=1084909
- commit fd3a75e
* Wed Nov 29 2023 kbuild@suse.de
- Automatically updated to 6.7-rc3-next-20231129
- commit 4ef5ba1
* Tue Nov 28 2023 kbuild@suse.de
- Automatically updated to 6.7-rc3-next-20231128
- commit 17adee0
* Mon Nov 27 2023 kbuild@suse.de
- Automatically updated to 6.7-rc2-next-20231127
- commit c29c739
* Mon Nov 27 2023 mkubecek@suse.cz
- Update to 6.7-rc3
- refresh configs
- commit 5f86846
* Fri Nov 24 2023 kbuild@suse.de
- Automatically updated to 6.7-rc2-next-20231124
- commit 7140630
* Fri Nov 24 2023 fcrozat@suse.com
- Ensure ia32_emulation is always enabled for kernel-obs-build
  If ia32_emulation is disabled by default, ensure it is enabled
  back for OBS kernel to allow building 32bit binaries (jsc#PED-3184)
  [ms: Always pass the parameter, no need to grep through the config which
  may not be very reliable]
- commit 56a2c2f
* Thu Nov 23 2023 kbuild@suse.de
- Automatically updated to 6.7-rc2-next-20231123
- commit c42ff85
* Wed Nov 22 2023 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_WSA883X=m for Thinkpad X13s audio (bsc#1217412)
- commit 4b9907b
* Wed Nov 22 2023 kbuild@suse.de
- Automatically updated to 6.7-rc2-next-20231122
- commit 8731613
* Wed Nov 22 2023 msuchanek@suse.de
- rpm: Define git commit as macro
- commit bcc92c8
* Wed Nov 22 2023 msuchanek@suse.de
- kernel-source: Move provides after sources
- commit dbbf742
* Tue Nov 21 2023 kbuild@suse.de
- Automatically updated to 6.7-rc2-next-20231121
- commit 46f7527
* Mon Nov 20 2023 kbuild@suse.de
- Automatically updated to 6.7-rc2-next-20231120
- commit 9395a06
* Mon Nov 20 2023 mkubecek@suse.cz
- Update to 6.7-rc2
- refresh
  - patches.suse/firmware-qemu_fw_cfg-Do-not-hard-depend-on-CONFIG_HA.patch
- update configs
  - riscv64
  - FW_CFG_SYSFS=m
  - FW_CFG_SYSFS_CMDLINE=y
- commit ee09ffd
* Fri Nov 17 2023 kbuild@suse.de
- Automatically updated to 6.7-rc1-next-20231117
- commit 41c2665
* Thu Nov 16 2023 kbuild@suse.de
- Automatically updated to 6.7-rc1-next-20231116
- commit dd70ad8
* Wed Nov 15 2023 msuchanek@suse.de
- Add ksym-provides tool (bsc#1077692).
- commit 6997373
* Wed Nov 15 2023 kbuild@suse.de
- Automatically updated to 6.7-rc1-next-20231115
- commit 2b5d7fa
* Tue Nov 14 2023 kbuild@suse.de
- Automatically updated to 6.7-rc1-next-20231114
- commit 34e7b4c
* Mon Nov 13 2023 schwab@suse.de
- rpm/check-for-config-changes: add HAVE_SHADOW_CALL_STACK to IGNORED_CONFIGS_RE
  Not supported by our compiler.
- commit eb32b5a
* Mon Nov 13 2023 mkubecek@suse.cz
- Update to 6.7-rc1
- drop 36 patches (31 stable, 5 mainline)
  - patches.kernel.org/*
  - patches.rpmify/kbuild-dummy-tools-pretend-we-understand-fpatchable-.patch
  - patches.suse/firmware-Add-support-for-Qualcomm-UEFI-Secure-Applic.patch
  - patches.suse/firmware-qcom_scm-Add-support-for-Qualcomm-Secure-Ex.patch
  - patches.suse/lib-ucs2_string-Add-UCS-2-strscpy-function.patch
  - patches.suse/wifi-ath11k-rename-the-sc-naming-convention-to-ab.patch
- refresh
  - patches.rpmify/Add-ksym-provides-tool.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
  - patches.suse/wifi-ath11k-support-hibernation.patch
- fix patch metadata
  - patches.rpmify/Add-ksym-provides-tool.patch
- disable ARM architectures (need config update)
- new config options
  - Processor type and features
  - CONFIG_INTEL_TDX_HOST=n
  - Binary Emulations
  - CONFIG_IA32_EMULATION_DEFAULT_DISABLED=n
  - Virtualization
  - CONFIG_KVM_MAX_NR_VCPUS=4096
  - Enable loadable module support
  - CONFIG_MODULE_SIG_SHA3_256=n
  - CONFIG_MODULE_SIG_SHA3_384=n
  - CONFIG_MODULE_SIG_SHA3_512=n
  - Memory Management options
  - CONFIG_PCP_BATCH_SCALE_MAX=5
  - Networking support
  - CONFIG_TCP_AO=y
  - File systems
  - CONFIG_BCACHEFS_FS=m
  - CONFIG_BCACHEFS_QUOTA=y
  - CONFIG_BCACHEFS_POSIX_ACL=y
  - CONFIG_BCACHEFS_DEBUG_TRANSACTIONS=n
  - CONFIG_BCACHEFS_DEBUG=n
  - CONFIG_BCACHEFS_TESTS=n
  - CONFIG_BCACHEFS_LOCK_TIME_STATS=n
  - CONFIG_BCACHEFS_NO_LATENCY_ACCT=n
  - Cryptographic API
  - CONFIG_CRYPTO_JITTERENTROPY_MEMSIZE_2=y
  - CONFIG_CRYPTO_JITTERENTROPY_MEMSIZE_128=n
  - CONFIG_CRYPTO_JITTERENTROPY_MEMSIZE_1024=n
  - CONFIG_CRYPTO_JITTERENTROPY_MEMSIZE_8192=n
  - CONFIG_CRYPTO_JITTERENTROPY_OSR=1
  - CONFIG_SECONDARY_TRUSTED_KEYRING_SIGNED_BY_BUILTIN=n
  - Library routines
  - CONFIG_LWQ_TEST=n
  - Kernel hacking
  - CONFIG_DEBUG_CLOSURES=n
  - CONFIG_TEST_OBJPOOL=n
  - PCI support
  - CONFIG_PCIEAER_CXL=y
  - NVME Support
  - CONFIG_NVME_TCP_TLS=y
  - CONFIG_NVME_HOST_AUTH=y
  - CONFIG_NVME_TARGET_TCP_TLS=y
  - Network device support
  - CONFIG_NETKIT=y
  - CONFIG_IDPF=m
  - CONFIG_MLX5_DPLL=m
  - CONFIG_MCTP_TRANSPORT_I3C=m
  - CONFIG_MT7925E=m
  - CONFIG_MT7925U=m
  - Hardware Monitoring support
  - CONFIG_SENSORS_POWERZ=m
  - CONFIG_SENSORS_LTC2991=m
  - Multimedia support
  - CONFIG_VIDEO_MGB4=m
  - CONFIG_VIDEO_MT9M114=m
  - Sound card support
  - CONFIG_SND_AMD_ASOC_ACP63=m
  - CONFIG_SND_SOC_INTEL_AVS_MACH_RT5514=m
  - CONFIG_SND_SOC_INTEL_SOF_DA7219_MACH=m
  - CONFIG_SND_SOC_SOF_AMD_ACP63=m
  - CONFIG_SND_SOC_AW87390=n
  - CONFIG_SND_SOC_AW88399=n
  - CONFIG_SND_SOC_RTQ9128=m
  - USB support
  - CONFIG_USB_PCI_AMD=y
  - CONFIG_USB_LJCA=m
  - CONFIG_TYPEC_MUX_PTN36502=m
  - Industrial I/O support
  - CONFIG_LTC2309=n
  - CONFIG_MCP3564=n
  - CONFIG_ROHM_BM1390=n
  - Misc drivers
  - CONFIG_I2C_LJCA=m
  - CONFIG_SPI_LJCA=m
  - CONFIG_GPIO_LJCA=m
  - CONFIG_FUEL_GAUGE_MM8013=m
  - CONFIG_REGULATOR_MAX77503=m
  - CONFIG_LEDS_TRIGGER_GPIO=m
  - CONFIG_XEN_PRIVCMD_EVENTFD=y
  - CONFIG_INSPUR_PLATFORM_PROFILE=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - DRM_PANEL_ILITEK_ILI9882T=n
  - DRM_PANEL_JDI_LPM102A188A=n
  - DRM_PANEL_RAYDIUM_RM692E5=n
  - LEDS_KTD202X=m
  - ppc64le
  - PROBE_EVENTS_BTF_ARGS=y
  - s390x/zfcdump
  - CERT_STORE=y
  - BLK_SED_OPAL=n
  - DNS_RESOLVER=n
  - QUOTA_NETLINK_INTERFACE=n
  - KEYS_REQUEST_CACHE=n
  - PERSISTENT_KEYRINGS=n
  - TRUSTED_KEYS=n
  - ENCRYPTED_KEYS=n
  - KEY_DH_OPERATIONS=n
  - KEY_NOTIFICATIONS=n
  - ASYMMETRIC_KEY_TYPE=n
  - SYSTEM_BLACKLIST_KEYRING=n
  - RAID6_PQ_BENCHMARK=n
  - riscv64
  - ARCH_SOPHGO=y
  - RISCV_MISALIGNED=y
  - SHADOW_CALL_STACK=y
  - PCIE_RCAR_GEN4_HOST=m
  - PCIE_RCAR_GEN4_EP=m
  - SND_SOC_JH7110_PWMDAC=m
  - RUNTIME_KERNEL_TESTING_MENU=n
  - copied from arm64
  - SERIO_AMBAKMI=n
  - SERIAL_AMBA_PL010=y
  - SERIAL_AMBA_PL011=y
  - I2C_NOMADIK=n
  - SPI_PL022=m
  - GPIO_PL061=y
  - MMC_ARMMMCI=m
  - MMC_SDHI_INTERNAL_DMAC=m
  - RTC_DRV_PL030=y
  - RTC_DRV_PL031=y
  - AMBA_PL08X=n
  - PL330_DMA=m
  - ARM_MHU=n
  - ARM_MHU_V2=m
  - PL320_MBOX=n
  - ARM_PL172_MPMC=m
  - SERIAL_AMBA_PL010_CONSOLE=y
  - SERIAL_AMBA_PL011_CONSOLE=y
  - MMC_STM32_SDMMC=y
- commit 6d2026a
* Mon Nov 13 2023 kbuild@suse.de
- Automatically updated to 6.6-next-20231113
- commit 0d0a04d
* Fri Nov 10 2023 jdelvare@suse.de
- Disable Loongson drivers
  Loongson is a mips architecture, I don't think it makes sense to
  build Loongson drivers on other architectures.
- commit 060b1ab
* Fri Nov 10 2023 kbuild@suse.de
- Automatically updated to 6.6-next-20231110
- commit 8147c0b
* Thu Nov  9 2023 kbuild@suse.de
- Automatically updated to 6.6-next-20231109
- commit 027cb1f
* Wed Nov  8 2023 kbuild@suse.de
- Automatically updated to 6.6-next-20231108
- commit 098db35
* Tue Nov  7 2023 kbuild@suse.de
- Automatically updated to 6.6-next-20231107
- commit a9e6433
* Mon Nov  6 2023 kbuild@suse.de
- Automatically updated to 6.6-next-20231106
- commit b53349d
* Fri Nov  3 2023 kbuild@suse.de
- Automatically updated to 6.6-next-20231103
- commit 6b5544a
* Thu Nov  2 2023 kbuild@suse.de
- Automatically updated to 6.6-next-20231102
- commit 0dc9821
* Wed Nov  1 2023 schwab@suse.de
- riscv: enable CONFIG_PCI_HOST_GENERIC
  Needed for the pci host controller emulated by qemu.
- commit b4e99f6
* Wed Nov  1 2023 kbuild@suse.de
- Automatically updated to 6.6-next-20231101
- commit 92b27dc
* Wed Nov  1 2023 jslaby@suse.cz
- Delete patches.rpmify/x86-Let-AS_WRUSS-depend-on-X86_64.patch.
- Update config files.
  This effectively reverts 9ab2e0780c8a2fb9a84db5bad59fbe3ab526a6c3. The
  patch was not accepted upstream:
  https://lore.kernel.org/all/20231031140504.GCZUEJkMPXSrEDh3MA@fat_crate.local/
  Instead, we merged the packaging branch which fixes this in
  rpm/check-for-config-changes instead.
- rpm/check-for-config-changes: add AS_WRUSS to IGNORED_CONFIGS_RE
  Add AS_WRUSS as an IGNORED_CONFIGS_RE entry in check-for-config-changes
  to fix build on x86_32.
  There was a fix submitted to upstream but it was not accepted:
  https://lore.kernel.org/all/20231031140504.GCZUEJkMPXSrEDh3MA@fat_crate.local/
  So carry this in IGNORED_CONFIGS_RE instead.
- commit 629ebac
* Tue Oct 31 2023 petr@tesarici.cz
- config: enable NFS_V4_2_READ_PLUS (bsc#1216736)
  This option was introduced and disabled by default because of unresolved
  issues. As stated in mainline commit 9cf2744d2491 ("NFS: Enable the
  READ_PLUS operation by default") which changes the upstream default to
  enabled, these issues are addressed so that it is safe to enable the
  option and as it allows to transfer sparse files more efficiently, it is
  desirable to do so.
- commit f9c67bc
* Tue Oct 31 2023 kbuild@suse.de
- Automatically updated to 6.6-next-20231031
- commit fbf7ea2
* Tue Oct 31 2023 jslaby@suse.cz
- x86: Let AS_WRUSS depend on X86_64 (i386-build-fix).
- Update config files.
- commit 24d7510
* Mon Oct 30 2023 kbuild@suse.de
- Automatically updated to 6.6-rc7-next-20231030
- commit d6e1399
* Mon Oct 30 2023 msuchanek@suse.de
- kbuild: dummy-tools: Add support for -fpatchable-function-entry (dummy-tools).
  Update config files.
- commit e6acefb
* Mon Oct 30 2023 mkubecek@suse.cz
- Update to 6.6 final
- refresh configs (headers only)
- commit 05807fe
* Sun Oct 29 2023 mkubecek@suse.cz
- update and reenable armv7hl configs
  Where possible, new values are copied from arm64. The rest is guessed,
  mostly based on existing values of similar config options.
- armv7hl specific config options:
  - TI_ICSS_IEP=m
- commit 90db8ed
* Fri Oct 27 2023 kbuild@suse.de
- Automatically updated to 6.6-rc7-next-20231027
- commit 4835238
* Thu Oct 26 2023 kbuild@suse.de
- Automatically updated to 6.6-rc7-next-20231026
- commit e491a3b
* Tue Oct 24 2023 kbuild@suse.de
- Automatically updated to 6.6-rc7-next-20231024
- commit 3020ece
* Mon Oct 23 2023 kbuild@suse.de
- Automatically updated to 6.6-rc6-next-20231023
- commit 192aad6
* Mon Oct 23 2023 mkubecek@suse.cz
- Update to 6.6-rc7
- refresh configs
- commit 71b3fe8
* Fri Oct 20 2023 dmueller@suse.com
- config.conf: Reenable arm64
- Update config files:
  * Same settings like x86_64, plus all ARM specific errata turned on
  * rest all mod
- commit 105a42a
* Fri Oct 20 2023 kbuild@suse.de
- Automatically updated to 6.6-rc6-next-20231020
- commit 8263e77
* Thu Oct 19 2023 kbuild@suse.de
- Automatically updated to 6.6-rc6-next-20231019
- commit 962f76e
* Thu Oct 19 2023 mbrugger@suse.com
- arm64: Update config files.
  Make iMX93 clock and pinctrl driver build-in.
- commit cd18ec4
* Sun Oct 15 2023 mkubecek@suse.cz
- Update to 6.6-rc6
- refresh configs
- commit 7cb9195
* Sat Oct 14 2023 matwey.kornilov@gmail.com
- config: Reenable Rockchip RK8XX hardware
  In Linux commit
    c20e8c5b1203 ("mfd: rk808: Split into core and i2c")
  CONFIG_MFD_RK808 was renamed to CONFIG_MFD_RK8XX.
  Reenable options required to boot kernel 6.5 on Rock64 board.
- commit d3a79a6
* Tue Oct 10 2023 kbuild@suse.de
- Automatically updated to 6.6-rc5-next-20231010
- commit 114e13e
* Mon Oct  9 2023 svarbanov@suse.de
- config/arm64: Unset default IOMMU passthrough option (jsc#PED-7009)
  This will effectively enable ARM64 SMMU translation by default,
  which will help to avoid installation and runtime issues on some
  platforms. The passtrhough mode could still be enabled by kernel
  cmdline.
- commit 45dd510
* Mon Oct  9 2023 schwab@suse.de
- mkspec-dtb: add toplevel symlinks also on arm
- commit ed29cae
* Mon Oct  9 2023 kbuild@suse.de
- Automatically updated to 6.6-rc5-next-20231009
- commit 4059809
* Sun Oct  8 2023 mkubecek@suse.cz
- Update to 6.6-rc5
- update configs
  - IMA_BLACKLIST_KEYRING=n
  - IMA_LOAD_X509=n
  - IPU_BRIDGE=m (new on riscv64)
- commit 013a39f
* Sat Oct  7 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Convert the document to Markdown
  (jsc#PED-5021)
- commit c05cfc9
* Sat Oct  7 2023 petr.pavlu@suse.com
- doc/README.SUSE: Convert the document to Markdown (jsc#PED-5021)
- commit bff5e3e
* Fri Oct  6 2023 kbuild@suse.de
- Automatically updated to 6.6-rc4-next-20231006
- commit 9b26368
* Thu Oct  5 2023 kbuild@suse.de
- Automatically updated to 6.6-rc4-next-20231005
- commit 1ddaa7a
* Wed Oct  4 2023 kbuild@suse.de
- Automatically updated to 6.6-rc4-next-20231004
- commit e042f73
* Tue Oct  3 2023 kbuild@suse.de
- Automatically updated to 6.6-rc4-next-20231003
- commit 38c5516
* Tue Oct  3 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Remove the list of links (jsc#PED-5021)
  All links have been incorporated into the text. Remove now unnecessary
  list at the end of the document.
- commit 43d62b1
* Tue Oct  3 2023 petr.pavlu@suse.com
- doc/README.SUSE: Adjust heading style (jsc#PED-5021)
  * Underscore all headings as a preparation for Markdown conversion.
  * Use title-style capitalization for the document name and
  sentence-style capitalization for section headings, as recommended in
  the current SUSE Documentation Style Guide.
- commit 11e3267
* Fri Sep 29 2023 kbuild@suse.de
- Automatically updated to 6.6-rc3-next-20230929
- commit bb80882
* Thu Sep 28 2023 kbuild@suse.de
- Automatically updated to 6.6-rc3-next-20230928
- commit f0ea608
* Wed Sep 27 2023 kbuild@suse.de
- Automatically updated to 6.6-rc3-next-20230927
- commit 8a96640
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Reflow text to 80-column width
  (jsc#PED-5021)
- commit be0158c
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Update information about the tools
  (jsc#PED-5021)
  * Replace bugzilla.novell.com with bugzilla.suse.com and FATE with Jira.
  * Limit the range of commits in the exportpatch example to prevent it
  from running for too long.
  * Incorporate URLs directly into the text.
  * Fix typos and improve some wording, in particular avoid use of "there
  is/are" and prefer the present tense over the future one.
- commit c0bea0c
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Update information about the patch
  format (jsc#PED-5021)
  * Replace bugzilla.novell.com with bugzilla.suse.com and FATE with Jira.
  * Remove references to links to the patchtools and kernel source. They
  are incorporated in other parts of the text.
  * Use sentence-style capitalization for section headings, as recommended
  in the current SUSE Documentation Style Guide.
  * Fix typos and some wording, in particular avoid use of "there is/are".
- commit ce98345
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Update the summary and background
  (jsc#PED-5021)
  * Drop information about patches being split into directories per
  a subsystem because that is no longer the case.
  * Remove the mention that the expanded tree is present since SLE11-SP2
  as that is now only a historical detail.
  * Incorporate URLs and additional information in parenthenses directly
  into the text.
  * Fix typos and improve some wording.
- commit 640988f
* Tue Sep 26 2023 kbuild@suse.de
- Automatically updated to 6.6-rc3-next-20230926
- commit a45c542
* Mon Sep 25 2023 msuchanek@suse.de
- kernel-binary: Move build-time definitions together
  Move source list and build architecture to buildrequires to aid in
  future reorganization of the spec template.
- commit 30e2cef
* Mon Sep 25 2023 kbuild@suse.de
- Automatically updated to 6.6-rc3-next-20230925
- commit 66dcd76
* Thu Sep 21 2023 kbuild@suse.de
- Automatically updated to 6.6-rc2-next-20230921
- commit 7708990
* Wed Sep 20 2023 msuchanek@suse.de
- kernel-binary: python3 is needed for build
  At least scripts/bpf_helpers_doc.py requires python3 since Linux 4.18
  Other simimlar scripts may exist.
- commit c882efa
* Wed Sep 20 2023 kbuild@suse.de
- Automatically updated to 6.6-rc2-next-20230920
- commit 1c112c7
* Tue Sep 19 2023 kbuild@suse.de
- Automatically updated to 6.6-rc2-next-20230919
- commit 11bd049
* Tue Sep 19 2023 schwab@suse.de
- riscv: enable CONFIG_MEDIA_PLATFORM_SUPPORT
  - MEDIA_PLATFORM_SUPPORT=y
  - V4L2_H264=m
  - V4L2_VP9=m
  - MEDIA_PLATFORM_DRIVERS=y
  - V4L_PLATFORM_DRIVERS=y
  - SDR_PLATFORM_DRIVERS=y
  - DVB_PLATFORM_DRIVERS=y
  - V4L_MEM2MEM_DRIVERS=y
  - VIDEO_MEM2MEM_DEINTERLACE=m
  - VIDEO_MUX=m
  - VIDEO_CADENCE_CSI2RX=m
  - VIDEO_CADENCE_CSI2TX=m
  - VIDEO_CAFE_CCIC=m
  - VIDEO_RCAR_ISP=m
  - VIDEO_RCAR_CSI2=m
  - VIDEO_RCAR_VIN=m
  - VIDEO_RZG2L_CSI2=m
  - VIDEO_RZG2L_CRU=m
  - VIDEO_RENESAS_FCP=m
  - VIDEO_RENESAS_FDP1=m
  - VIDEO_RENESAS_JPU=m
  - VIDEO_RENESAS_VSP1=m
  - VIDEO_RCAR_DRIF=m
  - VIDEO_SUN4I_CSI=m
  - VIDEO_SUN6I_CSI=m
  - VIDEO_SUN6I_MIPI_CSI2=m
  - VIDEO_SUN8I_A83T_MIPI_CSI2=m
  - VIDEO_SUN8I_DEINTERLACE=m
  - VIDEO_SUN8I_ROTATE=m
  - VIDEO_HANTRO=m
  - VIDEO_HANTRO_SUNXI=y
  - VIDEO_XILINX=m
  - VIDEO_XILINX_CSI2RXSS=m
  - VIDEO_XILINX_TPG=m
  - VIDEO_XILINX_VTC=m
  - SMS_SDIO_DRV=m
  - SMS_SIANO_DEBUGFS=n
  - VIDEO_SUN6I_ISP=m
- commit 3c603d0
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Reflow text to 80-column width (jsc#PED-5021)
- commit e8f2c67
* Mon Sep 18 2023 tiwai@suse.de
- Update config files: make SCSI/ATA drivers modules again
  As discussed on opensuse-kernel ML, we want to make SCSI and ATA
  drivers from built-in back to modules again:
  https://lists.opensuse.org/archives/list/kernel@lists.opensuse.org/thread/MLRQW7RFEAKTAP63NMPFFIYTXAF7E3I3/
  They were made as built-in many many years ago just for boot speed up
  and a slight hope of initrd-less systems.  But it makes more sense to
  align with the SLE configurations.
- commit ecc073b
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Minor content clean up (jsc#PED-5021)
  * Mark the user's build directory as a variable, not a command:
  'make -C $(your_build_dir)' -> 'make -C $YOUR_BUILD_DIR'.
  * Unify how to get the current directory: 'M=$(pwd)' -> 'M=$PWD'.
  * 'GIT' / 'git' -> 'Git'.
- commit 1cb4ec8
* Mon Sep 18 2023 kbuild@suse.de
- Automatically updated to 6.6-rc2-next-20230918
- commit dbeb4da
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about module paths
  (jsc#PED-5021)
  * Use version variables to describe names of the
  /lib/modules/$VERSION-$RELEASE-$FLAVOR/... directories
  instead of using specific example versions which get outdated quickly.
  * Note: Keep the /lib/modules/ prefix instead of using the new
  /usr/lib/modules/ location for now. The updated README is expected to
  be incorporated to various branches that are not yet usrmerged.
- commit 7eba2f0
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about custom patches
  (jsc#PED-5021)
  * Replace mention of various patches.* directories with only
  patches.suse as the typical location for patches.
  * Replace i386 with x86_64 in the example how to define a config addon.
  * Fix some typos and wording.
- commit 2997d22
* Mon Sep 18 2023 mkubecek@suse.cz
- Update to 6.6-rc2
- eliminate 1 patch
  - patches.rpmify/kbuild-avoid-long-argument-lists-in-make-modules_ins.patch
- refresh configs
- commit 2de1286
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about config files
  (jsc#PED-5021)
  * Use version variables to describe a name of the /boot/config-... file
  instead of using specific example versions which get outdated quickly.
  * Replace removed silentoldconfig with oldconfig.
  * Mention that oldconfig can automatically pick a base config from
  "/boot/config-$(uname -r)".
  * Avoid writing additional details in parentheses, incorporate them
  instead properly in the text.
- commit cba5807
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update the patch selection section
  (jsc#PED-5021)
  * Make the steps how to obtain expanded kernel source more generic in
  regards to version numbers.
  * Use '#' instead of '$' as the command line indicator to signal that
  the steps need to be run as root.
  * Update the format of linux-$SRCVERSION.tar.bz2 to xz.
  * Improve some wording.
- commit e14852c
* Fri Sep 15 2023 kbuild@suse.de
- Automatically updated to 6.6-rc1-next-20230915
- commit 954a6c6
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about (un)supported modules
  (jsc#PED-5021)
  * Update the list of taint flags. Convert it to a table that matches the
  upstream documentation format and describe specifically flags that are
  related to module support status.
  * Fix some typos and wording.
- commit e46f0df
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Bring information about compiling up to date
  (jsc#PED-5021)
  * When building the kernel, don't mention to initially change the
  current directory to /usr/src/linux because later description
  discourages it and specifies to use 'make -C /usr/src/linux'.
  * Avoid writing additional details in parentheses, incorporate them
  instead properly in the text.
  * Fix the obsolete name of /etc/modprobe.d/unsupported-modules ->
  /etc/modprobe.d/10-unsupported-modules.conf.
  * Drop a note that a newly built kernel should be added to the boot
  manager because that normally happens automatically when running
  'make install'.
  * Update a link to the Kernel Module Packages Manual.
  * When preparing a build for external modules, mention use of the
  upstream recommended 'make modules_prepare' instead of a pair of
  'make prepare' + 'make scripts'.
  * Fix some typos+grammar.
- commit b9b7e79
* Thu Sep 14 2023 kbuild@suse.de
- Automatically updated to 6.6-rc1-next-20230914
- commit a928949
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Bring the overview section up to date
  (jsc#PED-5021)
  * Update information in the overview section that was no longer
  accurate.
  * Improve wording and fix some typos+grammar.
- commit 798c075
* Wed Sep 13 2023 jslaby@suse.cz
- sysctl/defaults: increase vm.max_map_count (bsc#1214445)
- commit 212337f
* Wed Sep 13 2023 kbuild@suse.de
- Automatically updated to 6.6-rc1-next-20230913
- commit 9e8f5df
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update the references list (jsc#PED-5021)
  * Remove the reference to Linux Documentation Project. It has been
  inactive for years and mostly contains old manuals that aren't
  relevant for contemporary systems and hardware.
  * Update the name and link to LWN.net. The original name "Linux Weekly
  News" has been deemphasized over time by its authors.
  * Update the link to Kernel newbies website.
  * Update the reference to The Linux Kernel Module Programming Guide. The
  document has not been updated for over a decade but it looks its
  content is still relevant for today.
  * Point Kernel Module Packages Manual to the current version.
  * Add a reference to SUSE SolidDriver Program.
- commit 0edac75
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update title information (jsc#PED-5021)
  * Drop the mention of kernel versions from the readme title.
  * Remove information about the original authors of the document. Rely as
  in case of other readmes on Git metadata to get information about all
  contributions.
  * Strip the table of contents. The document is short and easy to
  navigate just by scrolling through it.
- commit 06f5139
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about DUD (jsc#PED-5021)
  Remove a dead link to description of Device Update Disks found
  previously on novell.com. Replace it with a short section summarizing
  what DUD is and reference the mkdud + mksusecd tools and their
  documentation for more information.
- commit 7eeba4e
* Wed Sep 13 2023 jslaby@suse.cz
- config.conf: Drop ppc64 (BE)
- Delete config/ppc64/debug.
- Delete config/ppc64/default.
- Delete config/ppc64/kvmsmall.
- Delete config/ppc64/vanilla.
  The ppc64 builds are being stopped in OBS. Stop producing the big endian
  kernel too.
  See also:
  https://build.opensuse.org/request/show/1110638
  https://lists.opensuse.org/archives/list/factory@lists.opensuse.org/message/G6IJ4GAEHXL23FYDPZ4J6ML4Z2WY7ARF/
  https://lists.opensuse.org/archives/list/factory@lists.opensuse.org/message/SELOVYRDN5ZDDQ2EN7CXNS7BH33XACLU/
- commit 6a654e6
* Wed Sep 13 2023 clin@suse.com
- Update config files: add QSEECOM support for Lenovo X13s (bsc#1215268)
- commit 6557648
* Tue Sep 12 2023 tiwai@suse.de
- Update config files: enable audio on Lenovo X13s (bsc#1215256)
  Enable CONFIG_SND_SOC_LPASS_*_MACRO for arm64.
- commit 34d220f
* Tue Sep 12 2023 kbuild@suse.de
- Automatically updated to 6.6-rc1-next-20230912
- commit 31d8ab2
* Tue Sep 12 2023 petr.pavlu@suse.com
- rpm/kernel-binary.spec.in: Drop use of KBUILD_OVERRIDE=1
  Genksyms has functionality to specify an override for each type in
  a symtypes reference file. This override is then used instead of an
  actual type and allows to preserve modversions (CRCs) of symbols that
  reference the type. It is kind of an alternative to doing kABI fix-ups
  with '#ifndef __GENKSYMS__'. The functionality is hidden behind the
  genksyms --preserve option which primarily tells the tool to strictly
  verify modversions against a given reference file or fail.
  Downstream patch patches.suse/genksyms-add-override-flag.diff which is
  present in various kernel-source branches separates the override logic.
  It allows it to be enabled with a new --override flag and used without
  specifying the --preserve option. Setting KBUILD_OVERRIDE=1 in the spec
  file is then a way how the build is told that --override should be
  passed to all invocations of genksyms. This was needed for SUSE kernels
  because their build doesn't use --preserve but instead resulting CRCs
  are later checked by scripts/kabi.pl.
  However, this override functionality was not utilized much in practice
  and the only use currently to be found is in SLE11-SP1-LTSS. It means
  that no one should miss this option and KBUILD_OVERRIDE=1 together with
  patches.suse/genksyms-add-override-flag.diff can be removed.
  Notes for maintainers merging this commit to their branches:
  * Downstream patch patches.suse/genksyms-add-override-flag.diff can be
  dropped after merging this commit.
  * Branch SLE11-SP1-LTSS uses the mentioned override functionality and
  this commit should not be merged to it, or needs to be reverted
  afterwards.
- commit 4aa02b8
* Mon Sep 11 2023 mkubecek@suse.cz
- Update to 6.6-rc1
- drop 47 patches (44 stable, 3 mainline)
  - patches.kernel.org/*
  - patches.rpmify/Revert-kbuild-Hack-for-depmod-not-handling-X.Y-versi.patch
  - patches.rpmify/kbuild-dummy-tools-support-make-MPROFILE_KERNEL-chec.patch
  - patches.suse/wifi-rtw89-Fix-loading-of-compressed-firmware.patch
- refresh
  - patches.suse/0001-bsc-1204315-Disable-sysfb-before-creating-simple-fra.patch
  - patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/wifi-ath11k-add-support-for-suspend-in-power-down-st.patch
- add build failure fix
  - patches.rpmify/kbuild-avoid-long-argument-lists-in-make-modules_ins.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - CRASH_HOTPLUG=y
  - CRASH_MAX_MEMORY_RANGES=8192
  - Processor type and features
  - X86_USER_SHADOW_STACK=n
  - Virtualization
  - KVM_PROVE_MMU=n
  - Memory Management options
  - RANDOM_KMALLOC_CACHES=n
  - File systems
  - OVERLAY_FS_DEBUG=n
  - TMPFS_QUOTA=y
  - EROFS_FS_ZIP_DEFLATE=y
  - Security options
  - SECURITY_SELINUX_DEBUG=n
  - LIST_HARDENED=n
  - Library routines
  - SWIOTLB_DYNAMIC=n
  - DMA_NUMA_CMA=y
  - Multiple devices driver support (RAID and LVM)
  - MD_BITMAP_FILE=y
  - Network device support
  - NETCONSOLE_EXTENDED_LOG=n
  - MLX5_MACSEC=y
  - MARVELL_88Q2XXX_PHY=m
  - Hardware Monitoring support
  - SENSORS_HS3001=m
  - SENSORS_MP2975_REGULATOR=y
  - Multifunction device drivers
  - MFD_CS42L43_I2C=m
  - MFD_CS42L43_SDW=m
  - Voltage and Current Regulator Support
  - REGULATOR_AW37503=m
  - REGULATOR_MAX77857=m
  - REGULATOR_RTQ2208=m
  - Multimedia support
  - INTEL_VSC=m
  - VIDEO_CAMERA_SENSOR=y
  - VIDEO_DW9719=m
  - Graphics support
  - DRM_LOONGSON=m
  - FB_DEVICE=y
  - Sound card support
  - SND_HDA_SCODEC_CS35L56_I2C=m
  - SND_HDA_SCODEC_CS35L56_SPI=m
  - SND_HDA_SCODEC_TAS2781_I2C=m
  - SND_SOC_INTEL_AVS_MACH_ES8336=m
  - SND_SOC_INTEL_AVS_MACH_RT5663=m
  - SND_SOC_SOF_AMD_VANGOGH=m
  - SND_SOC_SOF_LUNARLAKE=m
  - SND_SOC_AUDIO_IIO_AUX=n
  - SND_SOC_AW88261=n
  - SND_SOC_CS42L43=m
  - SND_SOC_CS42L43_SDW=m
  - SND_SOC_RT1017_SDCA_SDW=m
  - LED Support
  - LEDS_PCA995X=m
  - LEDS_SIEMENS_SIMATIC_IPC_ELKHARTLAKE=m
  - X86 Platform Specific Device Drivers
  - HP_BIOSCFG=m
  - SIEMENS_SIMATIC_IPC_BATT=m
  - SIEMENS_SIMATIC_IPC_BATT_APOLLOLAKE=m
  - SIEMENS_SIMATIC_IPC_BATT_ELKHARTLAKE=m
  - SIEMENS_SIMATIC_IPC_BATT_F7188X=m
  - SEL3350_PLATFORM=m
  - Industrial I/O support
  - MCP4728=n
  - IRSD200=n
  - PHY Subsystem
  - PHY_RTK_RTD_USB2PHY=m
  - PHY_RTK_RTD_USB3PHY=m
  - Counter support
  - 104_QUAD_8=m
  - INTEL_QEP=m
  - INTERRUPT_CNT=m
  - Misc drivers
  - TOUCHSCREEN_IQS7211=m
  - I2C_ATR=m
  - SPI_CS42L43=n
  - PTP_1588_CLOCK_MOCK=m
  - PINCTRL_CS42L43=m
  - GPIO_DS4520=m
  - HID_GOOGLE_STADIA_FF=m
  - USB_CONFIGFS_F_MIDI2=y
  - XILINX_DMA=m
  - PDS_VFIO_PCI=m
  - XEN_PRIVCMD_IRQFD=y
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - PCI_DYNAMIC_OF_NODES=y
  - REGULATOR_MAX5970=m
  - VIDEO_DS90UB913=m
  - VIDEO_DS90UB953=m
  - VIDEO_DS90UB960=m
  - DRM_PANEL_STARTEK_KD070FHFID015=n
  - DRM_PANEL_VISIONOX_R66451=n
  - LEDS_GROUP_MULTICOLOR=m
  - COMMON_CLK_VC3=m
  - ppc64 / ppc64le
  - FSI_MASTER_I2CR=n
  - INTEGRITY_MACHINE_KEYRING=y
  - ppc64le
  - CRYPTO_CHACHA20_P10=m
  - CRYPTO_POLY1305_P10=m
  - s390x
  - CERT_STORE=y
  - S390_HYPFS=y
  - FUNCTION_GRAPH_RETVAL=y
  - riscv64
  - PREEMPT_DYNAMIC=y
  - RANDOMIZE_BASE=y
  - RISCV_ISA_FALLBACK=y
  - CFI_CLANG=n
  - CAN_SUN4I=m
  - CEC_GPIO=m
  - CLK_STARFIVE_JH7110_STG=m
  - SUN20I_GPADC=n
  - PHY_STARFIVE_JH7110_DPHY_RX=m
  - PHY_STARFIVE_JH7110_PCIE=m
  - PHY_STARFIVE_JH7110_USB=m
  - DEBUG_FORCE_FUNCTION_ALIGN_64B=n
  - DEBUG_PREEMPT=n
  - PREEMPT_TRACER=n
  - CEC_PIN_ERROR_INJ=n
- commit f503b6c
* Mon Sep 11 2023 kbuild@suse.de
- Automatically updated to 6.6-rc1-next-20230911
- commit 5b8bcdd
* Fri Sep  8 2023 kbuild@suse.de
- Automatically updated to 6.5-next-20230908
- commit c1ec635
* Thu Sep  7 2023 kbuild@suse.de
- Automatically updated to 6.5-next-20230907
- commit 72812f8
* Wed Sep  6 2023 kbuild@suse.de
- Automatically updated to 6.5-next-20230906
- commit 87aa9f3
* Wed Sep  6 2023 mkubecek@suse.cz
- config: refresh
- commit f53c1ca
* Tue Sep  5 2023 msuchanek@suse.de
- Update config files.
  IPR is powerpc-only driver, disable on other architectures.
- commit bda4755
* Tue Sep  5 2023 kbuild@suse.de
- Automatically updated to 6.5-next-20230905
- commit a5666c8
* Thu Aug 31 2023 kbuild@suse.de
- Automatically updated to 6.5-next-20230831
- commit 4ac22b6
* Thu Aug 31 2023 tiwai@suse.de
- firmware: qemu_fw_cfg: Do not hard depend on
  CONFIG_HAS_IOPORT_MAP (bsc#1214773).
- Update config files: enable CONFIG_FW_CFG_SYSFS for armv7hl
- commit bcf4d8e
* Wed Aug 30 2023 kbuild@suse.de
- Automatically updated to 6.5-next-20230830
- commit 87f3d46
* Wed Aug 30 2023 jslaby@suse.cz
- rpm/mkspec-dtb: dtbs have moved to vendor sub-directories in 6.5
  By commit 724ba6751532 ("ARM: dts: Move .dts files to vendor
  sub-directories").
  So switch to them.
- rpm/mkspec-dtb: support for nested subdirs
  Commit 724ba6751532 ("ARM: dts: Move .dts files to vendor
  sub-directories") moved the dts to nested subdirs, add a support for
  that. That is, generate a %%dir entry in %%files for them.
- commit 7aee36a
* Tue Aug 29 2023 jslaby@suse.cz
- kbuild: dummy-tools: support make MPROFILE_KERNEL checks work
  on BE (ppc64-build-fix).
- Update config files.
  Fix ppc64 build and update configs accordingly (values taken from
  ppc64le).
- commit c54cff9
* Tue Aug 29 2023 kbuild@suse.de
- Automatically updated to 6.5-next-20230829
- commit 879c38d
* Tue Aug 29 2023 mkubecek@suse.cz
- config: refresh
- commit 181c2d1
* Mon Aug 28 2023 kbuild@suse.de
- Automatically updated to 6.5-next-20230828
- commit 23bfff1
* Mon Aug 28 2023 mkubecek@suse.cz
- Update to 6.5 final
- refresh configs (headers only)
- commit bc94c6f
* Fri Aug 25 2023 kbuild@suse.de
- Automatically updated to 6.5-rc7-next-20230825
- commit 0bd79a1
* Thu Aug 24 2023 msuchanek@suse.de
- Update ppc64 config
  - CONFIG_COMPAT_32BIT_TIME=n
  - CONFIG_IMA_ARCH_POLICY=y
  - CONFIG_IMA_DISABLE_HTABLE=y
  - CONFIG_IMA_KEXEC=y
  - CONFIG_IMA_KEYRINGS_PERMIT_SIGNED_BY_BUILTIN_OR_SECONDARY=y
  - CONFIG_LOAD_PPC_KEYS=y
  - CONFIG_PPC_SECURE_BOOT=y
  - CONFIG_PPC_SECVAR_SYSFS=y
- commit 7070ed5
* Thu Aug 24 2023 kbuild@suse.de
- Automatically updated to 6.5-rc7-next-20230824
- commit 72c74e0
* Wed Aug 23 2023 kbuild@suse.de
- Automatically updated to 6.5-rc7-next-20230823
- commit eaf4cba
* Wed Aug 23 2023 msuchanek@suse.de
- old-flavors: Drop 2.6 kernels.
  2.6 based kernels are EOL, upgrading from them is no longer suported.
- commit 7bb5087
* Tue Aug 22 2023 kbuild@suse.de
- Automatically updated to 6.5-rc7-next-20230822
- commit 6e51176
* Mon Aug 21 2023 kbuild@suse.de
- Automatically updated to 6.5-rc7-next-20230821
- commit a1dd4c6
* Fri Aug 18 2023 msuchanek@suse.de
- mkspec: Allow unsupported KMPs (bsc#1214386)
- commit 55d8b82
* Fri Aug 18 2023 kbuild@suse.de
- Automatically updated to 6.5-rc6-next-20230818
- commit f9b19a5
* Fri Aug 18 2023 msuchanek@suse.de
- check-for-config-changes: ignore BUILTIN_RETURN_ADDRESS_STRIPS_PAC (bsc#1214380).
  gcc7 on SLE 15 does not support this while later gcc does.
- commit 5b41c27
* Thu Aug 17 2023 kbuild@suse.de
- Automatically updated to 6.5-rc6-next-20230817
- commit 5206fba
* Wed Aug 16 2023 msuchanek@suse.de
- kernel-binary: Common dependencies cleanup
  Common dependencies are copied to a subpackage, there is no need for
  copying defines or build dependencies there.
- commit 254b03c
* Wed Aug 16 2023 msuchanek@suse.de
- kernel-binary: Drop code for kerntypes support
  Kerntypes was a SUSE-specific feature dropped before SLE 12.
- commit 2c37773
* Wed Aug 16 2023 kbuild@suse.de
- Automatically updated to 6.5-rc6-next-20230816
- commit e940ffa
* Sun Aug 13 2023 mkubecek@suse.cz
- Update to 6.5-rc6
- update configs
  - x86
  - GDS_FORCE_MITIGATION=n
  - x86_64
  - CPU_SRSO=y
- commit c512b99
* Wed Aug  9 2023 kbuild@suse.de
- Automatically updated to 6.5-rc5-next-20230809
- commit 046d1a5
* Tue Aug  8 2023 kbuild@suse.de
- Automatically updated to 6.5-rc5-next-20230808
- commit f53e9ef
* Mon Aug  7 2023 kbuild@suse.de
- Automatically updated to 6.5-rc5-next-20230807
- commit 0d8b6d3
* Fri Aug  4 2023 kbuild@suse.de
- Automatically updated to 6.5-rc4-next-20230804
- commit 2d41708
* Thu Aug  3 2023 kbuild@suse.de
- Automatically updated to 6.5-rc4-next-20230803
- commit 0444aa1
* Wed Aug  2 2023 kbuild@suse.de
- Automatically updated to 6.5-rc4-next-20230802
- commit d62a4e3
* Tue Aug  1 2023 kbuild@suse.de
- Automatically updated to 6.5-rc4-next-20230801
- commit 9d43875
* Mon Jul 31 2023 kbuild@suse.de
- Automatically updated to 6.5-rc4-next-20230731
- commit 31c3521
* Sun Jul 30 2023 mkubecek@suse.cz
- Update to 6.5-rc4
- refresh configs
- commit b4ee2f3
* Fri Jul 28 2023 kbuild@suse.de
- Automatically updated to 6.5-rc3-next-20230728
- commit e719dc4
* Fri Jul 28 2023 msuchanek@suse.de
- kernel-binary.spec.in: Remove superfluous %%%% in Supplements
  Fixes: 02b7735e0caf ("rpm/kernel-binary.spec.in: Add Enhances and Supplements tags to in-tree KMPs")
- commit 264db74
* Thu Jul 27 2023 kbuild@suse.de
- Automatically updated to 6.5-rc3-next-20230727
- commit 9f6f2c5
* Wed Jul 26 2023 kbuild@suse.de
- Automatically updated to 6.5-rc3-next-20230726
- commit ae206de
* Tue Jul 25 2023 msuchanek@suse.de
- Restore patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch
- commit 7e99105
* Tue Jul 25 2023 kbuild@suse.de
- Automatically updated to 6.5-rc3-next-20230725
- commit 0ddd724
* Mon Jul 24 2023 jslaby@suse.cz
- Update config files. (bsc#1213592)
  Disable old unmaintained serial drivers
- commit e292c9e
* Mon Jul 24 2023 kbuild@suse.de
- Automatically updated to 6.5-rc3-next-20230724
- commit 5a87315
* Sun Jul 23 2023 schwab@suse.de
- rpm/mkspec-dtb: add riscv64 dtb-allwinner subpackage
- commit ec82ffc
* Fri Jul 21 2023 kbuild@suse.de
- Automatically updated to 6.5-rc2-next-20230721
- commit 440b93d
* Thu Jul 20 2023 kbuild@suse.de
- Automatically updated to 6.5-rc2-next-20230720
- commit 94e9384
* Wed Jul 19 2023 kbuild@suse.de
- Automatically updated to 6.5-rc2-next-20230719
- commit 753fee0
* Tue Jul 18 2023 kbuild@suse.de
- Automatically updated to 6.5-rc2-next-20230718
- commit d68e5e7
* Mon Jul 17 2023 msuchanek@suse.de
- Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch.
  Update to match current kmod (bsc#1212835).
- rpm: Update dependency to match current kmod.
- commit 31e00b1
* Mon Jul 17 2023 kbuild@suse.de
- Automatically updated to 6.5-rc1-next-20230717
- commit 272f71a
* Fri Jul 14 2023 kbuild@suse.de
- Automatically updated to 6.5-rc1-next-20230714
- commit 163826a
* Thu Jul 13 2023 kbuild@suse.de
- Automatically updated to 6.5-rc1-next-20230713
- commit c57b996
* Wed Jul 12 2023 kbuild@suse.de
- Automatically updated to 6.5-rc1-next-20230712
- commit 197365e
* Tue Jul 11 2023 kbuild@suse.de
- Automatically updated to 6.5-rc1-next-20230711
- commit 94fcb9f
* Mon Jul 10 2023 schwab@suse.de
- rpm/check-for-config-changes: ignore also RISCV_ISA_* and DYNAMIC_SIGFRAME
  They depend on CONFIG_TOOLCHAIN_HAS_*.
- commit 1007103
* Mon Jul 10 2023 kbuild@suse.de
- Automatically updated to 6.5-rc1-next-20230710
- commit 5bf4acc
* Mon Jul 10 2023 mkubecek@suse.cz
- refresh vanilla configs
- commit 86f687d
* Mon Jul 10 2023 jslaby@suse.cz
- Delete
  patches.suse/Revert-x86-mm-try-VMA-lock-based-page-fault-handling.patch.
- Update config files.
  It was fixed in 6.5-rc1 by commits:
  fb49c455 fork: lock VMAs of the parent process when forking
  2b4f3b49 fork: lock VMAs of the parent process when forking
  1c7873e3 mm: lock newly mapped VMA with corrected ordering
  33313a74 mm: lock newly mapped VMA which can be modified after it becomes visible
  c137381f mm: lock a vma before stack expansion
  So drop the downstream revert and reset the configs -- leave STATS off
  as per default.
- commit 6982ac9
* Mon Jul 10 2023 mkubecek@suse.cz
- Update to 6.5-rc1
- drop 34 patches (33 stable, 1 mainline)
  - patches.kernel.org/*
  - patches.suse/HID-microsoft-Add-rumble-support-to-latest-xbox-cont.patch
- refresh
  - patches.suse/0003-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mode.patch
  - patches.suse/0004-efi-Lock-down-the-kernel-at-the-integrity-level-if-b.patch
  - patches.suse/HID-microsoft-Add-rumble-support-to-latest-xbox-cont.patch
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- add build failure fix
  - patches.rpmify/objtool-initialize-all-of-struct-elf.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - CACHESTAT_SYSCALL=y
  - Power management and ACPI options
  - X86_AMD_PSTATE_DEFAULT_MODE=3
  - Memory Management options
  - ZSWAP_EXCLUSIVE_LOADS_DEFAULT_ON=n
  - SLAB_DEPRECATED=n
  - Cryptographic API
  - CRYPTO_JITTERENTROPY_TESTINTERFACE=n
  - Kernel hacking
  - HARDLOCKUP_DETECTOR_PREFER_BUDDY=n
  - WQ_CPU_INTENSIVE_REPORT=n
  - FUNCTION_GRAPH_RETVAL=y
  - FPROBE_EVENTS=y
  - PROBE_EVENTS_BTF_ARGS=y
  - PCI support
  - PCI_EPF_MHI=m
  - CXL_PMU=m
  - Misc devices
  - INTEL_MEI_GSC_PROXY=m
  - TPS6594_ESM=m
  - TPS6594_PFSM=m
  - Network device support
  - CAN_F81604=m
  - PPPOE_HASH_BITS_1=n
  - PPPOE_HASH_BITS_2=n
  - PPPOE_HASH_BITS_4=y
  - PPPOE_HASH_BITS_8=n
  - RTW88_8723DS=m
  - RTW89_8851BE=m
  - Hardware Monitoring support
  - MAX31827=m
  - SENSORS_HP_WMI=m
  - Multifunction device drivers
  - MFD_MAX77541=n
  - MFD_TPS6594_I2C=m
  - MFD_TPS6594_SPI=m
  - Sound card support
  - SND_SEQ_UMP=y
  - SND_UMP_LEGACY_RAWMIDI=y
  - SND_PCMTEST=m
  - SND_USB_AUDIO_MIDI_V2=y
  - SND_SOC_CHV3_I2S=m
  - SND_SOC_CHV3_CODEC=m
  - SND_SOC_MAX98388=m
  - SND_SOC_RT722_SDCA_SDW=m
  - SND_SOC_TAS2781_I2C=n
  - SND_SOC_WSA884X=n
  - HID bus support
  - HID_NVIDIA_SHIELD=m
  - NVIDIA_SHIELD_FF=y
  - USB support
  - USB_CDNS2_UDC=m
  - TYPEC_MUX_NB7VPQ904M=m
  - LED Support
  - LEDS_AW200XX=m
  - LEDS_CHT_WCOVE=m
  - LEDS_SIEMENS_SIMATIC_IPC_APOLLOLAKE=m
  - LEDS_SIEMENS_SIMATIC_IPC_F7188X=m
  - X86 Platform Specific Device Drivers
  - YOGABOOK=m
  - AMD_PMF_DEBUG=n
  - Industrial I/O support
  - ROHM_BU27008=m
  - OPT4001=n
  - X9250=m
  - MPRLS0025PA=n
  - Misc devices
  - INTEL_MEI_GSC_PROXY=m
  - TPS6594_ESM=m
  - TPS6594_PFSM=m
  - THERMAL_DEFAULT_GOV_BANG_BANG=n
  - REGULATOR_RAA215300=m
  - VIDEO_OV01A10=m
  - DRM_AMDGPU_WERROR=n
  - PDS_VDPA=m
  - INTEL_RAPL_TPMI=m
  - CXL_PMU=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - MFD_MAX5970=m
  - MFD_RK8XX_I2C=n
  - MFD_RK8XX_SPI=n
  - REGULATOR_TPS6287X=m
  - REGULATOR_TPS6594=m
  - DRM_PANEL_SAMSUNG_S6D7AA0=n
  - i386
  - SND_SOC_SSM3515=n
  - i386/default
  - TOUCHSCREEN_MK712=m
  - s390x
  - RFKILL_GPIO=m
  - TI_ST=m
  - GP_PCI1XXXX=m
  - MDIO_GPIO=m
  - ISDN=n
  - I2C_CBUS_GPIO=m
  - I2C_GPIO=m
  - I2C_GPIO_FAULT_INJECTOR=n
  - GPIOLIB_FASTPATH_LIMIT=512
  - DEBUG_GPIO=n
  - GPIO_SYSFS=y
  - GPIO_CDEV_V1=y
  - GPIO_DWAPB=n
  - GPIO_GENERIC_PLATFORM=m
  - GPIO_MB86S7X=n
  - GPIO_AMD_FCH=m
  - GPIO_FXL6408=m
  - GPIO_MAX7300=m
  - GPIO_MAX732X=m
  - GPIO_PCA953X=m
  - GPIO_PCA953X_IRQ=y
  - GPIO_PCA9570=m
  - GPIO_PCF857X=m
  - GPIO_TPIC2810=m
  - GPIO_BT8XX=n
  - GPIO_PCI_IDIO_16=m
  - GPIO_PCIE_IDIO_24=m
  - GPIO_RDC321X=n
  - GPIO_AGGREGATOR=m
  - GPIO_LATCH=m
  - GPIO_MOCKUP=m
  - GPIO_VIRTIO=m
  - GPIO_SIM=m
  - SENSORS_LTC2992=n
  - SENSORS_SHT15=m
  - MEN_A21_WDT=m
  - SSB_DRIVER_GPIO=y
  - TPS65010=m
  - REGULATOR_GPIO=m
  - REGULATOR_TPS65132=m
  - FB_SSD1307=n
  - HD44780=m
  - PANEL_CHANGE_MESSAGE=n
  - EXTCON_GPIO=m
  - EXTCON_MAX3355=m
  - EXTCON_PTN5150=m
  - EXTCON_USB_GPIO=n
  - MUX_GPIO=n
  - s390x/zfcpdump
  - NVME_TARGET=y
  - NVME_TARGET_LOOP=y
  - NVME_TARGET_FC=y
  - NVME_TARGET_AUTH=n
  - NVME_MULTIPATH=y
  - NVME_VERBOSE_ERRORS=n
  - NVME_AUTH=n
  - NVME_TARGET_PASSTHRU=n
  - MOST=n
  - riscv64
  - LD_DEAD_CODE_DATA_ELIMINATION=n
  - ARCH_THEAD=y
  - IRQ_STACKS=y
  - THREAD_SIZE_ORDER=2
  - SUSPEND=y
  - SUSPEND_SKIP_SYNC=n
  - PM_AUTOSLEEP=n
  - PM_USERSPACE_AUTOSLEEP=n
  - PM_WAKELOCKS=n
  - PM_TEST_SUSPEND=n
  - ACPI=y
  - ACPI_DEBUGGER=n
  - ACPI_SPCR_TABLE=y
  - ACPI_EC_DEBUGFS=m
  - ACPI_AC=m
  - ACPI_BATTERY=m
  - ACPI_BUTTON=m
  - ACPI_TINY_POWER_BUTTON=m
  - ACPI_TINY_POWER_BUTTON_SIGNAL=38
  - ACPI_VIDEO=m
  - ACPI_FAN=m
  - ACPI_TAD=m
  - ACPI_DOCK=y
  - ACPI_IPMI=m
  - ACPI_CUSTOM_DSDT_FILE=""
  - ACPI_DEBUG=y
  - ACPI_PCI_SLOT=y
  - ACPI_CONTAINER=y
  - ACPI_HED=y
  - ACPI_CUSTOM_METHOD=m
  - ACPI_NFIT=m
  - NFIT_SECURITY_DEBUG=n
  - ACPI_CONFIGFS=m
  - ACPI_PFRUT=m
  - ACPI_FFH=y
  - PMIC_OPREGION=y
  - BT_HCIUART_RTL=y
  - PCIE_EDR=y
  - HOTPLUG_PCI_ACPI=y
  - HOTPLUG_PCI_ACPI_IBM=m
  - CXL_ACPI=m
  - FW_CACHE=y
  - ISCSI_IBFT=m
  - EFI_CUSTOM_SSDT_OVERLAYS=y
  - PNP_DEBUG_MESSAGES=n
  - ATA_ACPI=y
  - SATA_ZPODD=y
  - PATA_ACPI=m
  - NET_SB1000=n
  - FUJITSU_ES=m
  - TOUCHSCREEN_CHIPONE_ICN8505=m
  - INPUT_SOC_BUTTON_ARRAY=m
  - SERIAL_8250_PNP=y
  - TCG_INFINEON=m
  - ACPI_I2C_OPREGIOSENSORS_ACPI_POWERN=y
  - I2C_AMD_MP2=m
  - I2C_SCMI=m
  - SPI_RZV2M_CSI=m
  - PINCTRL_AMD=y
  - GPIO_AMDPT=m
  - SENSORS_NCT6775=m
  - SENSORS_ACPI_POWER=m
  - WDAT_WDT=m
  - IR_ENE=m
  - IR_FINTEK=m
  - IR_ITE_CIR=m
  - IR_NUVOTON=m
  - VIDEO_OV2740=m
  - VIDEO_OV9734=m
  - DRM_SHMOBILE=n
  - SND_HDA_SCODEC_CS35L41_I2C=m
  - SND_HDA_SCODEC_CS35L41_SPI=m
  - SND_SOC_AMD_CZ_DA7219MX98357_MACH=m
  - SND_SOC_AMD_ST_ES8336_MACH=m
  - SND_SOC_SOF_ACPI=m
  - SND_SOC_STARFIVE=m
  - SND_SOC_JH7110_TDM=m
  - SND_SOC_SSM3515=n
  - I2C_HID_ACPI=m
  - USB_CDNS3_PCI_WRAP=m
  - USB_CDNS3_STARFIVE=m
  - USB_CDNSP_PCI=m
  - USB_CDNSP_HOST=y
  - UCSI_ACPI=m
  - MMC_SDHCI_ACPI=m
  - VMGENID=m
  - PCC=y
  - ACPI_ALS=m
  - PWM_MICROCHIP_CORE=m
  - INTEL_TH_ACPI=m
  - CRYPTO_DEV_JH7110=m
  - PER_VMA_LOCK_STATS=y
  - HARDLOCKUP_DETECTOR=y
  - BOOTPARAM_HARDLOCKUP_PANIC=y
  - ACPI_PCC=y
  - SENSORS_XGENE=m
- commit 645a6ad
* Fri Jul  7 2023 kbuild@suse.de
- Automatically updated to 6.4-next-20230707
- commit 06005cd
* Thu Jul  6 2023 kbuild@suse.de
- Automatically updated to 6.4-next-20230706
- commit bb1fd02
* Wed Jul  5 2023 kbuild@suse.de
- Automatically updated to 6.4-next-20230705
- commit a575fce
* Tue Jul  4 2023 kbuild@suse.de
- Automatically updated to 6.4-next-20230704
- commit d2ea54e
* Mon Jul  3 2023 kbuild@suse.de
- Automatically updated to 6.4-next-20230703
- commit 05a43ee
* Mon Jul  3 2023 msuchanek@suse.de
- Remove more packaging cruft for SLE < 12 SP3
- commit a16781c
* Mon Jul  3 2023 jslaby@suse.cz
- Linux 6.4.1 (bsc#1012628).
- x86/microcode/AMD: Load late on both threads too (bsc#1012628).
- x86/smp: Make stop_other_cpus() more robust (bsc#1012628).
- x86/smp: Dont access non-existing CPUID leaf (bsc#1012628).
- x86/smp: Remove pointless wmb()s from native_stop_other_cpus()
  (bsc#1012628).
- x86/smp: Use dedicated cache-line for mwait_play_dead()
  (bsc#1012628).
- x86/smp: Cure kexec() vs. mwait_play_dead() breakage
  (bsc#1012628).
- cpufreq: amd-pstate: Make amd-pstate EPP driver name hyphenated
  (bsc#1012628).
- can: isotp: isotp_sendmsg(): fix return error fix on TX path
  (bsc#1012628).
- maple_tree: fix potential out-of-bounds access in
  mas_wr_end_piv() (bsc#1012628).
- mm: introduce new 'lock_mm_and_find_vma()' page fault helper
  (bsc#1012628).
- mm: make the page fault mmap locking killable (bsc#1012628).
- arm64/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- powerpc/mm: Convert to using lock_mm_and_find_vma()
  (bsc#1012628).
- mips/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- riscv/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- arm/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- mm/fault: convert remaining simple cases to
  lock_mm_and_find_vma() (bsc#1012628).
- powerpc/mm: convert coprocessor fault to lock_mm_and_find_vma()
  (bsc#1012628).
- mm: make find_extend_vma() fail if write lock not held
  (bsc#1012628).
- execve: expand new process stack manually ahead of time
  (bsc#1012628).
- mm: always expand the stack with the mmap write lock held
  (bsc#1012628).
- HID: wacom: Use ktime_t rather than int when dealing with
  timestamps (bsc#1012628).
- gup: add warning if some caller would seem to want stack
  expansion (bsc#1012628).
- mm/khugepaged: fix regression in collapse_file() (bsc#1012628).
- fbdev: fix potential OOB read in fast_imageblit() (bsc#1012628).
- HID: hidraw: fix data race on device refcount (bsc#1012628).
- HID: logitech-hidpp: add HIDPP_QUIRK_DELAYED_INIT for the T651
  (bsc#1012628).
- Revert "thermal/drivers/mediatek: Use devm_of_iomap to avoid
  resource leak in mtk_thermal_probe" (bsc#1012628).
- sparc32: fix lock_mm_and_find_vma() conversion (bsc#1012628).
- parisc: fix expand_stack() conversion (bsc#1012628).
- csky: fix up lock_mm_and_find_vma() conversion (bsc#1012628).
- xtensa: fix NOMMU build with lock_mm_and_find_vma() conversion
  (bsc#1012628).
- Refresh
  patches.suse/Revert-x86-mm-try-VMA-lock-based-page-fault-handling.patch.
- Update config files (CONFIG_LOCK_MM_AND_FIND_VMA=y).
  There is no choice.
- commit 63da5c1
* Fri Jun 30 2023 msuchanek@suse.de
- Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch.
  Get module prefix from kmod (bsc#1212835).
  Uses jq to parse 'kmod config' output.
- Get module prefix from kmod (bsc#1212835).
- commit 49ee007
* Fri Jun 30 2023 kbuild@suse.de
- Automatically updated to 6.4-next-20230630
- commit 75ccd37
* Fri Jun 30 2023 mkubecek@suse.cz
- rpm/check-for-config-changes: ignore also PAHOLE_HAS_*
  We now also have options like CONFIG_PAHOLE_HAS_LANG_EXCLUDE.
- commit 86b52c1
* Thu Jun 29 2023 msuchanek@suse.de
- usrmerge: Adjust module path in the kernel sources (bsc#1212835).
  With the module path adjustment applied as source patch only
  ALP/Tumbleweed kernel built on SLE/Leap needs the path changed back to
  non-usrmerged.
- commit 571a8e7
* Thu Jun 29 2023 jslaby@suse.cz
- Revert "x86/mm: try VMA lock-based page fault handling first"
  (bsc#1212775).
- Update config files.
- commit 1ec01ee
* Thu Jun 29 2023 kbuild@suse.de
- Automatically updated to 6.4-next-20230629
- commit cfb1b55
* Wed Jun 28 2023 kbuild@suse.de
- Automatically updated to 6.4-next-20230628
- commit 2cd0a66
* Tue Jun 27 2023 kbuild@suse.de
- Automatically updated to 6.4-next-20230627
- commit 7e9ecfc
* Mon Jun 26 2023 msuchanek@suse.de
- kernel-docs: Use python3 together with python3-Sphinx (bsc#1212741).
- commit 95a40a6
* Mon Jun 26 2023 kbuild@suse.de
- Automatically updated to 6.4-rc7-next-20230626
- commit 0f8c12a
* Mon Jun 26 2023 mkubecek@suse.cz
- Update to 6.4 final
- refresh configs (headers only)
- commit 9a32771
* Fri Jun 23 2023 kbuild@suse.de
- Automatically updated to 6.4-rc7-next-20230623
- commit bdb3489
* Thu Jun 22 2023 kbuild@suse.de
- Automatically updated to 6.4-rc7-next-20230622
- commit d040583
* Wed Jun 21 2023 kbuild@suse.de
- Automatically updated to 6.4-rc7-next-20230621
- commit cad4a5c
* Tue Jun 20 2023 kbuild@suse.de
- Automatically updated to 6.4-rc7-next-20230620
- commit edd94d1
* Mon Jun 19 2023 msuchanek@suse.de
- Build documentation.
- commit 8bc0e6a
* Mon Jun 19 2023 kbuild@suse.de
- Automatically updated to 6.4-rc7-next-20230619
- commit c446d22
* Fri Jun 16 2023 kbuild@suse.de
- Automatically updated to 6.4-rc6-next-20230616
- commit 41694c4
* Thu Jun 15 2023 msuchanek@suse.de
- kernel-docs: Add buildrequires on python3-base when using python3
  The python3 binary is provided by python3-base.
- commit c5df526
* Thu Jun 15 2023 kbuild@suse.de
- Automatically updated to 6.4-rc6-next-20230615
- commit 61df5f8
* Wed Jun 14 2023 kbuild@suse.de
- Automatically updated to 6.4-rc6-next-20230614
- commit 56b8b74
* Tue Jun 13 2023 dmueller@suse.com
- config.conf: reenable armv6 configs
- Update config files (same settings like armv7hl)
- commit 66a015e
* Tue Jun 13 2023 kbuild@suse.de
- Automatically updated to 6.4-rc6-next-20230613
- commit 5ed38ef
* Sun Jun 11 2023 mkubecek@suse.cz
- Update to 6.4-rc6
- refresh configs
- commit f980b61
* Sun Jun 11 2023 mkubecek@suse.cz
- config: refresh arm64/vanilla
- commit 2eb8f95
* Sun Jun 11 2023 dmueller@suse.com
- config.conf: reenable armv7hl
- Update config files for armv7hl/6.4.0rc6
- commit a349c65
* Sun Jun 11 2023 dmueller@suse.com
- config.conf: Reenable arm64 configs
- config: Update to 6.4-rc5:
  * this includes lowering the ARCH_FORCE_MAX_ORDER by one given the
    change of definition in mainline commit 23baf831a32c
    ("mm, treewide: redefine MAX_ORDER sanely")
  * config change from x86_64 adopted for arm64. Enabled all erratas,
    rest compile as modules
- commit 9be3079
* Fri Jun  9 2023 msuchanek@suse.de
- Move setting %%%%build_html to config.sh
- commit dd39da3
* Fri Jun  9 2023 kbuild@suse.de
- Automatically updated to 6.4-rc5-next-20230609
- commit 5a07aee
* Fri Jun  9 2023 msuchanek@suse.de
- Fix missing top level chapter numbers on SLE12 SP5 (bsc#1212158).
- commit 7ebcbd5
* Thu Jun  8 2023 msuchanek@suse.de
- Move setting %%%%split_optional to config.sh
- commit 8b0828d
* Thu Jun  8 2023 msuchanek@suse.de
- Move setting %%%%supported_modules_check to config.sh
- commit 3fcb4e0
* Thu Jun  8 2023 msuchanek@suse.de
- rpm/kernel-docs.spec.in: pass PYTHON=python3 to fix build error (bsc#1160435)
- commit 799f050
* Thu Jun  8 2023 kbuild@suse.de
- Automatically updated to 6.4-rc5-next-20230608
- commit 6fb314a
* Thu Jun  8 2023 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Fix compatibility wth newer rpm
- commit 334fb4d
* Wed Jun  7 2023 msuchanek@suse.de
- Also include kernel-docs build requirements for ALP
- commit 114d088
* Wed Jun  7 2023 msuchanek@suse.de
- Move the kernel-binary conflicts out of the spec file.
  Thie list of conflicting packages varies per release.
  To reduce merge conflicts move the list out of the spec file.
- commit 4d81125
* Wed Jun  7 2023 msuchanek@suse.de
- Avoid unsuported tar parameter on SLE12
- commit f11765a
* Wed Jun  7 2023 msuchanek@suse.de
- Move obsolete KMP list into a separate file.
  The list of obsoleted KMPs varies per release, move it out of the spec
  file.
- commit 016bc55
* Wed Jun  7 2023 msuchanek@suse.de
- Trim obsolete KMP list.
  SLE11 is out of support, we do not need to handle upgrading from SLE11
  SP1.
- commit 08819bb
* Wed Jun  7 2023 kbuild@suse.de
- Automatically updated to 6.4-rc5-next-20230607
- commit f534c63
* Wed Jun  7 2023 msuchanek@suse.de
- Generalize kernel-docs build requirements.
- Generalize kernel-doc build requirements.
- commit c92b2cd
* Tue Jun  6 2023 msuchanek@suse.de
- kernel-binary: Add back kernel-default-base guarded by option
  Add configsh option for splitting off kernel-default-base, and for
  not signing the kernel on non-efi
- commit 28c22af
* Tue Jun  6 2023 kbuild@suse.de
- Automatically updated to 6.4-rc5-next-20230606
- commit cd99af5
* Mon Jun  5 2023 kbuild@suse.de
- Automatically updated to 6.4-rc5-next-20230605
- commit d1010a7
* Sun Jun  4 2023 mkubecek@suse.cz
- Update to 6.4-rc5
- refresh configs
- commit 075e530
* Fri Jun  2 2023 kbuild@suse.de
- Automatically updated to 6.4-rc4-next-20230602
- commit 445ae86
* Fri Jun  2 2023 msuchanek@suse.de
- usrmerge: Compatibility with earlier rpm (boo#1211796)
- commit 2191d32
* Thu Jun  1 2023 msuchanek@suse.de
- Fix usrmerge error (boo#1211796)
- commit da84579
* Thu Jun  1 2023 kbuild@suse.de
- Automatically updated to 6.4-rc4-next-20230601
- commit 9c5ac38
* Thu Jun  1 2023 jslaby@suse.cz
- Update config files -- X86_KERNEL_IBT=y (bsc#1211890).
- commit b09c4fc
* Wed May 31 2023 kbuild@suse.de
- Automatically updated to 6.4-rc4-next-20230531
- commit 2a86e20
* Tue May 30 2023 kbuild@suse.de
- Automatically updated to 6.4-rc4-next-20230530
- commit 6729e8b
* Mon May 29 2023 msuchanek@suse.de
- Remove usrmerge compatibility symlink in buildroot (boo#1211796)
  Besides Makefile depmod.sh needs to be patched to prefix /lib/modules.
  Requires corresponding patch to kmod.
- commit b8e00c5
* Sun May 28 2023 mkubecek@suse.cz
- Update to 6.4-rc4
- refresh configs
- commit 017b111
* Fri May 26 2023 jlee@suse.com
- Revert "Disable lockdown. (bsc#1209006)"
  This reverts commit 44ca817f15b215421a4c788790dd5351c186d1df.
  Let's enable kernel lockdown function in master branch again.
  This time we will test with NVIDIA KMP.
- commit 62ca4d6
* Fri May 26 2023 jlee@suse.com
- Revert "Revert "Update config files." (bsc#1211166)"
  This reverts commit 944713a45f59680c926e1a4d51798970f8af1767.
  Let's enable kernel lockdown function in master branch again.
  This time we will test with NVIDIA KMP.
- commit 4264f8b
* Thu May 25 2023 kbuild@suse.de
- Automatically updated to 6.4-rc3-next-20230525
- commit 9548b6c
* Wed May 24 2023 kbuild@suse.de
- Automatically updated to 6.4-rc3-next-20230524
- commit e2428ff
* Tue May 23 2023 kbuild@suse.de
- Automatically updated to 6.4-rc3-next-20230523
- commit c9b0a9f
* Mon May 22 2023 msuchanek@suse.de
- kernel-source: Remove unused macro variant_symbols
- commit 915ac72
* Mon May 22 2023 kbuild@suse.de
- Automatically updated to 6.4-rc3-next-20230522
- commit f06e6c7
* Sun May 21 2023 mkubecek@suse.cz
- Update to 6.4-rc3
- eliminate 1 patch
  - patches.suse/SUNRPC-Fix-encoding-of-rejected-RPCs.patch (29cd2927fb91)
- update configs
  - VFIO_CCW=m (s390x only)
- commit 2163de3
* Fri May 19 2023 kbuild@suse.de
- Automatically updated to 6.4-rc2-next-20230519
- commit 9ea94a4
* Thu May 18 2023 kbuild@suse.de
- Automatically updated to 6.4-rc2-next-20230518
- commit 0dbd80b
* Wed May 17 2023 kbuild@suse.de
- Automatically updated to 6.4-rc2-next-20230517
- commit 19baba6
* Tue May 16 2023 kbuild@suse.de
- Automatically updated to 6.4-rc2-next-20230516
- commit 0273ee1
* Mon May 15 2023 kbuild@suse.de
- Automatically updated to 6.4-rc2-next-20230515
- commit d620ce3
* Fri May 12 2023 kbuild@suse.de
- Automatically updated to 6.4-rc1-next-20230512
- commit 8eb6cd9
* Fri May 12 2023 dmueller@suse.com
- config: align all architectures on CONFIG_HZ=300 (bsc#1196438)
- commit f587f37
* Thu May 11 2023 kbuild@suse.de
- Automatically updated to 6.4-rc1-next-20230511
- commit 84b177e
* Wed May 10 2023 kbuild@suse.de
- Automatically updated to 6.4-rc1-next-20230510
- commit a328a9f
* Tue May  9 2023 kbuild@suse.de
- Automatically updated to 6.4-rc1-next-20230509
- commit 0913912
* Tue May  9 2023 schwab@suse.de
- rpm/constraints.in: Increase disk size constraint for riscv64 to 52GB
- commit 1c1a4cd
* Tue May  9 2023 jslaby@suse.cz
- Revert "Update config files." (bsc#1211166)
  This reverts commit 90a46594a115a4abf9381bd4c327fd875ac0da0b.
  Lockdown is not ready and was disabled in stable. Since this is still
  not resolved in 6.3/6.4-rc, let's disable it in master completely too.
  And let's retry once everything is ready.
- commit 872ab05
* Mon May  8 2023 kbuild@suse.de
- Automatically updated to 6.4-rc1-next-20230508
- commit fc256e1
* Mon May  8 2023 mkubecek@suse.cz
- config: use ARCH_FORCE_MAX_ORDER=8 on ppc64/ppc64le
  Mainline commit 23baf831a32c ("mm, treewide: redefine MAX_ORDER sanely")
  redefined the meaning of MAX_ORDER, and therefore also related
  ARCH_FORCE_MAX_ORDER config option to be one lower than the old value so
  that having ARCH_FORCE_MAX_ORDER=9 with 64KB pages results in build time
  error "Allocator MAX_ORDER exceeds SECTION_SIZE".
  Update the values on ppc64 and ppc64le architectures from 9 to 8 to
  preserve the old behaviour and fix the build error.
- commit d6dd1e0
* Sun May  7 2023 mkubecek@suse.cz
- Update to 6.4-rc1
- drop 14 patches (12 stable, 2 mainline)
  - patches.kernel.org/*
  - patches.suse/ath11k-pci-Add-more-MODULE_FIRMWARE-entries.patch
  - patches.suse/usbtv-usbtv_set_regs-the-pipe-is-output.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/0001-regulator-mt6360-Add-OF-match-table.patch
  - patches.suse/0001-security-lockdown-expose-a-hook-to-lock-the-kernel-down.patch
  - patches.suse/0002-regulator-mt6358-Add-OF-match-table.patch
  - patches.suse/0003-regulator-mt6323-Add-OF-match-table.patch
  - patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch
- disable ARM architectures (need config update)
- new config options
  - Processor type and features
  - ADDRESS_MASKING=y
  - Enable loadable module support
  - MODULE_DEBUG=n
  - Memory Management options
  - DMAPOOL_TEST=n
  - Networking support
  - MAX_SKB_FRAGS=17
  - BT_NXPUART=m
  - File systems
  - XFS_SUPPORT_ASCII_CI=y
  - Security options
  - INTEGRITY_CA_MACHINE_KEYRING=n
  - Kernel hacking
  - PER_VMA_LOCK_STATS=y
  - USER_EVENTS=n
  - FAULT_INJECTION_CONFIGFS=n
  - Generic Driver Options
  - FW_LOADER_DEBUG=y
  - FW_DEVLINK_SYNC_STATE_TIMEOUT=n
  - Block devices
  - BLKDEV_UBLK_LEGACY_OPCODES=y
  - Serial ATA and Parallel ATA drivers (libata)
  - PATA_PARPORT_BPCK6=m
  - Generic Target Core Mod (TCM) and ConfigFS Infrastructure
  - REMOTE_TARGET=m
  - Network device support
  - NET_DSA_MT7530_MDIO=m
  - NET_DSA_MT7530_MMIO=m
  - NET_DSA_QCA8K_LEDS_SUPPORT=y
  - PDS_CORE=m
  - MICROCHIP_T1S_PHY=m
  - NXP_CBTX_PHY=m
  - RTW88_8822BS=m
  - RTW88_8822CS=m
  - RTW88_8821CS=m
  - GPIO Support
  - GPIO_FXL6408=m
  - GPIO_ELKHARTLAKE=m
  - Voltage and Current Regulator Support
  - REGULATOR_RT4803=m
  - REGULATOR_RT5739=m
  - Sound card support
  - SND_SOC_CS35L56_I2C=m
  - SND_SOC_CS35L56_SPI=m
  - SND_SOC_CS35L56_SDW=m
  - SND_SOC_MAX98363=m
  - SND_SOC_RT712_SDCA_DMIC_SDW=m
  - X86 Platform Specific Device Drivers
  - LENOVO_YMC=m
  - INTEL_BYTCRC_PWRSRC=m
  - MSI_EC=m
  - Industrial I/O support
  - TI_ADS1100=n
  - ROHM_BU27034=n
  - NVMEM Support
  - NVMEM_LAYOUT_SL28_VPD=m
  - NVMEM_LAYOUT_ONIE_TLV=m
  - Misc drivers
  - TOUCHSCREEN_NOVATEK_NVT_TS=m
  - PTP_DFL_TOD=m
  - SENSORS_ACBEL_FSG032=m
  - DRM_VIRTIO_GPU_KMS=y
  - DRM_ACCEL_QAIC=m
  - I2C_HID_OF=m
  - LEDS_BD2606MVV=m
  - HYPERV_VTL_MODE=n
  - SOUNDWIRE_AMD=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - MFD_MAX597X=m
  - REGULATOR_MAX597X=m
  - DRM_PANEL_MAGNACHIP_D53E6EA8966=n
  - DRM_PANEL_NOVATEK_NT36523=n
  - DRM_PANEL_SONY_TD4353_JDI=n
  - DRM_SAMSUNG_DSIM=n
  - UCSI_PMIC_GLINK=m
  - COMMON_CLK_SI521XX=m
  - i386
  - CAN_BXCAN=m
  - ppc64le
  - CRYPTO_AES_GCM_P10=m
  - s390x
  - SECRETMEM=y
  - SCSI_IPR=m
  - SCSI_IPR_TRACE=y
  - SCSI_IPR_DUMP=y
  - GCC_PLUGIN_STACKLEAK=n
  - DEBUG_FORCE_FUNCTION_ALIGN_64B=n
  - riscv64
  - SCHED_MC=y
  - RISCV_ISA_SVNAPOT=y
  - RISCV_ISA_ZICBOZ=y
  - RELOCATABLE=y
  - HIBERNATION=y
  - HIBERNATION_SNAPSHOT_DEV=y
  - PM_STD_PARTITION=""
  - PM_AUTOSLEEP=n
  - PM_USERSPACE_AUTOSLEEP=n
  - PM_WAKELOCKS=n
  - FW_CACHE=y
  - DWMAC_STARFIVE=m
  - CAN_BXCAN=m
  - AIRO=m
  - SPI_CADENCE_QUADSPI=m
  - SENSORS_SFCTEMP=m
  - STARFIVE_WATCHDOG=m
  - RZ_MTU3=n
  - SND_SOC_MAX98090=n
  - CLK_STARFIVE_JH7110_SYS=y
  - CLK_STARFIVE_JH7110_AON=m
- commit 473b355
* Sat May  6 2023 kbuild@suse.de
- Automatically updated to 6.3-next-20230505
- commit 65e0c5a
* Fri May  5 2023 msuchanek@suse.de
- Remove obsolete rpm spec constructs
  defattr does not need to be specified anymore
  buildroot does not need to be specified anymore
- commit c963185
* Fri May  5 2023 msuchanek@suse.de
- kernel-spec-macros: Fix up obsolete_rebuilds_subpackage to generate
  obsoletes correctly (boo#1172073 bsc#1191731).
  rpm only supports full length release, no provides
- commit c9b5bc4
* Fri May  5 2023 kbuild@suse.de
- Automatically updated to 6.3-next-20230504
- commit 048b60d
* Thu May  4 2023 msuchanek@suse.de
- kernel-binary: install expoline.o (boo#1210791 bsc#1211089)
- commit d6c8c20
* Sat Apr 29 2023 kbuild@suse.de
- Automatically updated to 6.3-next-20230428
- commit e282cd4
* Fri Apr 28 2023 kbuild@suse.de
- Automatically updated to 6.3-next-20230427
- commit 0bdfb9a
* Thu Apr 27 2023 kbuild@suse.de
- Automatically updated to 6.3-next-20230426
- commit 7f36d54
* Thu Apr 27 2023 mkubecek@suse.cz
- update and reenable armv6hl configs
  New values are copied from arvm7hl.
- commit 78e6ea5
* Thu Apr 27 2023 mkubecek@suse.cz
- update and reenable armv7hl configs
  Where possible, new values are copied from arm64. The rest is guessed,
  mostly based on existing values of similar config options.
- commit 823899e
* Thu Apr 27 2023 mkubecek@suse.cz
- update and reenable arm64 configs
  Where possible, new values are copied from x86_64, i386 or riscv64. The
  rest is guessed, mostly based on existing values of similar config options.
- commit 3404884
* Wed Apr 26 2023 kbuild@suse.de
- Automatically updated to 6.3-next-20230425
- commit 1b1aba4
* Tue Apr 25 2023 kbuild@suse.de
- Automatically updated to 6.3-next-20230424
- commit d53ee63
* Sun Apr 23 2023 mkubecek@suse.cz
- Update to 6.3 final
- update configs
- commit a40e4bb
* Sat Apr 22 2023 kbuild@suse.de
- Automatically updated to 6.3-rc7-next-20230421
- commit ab2af3c
* Fri Apr 21 2023 kbuild@suse.de
- Automatically updated to 6.3-rc7-next-20230420
- commit b3cc688
* Thu Apr 20 2023 kbuild@suse.de
- Automatically updated to 6.3-rc7-next-20230419
- commit 9a8c384
* Wed Apr 19 2023 kbuild@suse.de
- Automatically updated to 6.3-rc7-next-20230418
- commit 429ec4f
* Tue Apr 18 2023 kbuild@suse.de
- Automatically updated to 6.3-rc7-next-20230417
- commit 9e50bf4
* Fri Apr 14 2023 msuchanek@suse.de
- k-m-s: Drop Linux 2.6 support
- commit 22b2304
* Fri Apr 14 2023 msuchanek@suse.de
- Remove obsolete KMP obsoletes (bsc#1210469).
- commit 7f325c6
* Fri Apr 14 2023 kbuild@suse.de
- Automatically updated to 6.3-rc6-next-20230413
- commit b73e7d9
* Wed Apr 12 2023 kbuild@suse.de
- Automatically updated to 6.3-rc6-next-20230412
- commit 77ad454
* Tue Apr 11 2023 kbuild@suse.de
- Automatically updated to 6.3-rc6-next-20230411
- commit 4a7dc99
* Thu Apr  6 2023 kbuild@suse.de
- Automatically updated to 6.3-rc5-next-20230406
- commit 0f607fb
* Wed Apr  5 2023 kbuild@suse.de
- Automatically updated to 6.3-rc5-next-20230405
- commit f74c725
* Tue Apr  4 2023 msuchanek@suse.de
- Define kernel-vanilla as source variant
  The vanilla_only macro is overloaded. It is used for determining if
  there should be two kernel sources built as well as for the purpose of
  determmioning if vanilla kernel should be used for kernel-obs-build.
  While the former can be determined at build time the latter needs to be
  baked into the spec file template. Separate the two while also making
  the latter more generic.
  $build_dtbs is enabled on every single rt and azure branch since 15.3
  when the setting was introduced, gate on the new $obs_build_variant
  setting as well.
- commit eb08123
* Tue Apr  4 2023 kbuild@suse.de
- Automatically updated to 6.3-rc5-next-20230404
- commit 72fd935
* Tue Apr  4 2023 jdelvare@suse.de
- Update config files: disable CONFIG_SENSORS_OCC_P8_I2C and CONFIG_SENSORS_OCC_P9_SBE
  These drivers are intended to run on the BMC of Power systems, not on
  the host, so they are useless in our distribution.
- commit 744cd89
* Mon Apr  3 2023 tiwai@suse.de
- rpm/constraints.in: increase the disk size for armv6/7 to 24GB
  It grows and the build fails recently on SLE15-SP4/5.
- commit 41ac816
* Sat Apr  1 2023 schwab@suse.de
- rpm/check-for-config-changes: add TOOLCHAIN_NEEDS_* to IGNORED_CONFIGS_RE
  This new form was added in commit e89c2e815e76 ("riscv: Handle
  zicsr/zifencei issues between clang and binutils").
- commit 234baea
* Fri Mar 31 2023 msuchanek@suse.de
- Disable compat options on ppc64le (jsc#PED-3184).
  CONFIG_PPC_TRANSACTIONAL_MEM=n
  CONFIG_COMPAT=n
- commit d9bfa16
* Fri Mar 31 2023 kbuild@suse.de
- Automatically updated to 6.3-rc4-next-20230331
- commit f2a9342
* Thu Mar 30 2023 kbuild@suse.de
- Automatically updated to 6.3-rc4-next-20230330
- commit 108687c
* Wed Mar 29 2023 kbuild@suse.de
- Automatically updated to 6.3-rc4-next-20230329
- commit f95fdc0
* Tue Mar 28 2023 kbuild@suse.de
- Automatically updated to 6.3-rc4-next-20230328
- commit 5735e0e
* Mon Mar 27 2023 kbuild@suse.de
- Automatically updated to 6.3-rc3-next-20230327
- commit 3611a82
* Mon Mar 27 2023 mkubecek@suse.cz
- Update to 6.3-rc4
- eliminate 1 patch
  - patches.suse/arm64-efi-Use-SMBIOS-processor-ID-to-key-off-Altra-q.patch (eb684408f3ea)
- refresh configs
- commit 0eb8dc6
* Fri Mar 24 2023 kbuild@suse.de
- Automatically updated to 6.3-rc3-next-20230324
- commit 144cd4d
* Thu Mar 23 2023 kbuild@suse.de
- Automatically updated to 6.3-rc3-next-20230323
- commit 23da280
* Wed Mar 22 2023 kbuild@suse.de
- Automatically updated to 6.3-rc3-next-20230322
- commit 90ec84f
* Tue Mar 21 2023 kbuild@suse.de
- Automatically updated to 6.3-rc3-next-20230321
- commit 227436c
* Mon Mar 20 2023 kbuild@suse.de
- Automatically updated to 6.3-rc3-next-20230320
- commit cf383cc
* Sun Mar 19 2023 mkubecek@suse.cz
- Update to 6.3-rc3
- eliminate 1 patch
  - patches.suse/powerpc-mm-Fix-false-detection-of-read-faults.patch (f2c7e3562b4c)
- refresh configs
- commit c80d9e5
* Fri Mar 17 2023 kbuild@suse.de
- Automatically updated to 6.3-rc2-next-20230317
- commit b9c82d8
* Thu Mar 16 2023 kbuild@suse.de
- Automatically updated to 6.3-rc2-next-20230316
- commit cdd5cc6
* Thu Mar 16 2023 shung-hsi.yu@suse.com
- rpm/group-source-files.pl: Fix output difference when / is in location
  While previous attempt to fix group-source-files.pl in 6d651362c38
  "rpm/group-source-files.pl: Deal with {pre,post}fixed / in location"
  breaks the infinite loop, it does not properly address the issue. Having
  prefixed and/or postfixed forward slash still result in different
  output.
  This commit changes the script to use the Perl core module File::Spec
  for proper path manipulation to give consistent output.
- commit 4161bf9
* Wed Mar 15 2023 kbuild@suse.de
- Automatically updated to 6.3-rc2-next-20230315
- commit fc4e8be
* Tue Mar 14 2023 msuchanek@suse.de
- Require suse-kernel-rpm-scriptlets at all times.
  The kernel packages call scriptlets for each stage, add the dependency
  to make it clear to libzypp that the scriptlets are required.
  There is no special dependency for posttrans, these scriptlets run when
  transactions are resolved. The plain dependency has to be used to
  support posttrans.
- commit 56c4dbe
* Tue Mar 14 2023 msuchanek@suse.de
- Replace mkinitrd dependency with dracut (bsc#1202353).
  Also update mkinitrd refrences in documentation and comments.
- commit e356c9b
* Tue Mar 14 2023 msuchanek@suse.de
- rpm/kernel-obs-build.spec.in: Remove SLE11 cruft
- commit 871eeb4
* Tue Mar 14 2023 kbuild@suse.de
- Automatically updated to 6.3-rc2-next-20230314
- commit 1b82ef9
* Mon Mar 13 2023 mkubecek@suse.cz
- Update to 6.3-rc2
- eliminate 1 patch
  - patches.suse/cpumask-fix-incorrect-cpumask-scanning-result-checks.patch
- update configs
  - FEALNX=m (x86, riscv64), =n otherwise (restored from < 6.2-rc1)
- commit e988902
* Fri Mar 10 2023 kbuild@suse.de
- Automatically updated to 6.3-rc1-next-20230310
- commit 76f6472
* Thu Mar  9 2023 kbuild@suse.de
- Automatically updated to 6.3-rc1-next-20230309
- commit 705df34
* Thu Mar  9 2023 jslaby@suse.cz
- Disable lockdown. (bsc#1209006 bsc#1211166)
  This somehow doesn't play good wrt to external modules.
  When all is ready again, we can revert this revert.
- commit 7c62bc7
* Thu Mar  9 2023 jlee@suse.com
- Update config files.
  Add the following config to x86_64, arm64 and i386.
  CONFIG_IMA_ARCH_POLICY=y
  CONFIG_IMA_SECURE_AND_OR_TRUSTED_BOOT=y
  This config be used to detect secure boot. (bsc#1209006)
- commit bf31f26
* Wed Mar  8 2023 kbuild@suse.de
- Automatically updated to 6.3-rc1-next-20230308
- commit 6532377
* Wed Mar  8 2023 msuchanek@suse.de
- Do not sign the vanilla kernel (bsc#1209008).
- commit cee4d89
* Tue Mar  7 2023 shung-hsi.yu@suse.com
- rpm/group-source-files.pl: Deal with {pre,post}fixed / in location
  When the source file location provided with -L is either prefixed or
  postfixed with forward slash, the script get stuck in a infinite loop
  inside calc_dirs() where $path is an empty string.
  user@localhost:/tmp> perl "$HOME/group-source-files.pl" -D devel.files -N nondevel.files -L /usr/src/linux-5.14.21-150500.41/
  ...
  path = /usr/src/linux-5.14.21-150500.41/Documentation/Kconfig
  path = /usr/src/linux-5.14.21-150500.41/Documentation
  path = /usr/src/linux-5.14.21-150500.41
  path = /usr/src
  path = /usr
  path =
  path =
  path =
  ... # Stuck in an infinite loop
  This workarounds the issue by breaking out the loop once path is an
  empty string. For a proper fix we'd want something that
  filesystem-aware, but this workaround should be enough for the rare
  occation that this script is ran manually.
  Link: http://mailman.suse.de/mlarch/SuSE/kernel/2023/kernel.2023.03/msg00024.html
- commit 6d65136
* Tue Mar  7 2023 kbuild@suse.de
- Automatically updated to 6.3-rc1-next-20230307
- commit f5803ef
* Mon Mar  6 2023 msuchanek@suse.de
- kernel-module-subpackage: Fix expansion with -b parameter (bsc#1208179).
  When -b is specified the script is prefixed with KMP_NEEDS_MKINITRD=1
  which sets the variable for a simple command.
  However, the script is no longer a simple command. Export the variable
  instead.
- commit 152a069
* Mon Mar  6 2023 kbuild@suse.de
- Automatically updated to 6.2-next-20230306
- commit 6aa14e7
* Mon Mar  6 2023 mkubecek@suse.cz
- Update to 6.3-rc1
- drop 32 patches (30 stable, 2 mainline)
  - patches.kernel.org/*
  - patches.rpmify/bpf_doc-Fix-build-error-with-older-python-versions.patch
  - patches.suse/objtool-Check-that-module-init-exit-function-is-an-i.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- disable ARM architectures (need config update)
- new config options
  - General setup
  - BOOT_CONFIG_FORCE=n
  - Memory Management options
  - ZSMALLOC_CHAIN_SIZE=8
  - Networking support
  - AF_RXRPC_INJECT_RX_DELAY=n
  - File systems
  - EROFS_FS_PCPU_KTHREAD=n
  - RPCSEC_GSS_KRB5_ENCTYPES_DES=n
  - RPCSEC_GSS_KRB5_ENCTYPES_AES_SHA1=y
  - RPCSEC_GSS_KRB5_ENCTYPES_CAMELLIA=y
  - RPCSEC_GSS_KRB5_ENCTYPES_AES_SHA2=y
  - Cryptographic API
  - CRYPTO_ARIA_AESNI_AVX2_X86_64=m
  - CRYPTO_ARIA_GFNI_AVX512_X86_64=m
  - Kernel hacking
  - NMI_CHECK_CPU=y
  - RCU_CPU_STALL_CPUTIME=y
  - TEST_DHRY=n
  - Serial ATA and Parallel ATA drivers (libata)
  - PATA_PARPORT renamed from PARIDE
  - PATA_PARPORT_* renamed from PARIDE_*
  - Network device support
  - NET_DSA_MICROCHIP_KSZ_PTP=y
  - NET_DSA_MSCC_OCELOT_EXT=m
  - NCN26000_PHY=m
  - ATH12K=m
  - ATH12K_DEBUG=n
  - ATH12K_TRACING=n
  - Character devices
  - SERIAL_8250_PCI1XXXX=y
  - SERIAL_8250_DFL=m
  - Power supply class support
  - CHARGER_RT9467=m
  - CHARGER_RT9471=m
  - Hardware Monitoring support
  - SENSORS_MC34VR500=m
  - SENSORS_MPQ7932=m
  - SENSORS_MPQ7932_REGULATOR=y
  - SENSORS_TDA38640=m
  - SENSORS_TDA38640_REGULATOR=y
  - Multifunction device drivers
  - MFD_INTEL_M10_BMC_SPI=n
  - MFD_INTEL_M10_BMC_PMCI=n
  - Multimedia support
  - VIDEO_IMX296=m
  - VIDEO_OV8858=m
  - Graphics support
  - DRM_PANEL_AUO_A030JTN01=n
  - DRM_PANEL_ORISETECH_OTA5601A=n
  - BACKLIGHT_KTZ8866=m
  - Compute Acceleration Framework
  - DRM_ACCEL_HABANALABS=m
  - DRM_ACCEL_IVPU=m
  - Sound card support
  - SND_HDA_CTL_DEV_ID=n
  - SND_SOC_AW88395=n
  - SND_SOC_CS42L42_SDW=m
  - SND_SOC_IDT821034=n
  - SND_SOC_PEB2466=n
  - SND_SOC_RT712_SDCA_SDW=m
  - SND_SOC_SMA1303=n
  - HID_SUPPORT=y
  - HID_SUPPORT=y
  - HID_EVISION=m
  - STEAM_FF=y
  - HID_BPF=y
  - I2C_HID=m
  - vDPA drivers
  - MLX5_VDPA_STEERING_DEBUG=n
  - SNET_VDPA=m
  - Industrial I/O support
  - TI_ADS7924=n
  - TI_LMP92064=n
  - MAX5522=n
  - TI_TMAG5273=n
  - Misc devices
  - REGULATOR_MAX20411=m
  - TYPEC_MUX_GPIO_SBU=m
  - XILINX_XDMA=m
  - CROS_EC_UART=m
  - INTEL_TPMI=m
  - INTEL_IOMMU_PERF_EVENTS=y
  - WPCM450_SOC=m
  - DEV_DAX_CXL=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - VIDEO_IMX415=m
  - DRM_PANEL_HIMAX_HX8394=n
  - DRM_PANEL_VISIONOX_VTDR6130=n
  - QCOM_PMIC_GLINK=m
  - BATTERY_QCOM_BATTMGR=m
  - ppc64le / ppc64
  - KCSAN=n
  - s390x
  - FPROBE=y
  - s390x/zfcpdump
  - GLOB_SELFTEST=n
  - riscv64
  - ARCH_SUNXI=y
  - RISCV_ISA_ZBB=y
  - SUN50I_DE2_BUS=n
  - SUNXI_RSB=m
  - MTD_NAND_SUNXI=m
  - AHCI_SUNXI=m
  - NET_VENDOR_ALLWINNER=y
  - SUN4I_EMAC=m
  - DWMAC_SUNXI=m
  - DWMAC_SUN8I=m
  - KEYBOARD_SUN4I_LRADC=m
  - TOUCHSCREEN_SUN4I=m
  - SERIO_SUN4I_PS2=m
  - SERIAL_EARLYCON_SEMIHOST=y
  - HW_RANDOM_JH7110=m
  - I2C_MV64XXX=m
  - SPI_SUN4I=m
  - SPI_SUN6I=m
  - PINCTRL_STARFIVE_JH7110_SYS=m
  - PINCTRL_STARFIVE_JH7110_AON=m
  - PINCTRL_SUN*=y
  - SUN8I_THERMAL=m
  - SUNXI_WATCHDOG=m
  - MFD_SUN4I_GPADC=n
  - MFD_AC100=n
  - MFD_AXP20X_RSB=n
  - MFD_SUN6I_PRCM=n
  - IR_SUNXI=m
  - DRM_SUN4I=n
  - SND_SUN4I_CODEC=m
  - SND_SUN4I_I2S=m
  - SND_SUN4I_SPDIF=m
  - SND_SUN50I_DMIC=m
  - MMC_DW_STARFIVE=m
  - MMC_SUNXI=m
  - RTC_DRV_SUN6I=n
  - DMA_SUN6I=m
  - VIDEO_SUNXI=y
  - VIDEO_SUNXI_CEDRUS=m
  - SUNXI_CCU=m
  - SUN20I_D1_CCU=m
  - SUN20I_D1_R_CCU=m
  - SUN6I_RTC_CCU=m
  - SUN8I_DE2_CCU=m
  - HWSPINLOCK_SUN6I=m
  - SUN6I_MSGBOX=m
  - SUN50I_IOMMU=y
  - JH71XX_PMU=n
  - SUN20I_PPU=n
  - ARM_SUN8I_A33_MBUS_DEVFREQ=m
  - PWM_SUN4I=m
  - PHY_SUN4I_USB=m
  - PHY_SUN6I_MIPI_DPHY=m
  - PHY_SUN9I_USB=m
  - PHY_SUN50I_USB3=m
  - NVMEM_SUNXI_SID=m
  - HUGETLB_PAGE_OPTIMIZE_VMEMMAP_DEFAULT_ON=n
  - CRYPTO_DEV_ALLWINNER=y
  - CRYPTO_DEV_SUN4I_SS=m
  - CRYPTO_DEV_SUN4I_SS_PRNG=y
  - CRYPTO_DEV_SUN4I_SS_DEBUG=n
  - CRYPTO_DEV_SUN8I_CE=m
  - CRYPTO_DEV_SUN8I_CE_DEBUG=n
  - CRYPTO_DEV_SUN8I_CE_HASH=y
  - CRYPTO_DEV_SUN8I_CE_PRNG=y
  - CRYPTO_DEV_SUN8I_CE_TRNG=y
  - CRYPTO_DEV_SUN8I_SS=m
  - CRYPTO_DEV_SUN8I_SS_DEBUG=n
  - CRYPTO_DEV_SUN8I_SS_PRNG=y
  - CRYPTO_DEV_SUN8I_SS_HASH=y
  - USB_MUSB_SUNXI=m
- commit 7cf1523
* Fri Mar  3 2023 kbuild@suse.de
- Automatically updated to 6.2-next-20230303
- commit 6ab5d77
* Thu Mar  2 2023 kbuild@suse.de
- Automatically updated to 6.2-next-20230302
- commit c4defa8
* Wed Mar  1 2023 jslaby@suse.cz
- Update config files. Disable old pcmcia drivers (bsc#1208780).
- commit ae0102e
* Wed Mar  1 2023 jslaby@suse.cz
- Update config files. Disable old pcmcia socket drivers (bsc#1208780).
- commit 368ca1b
* Wed Mar  1 2023 kbuild@suse.de
- Automatically updated to 6.2-next-20230301
- commit 38e55a1
* Wed Mar  1 2023 jslaby@suse.cz
- Update config files. Disable char/pcmcia drivers (bsc#1208775).
- commit b52eb3f
* Tue Feb 28 2023 schwab@suse.de
- config: riscv64: enable SPI_SPIDEV and SPI_SLAVE
- commit a2b0e34
* Tue Feb 28 2023 kbuild@suse.de
- Automatically updated to 6.2-next-20230228
- commit 590444a
* Mon Feb 27 2023 kbuild@suse.de
- Automatically updated to 6.2-next-20230227
- commit 6f7fc55
* Sat Feb 25 2023 kbuild@suse.de
- Automatically updated to 6.2-next-20230225
- commit 3b0acc7
* Fri Feb 24 2023 msuchanek@suse.de
- Disable PS3 support
  The PS3 hardware cannot be used with up-to-date firmware.
- commit 2a64b75
* Fri Feb 24 2023 tzimmermann@suse.com
- uvesafb: Disable fbdev driver (boo#1208662)
  A VESA-based driver. Dropped in favor of generic DRM drivers.
- commit dbe58b5
* Fri Feb 24 2023 tzimmermann@suse.com
- ocfb: Disable fbdev driver (boo#1208660)
  The OpenCores fbdev driver is for an old homebrew chip design. Probably
  unused.
- commit d67b027
* Fri Feb 24 2023 tzimmermann@suse.com
- udlfb: Disable fbdev driver (boo#1208658)
  We've long shipped the DRM-based udl driver, which handles the same
  devices.
- commit 504c8d3
* Fri Feb 24 2023 msuchanek@suse.de
- Revert "kconfig: only write '# CONFIG_FOO is not set' for
  visible symbols" (bsc#1093118).
- Add ksym-provides tool (bsc#1077692).
- commit f68e2da
* Fri Feb 24 2023 tzimmermann@suse.com
- ssd1307fb: Replace with ssd130x (boo#1208656)
  Replace fbdev's ssd1307fb driver with the new DRM-based driver
  ssd130x. Adds support for SPI and Wayland-based userspace.
- commit 616d8a3
* Fri Feb 24 2023 kbuild@suse.de
- Automatically updated to 6.2-next-20230224
- commit 63dceec
* Fri Feb 24 2023 tzimmermann@suse.com
- vfb: Disable fbdev driver (boo#1208646)
  The vfb fbdev driver is backed by system memory and only relevant for
  testing. Disable it. There is DRM's vkms, if a software-only driver is
  required.
- commit 33a26e0
* Fri Feb 24 2023 tzimmermann@suse.com
- Disable gxt4500 fbdev driver (boo#1208642)
  The gxt4500 driver serves a 20yrs-old graphics hardware for
  IBM RS/6000 system. Probably not in use any longer.
- commit ae29323
* Thu Feb 23 2023 kbuild@suse.de
- Automatically updated to 6.2-next-20230223
- commit fbd2877
* Wed Feb 22 2023 kbuild@suse.de
- Automatically updated to 6.2-next-20230222
- commit e6d9092
* Tue Feb 21 2023 kbuild@suse.de
- Automatically updated to 6.2-next-20230221
- commit 1db7b52
* Mon Feb 20 2023 kbuild@suse.de
- Automatically updated to 6.2-rc8-next-20230220
- commit 77401a4
* Mon Feb 20 2023 mkubecek@suse.cz
- Update to 6.2 final
- refresh configs
- commit 8f8926e
* Sat Feb 18 2023 jlee@suse.com
- efi: Lock down the kernel if booted in secure boot mode
  (jsc#SLE-9870, bsc#1198101).
- Update config files.
  - The shim for openSUSE Tumbleweed needs to be reviewed by upstream
    and signed by Microsoft. So we need to lockdown kernel on x86_64
    and arm64 because EFI secure boot.
  - We disable CONFIG_LOCK_DOWN_IN_EFI_SECURE_BOOT in other
    architectures.
- commit c0c4374
* Fri Feb 17 2023 kbuild@suse.de
- Automatically updated to 6.2-rc8-next-20230217
- commit e6eb683
* Thu Feb 16 2023 mkoutny@suse.com
- Update config files.
  Disable CONFIG_BLK_CGROUP_IOPRIO.
  io.prio.class is a misdesigned mechanism that doesn't fit well with the
  cgroup (especially v2):
- it's not properly hierarchical
  - cgroup-wise: parent cgroup has no contol over child cgroup
  - task-wise: priority impact outside of a cgroup (i.e. affects
    cousins competition)
- it's not device dependent (device oblivious)
  Disable it in openSUSE Tumbleweed (and future products) so that we don't
  teach users to use it and force ourselves to support it.
- commit b1cd4e0
* Thu Feb 16 2023 kbuild@suse.de
- Automatically updated to 6.2-rc8-next-20230216
- commit 5d097aa
* Wed Feb 15 2023 kbuild@suse.de
- Automatically updated to 6.2-rc8-next-20230215
- commit ac0345d
* Tue Feb 14 2023 kbuild@suse.de
- Automatically updated to 6.2-rc8-next-20230214
- commit f794fe6
* Tue Feb 14 2023 jslaby@suse.cz
- Update config files.
  Just run oldconfig.
- commit 7c0d0b3
* Tue Feb 14 2023 jslaby@suse.cz
- Update config files. Enable budget-ci module (bsc#1206774)
  Needed for saa7146 support.
- commit ed0a02c
* Tue Feb 14 2023 jlee@suse.com
- Removed the support of EINJ (bsc#1023051, CVE-2016-3695)
- Update config files.
- supported.conf: removed drivers/acpi/apei/einj support.
- commit eac56cb
* Mon Feb 13 2023 msuchanek@suse.de
- Update config files.
- commit 059273c
* Mon Feb 13 2023 msuchanek@suse.de
- Revert "kconfig: only write '# CONFIG_FOO is not set' for
  visible symbols" (bsc#1093118).
- Add ksym-provides tool (bsc#1077692).
- commit a58809e
* Mon Feb 13 2023 kbuild@suse.de
- Automatically updated to 6.2-rc7-next-20230213
- commit 58c37a4
* Fri Feb 10 2023 kbuild@suse.de
- Automatically updated to 6.2-rc7-next-20230210
- commit 7010037
* Thu Feb  9 2023 msuchanek@suse.de
- Update config files.
- commit b3cebf6
* Thu Feb  9 2023 msuchanek@suse.de
- Revert "kconfig: only write '# CONFIG_FOO is not set' for
  visible symbols" (bsc#1093118).
- Add ksym-provides tool (bsc#1077692).
- commit 5a1b29a
* Thu Feb  9 2023 kbuild@suse.de
- Automatically updated to 6.2-rc7-next-20230209
- commit 5ca3bad
* Wed Feb  8 2023 kbuild@suse.de
- Automatically updated to 6.2-rc7-next-20230208
- commit 2362df7
* Tue Feb  7 2023 kbuild@suse.de
- Automatically updated to 6.2-rc7-next-20230207
- commit 8ecd175
* Mon Feb  6 2023 kbuild@suse.de
- Automatically updated to 6.2-rc7-next-20230206
- commit 4c64219
* Fri Feb  3 2023 kbuild@suse.de
- Automatically updated to 6.2-rc6-next-20230203
- commit 9fbf75a
* Thu Feb  2 2023 kbuild@suse.de
- Automatically updated to 6.2-rc6-next-20230202
- commit 6419156
* Wed Feb  1 2023 kbuild@suse.de
- Automatically updated to 6.2-rc6-next-20230201
- commit 96bcd33
* Tue Jan 31 2023 kbuild@suse.de
- Automatically updated to 6.2-rc6-next-20230131
- commit dc833d1
* Mon Jan 30 2023 kbuild@suse.de
- Automatically updated to 6.2-rc6-next-20230130
- commit a070160
* Fri Jan 27 2023 kbuild@suse.de
- Automatically updated to 6.2-rc5-next-20230127
- commit 8945bca
* Wed Jan 25 2023 kbuild@suse.de
- Automatically updated to 6.2-rc5-next-20230125
- commit 0bdf906
* Tue Jan 24 2023 kbuild@suse.de
- Automatically updated to 6.2-rc5-next-20230124
- commit 6992248
* Mon Jan 23 2023 kbuild@suse.de
- Automatically updated to 6.2-rc5-next-20230123
- commit f8e0914
* Sun Jan 22 2023 mkubecek@suse.cz
- Update to 6.2-rc5
- refresh configs
- commit b0b4422
* Fri Jan 20 2023 kbuild@suse.de
- Automatically updated to 6.2-rc4-next-20230120
- commit fce4f33
* Fri Jan 20 2023 jslaby@suse.cz
- Update config files. Set saa7146 to pre-6.1 state (bsc#1206774).
  The driver was moved to staging and disabled by us in 6.1. Now it turned
  out it is actually used. So the driver is getting cleaned up. So enable
  it even when it is in staging, so that users can use it properly.
- commit 6185268
* Thu Jan 19 2023 kbuild@suse.de
- Automatically updated to 6.2-rc4-next-20230119
- commit d6d7081
* Wed Jan 18 2023 kbuild@suse.de
- Automatically updated to 6.2-rc4-next-20230118
- commit 1cb9cab
* Tue Jan 17 2023 kbuild@suse.de
- Automatically updated to 6.2-rc4-next-20230117
- commit 5b618a0
* Mon Jan 16 2023 schwab@suse.de
- rpm/mkspec-dtb: add riscv64 dtb-renesas subpackage
- commit 6020754
* Mon Jan 16 2023 kbuild@suse.de
- Automatically updated to 6.2-rc4-next-20230116
- commit b517506
* Sun Jan 15 2023 mkubecek@suse.cz
- Update to 6.2-rc4
- eliminate 2 patches
  - patches.suse/docs-Fix-the-docs-build-with-Sphinx-6.0.patch
  - patches.suse/drm-amdgpu-fix-pipeline-sync-v2.patch
- update configs
  - ARM64_ERRATUM_2645198=y (arm64)
  - SND_SOC_APQ8016_SBC=m (armv7hl/default, value from arm64)
  - SND_SOC_MSM8996=m (armv7hl/default, value from arm64)
  - SND_SOC_SC7180=m (armv7hl/default, value from arm64)
- commit 2d69715
* Fri Jan 13 2023 kbuild@suse.de
- Automatically updated to 6.2-rc3-next-20230113
- commit 4c24913
* Thu Jan 12 2023 kbuild@suse.de
- Automatically updated to 6.2-rc3-next-20230112
- commit 3eae324
* Wed Jan 11 2023 kbuild@suse.de
- Automatically updated to 6.2-rc3-next-20230111
- commit 304d6f8
* Tue Jan 10 2023 kbuild@suse.de
- Automatically updated to 6.2-rc3-next-20230110
- commit b091f42
* Mon Jan  9 2023 svarbanov@suse.de
- Update armv7 to 6.2.0-rc3
- update configs
- re-enable armv7
- commit 81f6856
* Mon Jan  9 2023 svarbanov@suse.de
- Update arm64 to 6.2.0-rc3
- update configs
- re-enable arm64
- commit e043adb
* Mon Jan  9 2023 kbuild@suse.de
- Automatically updated to 6.2-rc3-next-20230109
- commit 78e3371
* Mon Jan  9 2023 svarbanov@suse.de
- Update armv6 to 6.2.0-rc3
- update configs
- reenable armv6
- commit de87436
* Sun Jan  8 2023 mkubecek@suse.cz
- Update to 6.2-rc3
- eliminate 1 patch
  - patches.suse/tcp-Add-TIME_WAIT-sockets-in-bhash2.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
- update configs
  - CDROM_PKTCDVD=m (restored, except s390x)
  - CDROM_PKTCDVD_BUFFERS=8 (restored, except s390x)
  - CDROM_PKTCDVD_WCACHE=y (restored, except s390x)
- commit 774ca6a
* Fri Jan  6 2023 jeffm@suse.com
- rpm/kernel-binary.spec.in: Add Enhances and Supplements tags to in-tree KMPs
  This makes in-tree KMPs more consistent with externally built KMPs and
  silences several rpmlint warnings.
- commit 02b7735
* Fri Jan  6 2023 mkubecek@suse.cz
- rpm/check-for-config-changes: add OBJTOOL and FTRACE_MCOUNT_USE_*
  Dummy gcc pretends to support -mrecord-mcount option but actual gcc on
  ppc64le does not. Therefore ppc64le builds of 6.2-rc1 and later in OBS
  enable FTRACE_MCOUNT_USE_OBJTOOL and OBJTOOL config options, resulting in
  check failure.
  As we already have FTRACE_MCOUNT_USE_CC and FTRACE_MCOUNT_USE_RECORDMCOUNT
  in the exception list, replace them with a general pattern. And add OBJTOOL
  as well.
- commit 887416f
* Thu Jan  5 2023 jeffm@suse.com
- config: Added support for ALP releases in product identifiers
- Refresh patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch.
- commit 4c15334
* Mon Jan  2 2023 msuchanek@suse.de
- ppc64: Swap out FB_OF for OFDRM (boo#1193476)
  FB_OF=n
  AGP=n
  OFDRM=y
  DRM=y
  This disables support for the Apple UniNorth AGP bridge.
  yast does not support installing on Apple hardware anyway.
- commit 3b6e745
* Mon Jan  2 2023 schwab@suse.de
- config: riscv64: disable CONFIG_IPMMU_VMSA
  This is an ARM-only driver.
- commit aebd716
* Mon Dec 26 2022 mkubecek@suse.cz
- Update to 6.2-rc1
- drop 32 patches (25 stable, 7 mainline)
  - patches.kernel.org/*
  - patches.suse/NFSD-fix-use-after-free-in-__nfs42_ssc_open.patch
  - patches.suse/char-xillybus-Fix-trivial-bug-with-mutex.patch
  - patches.suse/char-xillybus-Prevent-use-after-free-due-to-race-con.patch
  - patches.suse/io_uring-net-ensure-compat-import-handlers-clear-fre.patch
  - patches.suse/media-dvb-core-Fix-UAF-due-to-refcount-races-at-rele.patch
  - patches.suse/misc-sgi-gru-fix-use-after-free-error-in-gru_set_con.patch
  - patches.suse/mm-mremap-fix-mremap-expanding-vma-with-addr-inside-.patch
- refresh
  - patches.suse/Input-elan_i2c-Add-deny-list-for-Lenovo-Yoga-Slim-7.patch
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/crasher.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- disable ARM architectures (need config update)
- new config options
  - General setup
  - RCU_LAZY=n
  - KALLSYMS_SELFTEST=n
  - Processor type and features
  - EFI_HANDOVER_PROTOCOL=y
  - Mitigations for speculative execution vulnerabilities
  - CALL_DEPTH_TRACKING=y
  - CALL_THUNKS_DEBUG=n
  - Power management and ACPI options
  - ACPI_FFH=y
  - Virtualization
  - KVM_SMM=y
  - Memory Management options
  - SLOB_DEPRECATED=n
  - SLUB_TINY=n
  - Networking support
  - BT_LE_L2CAP_ECRED=y
  - BT_HCIBTUSB_POLL_SYNC=y
  - BT_HCIBCM4377=m
  - RXPERF=m
  - File systems
  - SQUASHFS_CHOICE_DECOMP_BY_MOUNT=y
  - NFSD_V2=n
  - Kernel hacking
  - DEBUG_INFO_COMPRESSED_NONE=y
  - DEBUG_INFO_COMPRESSED_ZLIB=n
  - DEBUG_CGROUP_REF=n
  - FAULT_INJECTION_STACKTRACE_FILTER=n
  - Network device support
  - NFP_NET_IPSEC=y
  - MT7996E=m
  - RTW88_8822BU=m
  - RTW88_8822CU=m
  - RTW88_8723DU=m
  - RTW88_8821CU=m
  - RTW89_8852BE=m
  - Input device support
  - TOUCHSCREEN_CYTTSP5=m
  - TOUCHSCREEN_HYNITRON_CSTXXX=m
  - TOUCHSCREEN_HIMAX_HX83112B=m
  - Hardware Monitoring support
  - SENSORS_OCC_P8_I2C=m
  - SENSORS_OXP=m
  - Multimedia support
  - VIDEO_OV08X40=m
  - VIDEO_OV4689=m
  - VIDEO_TC358746=m
  - Graphics support
  - DRM_I915_PREEMPT_TIMEOUT_COMPUTE=7500
  - DRM_ACCEL=y
  - DRM_ACCEL=y
  - Sound card support
  - SND_SOC_INTEL_AVS_MACH_MAX98927=m
  - SND_SOC_INTEL_AVS_MACH_PROBE=m
  - SND_SOC_WM8961=n
  - X86 Platform Specific Device Drivers
  - DELL_WMI_DDV=m
  - X86_PLATFORM_DRIVERS_HP=y
  - INTEL_IFS=m
  - Industrial I/O support
  - IIO_KX022A_SPI=n
  - IIO_KX022A_I2C=n
  - AD4130=n
  - MAX11410=n
  - AD74115=n
  - ADF4377=n
  - MAX30208=m
  - Misc devices
  - CXL_REGION_INVALIDATION_TEST=n
  - ZRAM_MULTI_COMP=y
  - LEGACY_TIOCSTI=n
  - SPI_PCI1XXXX=n
  - GPIO_LATCH=m
  - ADVANTECH_EC_WDT=m
  - MFD_SMPRO=n
  - REGULATOR_RT6190=m
  - MANA_INFINIBAND=m
  - TDX_GUEST_DRIVER=m
  - CROS_HPS_I2C=m
  - IOMMUFD=n
  - NVDIMM_SECURITY_TEST=n
  - FPGA_MGR_LATTICE_SYSCONFIG_SPI=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - SPI_SN_F_OSPI=n
  - MFD_TPS65219=n
  - VIDEO_ST_VGXY61=m
  - DRM_PANEL_JADARD_JD9365DA_H3=n
  - DRM_PANEL_NEWVISION_NV3051D=n
  - i386
  - SND_SOC_RT1318_SDW=n
  - ppc64le / ppc64
  - SSIF_IPMI_BMC=m
  - SENSORS_OCC_P9_SBE=m
  - DRM_OFDRM=m
  - ppc64
  - PPC64_BIG_ENDIAN_ELF_ABI_V2=y
  - s390x
  - VCAP=y
  - HUGETLB_PAGE_OPTIMIZE_VMEMMAP_DEFAULT_ON=n
  - riscv64
  - ARCH_RENESAS=y
  - ERRATA_THEAD_PMU=y
  - CPU_FREQ=y
  - CPU_FREQ_STAT=y (arm64)
  - CPU_FREQ_DEFAULT_GOV_ONDEMAND=y (arm64)
  - CPU_FREQ_GOV_POWERSAVE=m
  - CPU_FREQ_GOV_USERSPACE=m
  - CPU_FREQ_GOV_CONSERVATIVE=m
  - CPU_FREQ_GOV_SCHEDUTIL=y
  - CPUFREQ_DT=m
  - PCIE_RCAR_HOST=y
  - PCIE_RCAR_EP=y
  - MTD_NAND_RENESAS=m
  - SCSI_LPFC=m
  - SCSI_LPFC_DEBUG_FS=n
  - SATA_RCAR=m
  - SH_ETH=m
  - RAVB=m
  - RENESAS_ETHER_SWITCH=m
  - CAN_RCAR=m
  - CAN_RCAR_CANFD=m
  - SERIAL_8250_EM=y
  - SERIAL_SH_SCI=n
  - I2C_RIIC=m
  - I2C_RZV2M=m
  - I2C_SH_MOBILE=m
  - I2C_RCAR=m
  - I2C_SLAVE_EEPROM=m
  - I2C_SLAVE_TESTUNIT=n
  - SPI_RSPI=m
  - SPI_SH_MSIOF=m
  - SPI_SH_HSPI=m
  - GPIO_RCAR=m
  - CPU_FREQ_THERMAL=y
  - RCAR_THERMAL=m
  - RCAR_GEN3_THERMAL=m
  - RZG2L_THERMAL=m
  - RENESAS_WDT=m
  - RENESAS_RZAWDT=m
  - RENESAS_RZN1WDT=m
  - RENESAS_RZG2LWDT=m
  - DRM_RZG2L_MIPI_DSI=n
  - FB_SH_MOBILE_LCDC=n
  - SND_SOC_SH4_FSI=n
  - SND_SOC_RCAR=n
  - MMC_SDHI=m
  - MMC_SDHI_SYS_DMAC=m
  - MMC_SH_MMCIF=m
  - SCSI_UFS_RENESAS=m
  - RTC_DRV_SH=m
  - RCAR_DMAC=m
  - RENESAS_USB_DMAC=m
  - CLK_RCAR_USB2_CLOCK_SEL=y
  - RENESAS_OSTM=y
  - IPMMU_VMSA=y
  - ARCH_R9A07G043=y
  - RENESAS_RPCIF=m
  - RZG2L_ADC=n
  - PWM_RCAR=m
  - PWM_RENESAS_TPU=m
  - RESET_RZG2L_USBPHY_CTRL=m
  - PHY_R8A779F0_ETHERNET_SERDES=m
  - PHY_RCAR_GEN2=m
  - PHY_RCAR_GEN3_PCIE=m
  - PHY_RCAR_GEN3_USB2=m
  - PHY_RCAR_GEN3_USB3=m
  - FPROBE=y
  - UCLAMP_TASK=n
  - ENERGY_MODEL=y
  - MCTP_TRANSPORT_I2C=m
  - INPUT_IBM_PANEL=m
  - IPMI_IPMB=m
  - SSIF_IPMI_BMC=m
  - IPMB_DEVICE_INTERFACE=m
  - SPI_RPCIF=m
  - THERMAL_GOV_POWER_ALLOCATOR=n
  - SND_SOC_RZ=n
  - RZ_DMAC=m
  - IOMMU_IO_PGTABLE_LPAE_SELFTEST=n
  - DTPM_CPU=y
  - DTPM_DEVFREQ=y
- commit 9b89f11
* Mon Dec 12 2022 mkubecek@suse.cz
- Update to 6.1 final
- refresh configs (headers only)
- commit dee3787
* Thu Dec  8 2022 jeffm@suse.com
- Revert "config: update CONFIG_LSM defaults"
  This reverts commit a05e86cb8200d8cf785b866375a4c9d06c09ab47.
  Commit 0a20128a486 (Revert "config: Enable BPF LSM" (bsc#1197746))
  indicates this needs more specific testing before merging.
- commit 07f3100
* Thu Dec  8 2022 jeffm@suse.com
- config: update CONFIG_LSM defaults (bsc#1205603).
  CONFIG_LSM determines what the default order of LSM usage is.  The
  default order is set based on whether AppArmor or SELinux is preferred
  in the config (we still prefer AppArmor).  The default set has changed
  over time and we haven't updated it, leading to things like bpf LSMs
  not working out of the box.
  This change just updates CONFIG_LSM to what the default would be now.
- config: update CONFIG_LSM defaults
  CONFIG_LSM determines what the default order of LSM usage is.  The
  default order is set based on whether AppArmor or SELinux is preferred
  in the config (we still prefer AppArmor).  The default set has changed
  over time and we haven't updated it, leading to things like bpf LSMs
  not working out of the box.
  This change just updates CONFIG_LSM to what the default would be now.
- commit c73e57e
* Thu Dec  8 2022 kbuild@suse.de
- Automatically updated to 6.1-rc8-next-20221208
- commit ae744f4
* Wed Dec  7 2022 kbuild@suse.de
- Automatically updated to 6.1-rc8-next-20221207
- commit 871d049
* Tue Dec  6 2022 kbuild@suse.de
- Automatically updated to 6.1-rc8-next-20221206
- commit 762b68f
* Mon Dec  5 2022 kbuild@suse.de
- Automatically updated to 6.1-rc7-next-20221205
- commit 7c1411b
* Fri Dec  2 2022 kbuild@suse.de
- Automatically updated to 6.1-rc7-next-20221202
- commit ba115a4
* Thu Dec  1 2022 kbuild@suse.de
- Automatically updated to 6.1-rc7-next-20221201
- commit 1f3a57f
* Wed Nov 30 2022 nstange@suse.de
- Add support for enabling livepatching related packages on -RT (jsc#PED-1706)
- commit 9d41244
* Wed Nov 30 2022 kbuild@suse.de
- Automatically updated to 6.1-rc7-next-20221130
- commit f7ab25e
* Tue Nov 29 2022 msuchanek@suse.de
- fbdev: make offb driver tristate (offb).
- Update config files.
- commit 345a87c
* Tue Nov 29 2022 msuchanek@suse.de
- Update ELFv2 ppc patchset to v6
- Refresh patches.rpmify/Option-to-build-big-endian-with-ELFv2-ABI.patch.
- Delete patches.rpmify/powerpc-module-arch-checks.patch.
- commit 9b6dc9c
* Tue Nov 29 2022 afaerber@suse.com
- config: arm64: Fix Freescale LPUART dependency (boo#1204063)
  Commit 8d7f37c61a07 inserted CONFIG_SERIAL_FSL_LPUART_CONSOLE=y
  but forgot to change CONFIG_SERIAL_FSL_LPUART=m to =y as dependency,
  as the upstream Kconfig appears to be missing it for this driver.
- commit ab87437
* Tue Nov 29 2022 kbuild@suse.de
- Automatically updated to 6.1-rc7-next-20221129
- commit 81858d0
* Mon Nov 28 2022 kbuild@suse.de
- Automatically updated to 6.1-rc6-next-20221128
- commit dc6962a
* Mon Nov 28 2022 mkubecek@suse.cz
- Update to 6.1-rc7
- update configs
  - x86: X86_AMD_PSTATE=y (was "m")
- commit 23af925
* Fri Nov 25 2022 kbuild@suse.de
- Automatically updated to 6.1-rc6-next-20221125
- commit 5d72afd
* Thu Nov 24 2022 kbuild@suse.de
- Automatically updated to 6.1-rc6-next-20221124
- commit 18b31f6
* Wed Nov 23 2022 mbrugger@suse.com
- arm64: Update config files.
  Enable configs for tegra234 serial console to work.
- commit 572e19a
* Wed Nov 23 2022 kbuild@suse.de
- Automatically updated to 6.1-rc6-next-20221123
- commit 1ff1ef3
* Wed Nov 23 2022 dmueller@suse.com
- config.conf: enable armv6/armv7hl configs
- armv6/7hl: Update config files.
- commit 356d8e8
* Tue Nov 22 2022 kbuild@suse.de
- Automatically updated to 6.1-rc6-next-20221122
- commit bfc4ab3
* Mon Nov 21 2022 kbuild@suse.de
- Automatically updated to 6.1-rc5-next-20221121
- commit 2fe0299
* Mon Nov 21 2022 mkubecek@suse.cz
- Update to 6.1-rc6
- eliminate 1 patch
  - patches.suse/Input-i8042-Apply-probe-defer-to-more-ASUS-ZenBook-m.patch
- update configs
  - INET_TABLE_PERTURB_ORDER=16 (default, previous value)
- commit 0e6bf8d
* Sat Nov 19 2022 msuchanek@suse.de
- Fix offb kconfig dependencies (offb).
  Update config files.
- commit c441016
* Fri Nov 18 2022 kbuild@suse.de
- Automatically updated to 6.1-rc5-next-20221118
- commit fd08431
* Thu Nov 17 2022 kbuild@suse.de
- Automatically updated to 6.1-rc5-next-20221117
- commit 3d95227
* Wed Nov 16 2022 kbuild@suse.de
- Automatically updated to 6.1-rc5-next-20221116
- commit a132220
* Tue Nov 15 2022 msuchanek@suse.de
- Update config files (bsc#1205447).
  INTEGRITY_MACHINE_KEYRING=y
  IMA_KEYRINGS_PERMIT_SIGNED_BY_BUILTIN_OR_SECONDARY=n
- commit 3af9124
* Tue Nov 15 2022 kbuild@suse.de
- Automatically updated to 6.1-rc5-next-20221115
- commit 933c940
* Mon Nov 14 2022 kbuild@suse.de
- Automatically updated to 6.1-rc5-next-20221114
- commit 58233b0
* Mon Nov 14 2022 mkubecek@suse.cz
- Update to 6.1-rc5
- update configs
  - CONFIG_DRM_RCAR_USE_MIPI_DSI=n (y on arm64, like DRM_RCAR_MIPI_DSI)
  - IOSM=n (except x86)
  - TEST_MAPLE_TREE=n
  - s390x/zfcpdump: RANDOMIZE_BASE=n
- commit 086be37
* Fri Nov 11 2022 kbuild@suse.de
- Automatically updated to 6.1-rc4-next-20221111
- commit 40f204d
* Thu Nov 10 2022 kbuild@suse.de
- Automatically updated to 6.1-rc4-next-20221110
- commit 221cf16
* Wed Nov  9 2022 kbuild@suse.de
- Automatically updated to 6.1-rc4-next-20221109
- commit 8a20cdb
* Wed Nov  9 2022 jlee@suse.com
- Update config files for enabling CONFIG_SECONDARY_TRUSTED_KEYRING
  In some architectures, e.g. ppc64, riscv64, x86_64, we have enabled the
  CONFIG_SECONDARY_TRUSTED_KEYRING and children kernel config. But we didn't
  enable it in other architectures.
  In the future, the CONFIG_SECONDARY_TRUSTED_KEYRING will be used with
  IMA in different architectures. So let's enable it in Tumbleweed in
  all architectures to align with SLE/Leap. Then user can use it for
  preparing IMA functions with secondary trusted keyring. (bsc#1203739)
- commit 0ced607
* Tue Nov  8 2022 kbuild@suse.de
- Automatically updated to 6.1-rc4-next-20221108
- commit b86b1fc
* Tue Nov  8 2022 jslaby@suse.cz
- rpm/check-for-config-changes: add TOOLCHAIN_HAS_* to IGNORED_CONFIGS_RE
  This new form was added in commit b8c86872d1dc (riscv: fix detection of
  toolchain Zicbom support).
- commit e9f2ba6
* Mon Nov  7 2022 ludwig.nussel@suse.de
- Add suse-kernel-rpm-scriptlets to kmp buildreqs (boo#1205149)
- commit 888e01e
* Mon Nov  7 2022 kbuild@suse.de
- Automatically updated to 6.1-rc3-next-20221107
- commit 10756af
* Fri Nov  4 2022 kbuild@suse.de
- Automatically updated to 6.1-rc3-next-20221104
- commit 3170728
* Thu Nov  3 2022 kbuild@suse.de
- Automatically updated to 6.1-rc3-next-20221103
- commit 7796aba
* Wed Nov  2 2022 kbuild@suse.de
- Automatically updated to 6.1-rc3-next-20221102
- commit a8e1091
* Tue Nov  1 2022 msuchanek@suse.de
- powerpc/64: Option to build big-endian with ELFv2 ABI (ppc64 ELFv2).
  Update patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch to a more recent version.
  Update config files.
- commit e05b38f
* Tue Nov  1 2022 msuchanek@suse.de
- module: add module_elf_check_arch for module-specific checks
  (https://patchwork.ozlabs.org/project/linuxppc-dev/list/?series=325514).
- Refresh patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch.
- commit 4e8d03b
* Tue Nov  1 2022 kbuild@suse.de
- Automatically updated to 6.1-rc3-next-20221101
- commit 8a31a91
* Mon Oct 31 2022 mkubecek@suse.cz
- Update to 6.1-rc3
- eliminate 1 patch
  - patches.suse/scsi-mpi3mr-select-CONFIG_SCSI_SAS_ATTRS.patch
- refresh configs
- commit 629211b
* Wed Oct 26 2022 mbrugger@suse.com
- arm64: Update config files. (bsc#1203558)
  Enable Renesas serial console and earlycon.
- commit b2c823e
* Mon Oct 17 2022 mkubecek@suse.cz
- update submitted patch
- update to v2 and rename
  - patches.suse/scsi-mpi3mr-add-explicit-dependency-on-CONFIG_SCSI_S.patch
  - > patches.suse/scsi-mpi3mr-select-CONFIG_SCSI_SAS_ATTRS.patch
- update config/x86_64/kvmsmall
  - SCSI_SAS_ATTRS=m (new dependency in 6.1-rc1)
- commit 6405ec5
* Mon Oct 17 2022 dmueller@suse.com
- config.conf: Reenable arm64
- Update config files (arm64). copy 6.1-rc1  from x86_64, enable
  all new SOC erratas, enable all new modules.
- commit 3ef6b8a
* Mon Oct 17 2022 schwab@suse.de
- rpm/check-for-config-changes: loosen pattern for AS_HAS_*
  This is needed to handle CONFIG_AS_HAS_NON_CONST_LEB128.
- commit bdc0bf7
* Mon Oct 17 2022 mkubecek@suse.cz
- Update to 6.1-rc1
- eliminate 21 patches (18 stable, 3 mainline)
  - patches.suse/ALSA-hda-realtek-Add-quirk-for-HP-Zbook-Firefly-14-G.patch
  - patches.suse/ALSA-hda-realtek-More-robust-component-matching-for-.patch
  - patches.suse/watchdog-wdat_wdt-fix-min-max-timer-value.patch
- disable
  - patches.suse/suse-hv-guest-os-id.patch (bsc#1189965)
- refresh
  - patches.suse/Input-i8042-Apply-probe-defer-to-more-ASUS-ZenBook-m.patch
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
- add DRM crash fix
  - patches.suse/drm-sched-Fix-kernel-NULL-pointer-dereference-error.patch
- disable ARM architectures (need config update)
- new config options
  - Processor type and features
  - XEN_PV_MSR_SAFE=y
  - Power management and ACPI options
  - X86_AMD_PSTATE_UT=n
  - General architecture-dependent options
  - CFI_CLANG=n
  - Memory Management options
  - LRU_GEN=y
  - LRU_GEN_ENABLED=n
  - LRU_GEN_STATS=n
  - Cryptographic API
  - CRYPTO_ARIA_AESNI_AVX_X86_64=m
  - Library routines
  - FORCE_NR_CPUS=n
  - Kernel hacking
  - DEBUG_MAPLE_TREE=n
  - TEST_DYNAMIC_DEBUG=n
  - Network device support
  - NGBE=m
  - NET_VENDOR_ADI=y
  - ADIN1110=m
  - MLX5_EN_MACSEC=y
  - PSE_CONTROLLER=y
  - PSE_REGULATOR=m
  - Input device support
  - KEYBOARD_PINEPHONE=m
  - TOUCHSCREEN_COLIBRI_VF50=m
  - Hardware Monitoring support
  - SENSORS_MAX31760=m
  - SENSORS_TPS546D24=m
  - SENSORS_EMC2305=m
  - Multifunction device drivers
  - MFD_MT6370=n
  - MFD_OCELOT=n
  - MFD_SY7636A=n
  - MFD_RT5120=n
  - Graphics support
  - DRM_USE_DYNAMIC_DEBUG=y
  - Sound card support
  - SND_SOC_AMD_PS=m
  - SND_SOC_AMD_PS_MACH=m
  - SND_SOC_SOF_AMD_REMBRANDT=m
  - SND_SOC_SOF_SKYLAKE=m
  - SND_SOC_SOF_KABYLAKE=m
  - SND_SOC_CS42L83=n
  - SND_SOC_SRC4XXX_I2C=n
  - HID support
  - HID_VRC2=m
  - HID_PXRC=m
  - HID_TOPRE=m
  - Industrial I/O support
  - MSA311=n
  - MAX11205=n
  - RICHTEK_RTQ6056=n
  - BOSCH_BNO055_SERIAL=n
  - BOSCH_BNO055_I2C=n
  - LTRF216A=n
  - Misc devices
  - GP_PCI1XXXX=m
  - AHCI_DWC=m
  - SERIAL_FSL_LPUART_CONSOLE=y
  - I2C_PCI1XXXX=m
  - SPI_MICROCHIP_CORE_QSPI=m
  - PINCTRL_CY8C95X0=m
  - EXAR_WDT=m
  - STAGING_MEDIA_DEPRECATED=n
  - CROS_TYPEC_SWITCH=m
  - AMD_PMF=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - PATA_OF_PLATFORM=m
  - COMMON_CLK_VC7=m
  - NVMEM_U_BOOT_ENV=m
  - ppc64le / ppc64
  - ARCH_FORCE_MAX_ORDER=9 (default)
  - INPUT_IBM_PANEL=m
  - KFENCE=y
  - KFENCE_SAMPLE_INTERVAL=0
  - KFENCE_NUM_OBJECTS=255
  - KFENCE_DEFERRABLE=n
  - KFENCE_STATIC_KEYS=y
  - KFENCE_STRESS_TEST_FAULTS=0
  - riscv64
  - EFI_ZBOOT=n
  - PINCTRL_STARFIVE_JH7100=m
  - CHARGER_RK817=m
  - SND_SOC_ES8326=m
  - SIFIVE_CCACHE=y
  - RESET_POLARFIRE_SOC=y
- commit 5db401d
* Wed Oct 12 2022 jslaby@suse.cz
- Linux 6.0.1 (bsc#1012628).
- xsk: Inherit need_wakeup flag for shared sockets (bsc#1012628).
- fs: fix UAF/GPF bug in nilfs_mdt_destroy (bsc#1012628).
- sparc: Unbreak the build (bsc#1012628).
- Makefile.extrawarn: Move -Wcast-function-type-strict to W=1
  (bsc#1012628).
- hardening: Remove Clang's enable flag for
  - ftrivial-auto-var-init=zero (bsc#1012628).
- docs: update mediator information in CoC docs (bsc#1012628).
- hwmon: (aquacomputer_d5next) Fix Quadro fan speed offsets
  (bsc#1012628).
- usb: mon: make mmapped memory read only (bsc#1012628).
- USB: serial: ftdi_sio: fix 300 bps rate for SIO (bsc#1012628).
- gpiolib: acpi: Add support to ignore programming an interrupt
  (bsc#1012628).
- gpiolib: acpi: Add a quirk for Asus UM325UAZ (bsc#1012628).
- RISC-V: Print SSTC in canonical order (bsc#1012628).
- bpf: Gate dynptr API behind CAP_BPF (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix state in __mtk_foe_entry_clear
  (bsc#1012628).
- bpf: Fix resetting logic for unreferenced kptrs (bsc#1012628).
- Bluetooth: use hdev->workqueue when queuing
  hdev->{cmd,ncmd}_timer works (bsc#1012628).
- Update config files.
- commit 83783f0
* Wed Oct  5 2022 msuchanek@suse.de
- Revert "constraints: increase disk space for all architectures"
  (bsc#1203693).
  This reverts commit 43a9011f904bc7328d38dc340f5e71aecb6b19ca.
- commit 3d33373
* Sun Oct  2 2022 mkubecek@suse.cz
- Update to 6.0 final
- eliminate 1 patch
  - patches.suse/vduse-prevent-uninitialized-memory-accesses.patch
- refresh configs (headers only)
- commit 9275401
* Tue Sep 27 2022 ykaukab@suse.de
- constraints: increase disk space for all architectures
  References: bsc#1203693
  aarch64 is already suffering. SLE15-SP5 x86_64 stats show that it is
  very close to the limit.
- commit 43a9011
* Sun Sep 25 2022 mkubecek@suse.cz
- Update to 6.0-rc7
- refresh configs
- commit 7fcc5d5
* Fri Sep 23 2022 dmueller@suse.com
- config(arm*): disable CONFIG_PM_AUTOSLEEP and CONFIG_PM_WAKELOCKS (bsc#1189677)
- commit 3ebfa34
* Thu Sep 22 2022 dmueller@suse.com
- config.conf: reenable armv6hl configs
- commit bf61d01
* Wed Sep 21 2022 dmueller@suse.com
- arm64: enable CONFIG_ARCH_RENESAS (bsc#1203558)
  Also compile everything as modules that isn't debug
  or deprecated that was previously disabled by the
  global RENESAS disablement.
- commit 1a6fd7e
* Wed Sep 21 2022 dmueller@suse.com
- config.conf: Reenable arm64 configs
- Update config files, taken from 6.0-rc1 update from x86_64,
  enabling all new erratas, enabling all new modules
- commit 4e7bd27
* Sun Sep 11 2022 mkubecek@suse.cz
- Update to 6.0-rc5
- eliminate 5 patches:
  - patches.suse/ASoC-nau8540-Implement-hw-constraint-for-rates.patch
  - patches.suse/ASoC-nau8821-Implement-hw-constraint-for-rates.patch
  - patches.suse/ASoC-nau8824-Fix-semaphore-unbalance-at-error-paths.patch
  - patches.suse/ASoC-nau8824-Implement-hw-constraint-for-rates.patch
  - patches.suse/ASoC-nau8825-Implement-hw-constraint-for-rates.patch
- refresh configs
- commit 57f3253
* Sun Sep  4 2022 mkubecek@suse.cz
- Update to 6.0-rc4
- refresh configs
- commit 1655cfd
* Thu Sep  1 2022 jslaby@suse.cz
- rpm/kernel-source.spec.in: simplify finding of broken symlinks
  "find -xtype l" will report them, so use that to make the search a bit
  faster (without using shell).
- commit 13bbc51
* Wed Aug 31 2022 msuchanek@suse.de
- mkspec: eliminate @NOSOURCE@ macro
  This should be alsways used with @SOURCES@, just include the content
  there.
- commit 403d89f
* Wed Aug 31 2022 msuchanek@suse.de
- kernel-source: include the kernel signature file
  We assume that the upstream tarball is used for released kernels.
  Then we can also include the signature file and keyring in the
  kernel-source src.rpm.
  Because of mkspec code limitation exclude the signature and keyring from
  binary packages always - mkspec does not parse spec conditionals.
- commit e76c4ca
* Wed Aug 31 2022 msuchanek@suse.de
- kernel-binary: move @NOSOURCE@ to @SOURCES@ as in other packages
- commit 4b42fb2
* Wed Aug 31 2022 msuchanek@suse.de
- dtb: Do not include sources in src.rpm - refer to kernel-source
  Same as other kernel binary packages there is no need to carry duplicate
  sources in dtb packages.
- commit 1bd288c
* Mon Aug 22 2022 mkubecek@suse.cz
- Update to 6.0-rc2
- drop upstreamed patch
  - patches.rpmify/kbuild-dummy-tools-pretend-we-understand-__LONG_DOUB.patch
- refresh configs
- commit 81247eb
* Thu Aug 18 2022 msuchanek@suse.de
- Update config files (bsc#1201361 bsc#1192968 https://github.com/rear/rear/issues/2554).
  ppc64: NVRAM=y
- commit e7f1b25
* Thu Aug 18 2022 tiwai@suse.de
- Update config files: CONFIG_SPI_AMD=m on x86 (bsc#1201418)
- commit a9486a1
* Tue Aug 16 2022 jslaby@suse.cz
- rpm/kernel-binary.spec.in: move vdso to a separate package (bsc#1202385)
  We do the move only on 15.5+.
- commit 9c7ade3
* Tue Aug 16 2022 jslaby@suse.cz
- rpm/kernel-binary.spec.in: simplify find for usrmerged
  The type test and print line are the same for both cases. The usrmerged
  case only ignores more, so refactor it to make it more obvious.
- commit 583c9be
* Mon Aug 15 2022 dmueller@suse.com
- config.conf: reenable armv7hl configs
- Update config files for armv7hl (following x86_64 settings,
  compiling as module unless DEBUG or DEPRECATED)
- commit 1c0d593
* Mon Aug 15 2022 dmueller@suse.com
- armv7hl: rebuilt as an overlay over default config
  generated automatically with scripts/config-diff
- commit 75f2a98
* Mon Aug 15 2022 dmueller@suse.com
- armv6/v7: enable BT_VIRTIO
- commit 8c747dd
* Mon Aug 15 2022 mkubecek@suse.cz
- Update to 6.0-rc1
- eliminate 4 patches (all mainline)
  - patches.suse/0001-drm-Always-warn-if-user-defined-modes-are-not-suppor.patch
  - patches.suse/0001-drm-client-Don-t-add-new-command-line-mode.patch
  - patches.suse/0001-drm-client-Look-for-command-line-modes-first.patch
  - patches.suse/ath9k-fix-use-after-free-in-ath9k_hif_usb_rx_cb.patch
- disable
  - patches.suse/Input-i8042-Apply-probe-defer-to-more-ASUS-ZenBook-m.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
  - patches.suse/Revert-zram-remove-double-compression-logic.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - CONTEXT_TRACKING_USER_FORCE=n
  - RCU_NOCB_CPU_DEFAULT_ALL=n
  - CGROUP_FAVOR_DYNMODS=n
  - Power management and ACPI options
  - PM_USERSPACE_AUTOSLEEP=n
  - Networking support
  - NF_FLOW_TABLE_PROCFS=y
  - NET_DSA_TAG_RZN1_A5PSW=m
  - File systems
  - DLM_DEPRECATED_API=n
  - Security options
  - SECURITY_APPARMOR_INTROSPECT_POLICY=y
  - SECURITY_APPARMOR_EXPORT_BINARY=y
  - SECURITY_APPARMOR_PARANOID_LOAD=y
  - IMA_KEXEC=n
  - Cryptographic API
  - CRYPTO_FIPS_NAME="Linux Kernel Cryptographic API"
  - CRYPTO_FIPS_CUSTOM_VERSION=n
  - CRYPTO_HCTR2=m
  - CRYPTO_POLYVAL_CLMUL_NI=m
  - CRYPTO_ARIA=m
  - Kernel hacking
  - SHRINKER_DEBUG=n
  - RV=n
  - PCI support
  - PCI_EPF_VNTB=m
  - Block devices
  - BLK_DEV_UBLK=m
  - NVME Support
  - NVME_AUTH=n
  - NVME_TARGET_AUTH=n
  - Network device support
  - NET_DSA_MICROCHIP_KSZ_SPI=m
  - NET_VENDOR_WANGXUN=y
  - TXGBE=m
  - CAN_NETLINK=y
  - CAN_CAN327=m
  - CAN_ESD_USB=m
  - Sound card support
  - SND_CTL_FAST_LOOKUP=y
  - SND_CTL_INPUT_VALIDATION=n
  - SND_CTL_DEBUG=n
  - SND_SOC_AMD_ST_ES8336_MACH=m
  - SND_AMD_ASOC_REMBRANDT=m
  - SND_SOC_AMD_RPL_ACP6x=m
  - SND_SOC_INTEL_AVS_MACH_DA7219=m
  - SND_SOC_INTEL_AVS_MACH_DMIC=m
  - SND_SOC_INTEL_AVS_MACH_HDAUDIO=m
  - SND_SOC_INTEL_AVS_MACH_I2S_TEST=m
  - SND_SOC_INTEL_AVS_MACH_MAX98357A=m
  - SND_SOC_INTEL_AVS_MACH_MAX98373=m
  - SND_SOC_INTEL_AVS_MACH_NAU8825=m
  - SND_SOC_INTEL_AVS_MACH_RT274=m
  - SND_SOC_INTEL_AVS_MACH_RT286=m
  - SND_SOC_INTEL_AVS_MACH_RT298=m
  - SND_SOC_INTEL_AVS_MACH_RT5682=m
  - SND_SOC_INTEL_AVS_MACH_SSM4567=m
  - SND_SOC_SOF_METEORLAKE=m
  - SND_SOC_TAS2780=n
  - SND_SOC_WSA883X=n
  - USB support
  - UCSI_STM32G0=m
  - TYPEC_ANX7411=m
  - Microsoft Surface Platform-Specific Device Drivers
  - SURFACE_AGGREGATOR_HUB=m
  - SURFACE_AGGREGATOR_TABLET_SWITCH=m
  - Industrial I/O support
  - ENVELOPE_DETECTOR=n
  - SD_ADC_MODULATOR=n
  - VF610_ADC=n
  - Misc devices
  - TCG_TIS_I2C=m
  - SPI_MICROCHIP_CORE=m
  - PINCTRL_METEORLAKE=m
  - SENSORS_LT7182S=m
  - VIDEO_AR0521=m
  - LEDS_IS31FL319X=m
  - INFINIBAND_ERDMA=m
  - XEN_VIRTIO_FORCE_GRANT=n
  - VIDEO_STKWEBCAM=n
  - PWM_CLK=m
  - RESET_TI_TPS380X=n
  - ANDROID_BINDER_IPC=n
  - FPGA_MGR_MICROCHIP_SPI=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - VCPU_STALL_DETECTOR=m
  - DRM_PANEL_EBBG_FT8719=n
  - DRM_TI_DLPC3433=n
  - DRM_LOGICVC=n
  - DRM_IMX_LCDIF=n
  - I2C_HID_OF_ELAN=m
  - USB_ONBOARD_HUB=m
  - RTC_DRV_NCT3018Y=m
  - ppc64(le), s390x and riscv64
  - SCSI_BUSLOGIC=m
  - SCSI_FLASHPOINT=n
  - ppc64le and riscv64
  - CRYPTO_DEV_QAT_DH895xCC=m
  - CRYPTO_DEV_QAT_C3XXX=m
  - CRYPTO_DEV_QAT_C62X=m
  - CRYPTO_DEV_QAT_4XXX=m
  - CRYPTO_DEV_QAT_DH895xCCVF=m
  - CRYPTO_DEV_QAT_C3XXXVF=m
  - CRYPTO_DEV_QAT_C62XVF=m
  - ppc64 / ppc64le
  - PSERIES_PLPKS=y
  - KVM_BOOK3S_HV_P9_TIMING=n
  - KVM_BOOK3S_HV_P8_TIMING=n
  - RANDOMIZE_KSTACK_OFFSET=y
  - RANDOMIZE_KSTACK_OFFSET_DEFAULT=y
  - PSERIES_WDT=m
  - s390x
  - VFIO_PCI_ZDEV_KVM=y
  - riscv64
  - ERRATA_THEAD_CMO=y
  - NONPORTABLE=n
  - RISCV_ISA_ZICBOM=y
  - RANDOM_TRUST_CPU=y
  - I2C_MICROCHIP_CORE=m
  - SND_SOC_HDA=m
  - USB_MUSB_POLARFIRE_SOC=m
  - RTC_DRV_POLARFIRE_SOC=m
- commit 7c5c079
* Wed Aug 10 2022 jeffm@suse.com
- config: Disable reiserfs kernel module (bsc#1202309).
  Future access of reiserfs file systems can be done by using the FUSE
  implementation of reiserfs that ships with GRUB.
  $ grub2-mount <dev> /path/to/mountpoint
- commit a9b5183
* Wed Aug 10 2022 jslaby@suse.cz
- kbuild: dummy-tools: pretend we understand __LONG_DOUBLE_128__
  (ppc config fix).
- Update config files.
  This sets PPC_LONG_DOUBLE_128 automatically and allows us to set
  DRM_AMD_SECURE_DISPLAY too. I set it to y to copy other architectures.
- commit 43d5e95
* Tue Aug  9 2022 jslaby@suse.cz
- Update config files -- set SECURITY_SELINUX_CHECKREQPROT_VALUE=0 (bsc#1202280)
- commit bb4b04d
* Wed Aug  3 2022 msuchanek@suse.de
- Update config files (bsc#1184924).
  +RANDOM_TRUST_BOOTLOADER on arm
  This is set on all other platforms in Tumbleweed, and only on ARM in
  Leap. The ARM platform is unique in that it can have random source
  defined in EFI firmware as well as device tree, and we don't test this
  configuration in Factory because of the inverted config situation
  betwween Tumbleweed and Leap.
- commit 51df72d
* Tue Aug  2 2022 msuchanek@suse.de
- Fix parsing of rpm/macros.kernel-source on SLE12 (bsc#1201019).
- commit 9816878
* Sun Jul 31 2022 mkubecek@suse.cz
- Update to 5.19 final
- refresh configs
- commit a2e0cb8
* Tue Jul 26 2022 mbrugger@suse.com
- armv7hl: Update config files. (bsc#1201857)
  Enable PCI wifi chips
- commit d62f477
* Mon Jul 25 2022 tzimmermann@suse.de
- config: riscv64: Enable DRM stack for early-boot graphics (boo#1201833)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit 1d1b7e8
* Mon Jul 25 2022 tzimmermann@suse.de
- config: armv7hl: Enable DRM stack for early-boot graphics (boo#1193475)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit 4f99fa7
* Mon Jul 25 2022 tzimmermann@suse.de
- config: armv6hl: Enable DRM stack for early-boot graphics (boo#1193475)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit 1f057d6
* Mon Jul 25 2022 tzimmermann@suse.de
- config: arm64: Enable DRM stack for early-boot graphics (boo#1193475)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit 3664499
* Mon Jul 25 2022 mkubecek@suse.cz
- Update to 5.19-rc8
- update configs
  - PINCTRL_AMD=y (arm64 only, no longer allowed to be a module)
- commit 5981def
* Sun Jul 24 2022 mkubecek@suse.cz
- config: update and enable armv6hl
  Config option values were taken from global 5.19 updates while armv6hl
  configs were disabled, arm64 updates in commit 14beb34d0af9 ("config:
  update and enable arm64") and armv7hl config updates in commit 36833cf30926
  ("config: update and enable armv7hl").
- commit 6e78e38
* Sun Jul 24 2022 mkubecek@suse.cz
- config: update and enable armv7hl
  The list below omits config options update globally while armv7hl configs
  were disabled and config options updated on arm64 for 5.19 in commit
  14beb34d0af9 ("config: update and enable arm64").
- new config options
  - ARCH_BCMBCA=y
  - ARCH_HPE=y
  - ARCH_HPE_GXP=y
  - CPU_LITTLE_ENDIAN=y
  - ARM_ERRATA_764319=y
  - GVE=m
  - PINCTRL_IMXRT1170=y
  - GXP_WATCHDOG=m
  - MEDIA_CEC_RC=y
  - COMMON_CLK_EN7523=y
- new config options in armv7hl/lpae
  - EDAC_SYNOPSYS=m
  - XILINX_INTC=y
- commit 08c0f7a
* Sun Jul 24 2022 mkubecek@suse.cz
- config: update and enable arm64
  The list below omits config options updated globally while arm64 configs
  were disabled.
- new config options
  - ARM64_SME=y
  - CRYPTO_SM4_ARM64_CE_BLK=m
  - CRYPTO_SM4_ARM64_NEON_BLK=m
  - CAN_CTUCANFD_PLATFORM=m
  - QCOM_SSC_BLOCK_BUS=y
  - MTK_ADSP_IPC=m
  - MTD_NAND_ECC_MEDIATEK=m
  - NVME_APPLE=m
  - VMWARE_VMCI=m
  - SPI_MTK_SNFI=m
  - PINCTRL_IMXRT1170=m
  - PINCTRL_MT6795=y
  - PINCTRL_SC7280_LPASS_LPI=m
  - PINCTRL_SM8250_LPASS_LPI=m
  - ROCKCHIP_VOP=y
  - ROCKCHIP_VOP2=y
  - DRM_MSM_MDP4=y
  - DRM_MSM_MDP5=y
  - DRM_MSM_DPU=y
  - DRM_MSM_HDMI=y
  - DRM_PANEL_NEWVISION_NV3052C=m
  - DRM_FSL_LDB=m
  - DRM_LONTIUM_LT9211=m
  - DRM_DW_HDMI_GP_AUDIO=m
  - DRM_SSD130X_SPI=m
  - SND_SERIAL_GENERIC=m
  - SND_SOC_MT8195_MT6359=m
  - SND_SOC_SOF_MT8186=m
  - SND_SOC_TEGRA186_ASRC=m
  - LEDS_QCOM_LPG=m
  - TEGRA186_GPC_DMA=m
  - COMMON_CLK_MT8186=y
  - SC_GCC_8280XP=m
  - SC_LPASS_CORECC_7280=m
  - APPLE_RTKIT=m
  - APPLE_SART=m
  - PWM_XILINX=m
  - NVMEM_APPLE_EFUSES=m
  - INTERCONNECT_QCOM_SC8280XP=m
  - INTERCONNECT_QCOM_SDX65=m
  - HTE_TEGRA194=m
  - HTE_TEGRA194_TEST=n
  - TRUSTED_KEYS_CAAM=y
  - CRYPTO_DEV_FSL_CAAM_PRNG_API=y
  - FIPS_SIGNATURE_SELFTEST=n
  - PAGE_TABLE_CHECK=y
  - PAGE_TABLE_CHECK_ENFORCED=n
  - VMWARE_VMCI_VSOCKETS=m
- commit 2b1d35f
* Sat Jul 23 2022 schwab@suse.de
- riscv: enable CONFIG_STRICT_DEVMEM
- new config options
  - CONFIG_EXCLUSIVE_SYSTEM_RAM=y
  - CONFIG_IO_STRICT_DEVMEM=y
- commit 8806b83
* Sat Jul 23 2022 schwab@suse.de
- riscv: enable CONFIG_FTRACE
  - new config options
  - CONFIG_BPF_LSM=y
  - CONFIG_TASKS_RUDE_RCU=y
  - CONFIG_TRACEPOINTS=y
  - CONFIG_KPROBES_ON_FTRACE=y
  - CONFIG_UPROBES=y
  - CONFIG_BATMAN_ADV_TRACING=n
  - CONFIG_NET_DROP_MONITOR=m
  - CONFIG_ATH5K_TRACER=n
  - CONFIG_ATH6KL_TRACING=n
  - CONFIG_WIL6210_TRACING=y
  - CONFIG_ATH10K_TRACING=n
  - CONFIG_ATH11K_TRACING=n
  - CONFIG_IWLWIFI_DEVICE_TRACING=n
  - CONFIG_STM_SOURCE_FTRACE=m
  - CONFIG_PSTORE_FTRACE=n
  - CONFIG_DEBUG_PAGE_REF=n
  - CONFIG_NOP_TRACER=y
  - CONFIG_TRACER_MAX_TRACE=y
  - CONFIG_TRACE_CLOCK=y
  - CONFIG_RING_BUFFER=y
  - CONFIG_EVENT_TRACING=y
  - CONFIG_CONTEXT_SWITCH_TRACER=y
  - CONFIG_RING_BUFFER_ALLOW_SWAP=y
  - CONFIG_TRACING=y
  - CONFIG_GENERIC_TRACER=y
  - CONFIG_BOOTTIME_TRACING=y
  - CONFIG_FUNCTION_TRACER=y
  - CONFIG_FUNCTION_GRAPH_TRACER=y
  - CONFIG_DYNAMIC_FTRACE=y
  - CONFIG_DYNAMIC_FTRACE_WITH_REGS=y
  - CONFIG_FUNCTION_PROFILER=y
  - CONFIG_STACK_TRACER=y
  - CONFIG_IRQSOFF_TRACER=n
  - CONFIG_SCHED_TRACER=y
  - CONFIG_HWLAT_TRACER=n
  - CONFIG_OSNOISE_TRACER=y
  - CONFIG_TIMERLAT_TRACER=y
  - CONFIG_FTRACE_SYSCALLS=y
  - CONFIG_TRACER_SNAPSHOT=y
  - CONFIG_TRACER_SNAPSHOT_PER_CPU_SWAP=y
  - CONFIG_BRANCH_PROFILE_NONE=y
  - CONFIG_PROFILE_ANNOTATED_BRANCHES=n
  - CONFIG_BLK_DEV_IO_TRACE=y
  - CONFIG_KPROBE_EVENTS=y
  - CONFIG_KPROBE_EVENTS_ON_NOTRACE=n
  - CONFIG_UPROBE_EVENTS=y
  - CONFIG_BPF_EVENTS=y
  - CONFIG_DYNAMIC_EVENTS=y
  - CONFIG_PROBE_EVENTS=y
  - CONFIG_BPF_KPROBE_OVERRIDE=n
  - CONFIG_FTRACE_MCOUNT_RECORD=y
  - CONFIG_FTRACE_MCOUNT_USE_CC=y
  - CONFIG_SYNTH_EVENTS=y
  - CONFIG_TRACE_EVENT_INJECT=n
  - CONFIG_TRACEPOINT_BENCHMARK=n
  - CONFIG_RING_BUFFER_BENCHMARK=m
  - CONFIG_TRACE_EVAL_MAP_FILE=n
  - CONFIG_FTRACE_RECORD_RECURSION=n
  - CONFIG_FTRACE_STARTUP_TEST=n
  - CONFIG_RING_BUFFER_STARTUP_TEST=n
  - CONFIG_RING_BUFFER_VALIDATE_TIME_DELTAS=n
  - CONFIG_PREEMPTIRQ_DELAY_TEST=m
  - CONFIG_SYNTH_EVENT_GEN_TEST=n
  - CONFIG_KPROBE_EVENT_GEN_TEST=n
- commit e4f98ab
* Thu Jul 21 2022 mbrugger@suse.com
- arm64: Update config files. (bsc#1198737)
  Enable RTC_DRV_RX8025 to support RX-8035 on Traveres Ten64 board.
- commit 44eb5f2
* Thu Jul 21 2022 kbuild@suse.de
- Automatically updated to 5.19-rc7-next-20220720
- commit 93addea
* Wed Jul 20 2022 ludwig.nussel@suse.de
- kernel-obs-build: include qemu_fw_cfg (boo#1201705)
- commit e2263d4
* Tue Jul 19 2022 kbuild@suse.de
- Automatically updated to 5.19-rc7-next-20220719
- commit 74dcfb7
* Mon Jul 18 2022 tzimmermann@suse.de
- config: i386: Enable DRM stack for early-boot graphics (boo#1193474)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit 5134b68
* Sun Jul 17 2022 mkubecek@suse.cz
- Update to 5.19-rc7
- drop obsolete patches
  - patches.suse/tty-extract-tty_flip_buffer_commit-from-tty_flip_buf.patch
  - patches.suse/tty-use-new-tty_insert_flip_string_and_push_buffer-i.patch
- update configs (x86 only)
  - SPECULATION_MITIGATIONS=y
  - RETHUNK=y
  - CPU_UNRET_ENTRY=y
  - CPU_IBPB_ENTRY=y
  - CPU_IBRS_ENTRY=y
- commit 61952fe
* Sat Jul 16 2022 kbuild@suse.de
- Automatically updated to 5.19-rc6-next-20220715
- commit a515e28
* Thu Jul 14 2022 jeffm@suse.com
- rpm/kernel-binary.spec.in: Require dwarves >= 1.22 on SLE15-SP3 or newer
  Dwarves 1.22 or newer is required to build kernels with BTF information
  embedded in modules.
- commit ee19e9d
* Thu Jul 14 2022 kbuild@suse.de
- Automatically updated to 5.19-rc6-next-20220714
- commit f35bff0
* Wed Jul 13 2022 kbuild@suse.de
- Automatically updated to 5.19-rc6-next-20220712
- commit 05aa11d
* Wed Jul 13 2022 schwab@suse.de
- config: riscv: disable RISCV_BOOT_SPINWAIT
  We now rely on the SBI HSM extension which is provided by openSBI 0.7 or
  later.
- commit cad5e7d
* Wed Jul 13 2022 schwab@suse.de
- config: riscv: disable RISCV_SBI_V01
  The SBI v0.1 API is obsolete.
- commit 48d2d4c
* Tue Jul 12 2022 kbuild@suse.de
- Automatically updated to 5.19-rc6-next-20220711
- commit ff64672
* Mon Jul 11 2022 mkubecek@suse.cz
- Update to 5.19-rc6
- update configs
  - s390x/zfcpdump
  - CRC32_S390=n
  - SHA512_S390=n
  - SHA1_S390=n
  - SHA256_S390=n
  - SHA3_256_S390=n
  - SHA3_512_S390=n
  - GHASH_S390=n
  - AES_S390=n
  - DES_S390=n
  - CHACHA_S390=n
  - KEXEC_FILE=n
- commit 1883fec
* Sat Jul  9 2022 kbuild@suse.de
- Automatically updated to 5.19-rc5-next-20220708
- commit 3c02007
* Thu Jul  7 2022 kbuild@suse.de
- Automatically updated to 5.19-rc5-next-20220707
- commit 73de65a
* Wed Jul  6 2022 kbuild@suse.de
- Automatically updated to 5.19-rc5-next-20220706
- commit e9e36ab
* Tue Jul  5 2022 kbuild@suse.de
- Automatically updated to 5.19-rc5-next-20220705
- commit d9c0d7c
* Mon Jul  4 2022 kbuild@suse.de
- Automatically updated to 5.19-rc4-next-20220704
- commit 170954b
* Mon Jul  4 2022 mkubecek@suse.cz
- Update to 5.19-rc5
- update contigs
  - VIRTIO_HARDEN_NOTIFICATION=n
- commit 70a62a7
* Fri Jul  1 2022 kbuild@suse.de
- Automatically updated to 5.19-rc4-next-20220701
- commit 1d32a72
* Thu Jun 30 2022 kbuild@suse.de
- Automatically updated to 5.19-rc4-next-20220630
- commit ce5a267
* Wed Jun 29 2022 kbuild@suse.de
- Automatically updated to 5.19-rc4-next-20220629
- commit ff7c9ba
* Mon Jun 27 2022 kbuild@suse.de
- Automatically updated to 5.19-rc4-next-20220627
- commit 183d941
* Mon Jun 27 2022 mkubecek@suse.cz
- Update to 5.19-rc4
- update configs
  - FIPS_SIGNATURE_SELFTEST=n
- commit 72f81ae
* Fri Jun 24 2022 mkubecek@suse.cz
- config: enable MLX90614
  MLX90614 is I2C (SMBus) remote temperature sensor.
  The boards are available for SBCs:
  https://www.waveshare.com/product/modules/sensors/temperature-humidity-barometer/infrared-temperature-sensor.htm
  Enable the driver for potential users.
  Link: https://lists.opensuse.org/archives/list/kernel@lists.opensuse.org/thread/VHBAZ4YTJZ6H2DTMELYWILNGMRBXBMPI/
- commit 6d69ce5
* Fri Jun 24 2022 kbuild@suse.de
- Automatically updated to 5.19-rc3-next-20220624
- commit 4d11887
* Thu Jun 23 2022 kbuild@suse.de
- Automatically updated to 5.19-rc3-next-20220623
- commit 54f9cdb
* Wed Jun 22 2022 kbuild@suse.de
- Automatically updated to 5.19-rc3-next-20220622
- commit bfc5963
* Wed Jun 22 2022 jslaby@suse.cz
- Update config files.
  Run oldconfig which unsets CC_NO_ARRAY_BOUNDS as dummy tools emulate gcc
  20. We are ignoring it thanks to update in packaging, so that real
  compilation sets this right later.
- commit 656751c
* Wed Jun 22 2022 jslaby@suse.cz
- rpm/check-for-config-changes: ignore GCC12/CC_NO_ARRAY_BOUNDS
  Upstream commit f0be87c42cbd (gcc-12: disable '-Warray-bounds'
  universally for now) added two new compiler-dependent configs:
  * CC_NO_ARRAY_BOUNDS
  * GCC12_NO_ARRAY_BOUNDS
  Ignore them -- they are unset by dummy tools (they depend on gcc version
  == 12), but set as needed during real compilation.
- commit a14607c
* Tue Jun 21 2022 kbuild@suse.de
- Automatically updated to 5.19-rc3-next-20220621
- commit 749ac79
* Mon Jun 20 2022 kbuild@suse.de
- Automatically updated to 5.19-rc3-next-20220620
- commit d2bf674
* Sun Jun 19 2022 mkubecek@suse.cz
- Update to 5.19-rc3
- update configs
  - XILINX_INTC=y (OF architectures - i386, ppc64/ppc64le, riscv64)
- commit b494893
* Fri Jun 17 2022 kbuild@suse.de
- Automatically updated to 5.19-rc2-next-20220617
- commit 11ff16f
* Thu Jun 16 2022 kbuild@suse.de
- Automatically updated to 5.19-rc2-next-20220616
- commit 6e45e67
* Wed Jun 15 2022 kbuild@suse.de
- Automatically updated to 5.19-rc2-next-20220615
- commit 6650a9e
* Tue Jun 14 2022 mkubecek@suse.cz
- kernel-binary.spec: check s390x vmlinux location
  As a side effect of mainline commit edd4a8667355 ("s390/boot: get rid of
  startup archive"), vmlinux on s390x moved from "compressed" subdirectory
  directly into arch/s390/boot. As the specfile is shared among branches,
  check both locations and let objcopy use one that exists.
- commit cd15543
* Tue Jun 14 2022 tiwai@suse.de
- Add missing recommends of kernel-install-tools to kernel-source-vanilla (bsc#1200442)
- commit 93b1375
* Tue Jun 14 2022 kbuild@suse.de
- Automatically updated to 5.19-rc2-next-20220614
- commit 3e8f768
* Mon Jun 13 2022 mkubecek@suse.cz
- config: add CC_NO_ARRAY_BOUNDS=y
  Mainline commit f0be87c42cbd ("gcc-12: disable '-Warray-bounds' universally
  for now") adds new config option CONFIG_CC_NO_ARRAY_BOUNDS which is only
  present for gcc12 (and not future gcc >= 13). Therefore it is not added
  with dummy gcc which pretends to be gcc20 but it is with Factory gcc12,
  resulting in failed "missing config option" check.
  As a quick hack, add CONFIG_CC_NO_ARRAY_BOUNDS=y to all full configs until
  we have a more robust solution (manually added config option won't survive
  a config update with run_oldconfig.sh).
- commit 5279e7b
* Mon Jun 13 2022 mkubecek@suse.cz
- config: refresh
- commit 9792dcb
* Mon Jun 13 2022 mkubecek@suse.cz
- Update to 5.19-rc2
- drop obsolete patch
  - patches.suse/drm-amdgpu-always-flush-the-TLB-on-gfx8.patch
- update configs
  - XEN_VIRTIO=y (x86 only)
- commit c64d99c
* Fri Jun 10 2022 kbuild@suse.de
- Automatically updated to 5.19-rc1-next-20220610
- commit a0e698b
* Thu Jun  9 2022 kbuild@suse.de
- Automatically updated to 5.19-rc1-next-20220609
- commit e67b2e5
* Wed Jun  8 2022 tiwai@suse.de
- Update config files: disable CONFIG_NET_DSA_REALTEK_* on x86_64 (bsc#1200254)
- commit e147d66
* Wed Jun  8 2022 kbuild@suse.de
- Automatically updated to 5.19-rc1-next-20220608
- commit aaef763
* Tue Jun  7 2022 tiwai@suse.de
- Update config files: restore CONFIG_I8K=y (bsc#1199958)
- commit d27b27a
* Tue Jun  7 2022 kbuild@suse.de
- Automatically updated to 5.19-rc1-next-20220607
- commit 963ff37
* Mon Jun  6 2022 mkubecek@suse.cz
- Update to 5.19-rc1
- eliminate 54 patches (48 stable, 5 mainline, 1 other)
  - patches.kernel.org/*
  - patches.rpmify/scripts-dummy-tools-add-pahole.patch
  - patches.suse/KVM-x86-avoid-calling-x86-emulator-without-a-decoded-instruction
  - patches.suse/Revert-net-af_key-add-check-for-pfkey_broadcast-in-f.patch
  - patches.suse/iommu-amd-Increase-timeout-waiting-for-GA-log-enablement
  - patches.suse/simplefb-Enable-boot-time-VESA-graphic-mode-selectio.patch
  - patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/genksyms-add-override-flag.diff
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- 5.19-rc1 regression fix
  - patches.suse/drm-amdgpu-always-flush-the-TLB-on-gfx8.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - CONFIG_BOOT_CONFIG_EMBED=n
  - CONFIG_INITRAMFS_PRESERVE_MTIME=y
  - Processor type and features
  - CONFIG_INTEL_TDX_GUEST=y
  - CONFIG_PERF_EVENTS_AMD_BRS=y
  - CONFIG_MICROCODE_LATE_LOADING=n
  - Enable loadable module support
  - CONFIG_MODULE_UNLOAD_TAINT_TRACKING=y
  - Memory Management options
  - CONFIG_PTE_MARKER_UFFD_WP=y
  - Networking support
  - CONFIG_CAN_CTUCANFD_PCI=m
  - File systems
  - CONFIG_CACHEFILES_ONDEMAND=n
  - CONFIG_HUGETLB_PAGE_OPTIMIZE_VMEMMAP_DEFAULT_ON=n
  - Security options
  - CONFIG_TRUSTED_KEYS_TPM=y
  - CONFIG_TRUSTED_KEYS_TEE=y
  - CONFIG_RANDSTRUCT_NONE=y
  - Cryptographic API
  - CONFIG_CRYPTO_SM3_GENERIC=m
  - CONFIG_CRYPTO_SM4_GENERIC=m
  - CONFIG_SYSTEM_BLACKLIST_AUTH_UPDATE=y
  - Kernel hacking
  - CONFIG_DEBUG_NET=n
  - CONFIG_RCU_EXP_CPU_STALL_TIMEOUT=0
  - Generic Driver Options
  - CONFIG_FW_LOADER_COMPRESS_XZ=y
  - CONFIG_FW_LOADER_COMPRESS_ZSTD=y
  - CONFIG_FW_UPLOAD=y
  - Firmware Drivers
  - CONFIG_EFI_DXE_MEM_ATTRIBUTES=y
  - CONFIG_EFI_DISABLE_RUNTIME=n
  - CONFIG_EFI_COCO_SECRET=y
  - Network device support
  - CONFIG_OCTEON_EP=m
  - CONFIG_SFC_SIENA=m
  - CONFIG_SFC_SIENA_MTD=y
  - CONFIG_SFC_SIENA_MCDI_MON=y
  - CONFIG_SFC_SIENA_SRIOV=y
  - CONFIG_SFC_SIENA_MCDI_LOGGING=y
  - CONFIG_ADIN1100_PHY=m
  - CONFIG_DP83TD510_PHY=m
  - CONFIG_WLAN_VENDOR_PURELIFI=y
  - CONFIG_PLFXLC=m
  - CONFIG_RTW89_8852CE=m
  - CONFIG_WLAN_VENDOR_SILABS=y
  - CONFIG_MTK_T7XX=m
  - Input device support
  - CONFIG_JOYSTICK_SENSEHAT=m
  - CONFIG_INPUT_IQS7222=m
  - Hardware Monitoring support
  - CONFIG_SENSORS_NCT6775_I2C=m
  - CONFIG_SENSORS_XDPE152=m
  - Sound card support
  - CONFIG_SND_SOC_CS35L45_SPI=m
  - CONFIG_SND_SOC_CS35L45_I2C=m
  - CONFIG_SND_SOC_MAX98396=m
  - CONFIG_SND_SOC_WM8731_I2C=n
  - CONFIG_SND_SOC_WM8731_SPI=n
  - CONFIG_SND_SOC_WM8940=n
  - Virtualization drivers
  - CONFIG_EFI_SECRET=m
  - CONFIG_SEV_GUEST=m
  - X86 Platform Specific Device Drivers
  - CONFIG_INTEL_IFS=m
  - CONFIG_WINMATE_FM07_KEYS=m
  - Industrial I/O support
  - CONFIG_DMARD06=n
  - CONFIG_IIO_RESCALE=m
  - CONFIG_DPOT_DAC=n
  - CONFIG_VF610_DAC=n
  - CONFIG_CM3605=n
  - CONFIG_AK8974=n
  - CONFIG_IIO_MUX=m
  - CONFIG_HTE=y
  - CONFIG_HTE=y
  - Misc devices
  - CONFIG_INTEL_MEI_GSC=m
  - CONFIG_MHI_BUS_EP=m
  - CONFIG_REGULATOR_RT5759=m
  - CONFIG_HID_MEGAWORLD_FF=m
  - CONFIG_TYPEC_MUX_FSA4480=m
  - CONFIG_LEDS_PWM_MULTICOLOR=m
  - CONFIG_CHROMEOS_ACPI=m
  - CONFIG_NVSW_SN2201=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - DRM_PANEL_NEWVISION_NV3052C=n
  - DRM_FSL_LDB=n
  - DRM_LONTIUM_LT9211=n
  - SND_SERIAL_GENERIC=m
  - LEDS_QCOM_LPG=m
  - OMAP_GPMC=m
  - OMAP_GPMC_DEBUG=n
  - PWM_XILINX=m
  - i386
  - CAN_CTUCANFD_PLATFORM=m
  - ppc64/ppc64le
  - KASAN=n
  - s390x
  - S390_UV_UAPI=m
  - MUX_ADG792A=n
  - riscv64
  - ERRATA_THEAD=y
  - ERRATA_THEAD_PBMT=y
  - RISCV_ISA_SVPBMT=y
  - KEXEC_FILE=y
  - COMPAT=y
  - ARCH_MMAP_RND_COMPAT_BITS=8 (default)
  - NETFILTER_XTABLES_COMPAT=y
  - CAN_CTUCANFD_PLATFORM=m
  - HW_RANDOM_POLARFIRE_SOC=m
  - DRM_DW_HDMI_GP_AUDIO=n
  - IMA_KEXEC=y
  - STACK_HASH_ORDER=20 (default)
  - PAGE_TABLE_CHECK=y
  - PAGE_TABLE_CHECK_ENFORCED=n
  - */debug
  - DEBUG_NET=y
- commit 4b8a618
* Mon Jun  6 2022 kbuild@suse.de
- Automatically updated to 5.19-rc1-next-20220606
- commit 946b797
* Fri Jun  3 2022 msuchanek@suse.de
- Align ppc ELF ABI v2 option name with upstream option naming.
- Update config files.
- Refresh patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch.
- commit 2a863b1
* Fri Jun  3 2022 msuchanek@suse.de
- Refresh patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch
  Refresh config files.
- commit 8bf53fe
* Fri Jun  3 2022 jack@suse.cz
- Remove mistakenly enabled CONFIG_JBD2_DEBUG.
- commit c8f8050
* Fri Jun  3 2022 kbuild@suse.de
- Automatically updated to 5.18-next-20220603
- commit 0730c97
* Thu Jun  2 2022 kbuild@suse.de
- Automatically updated to 5.18-next-20220602
- commit 9058840
* Wed Jun  1 2022 kbuild@suse.de
- Automatically updated to 5.18-next-20220601
- commit 5c6d849
* Tue May 31 2022 kbuild@suse.de
- Automatically updated to 5.18-next-20220531
- commit 4b36359
* Fri May 27 2022 kbuild@suse.de
- Automatically updated to 5.18-next-20220527
- commit 20890e4
* Fri May 27 2022 msuchanek@suse.de
- Update config files -- DEBUG_INFO_DWARF5 (bsc#1199932)
  Set DEBUG_INFO_DWARF5 which makes use of dwarf5 on gcc-7 and newer.
- commit 054a95e
* Thu May 26 2022 kbuild@suse.de
- Automatically updated to 5.18-next-20220526
- commit 13bb4be
* Thu May 26 2022 msuchanek@suse.de
- kernel-binary.spec: Support radio selection for debuginfo.
  To disable debuginfo on 5.18 kernel a radio selection needs to be
  switched to a different selection. This requires disabling the currently
  active option and selecting NONE as debuginfo type.
- commit 43b5dd3
* Thu May 26 2022 jslaby@suse.cz
- Update config files -- DEBUG_INFO_DWARF_TOOLCHAIN_DEFAULT (bsc#1199932)
  Set DEBUG_INFO_DWARF_TOOLCHAIN_DEFAULT which makes use of dwarf5 on
  gcc-11 and newer.
- commit b836934
* Wed May 25 2022 kbuild@suse.de
- Automatically updated to 5.18-next-20220525
- commit 7d22c27
* Tue May 24 2022 kbuild@suse.de
- Automatically updated to 5.18-next-20220524
- commit 96a0029
* Mon May 23 2022 schwab@suse.de
- Add dtb-starfive
- commit 85335b1
* Sun May 22 2022 mkubecek@suse.cz
- Update to 5.18 final
- refresh configs (headers only)
- commit 19b1274
* Sat May 21 2022 kbuild@suse.de
- Automatically updated to 5.18-rc7-next-20220520
- commit 914ed4d
* Thu May 19 2022 kbuild@suse.de
- Automatically updated to 5.18-rc7-next-20220519
- commit 54a46d9
* Wed May 18 2022 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix missing kernel-preempt-devel and KMP Provides (bsc#1199046)
- commit 84d7ba8
* Tue May 17 2022 kbuild@suse.de
- Automatically updated to 5.18-rc7-next-20220517
- commit 83f3f62
* Fri May 13 2022 kbuild@suse.de
- Automatically updated to 5.18-rc6-next-20220513
- commit 57bb0c3
* Thu May 12 2022 kbuild@suse.de
- Automatically updated to 5.18-rc6-next-20220512
- commit 264e226
* Wed May 11 2022 kbuild@suse.de
- Automatically updated to 5.18-rc6-next-20220510
- commit cc1baaf
* Tue May 10 2022 kbuild@suse.de
- Automatically updated to 5.18-rc6-next-20220509
- commit 5231e4b
* Fri May  6 2022 kbuild@suse.de
- Automatically updated to 5.18-rc5-next-20220506
- commit 145fd66
* Fri May  6 2022 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: Also depend on dracut-systemd (bsc#1195775)
- commit 5d4e32c
* Thu May  5 2022 kbuild@suse.de
- Automatically updated to 5.18-rc5-next-20220504
- commit 6b60b7e
* Tue May  3 2022 kbuild@suse.de
- Automatically updated to 5.18-rc5-next-20220503
- commit 652a3a4
* Mon May  2 2022 msuchanek@suse.de
- Update config files.
  No pmem support on s390 - no such device.
- commit 4982428
* Mon May  2 2022 dmueller@suse.com
- config.conf: reenable armv7hl configs
- Update config files for armv7hl lpae/default
- Inherit settings from x86_64
- Use =m where available
- stick with CONFIG_UNWINDER_FRAME_POINTER=y
- commit aa89a87
* Sun May  1 2022 mkubecek@suse.cz
- Update to 5.18-rc5
- new config options:
  - BLK_DEV_FD_RAWCMD=n
- commit 5745c6c
* Fri Apr 29 2022 msuchanek@suse.de
- Update config files (bsc#1199024).
  arm, i386 LIBNVDIMM y->m
  i386 X86_PMEM_LEGACY y->m
- commit a8c8d06
* Fri Apr 29 2022 kbuild@suse.de
- Automatically updated to 5.18-rc4-next-20220429
- commit 287a1f4
* Thu Apr 28 2022 kbuild@suse.de
- Automatically updated to 5.18-rc4-next-20220428
- commit f6cfcd1
* Wed Apr 27 2022 kbuild@suse.de
- Automatically updated to 5.18-rc4-next-20220427
- commit 94b7e41
* Tue Apr 26 2022 kbuild@suse.de
- Automatically updated to 5.18-rc4-next-20220426
- commit 90122c3
* Mon Apr 25 2022 msuchanek@suse.de
- pahole 1.22 required for full BTF features.
  also recommend pahole for kernel-source to make the kernel buildable
  with standard config
- commit 364f54b
* Mon Apr 25 2022 mkubecek@suse.cz
- Update to 5.18-rc4
- refresh configs
- commit 2723ffd
* Fri Apr 22 2022 dmueller@suse.com
- use jobs not processors in the constraints
  jobs is the number of vcpus available to the build, while processors
  is the total processor count of the machine the VM is running on.
- commit a6e141d
* Fri Apr 22 2022 kbuild@suse.de
- Automatically updated to 5.18-rc3-next-20220422
- commit 1335063
* Thu Apr 21 2022 dmueller@suse.com
- config.conf: reenable armv6hl config
  Uses same config settings like x86_64
- commit 1868756
* Thu Apr 21 2022 kbuild@suse.de
- Automatically updated to 5.18-rc3-next-20220421
- commit 9f421a4
* Thu Apr 21 2022 jslaby@suse.cz
- scripts: dummy-tools, add pahole (bsc#1198388).
- Update config files.
  The config files now contain the dummy PAHOLE_VERSION (9999).
- commit b56b582
* Wed Apr 20 2022 kbuild@suse.de
- Automatically updated to 5.18-rc3-next-20220420
- commit c425156
* Tue Apr 19 2022 kbuild@suse.de
- Automatically updated to 5.18-rc3-next-20220419
- commit 033ddb1
* Sun Apr 17 2022 mkubecek@suse.cz
- config: enable arm64 builds
- reenable arm64 configs after update to 5.18-rc2
- new arm64 config options:
  - SHADOW_CALL_STACK=n
  - RELR=n
  - KCOV=n
- commit cb97d9e
* Sun Apr 17 2022 mkubecek@suse.cz
- Update to 5.18-rc3
- update configs
  - x86_64
  - NET_DSA_REALTEK_RTL8365MB=m
  - NET_DSA_REALTEK_RTL8366RB=m
- commit 8932548
* Fri Apr 15 2022 dmueller@suse.com
- Update config files.
  set modprobe path to /usr/sbin/modprobe after usrmerge completion
  in Tumbleweed.
- commit 021c7c7
* Thu Apr 14 2022 dmueller@suse.com
- Update config files.
- set CONFIG_NO_HZ_FULL again on armv7/aarch64 (bsc#1189692)
- commit a0db72e
* Thu Apr 14 2022 dmueller@suse.com
- Update config files.
  Disable legacy pty support (bsc#1198506)
- commit 25a519a
* Thu Apr 14 2022 kbuild@suse.de
- Automatically updated to 5.18-rc2-next-20220414
- commit 40db408
* Thu Apr 14 2022 dmueller@suse.com
- Update config files.
  set CONFIG_LSM_MMAP_MIN_ADDR according to upstream default to
  32768/65536 to have a minimum protection against null pointer
  vulnerabilities. This was previously set to 0 to enable dosemu,
  but dosemu no longer requires that setting, especially not on
  non-x86.
- commit bf82e81
* Wed Apr 13 2022 mbrugger@suse.com
- arm64: Update config files to v5.18-rc2
- commit 752d6b6
* Wed Apr 13 2022 kbuild@suse.de
- Automatically updated to 5.18-rc2-next-20220413
- commit 24cee9f
* Wed Apr 13 2022 tiwai@suse.de
- Update config files: set CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE=y (bsc#1198276)
  Using efivars as the pstore default backend is dangerous, as it might fill up
  quickly with dumps, eventually resulting in a non-bootable system.
  The feature can be enabled manually via efi_pstore.pstore_disable=0 option.
- commit f8ce69d
* Tue Apr 12 2022 kbuild@suse.de
- Automatically updated to 5.18-rc2-next-20220412
- commit c7775a7
* Mon Apr 11 2022 kbuild@suse.de
- Automatically updated to 5.18-rc1-next-20220411
- commit 581148d
* Mon Apr 11 2022 mkubecek@suse.cz
- Update to 5.18-rc2
- eliminate 1 patch
  - patches.suse/net-fungible-Fix-reference-to-__udivdi3-on-32b-build.patch
- update configs
  - SATA_LPM_POLICY renamed to SATA_MOBILE_LPM_POLICY
- commit fd6d8fa
* Fri Apr  8 2022 kbuild@suse.de
- Automatically updated to 5.18-rc1-next-20220408
- commit 89c1eb8
* Thu Apr  7 2022 kbuild@suse.de
- Automatically updated to 5.18-rc1-next-20220407
- commit 6182ebb
* Wed Apr  6 2022 kbuild@suse.de
- Automatically updated to 5.18-rc1-next-20220406
- commit 6e48b43
* Tue Apr  5 2022 kbuild@suse.de
- Automatically updated to 5.18-rc1-next-20220405
- commit 13f41ad
* Mon Apr  4 2022 kbuild@suse.de
- Automatically updated to 5.18-rc1-next-20220404
- commit 7d99cb5
* Mon Apr  4 2022 mkubecek@suse.cz
- Update to 5.18-rc1
- eliminate 47 patches (42 stable, 5 mainline)
  - patches.kernel.org/*
  - patches.suse/Bluetooth-btusb-Add-missing-Chicony-device-for-Realt.patch
  - patches.suse/Revert-Input-clear-BTN_RIGHT-MIDDLE-on-buttonpads.patch
  - patches.suse/Revert-swiotlb-rework-fix-info-leak-with-DMA_FROM_DE.patch
  - patches.suse/block-restore-the-old-set_task_ioprio-behaviour-wrt-.patch
  - patches.suse/bpf-add-config-to-allow-loading-modules-with-BTF-mis.patch
- refresh
  - patches.suse/s390-export-symbols-for-crash-kmp.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- disable ARM architectures (need config update)
- new config options
  - General setup
    CLOCKSOURCE_WATCHDOG_MAX_SKEW_US=100
  - Processor type and features
    X86_KERNEL_IBT=n
  - Binary Emulations
    X86_X32_ABI=n (renamed X86_X32)
  - General architecture-dependent options
    RANDOMIZE_KSTACK_OFFSET=y
  - Enable the block layer
    BLOCK_LEGACY_AUTOLOAD=y
  - Networking support
    PAGE_POOL_STATS=n
  - File systems
    F2FS_UNFAIR_RWSEM=n
  - Security options
    USER_DECRYPTED_DATA=n
  - Cryptographic API
    CRYPTO_DH_RFC7919_GROUPS=y
    CRYPTO_SM3_AVX_X86_64=m
  - Kernel hacking
    DEBUG_INFO_NONE=n
    DEBUG_INFO_DWARF5=n
    KFENCE_DEFERRABLE=n
    FPROBE=y
  - PCI support
    CXL_PCI=m
  - NVME Support
    NVME_VERBOSE_ERRORS=n
  - Serial ATA and Parallel ATA drivers (libata)
    SATA_LPM_POLICY=0
  - Network device support
    NET_DSA_REALTEK=m
    NET_VENDOR_DAVICOM=y
    DM9051=m
    NET_VENDOR_FUNGIBLE=y
    FUN_ETH=m
    MT7921U=m
  - Input device support
    TOUCHSCREEN_IMAGIS=m
  - Power supply class support
    IP5XXX_POWER=m
    BATTERY_SAMSUNG_SDI=n
    BATTERY_UG3105=m
  - Hardware Monitoring support
    I8K=n
    SENSORS_LM25066_REGULATOR=y
    SENSORS_PLI1209BC=m
    SENSORS_PLI1209BC_REGULATOR=y
    SENSORS_XDPE122_REGULATOR=y
    SENSORS_SY7636A=m
    SENSORS_TMP464=m
    SENSORS_ASUS_EC=m
  - Voltage and Current Regulator Support
    REGULATOR_RT5190A=m
    REGULATOR_SY7636A=m
  - Multimedia support
    VIDEO_HI847=m
    VIDEO_OG01A1B=m
    VIDEO_OV08D10=m
  - Graphics support
    DRM_PANEL_MIPI_DBI=m
    DRM_SSD130X=n
  - Sound card support
    SND_SOC_AMD_ACP_PCI=m
    SND_SOC_INTEL_AVS=m
    SND_SOC_INTEL_SOF_SSP_AMP_MACH=m
    SND_SOC_AW8738=n
    SND_SOC_TAS5805M=n
  - HID support
    HID_RAZER=m
    HID_SIGMAMICRO=m
  - USB support
    TYPEC_RT1719=m
    TYPEC_WUSB3801=m
  - Staging drivers
    VIDEO_ZORAN_DC30=y
    VIDEO_ZORAN_ZR36060=y
    VIDEO_ZORAN_BUZ=y
    VIDEO_ZORAN_DC10=y
    VIDEO_ZORAN_LML33=y
    VIDEO_ZORAN_LML33R10=y
    VIDEO_ZORAN_AVS6EYES=y
  - X86 Platform Specific Device Drivers
    AMD_HSMP=m
    INTEL_CHTWC_INT33FE=m
    INTEL_SDSI=m
    SERIAL_MULTI_INSTANTIATE=m
  - Industrial I/O support
    ADXL367_SPI=n
    ADXL367_I2C=n
    ADA4250=n
    LTC2688=n
    ADMV1014=n
    ADMV4420=n
    SX9324=n
    SX9360=n
    PECI=n
    PECI=n
  - Misc drivers
    MTD_NAND_ECC_MXIC=n
    I2C_DESIGNWARE_AMDPSP=y
    SPI_INTEL_PCI=m
    SPI_INTEL_PLATFORM=m
    INTEL_HFI_THERMAL=y
    MFD_SIMPLE_MFD_I2C=n
    MLX5_VFIO_PCI=m
    VMGENID=y
    CHROMEOS_PRIVACY_SCREEN=m
    RPMSG_CTRL=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - OPEN_DICE=m
  - MFD_MAX77714=n
  - REGULATOR_TPS6286X=m
  - VIDEO_ISL7998X=m
  - DRM_PANEL_ILITEK_ILI9341=n
  - DRM_PANEL_NOVATEK_NT35560=n
  - DRM_ITE_IT6505=n
  - COMMON_CLK_RS9_PCIE=m
  - PHY_CADENCE_DPHY_RX=m
  - i586
  - DTPM_DEVFREQ=y
  - INTEGRITY_MACHINE_KEYRING=y
  - ppc64 / ppc64le
  - NET_DSA_REALTEK_MDIO=m
  - NET_DSA_REALTEK_RTL8365MB=m
  - NET_DSA_REALTEK_RTL8366RB=m
  - MCTP_TRANSPORT_I2C=m
  - CRC64_ROCKSOFT=m
  - s390x
  - EXPOLINE_EXTERN=y
  - CRC64_ROCKSOFT=m
  - riscv64
  - RSEQ=y
  - DEBUG_RSEQ=n
  - CPU_IDLE=y
  - CPU_IDLE_GOV_LADDER=y
  - CPU_IDLE_GOV_TEO=y
  - RISCV_SBI_CPUIDLE=y
  - CPU_IDLE_GOV_MENU=y
  - PARPORT_PC=m
  - PARPORT_SERIAL=m
  - PARPORT_PC_FIFO=y
  - PARPORT_PC_PCMCIA=n
  - PARIDE=m
  - PARIDE_*=m (PARIDE_EPATC8=y
  - SCSI_PPA=m
  - SCSI_IMM=m
  - SCSI_IZIP_EPP16=n
  - SCSI_IZIP_SLOW_CTR=n
  - NET_DSA_REALTEK_MDIO=m
  - NET_DSA_REALTEK_RTL8365MB=m
  - NET_DSA_REALTEK_RTL8366RB=m
  - KS0108=n
  - CLK_STARFIVE_JH7100_AUDIO=m
  - POLARFIRE_SOC_SYS_CTRL=m
  - IDLE_INJECT=y
  - RISCV_PMU=y
  - RISCV_PMU_LEGACY=y
  - RISCV_PMU_SBI=y
  - CPU_IDLE_THERMAL=y
- commit 308c107
* Fri Apr  1 2022 kbuild@suse.de
- Automatically updated to 5.17-next-20220401
- commit 6829b40
* Thu Mar 31 2022 mkubecek@suse.cz
- Revert "config: Enable BPF LSM" (bsc#1197746)
  This reverts commit c2c25b18721866d6211054f542987036ed6e0a50.
  This config change was reported to break boot if SELinux is enabled. Revert
  until we have a fix.
- commit 04bf3cc
* Thu Mar 31 2022 kbuild@suse.de
- Automatically updated to 5.17-next-20220331
- commit de727c3
* Wed Mar 30 2022 msuchanek@suse.de
- Update config files.
- commit 1b08872
* Wed Mar 30 2022 msuchanek@suse.de
- Refresh patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch.
- Refresh config files.
- Refresh patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch.
- commit 27dfe9c
* Wed Mar 30 2022 kbuild@suse.de
- Automatically updated to 5.17-next-20220330
- commit f07b5cf
* Tue Mar 29 2022 kbuild@suse.de
- Automatically updated to 5.17-next-20220329
- commit 5953b35
* Mon Mar 28 2022 kbuild@suse.de
- Automatically updated to 5.17-next-20220328
- commit af2342e
* Fri Mar 25 2022 kbuild@suse.de
- Automatically updated to 5.17-next-20220325
- commit 00afe47
* Thu Mar 24 2022 kbuild@suse.de
- Automatically updated to 5.17-next-20220324
- commit 33375bc
* Wed Mar 23 2022 kbuild@suse.de
- Automatically updated to 5.17-next-20220323
- commit fbb1dc4
* Tue Mar 22 2022 kbuild@suse.de
- Automatically updated to 5.17-next-20220322
- commit 51d1e46
* Mon Mar 21 2022 dmueller@suse.com
- rpm/constraints.in: skip SLOW_DISK workers for kernel-source
- commit e84694f
* Mon Mar 21 2022 msuchanek@suse.de
- macros.kernel-source: Fix conditional expansion.
  Fixes: bb95fef3cf19 ("rpm: Use bash for %%() expansion (jsc#SLE-18234).")
- commit 7e857f7
* Sun Mar 20 2022 mkubecek@suse.cz
- Update to 5.17 final
- refresh configs (headers only)
- commit e52aab8
* Sat Mar 19 2022 msuchanek@suse.de
- rpm: Use bash for %%() expansion (jsc#SLE-18234).
  Since 15.4 alternatives for /bin/sh are provided by packages
  <something>-sh. While the interpreter for the build script can be
  selected the interpreter for %%() cannot.
  The kernel spec files use bashisms in %%().
  While this could technically be fixed there is more serious underlying
  problem: neither bash nor any of the alternatives are 100%% POSIX
  compliant nor bug-free.
  It is not my intent to maintain bug compatibility with any number of
  shells for shell scripts embedded in the kernel spec file. The spec file
  syntax is not documented so embedding the shell script in it causes some
  unspecified transformation to be applied to it. That means that
  ultimately any changes must be tested by building the kernel, n times if
  n shells are supported.
  To reduce maintenance effort require that bash is used for kernel build
  always.
- commit bb95fef
* Fri Mar 18 2022 kbuild@suse.de
- Automatically updated to 5.17-rc8-next-20220318
- commit 6233e53
* Thu Mar 17 2022 kbuild@suse.de
- Automatically updated to 5.17-rc8-next-20220317
- commit 2360ea8
* Wed Mar 16 2022 ailiop@suse.com
- config: enable XFS_RT (bsc#1197190)
- commit eb8cd7c
* Wed Mar 16 2022 msuchanek@suse.de
- rpm: Run external scriptlets on uninstall only when available
  (bsc#1196514 bsc#1196114 bsc#1196942).
  When dependency cycles are encountered package dependencies may not be
  fulfilled during zypper transaction at the time scriptlets are run.
  This is a problem for kernel scriptlets provided by suse-module-tools
  when migrating to a SLE release that provides these scriptlets only as
  part of LTSS. The suse-module-tools that provides kernel scriptlets may
  be removed early causing migration to fail.
- commit ab8dd2d
* Wed Mar 16 2022 dmueller@suse.com
- rpm/*.spec.in: remove backtick usage
- commit 87ca1fb
* Wed Mar 16 2022 kbuild@suse.de
- Automatically updated to 5.17-rc8-next-20220316
- commit 0dd39d7
* Wed Mar 16 2022 msuchanek@suse.de
- rpm: SC2006: Use $(...) notation instead of legacy backticked `...`.
- commit f0d0e90
* Tue Mar 15 2022 dmueller@suse.com
- rpm/kernel-source.spec.in: call fdupes per subpackage
  It is a waste of time to do a global fdupes when we have
  subpackages.
- commit 1da8439
* Mon Mar 14 2022 mkubecek@suse.cz
- Update to 5.17-rc8
- update configs
  - arm64
  - MITIGATE_SPECTRE_BRANCH_HISTORY=y
  - armv7hl
  - HARDEN_BRANCH_HISTORY=y
- commit 8f57ebd
* Thu Mar 10 2022 kbuild@suse.de
- Automatically updated to 5.17-rc7-next-20220310
- commit 1d3619d
* Thu Mar 10 2022 dmueller@suse.com
- rpm/arch-symbols,guards,*driver: Replace Novell with SUSE.
- commit 174a64f
* Thu Mar 10 2022 dmueller@suse.com
- rpm/kernel-docs.spec.in: use %%%%license for license declarations
  Limited to SLE15+ to avoid compatibility nightmares.
- commit 73d560e
* Wed Mar  9 2022 dmueller@suse.com
- rpm/*.spec.in: Use https:// urls
- commit 77b5f8e
* Tue Mar  8 2022 kbuild@suse.de
- Automatically updated to 5.17-rc7-next-20220308
- commit c0895cc
* Mon Mar  7 2022 kbuild@suse.de
- Automatically updated to 5.17-rc6-next-20220307
- commit a9b3ad3
* Fri Mar  4 2022 kbuild@suse.de
- Automatically updated to 5.17-rc6-next-20220304
- commit e6f6e46
* Fri Mar  4 2022 mkubecek@suse.cz
- config: refresh
  Since commit bb988d4625a3 ("kernel-binary: Do not include sourcedir in
  certificate path."), MODULE_SIG_HASH config option is mandatory in diff
  configs.
- commit e525998
* Thu Mar  3 2022 kbuild@suse.de
- Automatically updated to 5.17-rc6-next-20220303
- commit 176043b
* Thu Mar  3 2022 pvorel@suse.cz
- config: ppc64{,le}: build vmx-crypto as module (bsc#1195768)
  Building CONFIG_CRYPTO_DEV_VMX_ENCRYPT as module is the default in
  mainline since v4.8, we use it in SLES and already in
  config/ppc64/default. Thus unify it in the other configs.
  There are build dependencies which has been fixed in mainline
  647d41d3952d ("crypto: vmx - add missing dependencies")
  (currently still at maintainer herbert/cryptodev-2.6 tree)
  But instead of waiting commit to be accepted or backporting it we just
  unify configs, which is useful anyway
- commit 2f88321
* Wed Mar  2 2022 msuchanek@suse.de
- kernel-binary.spec: Also exclude the kernel signing key from devel package.
  There is a check in OBS that fails when it is included. Also the key is
  not reproducible.
  Fixes: bb988d4625a3 ("kernel-binary: Do not include sourcedir in certificate path.")
- commit 68fa069
* Wed Mar  2 2022 msuchanek@suse.de
- rpm/check-for-config-changes: Ignore PAHOLE_VERSION.
- commit 88ba5ec
* Wed Mar  2 2022 kbuild@suse.de
- Automatically updated to 5.17-rc6-next-20220302
- commit b6b27a2
* Tue Mar  1 2022 kbuild@suse.de
- Automatically updated to 5.17-rc6-next-20220301
- commit 3e2f53a
* Sun Feb 27 2022 mkubecek@suse.cz
- config: update vanilla configs
  FB_BOOT_VESA_SUPPORT was replaced BOOT_VESA_SUPPORT by a patch but this
  patch is not applied to vanilla flavor so that we have to keep the option
  in */vanilla configs until the patch reaches mainline.
- commit 1f9bf3c
* Sun Feb 27 2022 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: add systemd-initrd and terminfo dracut module (bsc#1195775)
- commit d9a821b
* Sat Feb 26 2022 kbuild@suse.de
- Automatically updated to 5.17-rc5-next-20220225
- commit 29339c7
* Fri Feb 25 2022 kbuild@suse.de
- Automatically updated to 5.17-rc5-next-20220224
- commit 38011f3
* Thu Feb 24 2022 kbuild@suse.de
- Automatically updated to 5.17-rc5-next-20220223
- commit b8fd51a
* Wed Feb 23 2022 kbuild@suse.de
- Automatically updated to 5.17-rc5-next-20220222
- commit 060f7cd
* Wed Feb 23 2022 msuchanek@suse.de
- bpf: add config to allow loading modules with BTF mismatches (bsc#1194501).
- Update config files.
- commit 99dd863
* Wed Feb 23 2022 msuchanek@suse.de
- simplefb: Enable boot time VESA graphic mode selection (bsc#1193250).
- Update config files.
- commit eee6a21
* Mon Feb 21 2022 mkubecek@suse.cz
- Update to 5.17-rc5
- refresh configs
- commit 248ee14
* Thu Feb 17 2022 kbuild@suse.de
- Automatically updated to 5.17-rc4-next-20220217
- commit ca15b3b
* Wed Feb 16 2022 tzimmermann@suse.de
- Revert "config: x86-64: Enable DRM stack for early-boot graphics (boo#1193472)"
  This reverts commit a6b1e6089c7fbcb3dc149eb1a005a32f0345fa13.
  Going back to efifb/vesafb for now. See boo#1195885 and boo#1195887.
- commit aadd217
* Wed Feb 16 2022 kbuild@suse.de
- Automatically updated to 5.17-rc4-next-20220216
- commit 9eeaff7
* Wed Feb 16 2022 dmueller@suse.com
- config: Disable CONFIG_READ_ONLY_THP_FOR_FS (bsc#1195774)
- commit 1a9eda9
* Wed Feb 16 2022 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: use default dracut modules (bsc#1195926,
  bsc#1198484)
  Let's iron out the reduced initrd optimisation in Tumbleweed.
  Build full blown dracut initrd with systemd for SLE15 SP4.
- commit ea76821
* Tue Feb 15 2022 dmueller@suse.com
- config.conf: reenable armv6hl/armv7hl and aarch64
- Update config files:
  Taken choices from x86_64/default for all new options
  Otherwise =m where possible, =y otherwise unless DEBUG or EXPERIMENTAL
- commit 42f6b39
* Tue Feb 15 2022 kbuild@suse.de
- Automatically updated to 5.17-rc4-next-20220215
- commit ad2fb8b
* Mon Feb 14 2022 kbuild@suse.de
- Automatically updated to 5.17-rc4-next-20220214
- commit 743e212
* Fri Feb 11 2022 msuchanek@suse.de
- kernel-binary: Do not include sourcedir in certificate path.
  The certs macro runs before build directory is set up so it creates the
  aggregate of supplied certificates in the source directory.
  Using this file directly as the certificate in kernel config works but
  embeds the source directory path in the kernel config.
  To avoid this symlink the certificate to the build directory and use
  relative path to refer to it.
  Also fabricate a certificate in the same location in build directory
  when none is provided.
- commit bb988d4
* Fri Feb 11 2022 msuchanek@suse.de
- BTF: Don't break ABI when debuginfo is disabled.
- commit 3f9acd3
* Fri Feb 11 2022 msuchanek@suse.de
- constraints: Also adjust disk requirement for x86 and s390.
- commit 9719db0
* Fri Feb 11 2022 msuchanek@suse.de
- constraints: Increase disk space for aarch64
- commit 09c2882
* Fri Feb 11 2022 kbuild@suse.de
- Automatically updated to 5.17-rc3-next-20220211
- commit 4de58b9
* Thu Feb 10 2022 kbuild@suse.de
- Automatically updated to 5.17-rc3-next-20220210
- commit 590a0b7
* Wed Feb  9 2022 kbuild@suse.de
- Automatically updated to 5.17-rc3-next-20220209
- commit ced8754
* Tue Feb  8 2022 kbuild@suse.de
- Automatically updated to 5.17-rc3-next-20220208
- commit 0ad88ea
* Mon Feb  7 2022 kbuild@suse.de
- Automatically updated to 5.17-rc3-next-20220207
- commit 3909dc5
* Sun Feb  6 2022 mkubecek@suse.cz
- Update to 5.17-rc3
- eliminate 1 patch
  - patches.suse/cifs-fix-workstation_name-for-multiuser-mounts.patch
- update configs
  - FRAMEBUFFER_CONSOLE_LEGACY_ACCELERATION=n (y on i386)
- commit 011d00e
* Fri Feb  4 2022 kbuild@suse.de
- Automatically updated to 5.17-rc2-next-20220204
- commit ec4a7aa
* Thu Feb  3 2022 kbuild@suse.de
- Automatically updated to 5.17-rc2-next-20220203
- commit 95ae730
* Wed Feb  2 2022 kbuild@suse.de
- Automatically updated to 5.17-rc2-next-20220202
- commit 9d7d288
* Tue Feb  1 2022 kbuild@suse.de
- Automatically updated to 5.17-rc2-next-20220201
- commit 47c55b9
* Mon Jan 31 2022 ludwig.nussel@suse.de
- kernel-obs-build: include 9p (boo#1195353)
  To be able to share files between host and the qemu vm of the build
  script, the 9p and 9p_virtio kernel modules need to be included in
  the initrd of kernel-obs-build.
- commit 0cfe67a
* Mon Jan 31 2022 kbuild@suse.de
- Automatically updated to 5.17-rc2-next-20220131
- commit b7e5b79
* Mon Jan 31 2022 tzimmermann@suse.de
- config: x86-64: Enable DRM stack for early-boot graphics (boo#1193472)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit 70dbc17
* Sun Jan 30 2022 mkubecek@suse.cz
- Update to 5.17-rc2
- eliminate 3 patches
  - patches.suse/s390-uaccess-fix-compile-error.patch
  - patches.suse/tcp-Add-a-stub-for-sk_defer_free_flush.patch
  - patches.suse/tcp-add-a-missing-sk_defer_free_flush-in-tcp_splice_.patch
- refresh configs
- commit 4a05aeb
* Fri Jan 28 2022 kbuild@suse.de
- Automatically updated to 5.17-rc1-next-20220128
- commit 4caf0ac
* Fri Jan 28 2022 mkubecek@suse.cz
- config: disable REGULATOR_MAX20086 on s390x
  This driver seems to make little sense on s390x and it also fails to build
  due to disabled CONFIG_GPIOLIB.
- commit d7918d0
* Thu Jan 27 2022 kbuild@suse.de
- Automatically updated to 5.17-rc1-next-20220127
- commit 04e984b
* Wed Jan 26 2022 tiwai@suse.de
- Update config files: disable CONFIG_INTEL_IDXD_COMPAT (bsc#1194858)
  The compat support is rather unwanted, and this allows us to build
  idxd bus as module, too.
- commit c7100c5
* Tue Jan 25 2022 mrostecki@suse.de
- config: Enable BPF LSM
  This LSM might get more adoption both in core system projects and
  container/k8s works and it would be good to be ready to support them.
  BPF LSM is a feature available since kernel 5.7 which allows to write
  BPF programs attached to LSM hooks and allowing/denying a particular
  event.
  BPF LSM is already adopted in a (not yet default) restrict-fs feature in
  systemd[0].
  BPF LSM is also used in the lockc[1] project which we develop at SUSE.
  There should be no functional or performance changes for users who don't
  load any BPF LSM programs. BPF LSM works only if some BPF programs is
  explicitly loaded.
  [0] https://github.com/systemd/systemd/blob/main/src/core/bpf/restrict_fs/restrict-fs.bpf.c
  [1] https://github.com/rancher-sandbox/lockc
- commit 5d43e2e
* Tue Jan 25 2022 kbuild@suse.de
- Automatically updated to 5.17-rc1-next-20220125
- commit 8606c2f
* Mon Jan 24 2022 msuchanek@suse.de
- kernel-binary.spec.in: Move 20-kernel-default-extra.conf to the correctr
  directory (bsc#1195051).
- commit c80b5de
* Mon Jan 24 2022 kbuild@suse.de
- Automatically updated to 5.17-rc1-next-20220124
- commit b126738
* Mon Jan 24 2022 mkubecek@suse.cz
- Update to 5.17-rc1
- eliminated 73 patches (67 stable, 6 mainline)
  - patches.kernel.org/*
  - patches.suse/0001-usb-Add-Xen-pvUSB-protocol-description.patch
  - patches.suse/0002-usb-Introduce-Xen-pvUSB-frontend-xen-hcd.patch
  - patches.suse/ALSA-usb-audio-Add-minimal-mute-notion-in-dB-mapping.patch
  - patches.suse/ALSA-usb-audio-Fix-dB-level-of-Bose-Revolve-SoundLin.patch
  - patches.suse/ALSA-usb-audio-Use-int-for-dB-map-values.patch
  - patches.suse/mwifiex-Fix-skb_over_panic-in-mwifiex_usb_recv.patch
- refresh
  - patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch
  - patches.suse/iwlwifi-module-firmware-ucode-fix.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
- disable ARM architectures (need config update)
- new config options
  - Power management and ACPI options
  - ACPI_PFRUT=m
  - ACPI_PCC=y
  - X86_AMD_PSTATE=m
  - Memory Management options
  - ANON_VMA_NAME=y
  - Networking support
  - NET_9P_FD=m
  - File systems
  - CACHEFILES_ERROR_INJECTION=n
  - UNICODE_UTF8_DATA=y
  - Kernel hacking
  - NET_DEV_REFCNT_TRACKER=n
  - NET_NS_REFCNT_TRACKER=n
  - PAGE_TABLE_CHECK=y
  - PAGE_TABLE_CHECK_ENFORCED=n
  - FTRACE_SORT_STARTUP_TEST=n
  - TEST_REF_TRACKER=n
  - TEST_SIPHASH=n
  - Generic Driver Options
  - DEVTMPFS_SAFE=n
  - Network device support
  - NET_VENDOR_ENGLEDER=y
  - TSNEP=m
  - TSNEP_SELFTESTS=n
  - ICE_HWTS=y
  - NET_VENDOR_VERTEXCOM=y
  - MSE102X=m
  - MCTP_SERIAL=m
  - IWLMEI=m
  - WWAN_DEBUGFS=n
  - Hardware Monitoring support
  - SENSORS_NZXT_SMART2=m
  - SENSORS_DELTA_AHE50DC_FAN=m
  - SENSORS_IR38064_REGULATOR=y
  - SENSORS_MP5023=m
  - SENSORS_INA238=m
  - SENSORS_ASUS_WMI=m
  - SENSORS_ASUS_WMI_EC=m
  - Voltage and Current Regulator Support
  - REGULATOR_MAX20086=m
  - REGULATOR_TPS68470=m
  - Graphics support
  - TINYDRM_ILI9163=n
  - Sound card support
  - SND_HDA_SCODEC_CS35L41_I2C=m
  - SND_HDA_SCODEC_CS35L41_SPI=m
  - SND_SOC_INTEL_SOF_NAU8825_MACH=m
  - SND_SOC_SOF_AMD_TOPLEVEL=m
  - SND_SOC_SOF_AMD_RENOIR=m
  - SND_SOC_AK4375=n
  - SND_SOC_TLV320ADC3XXX=n
  - X86 Platform Specific Device Drivers
  - YOGABOOK_WMI=m
  - ASUS_TF103C_DOCK=m
  - INTEL_VSEC=m
  - X86_ANDROID_TABLETS=m
  - SIEMENS_SIMATIC_IPC=m
  - SIEMENS_SIMATIC_IPC_WDT=m
  - Common Clock Framework
  - COMMON_CLK_TPS68470=n
  - COMMON_CLK_LAN966X=n
  - Industrial I/O support
  - TI_ADS8344=n
  - TI_ADS8688=n
  - TI_ADS124S08=n
  - AD74413R=n
  - AD3552R=n
  - AD7293=n
  - MAX5821=n
  - ADMV8818=n
  - ADMV1013=n
  - Misc drivers
  - GNSS_USB=m
  - SERIAL_8250_PERICOM=y
  - GPIO_SIM=m
  - CHARGER_MAX77976=m
  - VIDEO_OV5693=m
  - HID_LETSKETCH=m
  - LEDS_SIEMENS_SIMATIC_IPC=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - DRM_RCAR_USE_LVDS=n
  - DRM_RCAR_MIPI_DSI=n
  - DRM_PANEL_BOE_BF060Y8M_AJ0=n
  - DRM_PANEL_JDI_R63452=n
  - DRM_PANEL_NOVATEK_NT35950=n
  - DRM_PANEL_SONY_TULIP_TRULY_NT35521=n
  - VIDEO_MAX96712=m
  - PHY_FSL_IMX8M_PCIE=m
  - x86_64
  - SLS=y
  - i386
  - PHY_LAN966X_SERDES=m
  - ppc64 / ppc64le
  - KVM_BOOK3S_HV_NESTED_PMU_WORKAROUND=n
  - SURFACE_PLATFORMS=n
  - s390x
  - SURFACE_PLATFORMS=n
  - CRYPTO_CHACHA_S390=m
  - riscv64
  - SOC_STARFIVE=y
  - RISCV_BOOT_SPINWAIT=y
  - PINCTRL_STARFIVE=m
  - SND_AMD_ACP_CONFIG=m
  - CLK_STARFIVE_JH7100=y
  - RESET_STARFIVE_JH7100=y
  - PHY_LAN966X_SERDES=m
- commit 13f9d36
* Fri Jan 21 2022 kbuild@suse.de
- Automatically updated to 5.16-next-20220121
- commit bed670a
* Thu Jan 20 2022 msuchanek@suse.de
- kernel-binary.spec: Do not use the default certificate path (bsc#1194943).
  Using the the default path is broken since Linux 5.17
- commit 68b36f0
* Thu Jan 20 2022 kbuild@suse.de
- Automatically updated to 5.16-next-20220120
- commit 4bdb937
* Tue Jan 18 2022 kbuild@suse.de
- Automatically updated to 5.16-next-20220118
- commit 1c516c4
* Mon Jan 17 2022 kbuild@suse.de
- Automatically updated to 5.16-next-20220117
- commit 109cbde
* Sun Jan 16 2022 kbuild@suse.de
- Automatically updated to 5.16-next-20220116
- commit 3dd6d82
* Sat Jan 15 2022 kbuild@suse.de
- Automatically updated to 5.16-next-20220115
- commit 6f5b452
* Fri Jan 14 2022 kbuild@suse.de
- Automatically updated to 5.16-next-20220114
- commit ca83ed9
* Thu Jan 13 2022 kbuild@suse.de
- Automatically updated to 5.16-next-20220113
- commit b331f67
* Wed Jan 12 2022 kbuild@suse.de
- Automatically updated to 5.16-next-20220112
- commit 6694463
* Tue Jan 11 2022 kbuild@suse.de
- Automatically updated to 5.16-next-20220111
- commit f49ffa6
* Mon Jan 10 2022 kbuild@suse.de
- Automatically updated to 5.16-rc8-next-20220110
- commit 321e20a
* Mon Jan 10 2022 mkubecek@suse.cz
- Update to 5.16 final
- refresh configs (headers only)
- commit e5ad967
* Sat Jan  8 2022 kbuild@suse.de
- Automatically updated to 5.16-rc8-next-20220107
- commit e15235d
* Fri Jan  7 2022 kbuild@suse.de
- Automatically updated to 5.16-rc8-next-20220106
- commit 7e42a74
* Fri Jan  7 2022 tiwai@suse.de
- rpm/kernel-binary.spec.in: Add Provides of kernel-preempt (jsc#SLE-18857)
  For smooth migration with the former kernel-preempt user, kernel-default
  provides kernel-preempt now when CONFIG_PREEMPT_DYNAMIC is defined.
- commit d292a81
* Wed Jan  5 2022 kbuild@suse.de
- Automatically updated to 5.16-rc8-next-20220105
- commit 6efe7a9
* Tue Jan  4 2022 kbuild@suse.de
- Automatically updated to 5.16-rc8-next-20220104
- commit 34ef7bb
* Mon Jan  3 2022 dmueller@suse.com
- Revert "config: disable BTRFS_ASSERT in default kernels"
  This was pushed without enough review, reverting.
- commit a725a41
* Mon Jan  3 2022 kbuild@suse.de
- config.conf: Add remaining architectures as disabled.
- commit 4841516
* Fri Dec 31 2021 schwab@suse.de
- config: Enable CONFIG_CMA on riscv64
  Non-default dependent config changes:
- DMA_CMA=y
- commit 9f1d139
* Thu Dec 30 2021 dmueller@suse.com
- fix rpm build warning
  tumbleweed rpm is adding these warnings to the log:
  It's not recommended to have unversioned Obsoletes: Obsoletes:      microcode_ctl
- commit 3ba8941
* Mon Dec 27 2021 mkubecek@suse.cz
- Update to 5.16-rc7
- refresh
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
- refresh configs
- commit d03c6ba
* Fri Dec 24 2021 kbuild@suse.de
- Automatically updated to 5.16-rc6-next-20211224
- commit 3e9f616
* Thu Dec 23 2021 kbuild@suse.de
- Automatically updated to 5.16-rc6-next-20211223
- commit 9e8a018
* Wed Dec 22 2021 dmueller@suse.com
- build initrd without systemd
  This reduces the size of the initrd by over 25%%, which
  improves startup time of the virtual machine by 0.5-0.6s on
  very fast machines, more on slower ones.
- commit ef4c569
* Wed Dec 22 2021 dmueller@suse.com
- config: disable BTRFS_ASSERT in default kernels
  BTRFS_ASSERT is marked as developer only option and hence
  shouldn't be enabled in the default kernel. we enable it
  in the debug flavor now.
  This improves performance of a fio randrw run by over 21%% and
  reduces code size by 25%%.
- commit 91b6218
* Wed Dec 22 2021 kbuild@suse.de
- Automatically updated to 5.16-rc6-next-20211221
- commit 7033454
* Tue Dec 21 2021 kbuild@suse.de
- Automatically updated to 5.16-rc5-next-20211220
- commit c758204
* Mon Dec 20 2021 dmueller@suse.com
- add kvmsmall flavor for aarch64
- commit deff41d
* Mon Dec 20 2021 mkubecek@suse.cz
- Update to 5.16-rc6
- refresh configs
- disable
  patches.suse/btrfs-use-the-new-VFS-super_block_dev.patch
  - needs an update after mainline commit 33fab972497a ("btrfs: fix double
    free of anon_dev after failure to create subvolume")
- commit 1edf65e
* Mon Dec 20 2021 mkubecek@suse.cz
- config: enable and refresh arm architectures
- commit 19efe39
* Sat Dec 18 2021 kbuild@suse.de
- Automatically updated to 5.16-rc5-next-20211217
- commit 9efcc24
* Fri Dec 17 2021 dmueller@suse.com
- kernel-obs-build: remove duplicated/unused parameters
  lbs=0 - this parameters is just giving "unused parameter" and it looks
  like I can not find any version that implemented this.
  rd.driver.pre=binfmt_misc is not needed when setup_obs is used, it
  alread loads the kernel module.
  quiet and panic=1 will now be also always added by OBS, so we don't have
  to set it here anymore.
- commit 972c692
* Fri Dec 17 2021 kbuild@suse.de
- Automatically updated to 5.16-rc5-next-20211216
- commit 5cda1fa
* Thu Dec 16 2021 mbrugger@suse.com
- armv6hl: Update config files.
  Update config to v5.16-rc5
- commit cc9e71d
* Thu Dec 16 2021 mbrugger@suse.com
- armv7hl: Update config files.
  Update config to v5.16-rc3
- commit 2fb8960
* Thu Dec 16 2021 mbrugger@suse.com
- arm64: Update config files.
  Update configs to v5.16-rc5
- commit fd480e2
* Thu Dec 16 2021 kbuild@suse.de
- Automatically updated to 5.16-rc5-next-20211215
- commit 78e1287
* Wed Dec 15 2021 kbuild@suse.de
- Automatically updated to 5.16-rc5-next-20211214
- commit 2f6f152
* Wed Dec 15 2021 jslaby@suse.cz
- Update config files.
  Disable REF_TRACKER and its users. It causes crashes:
  https://lore.kernel.org/all/a6b342b3-8ce1-70c8-8398-fceaee0b51ff@gmail.com/
- commit eddd55f
* Tue Dec 14 2021 dmueller@suse.com
- Revert "- rpm/*build: use buildroot macro instead of env variable"
  buildroot macro is not being expanded inside a shell script. go
  back to the environment variable usage. This reverts parts of
  commit e2f60269b9330d7225b2547e057ef0859ccec155.
- commit fe85f96
* Tue Dec 14 2021 dmueller@suse.com
- kernel-obs-build: include the preferred kernel parameters
  Currently the Open Build Service hardcodes the kernel boot parameters
  globally. Recently functionality was added to control the parameters
  by the kernel-obs-build package, so make use of that. parameters here
  will overwrite what is used by OBS otherwise.
- commit a631240
* Mon Dec 13 2021 msuchanek@suse.de
- config: INPUT_EVBUG=n (bsc#1192974).
  Debug driver unsuitable for production, only enabled on ppc64.
- commit 2ff8364
* Mon Dec 13 2021 dmueller@suse.com
- kernel-obs-build: inform build service about virtio-serial
  Inform the build worker code that this kernel supports virtio-serial,
  which improves performance and relability of logging.
- commit 301a3a7
* Mon Dec 13 2021 dmueller@suse.com
- rpm/*.spec.in: use buildroot macro instead of env variable
  The RPM_BUILD_ROOT variable is considered deprecated over
  a buildroot macro. future proof the spec files.
- commit e2f6026
* Fri Dec 10 2021 msuchanek@suse.de
- Refresh patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch.
- commit 371214b
* Thu Dec  9 2021 ohering@suse.de
- Disable hyperv_fb in favour of hyperv_drm (jsc#SLE-19733)
- commit 0adc81c
* Wed Dec  8 2021 kbuild@suse.de
- Automatically updated to 5.16-rc4-next-20211208
- commit 6f83e8f
* Tue Dec  7 2021 kbuild@suse.de
- Automatically updated to 5.16-rc4-next-20211207
- commit 285d4b2
* Mon Dec  6 2021 kbuild@suse.de
- Automatically updated to 5.16-rc4-next-20211206
- commit e51e30c
* Fri Dec  3 2021 kbuild@suse.de
- Automatically updated to 5.16-rc3-next-20211203
- commit a87f4c5
* Thu Dec  2 2021 kbuild@suse.de
- Automatically updated to 5.16-rc3-next-20211202
- commit 5603777
* Thu Dec  2 2021 jslaby@suse.cz
- rpm/kernel-binary.spec.in: don't strip vmlinux again (bsc#1193306)
  After usrmerge, vmlinux file is not named vmlinux-<version>, but simply
  vmlinux. And this is not reflected in STRIP_KEEP_SYMTAB we set.
  So fix this by removing the dash...
- commit 83af88d
* Wed Dec  1 2021 kbuild@suse.de
- Automatically updated to 5.16-rc3-next-20211201
- commit fd3a38c
* Wed Dec  1 2021 jslaby@suse.cz
- Update config files.
  Unset PAGE_TABLE_CHECK as it causes crashes during module load:
  https://lore.kernel.org/all/f81a6434-9f38-947e-02a8-9a9191285e52@kernel.org/
- commit 6d31fe2
* Tue Nov 30 2021 kbuild@suse.de
- Automatically updated to 5.16-rc3-next-20211130
- commit 553aebe
* Mon Nov 29 2021 kbuild@suse.de
- Automatically updated to 5.16-rc2-next-20211129
- commit 57013b1
* Mon Nov 29 2021 mkubecek@suse.cz
- Update to 5.16-rc3
- refresh configs
- commit bbb7346
* Fri Nov 26 2021 msuchanek@suse.de
- constraints: Build aarch64 on recent ARMv8.1 builders.
  Request asimdrdm feature which is available only on recent ARMv8.1 CPUs.
  This should prevent scheduling the kernel on an older slower builder.
- commit 60fc53f
* Fri Nov 26 2021 kbuild@suse.de
- Automatically updated to 5.16-rc2-next-20211126
- commit de86cf1
* Thu Nov 25 2021 kbuild@suse.de
- Automatically updated to 5.16-rc2-next-20211125
- commit a5a7188
* Wed Nov 24 2021 kbuild@suse.de
- Automatically updated to 5.16-rc2-next-20211124
- commit c3f61b4
* Tue Nov 23 2021 kbuild@suse.de
- Automatically updated to 5.16-rc2-next-20211123
- commit d8dfd16
* Tue Nov 23 2021 msuchanek@suse.de
- kernel-source.spec: install-kernel-tools also required on 15.4
- commit 6cefb55
* Mon Nov 22 2021 mkubecek@suse.cz
- config: disable unprivileged BPF by default (jsc#SLE-22573)
  Backport of mainline commit 8a03e56b253e ("bpf: Disallow unprivileged bpf
  by default") only changes kconfig default, used e.g. for "make oldconfig"
  when the config option is missing, but does not update our kernel configs
  used for build. Update also these to make sure unprivileged BPF is really
  disabled by default.
  [ddiss: extend to all tumbleweed kernel configs]
- commit 3d6bc45
* Mon Nov 22 2021 mkubecek@suse.cz
- update to 5.16-rc2
- refresh
  - patches.suse/suse-hv-guest-os-id.patch
- update configs (restore values before 5.14-rc1)
  - PSTORE_ZONE=m
  - PSTORE_BLK=m
  - PSTORE_BLK_BLKDEV=""
  - PSTORE_BLK_KMSG_SIZE=64
  - PSTORE_BLK_MAX_REASON=2
  - MTD_PSTORE=m
- commit 8c25599
* Thu Nov 18 2021 kbuild@suse.de
- Automatically updated to 5.16-rc1-next-20211118
- commit aa9ecdd
* Wed Nov 17 2021 kbuild@suse.de
- Automatically updated to 5.16-rc1-next-20211117
- commit a5e6629
* Tue Nov 16 2021 kbuild@suse.de
- Automatically updated to 5.16-rc1-next-20211116
- commit f50a593
* Tue Nov 16 2021 msuchanek@suse.de
- kernel-*-subpackage: Add dependency on kernel scriptlets (bsc#1192740).
- commit a133bf4
* Mon Nov 15 2021 kbuild@suse.de
- Automatically updated to 5.15-next-20211115
- commit d3a0bc7
* Mon Nov 15 2021 mkubecek@suse.cz
- Update to 5.16-rc1
- eliminated 26 patches (13 stable, 13 mainline)
  - patches.kernel.org/*
  - patches.suse/ALSA-usb-audio-Restrict-rates-for-the-shared-clocks.patch
  - patches.suse/Bluetooth-sco-Fix-lock_sock-blockage-by-memcpy_from_.patch
  - patches.suse/Input-i8042-Add-quirk-for-Fujitsu-Lifebook-T725.patch
  - patches.suse/arm64-dts-rockchip-Disable-CDN-DP-on-Pinebook-Pro.patch
  - patches.suse/rtw89-Fix-two-spelling-mistakes-in-debug-messages.patch
  - patches.suse/rtw89-Fix-variable-dereferenced-before-check-sta.patch
  - patches.suse/rtw89-Remove-redundant-check-of-ret-after-call-to-rt.patch
  - patches.suse/rtw89-add-Realtek-802.11ax-driver.patch
  - patches.suse/rtw89-fix-error-function-parameter.patch
  - patches.suse/rtw89-fix-return-value-check-in-rtw89_cam_send_sec_k.patch
  - patches.suse/rtw89-fix-return-value-in-hfc_pub_cfg_chk.patch
  - patches.suse/rtw89-remove-duplicate-register-definitions.patch
  - patches.suse/rtw89-remove-unneeded-semicolon.patch
- refresh
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/suse-hv-guest-os-id.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - PREEMPT_DYNAMIC=y
  - Processor type and features
  - SCHED_CLUSTER=y
  - STRICT_SIGALTSTACK_SIZE=n
  - Networking support
  - NETFILTER_EGRESS=y
  - MCTP=y
  - File systems
  - EROFS_FS_ZIP_LZMA=y
  - Library routines
  - XZ_DEC_MICROLZMA=y
  - Kernel hacking
  - DEBUG_PREEMPT=n
  - PREEMPT_TRACER=n
  - SCSI device support
  - SCSI_UFS_HWMON=y
  - Network device support
  - AMT=m
  - NET_VENDOR_ASIX=y
  - SPI_AX88796C=m
  - SPI_AX88796C_COMPRESSION=y
  - ICE_SWITCHDEV=y
  - MT7921S=m
  - Character devices
  - RPMSG_TTY=m
  - CEC support
  - CEC_GPIO=m
  - CEC_PIN_ERROR_INJ=n
  - Multimedia support
  - VIDEO_HI846=m
  - VIDEO_OV13B10=m
  - Graphics support
  - DRM_DEBUG_MODESET_LOCK=n
  - DRM_I915_PXP=y
  - Sound card support
  - SND_SOC_AMD_VANGOGH_MACH=m
  - SND_SOC_AMD_ACP6x=m
  - SND_SOC_AMD_ACP_COMMON=m
  - SND_SOC_AMD_YC_MACH=m
  - SND_AMD_ASOC_RENOIR=m
  - SND_SOC_AMD_LEGACY_MACH=m
  - SND_SOC_AMD_SOF_MACH=m
  - SND_SOC_INTEL_SOF_ES8336_MACH=m
  - SND_SOC_CS35L41_SPI=m
  - SND_SOC_CS35L41_I2C=m
  - SND_SOC_MAX98520=m
  - SND_SOC_RT9120=m
  - SND_SOC_NAU8821=m
  - HID support
  - HID_XIAOMI=m
  - HID_NINTENDO=m
  - NINTENDO_FF=y
  - X86 Platform Specific Device Drivers
  - NVIDIA_WMI_EC_BACKLIGHT=m
  - INTEL_ISHTP_ECLITE=m
  - BARCO_P50_GPIO=m
  - Industrial I/O support
  - ADXL313_I2C=n
  - ADXL313_SPI=n
  - ADXL355_I2C=n
  - ADXL355_SPI=n
  - SCD4X=n
  - SENSEAIR_SUNRISE_CO2=n
  - ADRF6780=n
  - MAX31865=m
  - Misc devices
  - INTEL_MEI_PXP=m
  - KEYBOARD_CYPRESS_SF=m
  - SENSORS_MAX6620=m
  - HT16K33=n
  - ALIBABA_ENI_VDPA=m
  - MLXREG_LC=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - SPI_CADENCE_XSPI=m
  - DRM_PANEL_EDP=m
  - DRM_PANEL_SAMSUNG_S6D27A1=n
  - DRM_PANEL_SHARP_LS060T1SX01=n
  - i386
    SND_AUDIO_GRAPH_CARD2=n
    SND_TEST_COMPONENT=m
  - ppc64
  - IPMI_IPMB=m
  - s390x
  - COMMAND_LINE_SIZE=4096 (default)
  - riscv64
  - TIME_NS=y
  - VIRTUALIZATION=y
  - KVM=m
  - SND_AUDIO_GRAPH_CARD2=n
  - SND_TEST_COMPONENT=m
  - */debug
  - DRM_DEBUG_MODESET_LOCK=y
- commit 7f0159b
* Fri Nov 12 2021 kbuild@suse.de
- Automatically updated to 5.15-next-20211112
- commit 224f467
* Thu Nov 11 2021 kbuild@suse.de
- Automatically updated to 5.15-next-20211111
- commit 2e8311c
* Thu Nov 11 2021 msuchanek@suse.de
- Fix problem with missing installkernel on Tumbleweed.
- commit 2ed6686
* Thu Nov 11 2021 mkubecek@suse.cz
- config: refresh
- drop PROFILE_ALL_BRANCHES where not available any more
- commit b15aad6
* Wed Nov 10 2021 kbuild@suse.de
- Automatically updated to 5.15-next-20211110
- commit a18f27b
* Tue Nov  9 2021 tiwai@suse.de
- Update config files: set CONFIG_FORTIFY_SOURCE=y consistently (bsc#1192476)
- commit 76d1da2
* Tue Nov  9 2021 kbuild@suse.de
- Automatically updated to 5.15-next-20211109
- commit a4a7abf
* Mon Nov  8 2021 msuchanek@suse.de
- Update config files (bsc#1192456).
  CONFIG_IMA_TRUSTED_KEYRING=y
- commit 0a73fd5
* Mon Nov  1 2021 mkubecek@suse.cz
- Update to 5.15 final
- refresh configs
  - drop CONFIG_RESET_PISTACHIO
- commit c3f08cc
* Mon Nov  1 2021 mkubecek@suse.cz
- config: update and enable armv6hl
  Update armv6hl configs to 5.15-rc7 and enable them. Where possible, values
  are taken from armv7hl, the rest is guesswork based on values of similar
  config options.
- commit 7a97758
* Mon Nov  1 2021 mkubecek@suse.cz
- config: update and enable armv7hl
  Update armv7hl configs to 5.15-rc7 and enable them. Where possible, values
  are taken from arm64, the rest is guesswork based on values of similar
  config options.
- commit 44cc72d
* Mon Nov  1 2021 mkubecek@suse.cz
- config: update and enable arm64
  Update arm64 configs to 5.15-rc7 and enable them. Where possible, values
  are taken from x86_64, the rest is guesswork based on values of similar
  config options.
- commit a704d20
* Thu Oct 28 2021 ykaukab@suse.de
- config: arm64: enable dpaa2 restool support
  References: bsc#1191190
- commit 59ee092
* Tue Oct 19 2021 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: move to zstd for the initrd
  Newer distros have capability to decompress zstd, which
  provides a 2-5%% better compression ratio at very similar
  cpu overhead. Plus this tests the zstd codepaths now as well.
- commit 3d53a5b
* Tue Oct 19 2021 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: reduce initrd functionality
  For building in OBS, we always build inside a virtual machine
  that gets a new, freshly created scratch filesystem image. So
  we do not need to handle fscks because that ain't gonna happen,
  as well as not we do not need to handle microcode update in the
  initrd as these only can be run on the host system anyway. We
  can also strip and hardlink as an additional optimisation that
  should not significantly hurt.
- commit c72c6fc
* Mon Oct 18 2021 mkubecek@suse.cz
- Update to 5.15-rc6
- refresh configs
  - drop SIMPLE_PM_BUS
- commit bbda4de
* Wed Oct 13 2021 msuchanek@suse.de
- kernel-spec-macros: Since rpm 4.17 %%verbose is unusable (bsc#1191229).
  The semantic changed in an incompatible way so invoking the macro now
  causes a build failure.
- commit 3e55f55
* Mon Oct 11 2021 mbrugger@suse.com
- rtw89: add Realtek 802.11ax driver (bsc#1191321).
- commit 6a57aa3
* Mon Oct 11 2021 tiwai@suse.de
- Enable CONFIG_RTW88_DEBUG and CONFIG_RTW89_DEBUG on debug flavors (bsc#1191321)
- commit 254afd2
* Mon Oct 11 2021 mkubecek@suse.cz
- Update to 5.15-rc5
- update configs
  - FIRMWARE_MEMMAP=y (ppc64, ppc64le, s390x)
  - FW_CFG_SYSFS=m (ppc64)
  - FB_SIMPLE=n (s390x)
- commit 9942c93
* Tue Oct  5 2021 ludwig.nussel@suse.de
- rpm: use _rpmmacrodir (boo#1191384)
- commit e350c14
* Thu Sep 30 2021 kbuild@suse.de
- Automatically updated to 5.15-rc3-next-20210930
- commit 57c3396
* Thu Sep 30 2021 jslaby@suse.cz
- Update config files.
  Restore to pre-next-20210927 state. There was a commit in next-20210927
  which broke this and was removed later in next-20210928.
- commit d782f60
* Thu Sep 30 2021 mbrugger@suse.com
- arm64: Update config files. (bsc#1185927)
  Set PINCTRL_ZYNQMP as build-in.
- commit cc33d5a
* Wed Sep 29 2021 kbuild@suse.de
- Automatically updated to 5.15-rc3-next-20210929
- commit 37c5978
* Tue Sep 28 2021 kbuild@suse.de
- Automatically updated to 5.15-rc3-next-20210928
- commit a714346
* Mon Sep 27 2021 msuchanek@suse.de
- kernel-binary.spec: Do not sign kernel when no key provided
  (bsc#1187167).
- commit 6c24533
* Mon Sep 27 2021 kbuild@suse.de
- Automatically updated to 5.15-rc3-next-20210927
- commit 21dbc7e
* Sun Sep 26 2021 mkubecek@suse.cz
- Update to 5.15-rc3
- eliminated 3 patches:
  - patches.rpmify/scripts-sorttable-riscv-fix-undelcred-identifier-EM_.patch
  - patches.suse/posix-cpu-timers-Fix-spuriously-armed-0-value-itimer.patch
  - patches.suse/nvmem-nintendo-otp-add-dependency-on-CONFIG_HAS_IOME.patch
    (still meaningful in upstream but no longer needed four our configs)
- refresh configs
  - drop NVMEM_NINTENDO_OTP
  - i386: drop XEN_PCIDEV_FRONTEND and SWIOTLB_XEN
- commit 30085f5
* Fri Sep 24 2021 kbuild@suse.de
- Automatically updated to 5.15-rc2-next-20210924
- commit 2abb8d8
* Thu Sep 23 2021 kbuild@suse.de
- Automatically updated to 5.15-rc2-next-20210923
- commit e3cb7bb
* Wed Sep 22 2021 msuchanek@suse.de
- kernel-binary.spec: suse-kernel-rpm-scriptlets required for uninstall as
  well.
  Fixes: e98096d5cf85 ("rpm: Abolish scritplet templating (bsc#1189841).")
- commit e082fbf
* Wed Sep 22 2021 kbuild@suse.de
- Automatically updated to 5.15-rc2-next-20210922
- commit c30e948
* Tue Sep 21 2021 kbuild@suse.de
- Automatically updated to 5.15-rc2-next-20210921
- commit 70e7f6b
* Mon Sep 20 2021 kbuild@suse.de
- Automatically updated to 5.15-rc2-next-20210920
- commit 11540ab
* Mon Sep 20 2021 mkubecek@suse.cz
- Update to 5.15-rc2
- eliminated 2 patches
  - patches.suse/memblock-introduce-saner-memblock_free_ptr-interface.patch
  - patches.suse/tools-bootconfig-define-memblock_free_ptr-to-fix-build-error.patch
- update configs
  - ARCH_NR_GPIO (1024 on x86_64, 512 on i386)
  - drop WARN_DYNAMIC_STACK on s390x
- commit a13f902
* Fri Sep 17 2021 msuchanek@suse.de
- kernel-binary.spec: Check for no kernel signing certificates.
  Also remove unused variable.
- commit bdc323e
* Fri Sep 17 2021 msuchanek@suse.de
- Revert "rpm/kernel-binary.spec: Use only non-empty certificates."
  This reverts commit 30360abfb58aec2c9ee7b6a27edebe875c90029d.
- commit 413e05b
* Fri Sep 17 2021 mkubecek@suse.cz
- nvmem: nintendo-otp: add dependency on CONFIG_HAS_IOMEM
  (202108250657.h5CWR7Xf-lkp@intel.com).
  Fix s390x/zfcpdump build.
- refresh configs (s390x/zfcpdump: NVMEM_NINTENDO_OTP=n)
- commit a19c933
* Fri Sep 17 2021 kbuild@suse.de
- Automatically updated to 5.15-rc1-next-20210917
- commit edf2ebc
* Fri Sep 17 2021 msuchanek@suse.de
- rpm/kernel-binary.spec: Use only non-empty certificates.
- commit 30360ab
* Thu Sep 16 2021 kbuild@suse.de
- Automatically updated to 5.15-rc1-next-20210916
- commit 3cefd4f
* Wed Sep 15 2021 mkubecek@suse.cz
- config: disable ZERO_CALL_USED_REGS
  This was enable due to a misunderstanding, I thought it was a workaround
  for a recent CPU vulnerability. Now it rather seems to be just another
  hardening with questionable gain and measurable performance impact.
- commit 9e57c7b
* Wed Sep 15 2021 kbuild@suse.de
- Automatically updated to 5.15-rc1-next-20210915
- commit a044e75
* Wed Sep 15 2021 vbabka@suse.cz
- config: disable CONFIG_SYSFB_SIMPLEFB
  The new option in 5.15 is a rename from CONFIG_X86_SYSFB which we had disabled
  due to bsc#855821. Moreover, enabling CONFIG_SYSFB_SIMPLEFB caused regression
  on my UEFI desktop - no printk output on screen between grub's loading of
  kernel and initrd, and a gpu modesetting driver taking over.
- commit 9edfe86
* Tue Sep 14 2021 kbuild@suse.de
- Automatically updated to 5.15-rc1-next-20210914
- commit cf61bf2
* Mon Sep 13 2021 kbuild@suse.de
- Automatically updated to 5.14-next-20210913
- commit 649946a
* Mon Sep 13 2021 mkubecek@suse.cz
- Update to 5.15-rc1
- eliminated 36 patches (27 stable, 9 mainline)
  - patches.kernel.org/*
  - patches.suse/Bluetooth-avoid-circular-locks-in-sco_sock_connect.patch
  - patches.suse/Bluetooth-btusb-Add-support-for-Foxconn-Mediatek-Chi.patch
  - patches.suse/Bluetooth-btusb-Add-support-for-IMC-Networks-Mediate.patch
  - patches.suse/Bluetooth-schedule-SCO-timeouts-with-delayed_work.patch
  - patches.suse/Bluetooth-switch-to-lock_sock-in-SCO.patch
  - patches.suse/HID-usbhid-Simplify-code-in-hid_submit_ctrl.patch
  - patches.suse/crypto-ecc-handle-unaligned-input-buffer-in-ecc_swap.patch
  - patches.suse/memcg-enable-accounting-of-ipc-resources.patch
  - patches.suse/watchdog-Fix-NULL-pointer-dereference-when-releasing.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/btrfs-use-the-new-VFS-super_block_dev.patch
  - patches.suse/suse-hv-guest-os-id.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - CONFIG_WERROR=n
  - CONFIG_PRINTK_INDEX=y
  - Processor type and features
  - CONFIG_PERF_EVENTS_AMD_UNCORE=m
  - Firmware Drivers
  - CONFIG_SYSFB_SIMPLEFB=y
  - Memory Management options
  - CONFIG_DAMON=n
  - Networking support
  - CONFIG_IPV6_IOAM6_LWTUNNEL=n
  - CONFIG_MCTP=m
  - File systems
  - CONFIG_F2FS_IOSTAT=y
  - CONFIG_NTFS3_FS=m
  - CONFIG_NTFS3_64BIT_CLUSTER=n
  - CONFIG_NTFS3_LZX_XPRESS=y
  - CONFIG_NTFS3_FS_POSIX_ACL=y
  - CONFIG_SMB_SERVER=m
  - CONFIG_SMB_SERVER_SMBDIRECT=n
  - CONFIG_SMB_SERVER_CHECK_CAP_NET_ADMIN=y
  - CONFIG_SMB_SERVER_KERBEROS5=y
  - Security options
  - CONFIG_ZERO_CALL_USED_REGS=y
  - Cryptographic API
  - CONFIG_CRYPTO_SM4_AESNI_AVX_X86_64=m
  - CONFIG_CRYPTO_SM4_AESNI_AVX2_X86_64=m
  - CONFIG_MODULE_SIG_KEY_TYPE_RSA=y
  - CONFIG_MODULE_SIG_KEY_TYPE_ECDSA=n
  - Kernel hacking
  - CONFIG_FAIL_SUNRPC=n
  - SCSI device support
  - CONFIG_SCSI_UFS_HPB=y
  - CONFIG_SCSI_UFS_FAULT_INJECTION=n
  - Network device support
  - CONFIG_NET_VENDOR_LITEX=y
  - CONFIG_MAXLINEAR_GPHY=m
  - CONFIG_MHI_WWAN_MBIM=m
  - Power management
  - CONFIG_CHARGER_CROS_PCHG=m
  - CONFIG_SENSORS_AQUACOMPUTER_D5NEXT=m
  - CONFIG_SENSORS_SBRMI=m
  - CONFIG_REGULATOR_RTQ2134=m
  - CONFIG_REGULATOR_RTQ6752=m
  - Graphics support
  - CONFIG_DRM_VMWGFX_MKSSTATS=n
  - CONFIG_DRM_PANEL_WIDECHIPS_WS2401=n
  - Sound card support
  - CONFIG_SND_HDA_CODEC_CS8409=m
  - CONFIG_SND_SOC_AMD_ACP5x=m
  - CONFIG_SND_SOC_ICS43432=n
  - CONFIG_SND_SOC_SDW_MOCKUP=m
  - DMA Engine support
  - CONFIG_INTEL_IDXD_COMPAT=y
  - CONFIG_AMD_PTDMA=m
  - X86 Platform Specific Device Drivers
  - CONFIG_MERAKI_MX100=m
  - CONFIG_INTEL_SAR_INT1092=m
  - IOMMU Hardware Support
  - CONFIG_IOMMU_DEFAULT_DMA_STRICT=n
  - CONFIG_IOMMU_DEFAULT_DMA_LAZY=n
  - Industrial I/O support
  - CONFIG_SENSIRION_SGP40=n
  - CONFIG_AD5110=n
  - Misc devices
  - CONFIG_I2C_VIRTIO=m
  - CONFIG_GPIO_VIRTIO=m
  - CONFIG_DMABUF_SYSFS_STATS=n
  - CONFIG_VDPA_USER=m
  - CONFIG_NVMEM_NINTENDO_OTP=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - HI6421V600_IRQ=m
  - LITEX_LITEETH=m
  - MFD_RSMU_I2C=n
  - MFD_RSMU_SPI=n
  - VIDEO_IMX335=m
  - VIDEO_IMX412=m
  - VIDEO_OV9282=m
  - DRM_PANEL_INNOLUX_EJ030NA=n
  - DRM_PANEL_SAMSUNG_ATNA33XC20=n
  - DRM_PANEL_SAMSUNG_DB7430=n
  - COMMON_CLK_XLNX_CLKWZRD=m
  - DMA_RESTRICTED_POOL=n
  - i386
  - CS89x0_ISA=n
  - ppc64
  - DEBUG_WX=n
  - PTDUMP_DEBUGFS=n
  - s390x
  - KCSAN=n
  - KFENCE=y (=n in zfcpdump)
  - KFENCE_STATIC_KEYS=y
  - KFENCE_SAMPLE_INTERVAL=0
  - KFENCE_NUM_OBJECTS=255
  - KFENCE_STRESS_TEST_FAULTS=0
  - riscv64
  - POWER_RESET_TPS65086=y
  - DRM_PANEL_ILITEK_ILI9341=n
- commit 16f64c8
* Mon Sep 13 2021 martin.wilck@suse.com
- fixup "rpm: support gz and zst compression methods" once more
  (bsc#1190428, bsc#1190358)
  Fixes: 3b8c4d9bcc24 ("rpm: support gz and zst compression methods")
  Fixes: 23510fce36ec ("fixup "rpm: support gz and zst compression methods"")
- commit 165378a
* Sun Sep 12 2021 martin.wilck@suse.com
- fixup "rpm: support gz and zst compression methods" once more
  Fixes: 3b8c4d9bcc24 ("rpm: support gz and zst compression methods")
  Fixes: 23510fce36ec ("fixup "rpm: support gz and zst compression methods"")
- commit 34e68f4
* Sun Sep 12 2021 martin.wilck@suse.com
- fixup "rpm: support gz and zst compression methods"
  Fixes: 3b8c4d9bcc24 ("rpm: support gz and zst compression methods")
- commit 23510fc
* Fri Sep 10 2021 msuchanek@suse.de
- kernel-cert-subpackage: Fix certificate location in scriptlets
  (bsc#1189841).
  Fixes: d9a1357edd73 ("rpm: Define $certs as rpm macro (bsc#1189841).")
- commit 8684de8
* Fri Sep 10 2021 msuchanek@suse.de
- kernel-binary.spec.in Stop templating the scriptlets for subpackages
  (bsc#1190358).
  The script part for base package case is completely separate from the
  part for subpackages. Remove the part for subpackages from the base
  package script and use the KMP scripts for subpackages instead.
- commit 5d1f677
* Fri Sep 10 2021 msuchanek@suse.de
- kernel-binary.spec: Do not fail silently when KMP is empty
  (bsc#1190358).
  Copy the code from kernel-module-subpackage that deals with empty KMPs.
- commit d7d2e6e
* Fri Sep 10 2021 kbuild@suse.de
- Automatically updated to 5.14-next-20210910
- commit 1177bfa
* Thu Sep  9 2021 kbuild@suse.de
- Automatically updated to 5.14-next-20210909
- commit 71b2764
* Wed Sep  8 2021 jslaby@suse.cz
- rpm/kernel-source.spec.in: do some more for vanilla_only
  Make sure:
  * sources are NOT executable
  * env is not used as interpreter
  * timestamps are correct
  We do all this for normal kernel builds, but not for vanilla_only
  kernels (linux-next and vanilla).
- commit b41e4fd
* Wed Sep  8 2021 kbuild@suse.de
- Automatically updated to 5.14-next-20210908
- commit d2220f8
* Wed Sep  8 2021 jslaby@suse.cz
- Update config files.
  Disable WERROR as it breaks build. For example:
  fs/qnx4/dir.c: In function 'qnx4_readdir':
  fs/qnx4/dir.c:51:32: error: 'strnlen' specified bound 48 exceeds source size 16 [-Werror=stringop-overread]
- commit d2ce8c8
* Tue Sep  7 2021 kbuild@suse.de
- Automatically updated to 5.14-next-20210907
- commit 4624ba8
* Mon Sep  6 2021 msuchanek@suse.de
- rpm: Fold kernel-devel and kernel-source scriptlets into spec files
  (bsc#1189841).
  These are unchanged since 2011 when they were introduced. No need to
  track them separately.
- commit 692d38b
* Mon Sep  6 2021 msuchanek@suse.de
- rpm: Abolish image suffix (bsc#1189841).
  This is used only with vanilla kernel which is not supported in any way.
  The only effect is has is that the image and initrd symlinks are created
  with this suffix.
  These symlinks are not used except on s390 where the unsuffixed symlinks
  are used by zipl.
  There is no reason why a vanilla kernel could not be used with zipl as
  well as it's quite unexpected to not be able to boot when only a vanilla
  kernel is installed.
  Finally we now have a backup zipl kernel so if the vanilla kernel is
  indeed unsuitable the backup kernel can be used.
- commit e2f37db
* Mon Sep  6 2021 msuchanek@suse.de
- kernel-binary.spec: Define $image as rpm macro (bsc#1189841).
- commit e602b0f
* Mon Sep  6 2021 kbuild@suse.de
- Automatically updated to 5.14-next-20210906
- commit 16839e3
* Mon Sep  6 2021 msuchanek@suse.de
- rpm: Define $certs as rpm macro (bsc#1189841).
  Also pass around only the shortened hash rather than full filename.
  As has been discussed in bsc#1124431 comment 51
  https://bugzilla.suse.com/show_bug.cgi?id=1124431#c51 the placement of
  the certificates is an API which cannot be changed unless we can ensure
  that no two kernels that use different certificate location can be built
  with the same certificate.
- commit d9a1357
* Sat Sep  4 2021 jslaby@suse.cz
- watchdog: Fix NULL pointer dereference when releasing cdev
  (bsc#1190093).
- Update config files.
  We can enable the option after this fix again.
- commit f2729b0
* Fri Sep  3 2021 kbuild@suse.de
- Automatically updated to 5.14-next-20210903
- commit 13bc70f
* Thu Sep  2 2021 kbuild@suse.de
- Automatically updated to 5.14-next-20210902
- commit 3c0e001
* Thu Sep  2 2021 jslaby@suse.cz
- Update config files. Disable CONFIG_WATCHDOG_HRTIMER_PRETIMEOUT
  (bsc#1190093)
- commit 20d4280
* Wed Sep  1 2021 kbuild@suse.de
- Automatically updated to 5.14-next-20210901
- commit 49e4cc4
* Tue Aug 31 2021 msuchanek@suse.de
- rpm: Abolish scritplet templating (bsc#1189841).
  Outsource kernel-binary and KMP scriptlets to suse-module-tools.
  This allows fixing bugs in the scriptlets as well as defining initrd
  regeneration policy independent of the kernel packages.
- commit e98096d
* Tue Aug 31 2021 mbrugger@suse.com
- arm64: Update config files. (bsc#1189922)
  Enable ISP1760_DUAL_ROLE
- commit 4791216
* Tue Aug 31 2021 kbuild@suse.de
- Automatically updated to 5.14-next-20210831
- commit 614a0fa
* Tue Aug 31 2021 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Use kmod-zstd provide.
  This makes it possible to use kmod with ZSTD support on non-Tumbleweed.
- commit 357f09a
* Mon Aug 30 2021 ludwig.nussel@suse.de
- rpm/kernel-binary.spec.in: avoid conflicting suse-release
  suse-release has arbitrary values in staging, we can't use it for
  dependencies. The filesystem one has to be enough (boo#1184804).
- commit 56f2cba
* Mon Aug 30 2021 mkubecek@suse.cz
- Update to 5.14 final
- refresh configs
- commit b2212de
* Mon Aug 30 2021 mkubecek@suse.cz
- config: update and enable armv6hl
  New config option values copied from arvm7hl.
- commit 84d6a0c
* Mon Aug 30 2021 mkubecek@suse.cz
- config: update and enable armv7hl
  New config option values copied from arm64 except:
  - PCI_IXP4XX=n (does not allow module build)
  - MTD_NAND_PL35X=m
  - IPMI_KCS_BMC_CDEV_IPMI=m
  - IPMI_KCS_BMC_SERIO=m
  - MSC313E_WATCHDOG=m
  - REGULATOR_MT6359=m
  - REGULATOR_RT5033=m
  - ARM_GT_INITIAL_PRESCALER_VAL=2 (default)
  - INTEL_QEP=m
- commit e9a2a32
* Sat Aug 28 2021 kbuild@suse.de
- Automatically updated to 5.14-rc7-next-20210827
- commit 29ed455
* Fri Aug 27 2021 kbuild@suse.de
- Automatically updated to 5.14-rc7-next-20210826
- commit f41595f
* Fri Aug 27 2021 ludwig.nussel@suse.de
- rpm: fix kmp install path
- commit 22ec560
* Thu Aug 26 2021 ludwig.nussel@suse.de
- post.sh: detect /usr mountpoint too
- commit c7b3d74
* Wed Aug 25 2021 kbuild@suse.de
- Automatically updated to 5.14-rc7-next-20210825
- commit 89822e9
* Tue Aug 24 2021 kbuild@suse.de
- Automatically updated to 5.14-rc7-next-20210823
- commit 7111c5d
* Mon Aug 23 2021 jeffm@suse.com
- config: re-modularize CRYPTO_{CTS,ECB,XTS} on arm* (bsc#1189034).
  Now that FS_ENCRYPTION_ALGS is modular, the crypto modules it utilizes
  can be modular as well.  CRYPTO_AES and CRYPTO_CBC are used by
  ENCRYPTED_KEYS and must remain built-in.  CRYPTO_SHA512 and CRYPTO_HMAC
  are used by module signature validation and must also remain built-in.
- commit 7d6a598
* Mon Aug 23 2021 jeffm@suse.com
- config: re-modularize CRYPTO_{GCM,GHASH,GF128MUL} on arm* (bsc#1189033).
  These modules were selected as built-in due to Kconfig changes between
  4.14-rc3 and 5.8-rc1 selecting them if BIG_KEYS was enabled.  They can
  be built as modules again now.
- commit 3a000cc
* Mon Aug 23 2021 martin.wilck@suse.com
- kernel-binary.spec.in: make sure zstd is supported by kmod if used
- commit f36412b
* Mon Aug 23 2021 martin.wilck@suse.com
- kernel-binary.spec.in: add zstd to BuildRequires if used
- commit aa61dba
* Mon Aug 23 2021 mkubecek@suse.cz
- config: refresh vanilla configs
  Vanilla configs also need to include DEBUG_INFO_BTF_MODULES even if the
  value does not differ from base config.
- commit 639fce2
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files. (arm & epaper drivers and other old graphics)
  Propagate recent epaper drivers and other old graphics changes to arms.
- commit bb2ba19
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files. (arm & CONFIG_GAMEPORT)
  Propagate recent CONFIG_GAMEPORT changes to arms.
- commit d9a458b
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files. (arm & CONFIG_BT_MSFTEXT)
  Propagate recent CONFIG_BT_MSFTEXT changes to arms.
- commit 3c87778
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files. (arm & ATALK)
  Propagate recent ATALK changes to arms.
- commit 0fc4b1a
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files. (arm & EXT4_FS)
  Propagate recent EXT4_FS changes to arms.
- commit 317be6e
* Mon Aug 23 2021 mkubecek@suse.cz
- Update to 5.14-rc7
- eliminated 3 patches:
  - patches.suse/mmc-sdhci-iproc-cap-min-clock-frequency-on-bcm2711.patch
  - patches.suse/mmc-sdhci-iproc-set-sdhci_quirk_cap_clock_base_broken-on-bcm2711.patch
  - patches.suse/crypto-drbg-select-SHA512.patch
- refresh configs
  - DYNAMIC_FTRACE_WITH_ARGS=y (x86_64 only)
- commit 91fb384
* Sun Aug 22 2021 mkubecek@suse.cz
- Merge branch 'packaging' into master
- refresh configs
  - DEBUG_INFO_BTF_MODULES is now mandatory even in diff configs
- commit fd1d212
* Sun Aug 22 2021 jeffm@suse.com
- config: enable CONFIG_NO_HZ_FULL where supported (bsc#1189692).
- commit e68c117
* Sun Aug 22 2021 jeffm@suse.com
- config: enable CONFIG_MAXSMP (bsc#1189691).
- commit dcb7e29
* Sat Aug 21 2021 jeffm@suse.com
- config: disable CONFIG_SOUNDWIRE_QCOM on x86 (bsc#1189686).
- commit 1fb897e
* Fri Aug 20 2021 jeffm@suse.com
- config: disable CONFIG_MD_MULTIPATH (bsc#1189678).
  First-class multipath on Linux has used dm-multipath for ages.
- commit 5484774
* Fri Aug 20 2021 jeffm@suse.com
- config: disable CONFIG_PM_AUTOSLEEP and CONFIG_PM_WAKELOCKS (bsc#1189677).
- commit fe2b443
* Fri Aug 20 2021 jeffm@suse.com
- config: disable CONFIG_ISDN on arm* (bsc#1189675).
  Without CONFIG_ISDN, we no longer need to carry:
- patches.suse/misdn-add-support-for-group-membership-check.
- config: disable CONFIG_ISDN (bsc#1189675).
  Without CONFIG_ISDN, we no longer need to carry:
- patches.suse/misdn-add-support-for-group-membership-check.
- commit 8eae245
* Fri Aug 20 2021 jeffm@suse.com
- config: enable CONFIG_PRINTK_CALLER on arm* (bsc#1189674).
- config: enable CONFIG_PRINTK_CALLER (bsc#1189674).
- commit 58ac85c
* Fri Aug 20 2021 afaerber@suse.com
- config: arm64: Update to 5.14-rc6
- commit f00169d
* Fri Aug 20 2021 martin.wilck@suse.com
- rpm: support gz and zst compression methods
  Extend commit 18fcdff43a00 ("rpm: support compressed modules") for
  compression methods other than xz.
- commit 3b8c4d9
* Fri Aug 20 2021 kbuild@suse.de
- Automatically updated to 5.14-rc6-next-20210820
- commit b96e7d7
* Fri Aug 20 2021 tiwai@suse.de
- Update config files: make pinctrl-cherryview built-in (bsc#1189447)
  Otherwise some devices aren't properly intiailized.
- commit e60a07b
* Thu Aug 19 2021 kbuild@suse.de
- Automatically updated to 5.14-rc6-next-20210819
- commit 7591502
* Wed Aug 18 2021 kbuild@suse.de
- Automatically updated to 5.14-rc6-next-20210818
- commit aa94ece
* Mon Aug 16 2021 msuchanek@suse.de
- kernel-binary.spec: Require dwarves for kernel-binary-devel when BTF is
  enabled (jsc#SLE-17288).
  About the pahole version: v1.18 should be bare mnimum, v1.22 should be
  fully functional, for now we ship git snapshot with fixes on top of
  v1.21.
- commit 8ba3382
* Mon Aug 16 2021 kbuild@suse.de
- Automatically updated to 5.14-rc5-next-20210816
- commit 9c1ec1d
* Mon Aug 16 2021 mkubecek@suse.cz
- Update to 5.14-rc6
- refresh configs
  - drop MQ_IOSCHED_DEADLINE_CGROUP
- commit 2651347
* Fri Aug 13 2021 kbuild@suse.de
- Automatically updated to 5.14-rc5-next-20210813
- commit f36553e
* Thu Aug 12 2021 kbuild@suse.de
- Automatically updated to 5.14-rc5-next-20210812
- commit 1c6aa7f
* Wed Aug 11 2021 msuchanek@suse.de
- README: Modernize build instructions.
- commit 8cc5c28
* Wed Aug 11 2021 jslaby@suse.cz
- rpm/kernel-obs-build.spec.in: make builds reproducible (bsc#1189305)
- commit 7f9ade7
* Tue Aug 10 2021 kbuild@suse.de
- Automatically updated to 5.14-rc5-next-20210810
- commit f925820
* Tue Aug 10 2021 ykaukab@suse.de
- config: arm64: enable audio support for Nvidia Tegra SOCs
- commit f912f9e
* Mon Aug  9 2021 jeffm@suse.com
- crypto: drbg - select SHA512 (bsc#1189034).
  config: CRYPTO_SHA512 is built-in again.
- commit 03113cc
* Mon Aug  9 2021 ludwig.nussel@suse.de
- Fix filesystem requirement and suse-release requires
  Reduce filesystem conflict to anything less than 16 to allow pulling the
  change into the next major stable version.
  Don't require suse-release as that's not technically required. Conflict
  with a too old one instead.
- commit 913f755
* Mon Aug  9 2021 mkubecek@suse.cz
- Update to 5.14-rc5
- update configs
  - PHYS_RAM_BASE_FIXED=n (riscv64 only, follow upstream revert)
- commit d94829e
* Sat Aug  7 2021 kbuild@suse.de
- Automatically updated to 5.14-rc4-next-20210806
- commit 25b7225
* Fri Aug  6 2021 kbuild@suse.de
- Automatically updated to 5.14-rc4-next-20210805
- commit 2df60d8
* Thu Aug  5 2021 kbuild@suse.de
- Automatically updated to 5.14-rc4-next-20210804
- commit 3402c5e
* Thu Aug  5 2021 jslaby@suse.cz
- rpm/kernel-source.rpmlintrc: ignore new include/config files
  In 5.13, since 0e0345b77ac4, config files have no longer .h suffix.
  Adapt the zero-length check.
  Based on Martin Liska's change.
- commit b6f021b
* Wed Aug  4 2021 jeffm@suse.com
- config: make CONFIG_INTEL_PMC_CORE modular (bsc#1189072).
  When this option was introduced, it was a boolean.  Since then it's
  been changed to a tristate and can be made modular again.
- config: config: disable epaper drivers and other old graphics (bsc#1189116).
- config: disable CONFIG_GAMEPORT (bsc#1189115).
  The last SoundBlaster card to use a Game Port shipped in 2001.  Devices
  that connect via Game Port can still be used with a USB adapter, which
  doesn't use the GAMEPORT driver.
- config: enable CONFIG_BT_MSFTEXT (bsc#1189113).
- config: disable CONFIG_ATALK (bsc#1189112).
  This disables support for native AppleTalk which Apple stopped
  supporting in 2009.  AppleTalk over IP is implemented using the netatalk
  package.
- config: enable CONFIG_CMA on x86_64 (bsc#1189109).
  CMA was enabled in SLE15-SP3 via jsc#SLE-17227.  One difference is that
  v5.10-rc1 (b7176c261cd) upstream added the ability to allocate areas for
  each NUMA node, which changed some of the defaults.
  The default number of areas (19) is used here.
- commit bfc3e1b
* Wed Aug  4 2021 jeffm@suse.com
- config: enable CONFIG_EFI_RCI2_TABLE (bsc#1189108).
- config: disable X86_X32 (bsc#1189069).
  This feature requires a userspace rebuild to use the X32 ABI and that
  hasn't happened.  If that support is eventually added, we can re-enable.
- commit 33c9a49
* Wed Aug  4 2021 kbuild@suse.de
- Automatically updated to 5.14-rc4-next-20210803
- commit a916132
* Tue Aug  3 2021 jeffm@jeffm.io
- config: re-modularize CRYPTO_{CTS,ECB,HMAC,SHA512,XTS} (bsc#1189034).
  Now that FS_ENCRYPTION_ALGS is modular, the crypto modules it utilizes
  can be modular as well.  CRYPTO_AES and CRYPTO_CBC are used by
  ENCRYPTED_KEYS and must remain built-in.
- commit 9aa55a2
* Tue Aug  3 2021 jeffm@jeffm.io
- config: re-modularize CRYPTO_{GCM,GHASH,GF128MUL} (bsc#1189033).
  These modules were selected as built-in due to Kconfig changes between
  4.14-rc3 and 5.8-rc1 selecting them if BIG_KEYS was enabled.  They can
  be built as modules again now.
- commit 1fcf630
* Tue Aug  3 2021 jeffm@jeffm.io
- config: re-modularize ext4 (bsc#1189032).
  ext2/3/4 hasn't been a default file system for SLE or openSUSE in many
  years.  There is little reason to continue to keep it as a built-in.
- commit 3313eeb
* Tue Aug  3 2021 kbuild@suse.de
- Automatically updated to 5.14-rc4-next-20210802
- commit 0424101
* Tue Aug  3 2021 mbrugger@suse.com
- arm64: Update config files. (bsc#1188702)
- commit 0fa8251
* Mon Aug  2 2021 mkubecek@suse.cz
- Update to 5.14-rc4
- refresh configs (cosmetic only)
- commit d8c9ffa
* Sat Jul 31 2021 kbuild@suse.de
- Automatically updated to 5.14-rc3-next-20210730
- commit fbd7c49
* Fri Jul 30 2021 kbuild@suse.de
- Automatically updated to 5.14-rc3-next-20210729
- commit 174f91e
* Thu Jul 29 2021 kbuild@suse.de
- Automatically updated to 5.14-rc3-next-20210728
- commit 4d201c6
* Wed Jul 28 2021 mkubecek@suse.cz
- use 3.0 SPDX identifier in rpm License tags
  As requested by Maintenance, change rpm License tags from "GPL-2.0"
  (SPDX 2.0) to "GPL-2.0-only" (SPDX 3.0) so that their scripts do not have
  to adjust the tags with each maintenance update submission.
- commit f888e0b
* Wed Jul 28 2021 kbuild@suse.de
- Automatically updated to 5.14-rc3-next-20210727
- commit 11452b2
* Tue Jul 27 2021 kbuild@suse.de
- Automatically updated to 5.14-rc3-next-20210726
- commit 68cac38
* Mon Jul 26 2021 mkubecek@suse.cz
- Update to 5.14-rc3
- eliminated 1 patch:
  - patches.suse/seq_file-disallow-extremely-large-seq-buffer-allocat.patch
- update configs
  - SND_SOC_SSM2518=n (x86 and riscv64)
  - drop SND_SOC_ZX_AUD96P22
- commit c7555ea
* Fri Jul 23 2021 kbuild@suse.de
- Automatically updated to 5.14-rc2-next-20210723
- commit 029b2fc
* Thu Jul 22 2021 kbuild@suse.de
- Automatically updated to 5.14-rc2-next-20210722
- commit 77270a2
* Wed Jul 21 2021 kbuild@suse.de
- Automatically updated to 5.14-rc2-next-20210721
- commit bddfdd7
* Tue Jul 20 2021 kbuild@suse.de
- Automatically updated to 5.14-rc2-next-20210720
- commit ada624d
* Mon Jul 19 2021 kbuild@suse.de
- Automatically updated to 5.14-rc2-next-20210719
- commit a15f4f5
* Sun Jul 18 2021 mkubecek@suse.cz
- Update to 5.14-rc2
- update configs
  - NCSI_OEM_CMD_KEEP_PHY=y
  - EDAC_IGEN6=m (x86_64 only)
- commit bad960f
* Fri Jul 16 2021 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Do not install usrmerged kernel on Leap
  (boo#1184804).
- commit 5b51131
* Fri Jul 16 2021 kbuild@suse.de
- Automatically updated to 5.14-rc1-next-20210716
- commit e704f3a
* Thu Jul 15 2021 kbuild@suse.de
- Automatically updated to 5.14-rc1-next-20210715
- commit 1242a95
* Wed Jul 14 2021 kbuild@suse.de
- Automatically updated to 5.14-rc1-next-20210714
- commit 4ad9a90
* Tue Jul 13 2021 kbuild@suse.de
- Automatically updated to 5.14-rc1-next-20210713
- commit dc39a3e
* Mon Jul 12 2021 mkubecek@suse.cz
- Update to 5.14-rc1
- eliminated 13 patches (3 stable, 9 mainline, 1 obsolete SUSE)
  - patches.kernel.org/5.13.1-001-Revert-KVM-x86-mmu-Drop-kvm_mmu_extended_role..patch
  - patches.kernel.org/5.13.1-002-mm-page_alloc-correct-return-value-of-populate.patch
  - patches.kernel.org/5.13.1-003-Linux-5.13.1.patch
  - patches.rpmify/scripts-mkmakefile-honor-second-argument.patch
  - patches.suse/ACPI-PM-s2idle-Add-missing-LPS0-functions-for-AMD.patch
  - patches.suse/ACPI-processor-idle-Fix-up-C-state-latency-if-not-or.patch
  - patches.suse/Bluetooth-btqca-Don-t-modify-firmware-contents-in-pl.patch
  - patches.suse/Input-elants_i2c-Fix-NULL-dereference-at-probing.patch
  - patches.suse/brcmfmac-Add-clm_blob-firmware-files-to-modinfo.patch
  - patches.suse/brcmfmac-Delete-second-brcm-folder-hierarchy.patch
  - patches.suse/crypto-ccp-Annotate-SEV-Firmware-file-names.patch
  - patches.suse/pinctrl-bcm2835-accept-fewer-than-expected-irqs.patch
  - patches.suse/proc-Avoid-mixing-integer-types-in-mem_rw.patch
- refresh
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/dm-table-switch-to-readonly
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/kernel-add-release-status-to-kernel-build.patch
  - patches.suse/supported-flag
- disable ARM architectures (need config update)
- new config options
  - General setup
  - SCHED_CORE=y
  - Power management and ACPI options
  - ACPI_PRMT=y
  - TPS68470_PMIC_OPREGION=y
  - Block layer
  - BLK_CGROUP_FC_APPID=y
  - BLK_CGROUP_IOPRIO=y
  - Networking support
  - NETFILTER_NETLINK_HOOK=m
  - File systems
  - HUGETLB_PAGE_FREE_VMEMMAP_DEFAULT_ON=n
  - Security options
  - IMA_DISABLE_HTABLE=n
  - Kernel hacking
  - STACKTRACE_BUILD_ID=y
  - DEBUG_FORCE_FUNCTION_ALIGN_64B=n
  - OSNOISE_TRACER=y
  - TIMERLAT_TRACER=y
  - TEST_SCANF=n
  - TEST_CLOCKSOURCE_WATCHDOG=n
  - PCI support
  - CXL_ACPI=m
  - CXL_PMEM=m
  - SCSI device support
  - SCSI_MPI3MR=m
  - SCSI_EFCT=m
  - Network device support
  - DWMAC_LOONGSON=m
  - MEDIATEK_GE_PHY=m
  - MOTORCOMM_PHY=m
  - WWAN_HWSIM=m
  - RPMSG_WWAN_CTRL=m
  - IOSM=m
  - PHY_CAN_TRANSCEIVER=m
  - INFINIBAND_IRDMA=m
  - Hardware Monitoring support
  - SENSORS_DPS920AB=m
  - SENSORS_MP2888=m
  - SENSORS_PIM4328=m
  - SENSORS_SHT4x=m
  - Voltage and Current Regulator Support
  - REGULATOR_MAX8893=m
  - REGULATOR_RT6160=m
  - REGULATOR_RT6245=m
  - REGULATOR_RT4831=m
  - Graphics support
  - HSA_AMD_SVM=y
  - DRM_SIMPLEDRM=m
  - DRM_HYPERV=m
  - FB_SSD1307=m
  - BACKLIGHT_RT4831=m
  - Sound card support
  - SND_SOC_INTEL_SOF_CS42L42_MACH=m
  - SND_SOC_TFA989X=n
  - SND_SOC_WCD938X_SDW=n
  - X86 Platform Specific Device Drivers
  - DELL_WMI_PRIVACY=y
  - WIRELESS_HOTKEY=m
  - THINKPAD_LMI=m
  - X86_PLATFORM_DRIVERS_INTEL=y
  - INTEL_SKL_INT3472=m
  - Common Clock Framework
  - ICST=n
  - CLK_SP810=n
  - LMK04832=m
  - IOMMU Hardware Support
  - VIRTIO_IOMMU=m
  - Industrial I/O support
  - FXLS8962AF_I2C=n
  - FXLS8962AF_SPI=n
  - SCA3300=n
  - TI_TSC2046=n
  - SPS30_I2C=n
  - SPS30_SERIAL=n
  - IIO_ST_LSM9DS0=n
  - TSL2591=n
  - TMP117=n
  - Misc devices
  - MTD_MCHP48L640=n
  - JOYSTICK_QWIIC=m
  - XILLYUSB=m
  - GPIO_TPS68470=n
  - BATTERY_RT5033=m
  - WATCHDOG_HRTIMER_PRETIMEOUT=y
  - MFD_RT4831=m
  - VIDEO_IMX208=m
  - LEDS_LT3593=m
  - RESET_MCHP_SPARX5=n
  - OF dependent (i386, ppc64 / ppc64le, riscv64)
  - MFD_QCOM_PM8008=n
  - DRM_ITE_IT66121=n
  - DRM_TI_SN65DSI83=n
  - i386
  - DRM_CROS_EC_ANX7688=n
  - ppc64 / ppc64le
  - STRICT_MODULE_RWX=y
  - PPC_RFI_SRR_DEBUG=n
  - ppc64
  - PS3_VERBOSE_RESULT=n
  - s390x
  - SPARX5_SWITCH=m
  - RESET_TI_SYSCON=n
  - riscv64
  - PHYS_RAM_BASE=0x80000000 (default)
  - VMAP_STACK=y
  - TRANSPARENT_HUGEPAGE=y
  - READ_ONLY_THP_FOR_FS=y
  - SND_SOC_RK817=n
  - SND_SOC_RT5640=m
  - POLARFIRE_SOC_MAILBOX=m
  - DEV_DAX=m
  - STACK_HASH_ORDER=20 (default)
  - KFENCE=y
  - KFENCE_STATIC_KEYS=y
  - KFENCE_SAMPLE_INTERVAL=0 (other archs, see bsc#1185565)
  - KFENCE_NUM_OBJECTS=255 (default)
  - KFENCE_STRESS_TEST_FAULTS=0 (default)
- commit 2c5f605
* Mon Jul 12 2021 kbuild@suse.de
- Automatically updated to 5.14-rc1-next-20210712
- commit e89c3a6
* Sun Jul 11 2021 schwab@suse.de
- config: riscv64: enable DRM_I2C_NXP_TDA998X
  This also selects SND_SOC_HDMI_CODEC, SND_PCM_ELD, SND_PCM_IEC958.
- commit c1e7a75
* Sun Jul 11 2021 schwab@suse.de
- config: riscv64: enable MFD_TPS65086
  Also enable the related drivers GPIO_TPS65086 and REGULATOR_TPS65086.
- commit 8c6675e
* Fri Jul  9 2021 mbrugger@suse.com
- arm64: Update config files. (bsc#1187589)
  Enable PL330 DMA controller.
- commit f11ae0c
* Fri Jul  9 2021 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Remove zdebug define used only once.
- commit 85a9fc2
* Fri Jul  9 2021 kbuild@suse.de
- Automatically updated to 5.13-next-20210709
- commit 9716440
* Thu Jul  8 2021 msuchanek@suse.de
- Update config files (boo#1187824).
  CRYPTO_FIPS=y
  CRYPTO_MANAGER_DISABLE_TESTS=n
- commit b0667ab
* Thu Jul  8 2021 msuchanek@suse.de
- kernel-binary.spec: Exctract s390 decompression code (jsc#SLE-17042).
- commit 7f97df2
* Thu Jul  8 2021 kbuild@suse.de
- Automatically updated to 5.13-next-20210708
- commit 2d1d534
* Thu Jul  8 2021 msuchanek@suse.de
- kernel-binary.spec: Fix up usrmerge for non-modular kernels.
- commit d718cd9
* Wed Jul  7 2021 schwab@suse.de
- config: riscv64: enable MFD_DA9063
  Also enable the related drivers DA9063_WATCHDOG, REGULATOR_DA9063,
  RTC_DRV_DA9063.
- commit 678732f
* Wed Jul  7 2021 kbuild@suse.de
- Automatically updated to 5.13-next-20210707
- commit 60a7d47
* Tue Jul  6 2021 kbuild@suse.de
- Automatically updated to 5.13-next-20210706
- commit 717ca7b
* Thu Jul  1 2021 msuchanek@suse.de
- kernel-binary.spec: Remove obsolete and wrong comment
  mkmakefile is repleced by echo on newer kernel
- commit d9209e7
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_SCSI_SNIC_DEBUG_FS=y (bsc#1158776 comment 19).
- commit 373d095
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_BLK_SED_OPAL=y on arm64 (bsc#1158776 comment 16).
- commit 61048da
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_SATA_ZPODD=y on arm64 (bsc#1158776 comment 14).
- commit 179ce8d
* Thu Jul  1 2021 ptesarik@suse.cz
- Disable MANDATORY_FILE_LOCKING on arm and arm64 (bsc#1158776 comment 12).
- commit 8b1f614
* Thu Jul  1 2021 ptesarik@suse.cz
- Disable 842 compression on arm64 (bsc#1158776 comment 11).
- commit 9e9ba62
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_USB_CHAOSKEY=m on arm64 (bsc#1158776 comment 9).
- commit e1876b6
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_INET_DIAG_DESTROY=y on arm64 (bsc#1158776 comment 7).
- commit f13730f
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_SLAB_FREELIST_RANDOM=y on arm64 (bsc#1158776 comment 6).
- commit 752d277
* Thu Jul  1 2021 ptesarik@suse.cz
- Disable CONFIG_PCCARD on arm64 (bsc#1158776 comment 2).
- commit b442f13
* Thu Jul  1 2021 kbuild@suse.de
- Automatically updated to 5.13-next-20210701
- commit 204042a
* Wed Jun 30 2021 kbuild@suse.de
- Automatically updated to 5.13-next-20210630
- commit 529c894
* Tue Jun 29 2021 kbuild@suse.de
- Automatically updated to 5.13-next-20210629
- commit d95b809
* Mon Jun 28 2021 mkubecek@suse.cz
- Update to 5.13 final
- refresh configs
  - update headers
  - armv7hl: drop GPIO_TQMX86
- commit 41d9a74
* Sat Jun 26 2021 kbuild@suse.de
- Automatically updated to 5.13-rc7-next-20210625
- commit cdc5295
* Fri Jun 25 2021 msuchanek@suse.de
- Revert "Update config files (bsc#1187167)" (bsc#1187711).
  The key is needed. When a random key is generaeted it is a problem with
  OBS repository setup. OBS should provide a signing key.
- commit e7a5876
* Fri Jun 25 2021 kbuild@suse.de
- Automatically updated to 5.13-rc7-next-20210624
- commit 8717d31
* Thu Jun 24 2021 kbuild@suse.de
- Automatically updated to 5.13-rc7-next-20210623
- commit 276a3b4
* Wed Jun 23 2021 kbuild@suse.de
- Automatically updated to 5.13-rc7-next-20210622
- commit ff0f0fb
* Wed Jun 23 2021 schwab@suse.de
- Add dtb-microchip
- commit c797107
* Tue Jun 22 2021 kbuild@suse.de
- Automatically updated to 5.13-rc7-next-20210621
- commit 55352e7
* Mon Jun 21 2021 mkubecek@suse.cz
- Update to 5.13-rc7
- eliminate 1 patch
  - patches.suse/0001-x86-ioremap-Map-efi_mem_reserve-memory-as-encrypted-.patch
- refresh configs
- commit de0ee54
* Sat Jun 19 2021 kbuild@suse.de
- Automatically updated to 5.13-rc6-next-20210618
- commit a05f9b4
* Fri Jun 18 2021 kbuild@suse.de
- Automatically updated to 5.13-rc6-next-20210617
- commit ec76f38
* Thu Jun 17 2021 ludwig.nussel@suse.de
- UsrMerge the kernel (boo#1184804)
- Move files in /boot to modules dir
  The file names in /boot are included as %%ghost links. The %%post script
  creates symlinks for the kernel, sysctl.conf and System.map in
  /boot for compatibility. Some tools require adjustments before we
  can drop those links. If boot is a separate partition, a copy is
  used instead of a link.
  The logic for /boot/vmlinuz and /boot/initrd doesn't change with
  this patch.
- Use /usr/lib/modules as module dir when usermerge is active in the
  target distro.
- commit 6f5ed04
* Thu Jun 17 2021 kbuild@suse.de
- Automatically updated to 5.13-rc6-next-20210616
- commit 12f8dde
* Wed Jun 16 2021 tiwai@suse.de
- Update config files: CONFIG_SND_HDA_INTEL=m for armv7hl, too (bsc#1187334)
  It's used by openQA.
- commit 8aafe59
* Wed Jun 16 2021 msuchanek@suse.de
- kernel-binary.spec.in: Regenerate makefile when not using mkmakefile.
- commit 6b30fe5
* Wed Jun 16 2021 msuchanek@suse.de
- Delete patches.rpmify/Revert-kbuild-merge-scripts-mkmakefile-to-top-Makefi.patch.
- commit 4b163f9
* Tue Jun 15 2021 kbuild@suse.de
- Automatically updated to 5.13-rc6-next-20210615
- commit dce7099
* Mon Jun 14 2021 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix handling of +arch marker (bsc#1186672)
  The previous commit made a module wrongly into Module.optional.
  Although it didn't influence on the end result, better to fix it.
  Also, add a comment to explain the markers briefly.
- commit 8f79742
* Mon Jun 14 2021 schwab@suse.de
- config: riscv64: enable STMMAC_PLATFORM
  This also makes DWMAC_DWC_QOS_ETH, DWMAC_GENERIC, DWMAC_INTEL_PLAT visible
  which are all enabled.
- commit b466050
* Fri Jun 11 2021 tiwai@suse.de
- Add arch-dependent support markers in supported.conf (bsc#1186672)
  We may need to put some modules as supported only on specific archs.
  This extends the supported.conf syntax to allow to put +arch additionally
  after the unsupported marker, then it'll be conditionally supported on
  that arch.
- commit 8cbdb41
* Fri Jun 11 2021 bwiedemann@suse.de
- Create Symbols.list and ipa-clones.list determistically
  without this patch, filesystem readdir order would influence
  order of entries in these files.
  This patch was done while working on reproducible builds for SLE.
- commit a898b6d
* Fri Jun 11 2021 kbuild@suse.de
- Automatically updated to 5.13-rc5-next-20210611
- commit 385fdc6
* Fri Jun 11 2021 tiwai@suse.de
- Update config files (bsc#1187167)
  Set empty to CONFIG_MODULE_SIG_KEY for reproducible builds
- commit fc28c35
* Thu Jun 10 2021 martin.wilck@suse.com
- kernel-binary.spec.in: Add Supplements: for -extra package on Leap
  kernel-$flavor-extra should supplement kernel-$flavor on Leap, like
  it does on SLED, and like the kernel-$flavor-optional package does.
- commit c60d87f
* Thu Jun 10 2021 kbuild@suse.de
- Automatically updated to 5.13-rc5-next-20210610
- commit 4922e85
* Wed Jun  9 2021 kbuild@suse.de
- Automatically updated to 5.13-rc5-next-20210608
- commit b1d3d2c
* Tue Jun  8 2021 kbuild@suse.de
- Automatically updated to 5.13-rc5-next-20210607
- commit acea063
* Mon Jun  7 2021 mkubecek@suse.cz
- Update to 5.13-rc5
- update configs
  - HID_SEMITEK=m
- commit 58a7cec
* Fri Jun  4 2021 msuchanek@suse.de
- libbpf: fix pr_warn type warnings on 32bit (format '%%ld' expects
  argument of type 'long int', but argument 3 has type 'int' a).
- commit 7faa5fa
* Fri Jun  4 2021 kbuild@suse.de
- Automatically updated to 5.13-rc4-next-20210604
- commit 3e643a1
* Thu Jun  3 2021 msuchanek@suse.de
- Refresh config files.
  Align across architectures:
  BPFILTER_UMH=m
- commit 0ff8348
* Thu Jun  3 2021 afaerber@suse.com
- config: armv7hl: Update to 5.13-rc4
- commit 8c7d021
* Thu Jun  3 2021 afaerber@suse.com
- config: armv6hl: Update to 5.13-rc4
- commit 44d2ff6
* Thu Jun  3 2021 afaerber@suse.com
- config: arm64: Update to 5.13-rc4
- commit bb20235
* Thu Jun  3 2021 kbuild@suse.de
- Automatically updated to 5.13-rc4-next-20210603
- commit ae6d1f0
* Thu Jun  3 2021 msuchanek@suse.de
- kernel-binary.spec.in: build-id check requires elfutils.
- commit 01569b3
* Wed Jun  2 2021 msuchanek@suse.de
- kernel-binary.spec: Only use mkmakefile when it exists
  Linux 5.13 no longer has a mkmakefile script
- commit b453c7b
* Wed Jun  2 2021 kbuild@suse.de
- Automatically updated to 5.13-rc4-next-20210602
- commit f18622b
* Tue Jun  1 2021 msuchanek@suse.de
- kernel-doc: Use Sphinx3.
  Sphinx2 is about to be removed from Factory.
- commit 23b4031
* Tue Jun  1 2021 kbuild@suse.de
- Automatically updated to 5.13-rc4-next-20210601
- commit 271728c
* Mon May 31 2021 mkubecek@suse.cz
- Update to 5.13-rc4
- eliminate 3 patches
  - patches.suse/bpf-Fix-alu32-const-subreg-bound-tracking-on-bitwise.patch
  - patches.suse/bpf-Prevent-writable-memory-mapping-of-read-only-rin.patch
  - patches.suse/bpf-ringbuf-Deny-reserve-of-buffers-larger-than-ring.patch
- update configs
  - BPF_UNPRIV_DEFAULT_OFF=n (backward compatible)
  - MEMTEST=y (riscv64 only, enabled on most architectures)
- commit c2a4581
* Fri May 28 2021 kbuild@suse.de
- Automatically updated to 5.13-rc3-next-20210528
- commit 35d267b
* Thu May 27 2021 msuchanek@suse.de
- Revert "kbuild: merge scripts/mkmakefile to top Makefile"
  (../scripts/mkmakefile: No such file or directory).
- commit 0a1d886
* Thu May 27 2021 msuchanek@suse.de
- Revert "mm/page_alloc: Work around a pahole limitation with zero-sized"
  This reverts commit 08fd21d5bab1e26e3b9beeffe64adcac775918c1.
- commit 40758df
* Thu May 27 2021 kbuild@suse.de
- Automatically updated to 5.13-rc3-next-20210527
- commit e6165d2
* Wed May 26 2021 kbuild@suse.de
- Automatically updated to 5.13-rc3-next-20210526
- commit 82c4bbb
* Wed May 26 2021 msuchanek@suse.de
- mm/page_alloc: Work around a pahole limitation with zero-sized
  struct pagesets (BPF:Invalid offset).
- commit 08fd21d
* Tue May 25 2021 kbuild@suse.de
- Automatically updated to 5.13-rc3-next-20210525
- commit 35f18e7
* Mon May 24 2021 kbuild@suse.de
- Automatically updated to 5.13-rc3-next-20210524
- commit 016e559
* Fri May 21 2021 kbuild@suse.de
- Automatically updated to 5.13-rc2-next-20210521
- commit 35260af
* Thu May 20 2021 kbuild@suse.de
- Automatically updated to 5.13-rc2-next-20210520
- commit 950287e
* Wed May 19 2021 kbuild@suse.de
- Automatically updated to 5.13-rc2-next-20210519
- commit 3455ff8
* Tue May 18 2021 kbuild@suse.de
- Automatically updated to 5.13-rc2-next-20210518
- commit 95611a9
* Sat May 15 2021 mkubecek@suse.cz
- kbuild: dummy-tools: adjust to stricter stackprotector check.
  Fix i386 builds after recent changes of stackprotector feature check and
  restore stackprotector related config options.
- commit f275d35
* Fri May 14 2021 kbuild@suse.de
- Automatically updated to 5.13-rc1-next-20210514
- commit eac7d9d
* Thu May 13 2021 kbuild@suse.de
- Automatically updated to 5.13-rc1-next-20210513
- commit 9d76180
* Thu May 13 2021 msuchanek@suse.de
- Delete patches.rpmify/drm-bridge-fix-LONTIUM_LT8912B-dependencies.patch.
  Upstreamed
- commit 576461f
* Wed May 12 2021 kbuild@suse.de
- Automatically updated to 5.13-rc1-next-20210512
- commit b30576a
* Wed May 12 2021 glin@suse.com
- scripts/git_sort/git_sort.py: add bpf git repo
- commit 65979e3
* Tue May 11 2021 kbuild@suse.de
- Automatically updated to 5.13-rc1-next-20210511
- commit 5d96965
* Mon May 10 2021 dmueller@suse.com
- Add dtb-apple (bsc#1185845)
- commit 2699ed6
* Mon May 10 2021 msuchanek@suse.de
- Refresh patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch.
- commit 58fbf49
* Mon May 10 2021 kbuild@suse.de
- Automatically updated to 5.13-rc1-next-20210510
- commit b198010
* Mon May 10 2021 mkubecek@suse.cz
- Update to 5.13-rc1
- eliminated 34 patches (22 stable, 12 other)
  - patches.kernel.org/*
  - patches.suse/clk-bcm-rpi-release-firmware-handle-on-unbind.patch
  - patches.suse/dt-bindings-pwm-add-binding-for-rpi-firmware-pwm-bus.patch
  - patches.suse/firmware-raspberrypi-introduce-devm_rpi_firmware_get.patch
  - patches.suse/firmware-raspberrypi-keep-count-of-all-consumers.patch
  - patches.suse/gpio-raspberrypi-exp-release-firmware-handle-on-unbind.patch
  - patches.suse/input-raspberrypi-ts-release-firmware-handle-when-not-needed.patch
  - patches.suse/media-dvb-usb-Fix-memory-leak-at-error-in-dvb_usb_de.patch
  - patches.suse/media-dvb-usb-Fix-use-after-free-access.patch
  - patches.suse/pwm-add-raspberry-pi-firmware-based-pwm-bus.patch
  - patches.suse/reset-raspberrypi-release-firmware-handle-on-unbind.patch
  - patches.suse/soc-bcm-raspberrypi-power-release-firmware-handle-on-unbind.patch
  - patches.suse/vchiq-release-firmware-handle-on-unbind.patch
- disable ARM architectures (need config update)
- refresh
  - patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/supported-flag
  - patches.suse/supported-flag-modverdir
  - patches.suse/vfs-add-super_operations-get_inode_dev
- config refresh (no longer available as module)
  - PVPANIC (m -> y)
  - NFS_V4_2_SSC_HELPER (m -> y)
- new config options
  - General setup
  - CGROUP_MISC=y
  - Virtualization
  - X86_SGX_KVM=y
  - General architecture-dependent options
  - RANDOMIZE_KSTACK_OFFSET_DEFAULT=y
  - Enable loadable module support
  - MODULE_COMPRESS_NONE=y
  - MODULE_COMPRESS_GZIP=n
  - MODULE_COMPRESS_XZ=n
  - MODULE_COMPRESS_ZSTD=n
  - MODPROBE_PATH="/sbin/modprobe"
  - Networking support
  - NF_LOG_SYSLOG=m
  - NETFILTER_XTABLES_COMPAT=y
  - PCPU_DEV_REFCNT=y
  - CAN_ETAS_ES58X=m
  - BT_AOSPEXT=y
  - BT_VIRTIO=m
  - File systems
  - NETFS_SUPPORT=m
  - NETFS_STATS=y
  - Security options
  - SECURITY_LANDLOCK=y
  - Cryptographic API
  - CRYPTO_ECDSA=y
  - SYSTEM_REVOCATION_LIST=y
  - SYSTEM_REVOCATION_KEYS=""
  - Kernel hacking
  - VMLINUX_MAP=y
  - TEST_DIV64=n
  - Virtualiation drivers
  - PVPANIC=y
  - PVPANIC_MMIO=m
  - PVPANIC_PCI=m
  - VDPA_SIM_BLOCK=m
  - VP_VDPA=m
  - Network device support
  - NET_DSA_MICROCHIP_KSZ8863_SMI=m
  - NET_VENDOR_MICROSOFT=y
  - MICROSOFT_MANA=m
  - MLX5_TC_SAMPLE=y
  - MARVELL_88X2222_PHY=m
  - NXP_C45_TJA11XX_PHY=m
  - WWAN=y
  - WWAN_CORE=m
  - MHI_WWAN_CTRL=m
  - Input device support
  - TOUCHSCREEN_HYCON_HY46XX=m
  - TOUCHSCREEN_ILITEK=m
  - TOUCHSCREEN_MSG2638=m
  - INPUT_IQS626A=m
  - Power supply class support
  - BATTERY_GOLDFISH=m
  - BATTERY_SURFACE=m
  - CHARGER_SURFACE=m
  - Hardware Monitoring support
  - SENSORS_NZXT_KRAKEN2=m
  - SENSORS_BPA_RS600=m
  - SENSORS_FSP_3Y=m
  - SENSORS_IR36021=m
  - SENSORS_MAX15301=m
  - SENSORS_STPDDC60=m
  - Graphics support
  - DRM_AMD_SECURE_DISPLAY=y
  - DRM_I915_REQUEST_TIMEOUT=20000
  - DRM_GUD=m
  - Sound card support
  - SND_SOC_FSL_RPMSG=n
  - SND_SOC_TLV320AIC3X_I2C=n
  - SND_SOC_TLV320AIC3X_SPI=n
  - SND_VIRTIO=m
  - HID support
  - HID_FT260=m
  - SURFACE_KBD=m
  - SURFACE_HID=m
  - X86 Platform Specific Device Drivers
  - GIGABYTE_WMI=m
  - ADV_SWBUTTON=m
  - Microsoft Surface Platform-Specific Device Drivers
  - SURFACE_AGGREGATOR_REGISTRY=m
  - SURFACE_DTX=m
  - SURFACE_PLATFORM_PROFILE=m
  - Industrial I/O support
  - BMI088_ACCEL=n
  - TI_ADS131E08=n
  - CROS_EC_MKBP_PROXIMITY=n
  - Misc devices
  - DW_XDATA_PCIE=m
  - I2C_CP2615=m
  - SPI_ALTERA_CORE=m
  - SPI_ALTERA_DFL=m
  - INTEL_TCC_COOLING=m
  - MFD_ATC260X_I2C=n
  - RTC_DRV_GOLDFISH=m
  - INTEL_IDXD_PERFMON=y
  - UIO_DFL=m
  - OF dependent (i386, ppc64 / ppc64le, riscv64)
  - MFD_NTXEC=n
  - MFD_ROHM_BD957XMUF=n
  - DRM_CHIPONE_ICN6211=n
  - DRM_LONTIUM_LT8912B=n
  - LEDS_RT4505=m
  - i386
  - MODULE_SIG_ALL=n
  - MODULE_SIG_SHA256=y
  - SND_SOC_RT1316_SDW=n
  - SND_SOC_RT711_SDCA_SDW=n
  - SND_SOC_RT715_SDCA_SDW=n
  - LEDS_LGM=m
  - MODULE_SIG_KEY="certs/signing_key.pem"
  - ppc64 / ppc64le
  - TIME_NS=y
  - STRICT_KERNEL_RWX=y
  - CMA_SYSFS=n
  - FSL_DPAA2_SWITCH=m
  - FSL_ENETC_IERB=m
  - DEBUG_RODATA_TEST=n
  - DEBUG_VM_PGTABLE=n
  - s390x
  - CMA_SYSFS=n
  - NET_DSA=n
  - CIO_INJECT=n
  - riscv64
  - SOC_MICROCHIP_POLARFIRE=y
  - RISCV_ERRATA_ALTERNATIVE=y
  - ERRATA_SIFIVE_CIP_453=y
  - ERRATA_SIFIVE_CIP_1200=y
  - KEXEC=y
  - CRASH_DUMP=y
  - PHYS_RAM_BASE_FIXED=n
  - XIP_KERNEL=n
  - STRICT_MODULE_RWX=y
  - PCIE_FU740
  - PROC_VMCORE=y
  - PROC_VMCORE_DEVICE_DUMP=y
  - FORTIFY_SOURCE=y
- commit ff4c1d6
* Fri May  7 2021 kbuild@suse.de
- Automatically updated to 5.12-next-20210507
- commit b19c951
* Thu May  6 2021 msuchanek@suse.de
- kernel-docs.spec.in: Build using an utf-8 locale.
  Sphinx cannot handle UTF-8 input in non-UTF-8 locale.
- commit 0db6da1
* Thu May  6 2021 kbuild@suse.de
- Automatically updated to 5.12-next-20210506
- commit f11aa8b
* Thu May  6 2021 msuchanek@suse.de
- rpm/kernel-docs.spec.in: amscls is required even for HTML docs.
- commit c14685f
* Thu May  6 2021 mkubecek@suse.cz
- config: disable kfence by default (bsc#1185565)
  Apperently the overhead of kfence is not as negligible as the help text
  seemed to promise so that it seems more appropriate to disable kfence by
  default by setting CONFIG_KFENCE_SAMPLE_INTERVAL to 0. Anyone who wants to
  enable it can still do so using the kfence.sample_interval command line
  parameter.
- commit 865b2a8
* Wed May  5 2021 msuchanek@suse.de
- Move patch to correct directory.
- commit 11a42cf
* Wed May  5 2021 msuchanek@suse.de
- rpm/kernel-docs.spec.in: Add amscls is required to build.
  [  781s] ! LaTeX Error: File `amsthm.sty' not found.
- commit 578ff38
* Wed May  5 2021 kbuild@suse.de
- Automatically updated to 5.12-next-20210505
- commit c0c7d08
* Wed May  5 2021 msuchanek@suse.de
- drm/bridge: fix LONTIUM_LT8912B dependencies
  (ERROR: modpost: "drm_display_mode_to_videomode"
  [drivers/gpu/drm/bridge/lontium-lt8912b.ko] undefined!).
- commit 7eb6ec7
* Wed May  5 2021 msuchanek@suse.de
- Revert "Update config files."
  This reverts commit d750ecc7b4fcd5d5556b1afd9fc2523d059b01f0.
  CONFIG_DRM_LONTIUM_LT8912B=m
- commit dddff06
* Wed May  5 2021 mkubecek@suse.cz
- rpm: drop /usr/bin/env in interpreter specification
  OBS checks don't like /usr/bin/env in script interpreter lines but upstream
  developers tend to use it. A proper solution would be fixing the depedency
  extraction and drop the OBS check error but that's unlikely to happen so
  that we have to work around the problem on our side and rewrite the
  interpreter lines in scripts before collecting files for packages instead.
- commit 45c5c1a
* Tue May  4 2021 msuchanek@suse.de
- Update config files.
  CONFIG_DRM_LONTIUM_LT8912B=n
  ERROR: modpost: "drm_display_mode_to_videomode" [drivers/gpu/drm/bridge/lontium-lt8912b.ko] undefined!
- commit d750ecc
* Tue May  4 2021 kbuild@suse.de
- Automatically updated to 5.12-next-20210504
- commit 64d2f79
* Tue May  4 2021 dwagner@suse.de
- scripts/git_sort/git_sort.py: Update nvme repositories
- commit e849c44
* Mon May  3 2021 kbuild@suse.de
- Automatically updated to 5.12-next-20210503
- commit 0559f48
* Sat May  1 2021 msuchanek@suse.de
- powerpc/64: BE option to use ELFv2 ABI for big endian kernels (BTFIDS vmlinux FAILED unresolved symbol vfs_truncate).
  Update config files.
- powerpc/64: BE option to use ELFv2 ABI for big endian kernels
  (BTFIDS vmlinux FAILED unresolved symbol vfs_truncate).
  Update config files.
- commit b0d3863
* Fri Apr 30 2021 kbuild@suse.de
- Automatically updated to 5.12-next-20210430
- commit f5666b6
* Fri Apr 30 2021 schwab@suse.de
- rpm/constraints.in: bump disk space to 45GB on riscv64
- commit f8b883f
* Thu Apr 29 2021 tiwai@suse.de
- Update config files: fix armv7hl/lpae config (bsc#1152773)
  CONFIG_OABI_COMPAT was left enabled mistakenly on lpae flavor, which
  resulted in the disablement of CONFIG_SECCOMP_FILTER.  Fix those.
  CONFIG_OABI_COMPAT -> disabled
  CONFIG_SECCOMP_FILTER=y
  CONFIG_HAVE_ARCH_SECCOMP_FILTER=y
  Also corrected the following with the update:
  CONFIG_HAVE_ARCH_AUDITSYSCALL=y
  CONFIG_AUDITSYSCALL=y
  CONFIG_FPE_NWFPE -> removed
  CONFIG_FPE_NWFPE_XP -> removed
  CONFIG_FPE_FASTFPE -> removed
- commit aa6c781
* Thu Apr 29 2021 kbuild@suse.de
- Automatically updated to 5.12-next-20210429
- commit cc9cadd
* Wed Apr 28 2021 kbuild@suse.de
- Automatically updated to 5.12-next-20210428
- commit 86cb9a3
* Wed Apr 28 2021 jslaby@suse.cz
- rpm/constraints.in: remove aarch64 disk size exception
  obs://Kernel:stable/kernel-default/ARM/aarch64 currrently fails:
  installing package kernel-default-livepatch-devel-5.12.0-3.1.g6208a83.aarch64 needs 3MB more space on the / filesystem
  The stats say:
  Maximal used disk space: 31799 Mbyte
  By default, we require 35G. For aarch64 we had an exception to lower
  this limit to 30G there. Drop this exception as it is obviously no
  longer valid.
- commit ee00b50
* Tue Apr 27 2021 kbuild@suse.de
- Automatically updated to 5.12-next-20210427
- commit 9ebc216
* Mon Apr 26 2021 kbuild@suse.de
- Automatically updated to 5.12-next-20210426
- commit 02a7ce0
* Sun Apr 25 2021 mkubecek@suse.cz
- Update to 5.12 final
- refresh configs (headers only)
- commit 4835129
* Sun Apr 25 2021 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Require new enough pahole.
  pahole 1.21 is required for building linux 5.12 BTF
- commit 1a332d8
* Sat Apr 24 2021 kbuild@suse.de
- Automatically updated to 5.12-rc8-next-20210423
- commit 814549d
* Fri Apr 23 2021 martin.wilck@suse.com
- rpm/macros.kernel-source: fix KMP failure in %%install (bsc#1185244)
- commit 52805ed
* Thu Apr 22 2021 msuchanek@suse.de
- rpm/kernel-obs-build.spec.in: Include essiv with dm-crypt (boo#1183063).
  Previously essiv was part of dm-crypt but now it is separate.
  Include the module in kernel-obs-build when available.
  Fixes: 7cf5b9e26d87 ("rpm/kernel-obs-build.spec.in: add dm-crypt for building with cryptsetup")
- commit fe15b78
* Thu Apr 22 2021 kbuild@suse.de
- Automatically updated to 5.12-rc8-next-20210422
- commit e8bd08c
* Thu Apr 22 2021 tiwai@suse.de
- Revert "rpm/kernel-binary.spec.in: Fix dependency of kernel-*-devel package (bsc#1184514)"
  This turned out to be a bad idea: the kernel-$flavor-devel package
  must be usable without kernel-$flavor, e.g. at the build of a KMP.
  And this change brought superfluous installation of kernel-preempt
  when a system had kernel-syms (bsc#1185113).
- commit d771304
* Wed Apr 21 2021 jslaby@suse.cz
- rpm/check-for-config-changes: add AS_HAS_* to ignores
  arch/arm64/Kconfig defines a lot of these. So far our current compilers
  seem to support them all. But it can quickly change with SLE later.
- commit a4d8194
* Tue Apr 20 2021 kbuild@suse.de
- Automatically updated to 5.12-rc8-next-20210420
- commit bf7a56b
* Mon Apr 19 2021 mkubecek@suse.cz
- Update to 5.12-rc8
- refresh configs
- commit 1fade33
* Sat Apr 17 2021 kbuild@suse.de
- Automatically updated to 5.12-rc7-next-20210416
- commit 853cfeb
* Fri Apr 16 2021 kbuild@suse.de
- Automatically updated to 5.12-rc7-next-20210415
- commit 642588a
* Thu Apr 15 2021 kbuild@suse.de
- Automatically updated to 5.12-rc7-next-20210414
- commit 6d69399
* Wed Apr 14 2021 jslaby@suse.cz
- rpm/check-for-config-changes: remove stale comment
  It is stale since 8ab393bf905a committed in 2005 :).
- commit c9f9f5a
* Tue Apr 13 2021 tiwai@suse.de
- rpm/mkspec: Use tilde instead of dot for version string with rc (bsc#1184650)
- commit f37613f
* Tue Apr 13 2021 kbuild@suse.de
- Automatically updated to 5.12-rc7-next-20210413
- commit daa0ed9
* Mon Apr 12 2021 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix dependency of kernel-*-devel package (bsc#1184514)
  The devel package requires the kernel binary package itself for building
  modules externally.
- commit 794be7b
* Sat Apr 10 2021 kbuild@suse.de
- Automatically updated to 5.12-rc6-next-20210409
- commit 677646c
* Fri Apr  9 2021 msuchanek@suse.de
- Add obsolete_rebuilds_subpackage (boo#1172073 bsc#1191731).
- commit f037781
* Fri Apr  9 2021 msuchanek@suse.de
- rpm/check-for-config-changes: Also ignore AS_VERSION added in 5.12.
- commit bd64cb2
* Fri Apr  9 2021 kbuild@suse.de
- Automatically updated to 5.12-rc6-next-20210408
- commit 95f2bdc
* Fri Apr  9 2021 msuchanek@suse.de
- post.sh: Return an error when module update fails (bsc#1047233 bsc#1184388).
- commit 18f65df
* Thu Apr  8 2021 msuchanek@suse.de
- Update config files.
- commit 028f30a
* Thu Apr  8 2021 msuchanek@suse.de
- Delete patches.rpmify/dummy-tools-fixup.patch.
- commit 179f38d
* Thu Apr  8 2021 kbuild@suse.de
- Automatically updated to 5.12-rc6-next-20210407
- commit c7e2f06
* Wed Apr  7 2021 kbuild@suse.de
- Automatically updated to 5.12-rc6-next-20210406
- commit a6a13a3
* Wed Apr  7 2021 dmueller@suse.com
- config.conf: reenable armv6/armv7 configs
  (all modules, otherwise same settings like arm64)
- commit d01d749
* Wed Apr  7 2021 dmueller@suse.com
- arm64: add debug config with KASAN enabled (bsc#1183716)
- commit 7831cf6
* Tue Apr  6 2021 dmueller@suse.com
- arm64: enable and update config for 5.12
- commit c7e5d4e
* Sat Apr  3 2021 msuchanek@suse.de
- Fix scripts/dummy-tools/gcc: unknown assembler invoked
- Update config files.
- commit 6055eb9
* Thu Apr  1 2021 kbuild@suse.de
- Automatically updated to 5.12-rc5-next-20210401
- commit 58c6f78
* Wed Mar 31 2021 kbuild@suse.de
- Automatically updated to 5.12-rc5-next-20210331
- commit ed599db
* Tue Mar 30 2021 kbuild@suse.de
- Automatically updated to 5.12-rc5-next-20210330
- commit b654687
* Mon Mar 29 2021 kbuild@suse.de
- Automatically updated to 5.12-rc4-next-20210329
- commit e126398
* Mon Mar 29 2021 mkubecek@suse.cz
- Update to 5.12-rc5
- refresh configs
  - XEN_BALLOON_MEMORY_HOTPLUG_LIMIT renamed to XEN_MEMORY_HOTPLUG_LIMIT (x86_64)
- commit 1f2ed0f
* Fri Mar 26 2021 kbuild@suse.de
- Automatically updated to 5.12-rc4-next-20210326
- commit 47b3ab5
* Fri Mar 26 2021 tiwai@suse.de
- Update config files: disable CONFIG_SND_HDA_INTEL_HDMI_SILENT_STREAM (bsc#1184019)
- commit 1a2dc3f
* Thu Mar 25 2021 kbuild@suse.de
- Automatically updated to 5.12-rc4-next-20210325
- commit 17b1c7d
* Wed Mar 24 2021 kbuild@suse.de
- Automatically updated to 5.12-rc4-next-20210324
- commit 873779a
* Tue Mar 23 2021 kbuild@suse.de
- Automatically updated to 5.12-rc4-next-20210323
- commit a29a472
* Mon Mar 22 2021 kbuild@suse.de
- Automatically updated to 5.12-rc4-next-20210322
- commit 10aa607
* Mon Mar 22 2021 mkubecek@suse.cz
- Update to 5.12-rc4
- update configs
  - VFIO=n (s390x/zfcpdump only)
  - drop SND_SOC_SIRF_AUDIO_CODEC (removed)
  - drop ADI_AXI_ADC (x86_64, depends on OF now)
- commit 430f1b5
* Mon Mar 22 2021 mkubecek@suse.cz
- config: disable obsolete crypto algorithms (bsc#1180928)
- CONFIG_CRYPTO_USER_API_ENABLE_OBSOLETE y->n
  - drop CRYPTO_ANUBIS
  - drop CRYPTO_ARC4
  - drop CRYPTO_KHAZAD
  - drop CRYPTO_SEED
  - drop CRYPTO_TEA
- commit d17512c
* Fri Mar 19 2021 kbuild@suse.de
- Automatically updated to 5.12-rc3-next-20210319
- commit 1582889
* Thu Mar 18 2021 msuchanek@suse.de
- Delete patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
  Not needed with dummy-tools (bcs#1181862).
- commit e354dc0
* Thu Mar 18 2021 kbuild@suse.de
- Automatically updated to 5.12-rc3-next-20210318
- commit 61846c1
* Wed Mar 17 2021 kbuild@suse.de
- Automatically updated to 5.12-rc3-next-20210317
- commit 9d7f0f4
* Tue Mar 16 2021 kbuild@suse.de
- Automatically updated to 5.12-rc3-next-20210316
- commit 5780783
* Tue Mar 16 2021 tiwai@suse.de
- Update config files: enable CONFIG_BMP280=m for x86 (bsc#1183198)
- commit 9905665
* Mon Mar 15 2021 kbuild@suse.de
- Automatically updated to 5.12-rc3-next-20210315
- commit 3ef63c0
* Mon Mar 15 2021 mkubecek@suse.cz
- Update to 5.12-rc3
- eliminated 3 patches
  - patches.rpmify/kbuild-dummy-tools-adjust-to-scripts-cc-version.sh.patch
  - patches.rpmify/kbuild-dummy-tools-fix-inverted-tests-for-gcc.patch
  - patches.rpmify/kbuild-dummy-tools-support-MPROFILE_KERNEL-checks-fo.patch
- update configs
  - COMPILE_TEST=n (s390x)
  - TMPFS_INODE64=y (s390x)
- commit 061ecc0
* Sun Mar 14 2021 mkubecek@suse.cz
- config: update with dummy toolchain
- new config options:
  - GCC_PLUGINS=y
  - GCC_PLUGIN_CYC_COMPLEXITY is not set
  - GCC_PLUGIN_LATENT_ENTROPY is not set
  - GCC_PLUGIN_RANDSTRUCT is not set
  - GCC_PLUGIN_STRUCTLEAK_USER is not set
  - GCC_PLUGIN_STRUCTLEAK_BYREF is not set
  - GCC_PLUGIN_STRUCTLEAK_BYREF_ALL is not set
- commit 1468adf
* Fri Mar 12 2021 kbuild@suse.de
- Automatically updated to 5.12-rc2-next-20210312
- commit 5e7dba1
* Thu Mar 11 2021 kbuild@suse.de
- Automatically updated to 5.12-rc2-next-20210311
- commit 9327209
* Wed Mar 10 2021 kbuild@suse.de
- Automatically updated to 5.12-rc2-next-20210310
- commit 69b863a
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: comment on the list
  To explain what it actually is.
- commit e94bacf
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: define ignores more strictly
  * search for whole words, so make wildcards explicit
  * use ' for quoting
  * prepend CONFIG_ dynamically, so it need not be in the list
- commit f61e954
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: sort the ignores
  They are growing so to make them searchable by humans.
- commit 67c6b55
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: add -mrecord-mcount ignore
  Added by 3b15cdc15956 (tracing: move function tracer options to Kconfig)
  upstream.
- commit 018b013
* Tue Mar  9 2021 kbuild@suse.de
- Automatically updated to 5.12-rc2-next-20210309
- commit cb12296
* Sun Mar  7 2021 mkubecek@suse.cz
- Update to 5.12-rc2
- eliminated 1 patch
  - patches.suse/swap-fix-swapfile-read-write-offset.patch
- update configs
  - KVM_XEN=n (x86)
  - SND_SOC_SOF_MERRIFIELD=m (i386)
- commit 619ac8c
* Fri Mar  5 2021 dmueller@suse.com
- ARMv6/v7: Update config files. (bsc#1183009)
  enable CONFIG_ARM_MODULE_PLTS to fix module loading issues
- commit 28f299e
* Fri Mar  5 2021 kbuild@suse.de
- Automatically updated to 5.12-rc1-next-20210305
- commit 025f329
* Fri Mar  5 2021 jslaby@suse.cz
- rpm/check-for-config-changes: declare sed args as an array
  So that we can reuse it in both seds.
  This also introduces IGNORED_CONFIGS_RE array which can be easily
  extended.
- commit a1976d2
* Thu Mar  4 2021 jslaby@suse.cz
- rpm/check-for-config-changes: ignore more configs
  Specifially, these:
  * CONFIG_CC_HAS_*
  * CONFIG_CC_HAVE_*
  * CONFIG_CC_CAN_*
  * CONFIG_HAVE_[A-Z]*_COMPILER
  * CONFIG_TOOLS_SUPPORT_*
  are compiler specific too. This will allow us to use super configs
  using kernel's dummy-tools.
- commit d12dcbd
* Thu Mar  4 2021 kbuild@suse.de
- Automatically updated to 5.12-rc1-next-20210304
- commit 41d2acb
* Wed Mar  3 2021 yousaf.kaukab@suse.com
- config: arm64: sync xgmac-mdio config with SLE
- commit d70961d
* Wed Mar  3 2021 yousaf.kaukab@suse.com
- config: arm64: sync coresight configs with SLE
- commit 02b0a50
* Wed Mar  3 2021 kbuild@suse.de
- Automatically updated to 5.12-rc1-next-20210303
- commit 88d9901
* Tue Mar  2 2021 kbuild@suse.de
- Automatically updated to 5.12-rc1-next-20210302
- commit 987c36f
* Tue Mar  2 2021 dmueller@suse.com
- Remove zte device tree builds
  The zte vendor directory has been dropped in 5.12.rc1 via this change:
  commit 89d4f98ae90d95716009bb89823118a8cfbb94dd
  Author: Arnd Bergmann <arnd@arndb.de>
  Date:   Mon Jan 18 14:06:09 2021 +0100
- commit 58ed798
* Mon Mar  1 2021 kbuild@suse.de
- Automatically updated to 5.11-next-20210301
- commit 82f82b7
* Mon Mar  1 2021 mkubecek@suse.cz
- Update to 5.12-rc1
- eliminated 30 patches (26 stable, 4 other)
  - patches.kernel.org/*
  - patches.suse/drm-bail-out-of-nouveau_channel_new-if-channel-init-.patch
  - patches.suse/floppy-reintroduce-O_NDELAY-fix.patch
  - patches.suse/media-uvcvideo-Accept-invalid-bFormatIndex-and-bFram.patch
  - patches.suse/nvmem-add-driver-to-expose-reserved-memory-as-nvmem.patch
- disable ARM architectures (need config update)
- refresh
  - patches.rpmify/Add-ksym-provides-tool.patch
  - patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch
  - patches.suse/acpi_thermal_passive_blacklist.patch
  - patches.suse/btrfs-use-the-new-VFS-super_block_dev.patch
  - patches.suse/supported-flag
  - patches.suse/supported-flag-modverdir
  - patches.suse/supported-flag-wildcards
  - patches.suse/vfs-add-super_operations-get_inode_dev
- new config options
  - Power management and ACPI options
  - CONFIG_ACPI_FPDT=y
  - General architecture-dependent options
  - CONFIG_LTO_NONE=y
  - Enable loadable module support
  - CONFIG_TRIM_UNUSED_KSYMS=n
  - Networking support
  - CONFIG_IP_VS_TWOS=m
  - CONFIG_NET_DSA_TAG_XRS700X=m
  - CONFIG_NFC_VIRTUAL_NCI=m
  - Library routines
  - CONFIG_STACK_HASH_ORDER=20
  - Kernel hacking
  - CONFIG_DEBUG_INFO_DWARF_TOOLCHAIN_DEFAULT=n
  - CONFIG_KFENCE=y
  - CONFIG_KFENCE_STATIC_KEYS=y
  - CONFIG_KFENCE_SAMPLE_INTERVAL=100
  - CONFIG_KFENCE_NUM_OBJECTS=255
  - CONFIG_KFENCE_STRESS_TEST_FAULTS=0
  - CONFIG_DEBUG_IRQFLAGS=n
  - PCI support
  - CONFIG_PCI_EPF_NTB=m
  - CONFIG_CXL_BUS=m
  - CONFIG_CXL_MEM=m
  - CONFIG_CXL_MEM_RAW_COMMANDS=n
  - Network device support
  - CONFIG_NET_DSA_XRS700X_I2C=m
  - CONFIG_NET_DSA_XRS700X_MDIO=m
  - CONFIG_MLX5_SF=y
  - CONFIG_XILINX_EMACLITE=n
  - CONFIG_MT7921E=m
  - Power management
  - CONFIG_CHARGER_LTC4162L=m
  - CONFIG_CHARGER_BQ256XX=m
  - CONFIG_SENSORS_AHT10=m
  - CONFIG_SENSORS_TPS23861=m
  - CONFIG_REGULATOR_MT6315=m
  - Multimedia support
  - CONFIG_CIO2_BRIDGE=y
  - CONFIG_VIDEO_OV5648=m
  - CONFIG_VIDEO_OV8865=m
  - CONFIG_VIDEO_RDACM21=m
  - Sound card support
  - CONFIG_SND_JACK_INJECTION_DEBUG=n
  - CONFIG_SND_INTEL_BYT_PREFER_SOF=y
  - CONFIG_SND_SOC_RT5659=m
  - CONFIG_SND_SOC_LPASS_RX_MACRO=n
  - CONFIG_SND_SOC_LPASS_TX_MACRO=n
  - HID support
  - CONFIG_HID_PLAYSTATION=m
  - CONFIG_PLAYSTATION_FF=y
  - CONFIG_I2C_HID_ACPI=m
  - USB support
  - CONFIG_USB_CDNS_SUPPORT=m
  - CONFIG_USB_CDNSP_PCI=m
  - CONFIG_USB_CDNSP_GADGET=y
  - CONFIG_USB_CDNSP_HOST=y
  - CONFIG_USB_SERIAL_XR=m
  - LED Support
  - CONFIG_LEDS_TRIGGER_TTY=m
  - CONFIG_LEDS_BLINK=y
  - Microsoft Surface Platform-Specific Device Drivers
  - CONFIG_SURFACE_HOTPLUG=m
  - CONFIG_SURFACE_ACPI_NOTIFY=m
  - CONFIG_SURFACE_AGGREGATOR=m
  - CONFIG_SURFACE_AGGREGATOR_CDEV=m
  - CONFIG_SURFACE_AGGREGATOR_BUS=y
  - CONFIG_SURFACE_AGGREGATOR_ERROR_INJECTION=n
  - Industrial I/O support
  - CONFIG_AD5766=n
  - CONFIG_YAMAHA_YAS530=n
  - CONFIG_HID_SENSOR_CUSTOM_INTEL_HINGE=n
  - Generic powercap sysfs driver
  - CONFIG_DTPM=y
  - CONFIG_DTPM_CPU=y
  - Misc devices
  - CONFIG_BCM_VK=m
  - CONFIG_BCM_VK_TTY=y
  - CONFIG_TCG_TIS_I2C_CR50=m
  - CONFIG_SVC_I3C_MASTER=m
  - CONFIG_MMC_CRYPTO=y
  - CONFIG_INTEL_LDMA=y
  - CONFIG_DMABUF_DEBUG=n
  - CONFIG_ACRN_HSM=m
  - CONFIG_FPGA_DFL_EMIF=m
  - CONFIG_NTB_EPF=m
  - CONFIG_FPGA_DFL_NIOS_INTEL_PAC_N3000=m
  - x86
  - CONFIG_X86_PLATFORM_DRIVERS_DELL=y
  - OF dependent drivers (i386, ppc64/ppc64le, riscv64)
  - PCIE_MICROCHIP_HOST=y
  - VIDEO_IMX334=m
  - DRM_PANEL_DSI_CM=n
  - DRM_PANEL_KHADAS_TS050=n
  - I2C_HID_OF=m
  - I2C_HID_OF_GOODIX=m
  - COMMON_CLK_AXI_CLKGEN=m
  - i386
  - NET_DSA_MV88E6XXX_PTP=y
  - SPI_CADENCE_QUADSPI=m
  - LEDS_BLINK_LGM=m
  - s390x
  - TIME_NS=y
  - DEBUG_ENTRY=n
  - riscv64
  - NUMA=y
  - NODES_SHIFT=2
  - SPARSEMEM_VMEMMAP=y
  - DEFERRED_STRUCT_PAGE_INIT=y
  - LEDS_BLINK_LGM=m
  - KGDB_HONOUR_BLOCKLIST=y
  - FAIL_FUNCTION=n
  - KPROBES_SANITY_TEST=n
  - NUMA_BALANCING=y
  - NUMA_BALANCING_DEFAULT_ENABLED=y
- commit fee1fef
* Mon Mar  1 2021 mkubecek@suse.cz
- rpm/kernel-source.spec.in: temporary workaround for a build failure
  Upstream c6x architecture removal left a dangling link behind which
  triggers openSUSE post-build check in kernel-source, failing
  kernel-source build.
  A fix deleting the danglink link has been submitted but it did not make
  it into 5.12-rc1. Unfortunately we cannot add it as a patch as patch
  utility does not handle symlink removal. Add a temporary band-aid which
  deletes all dangling symlinks after unpacking the kernel source tarball.
  [jslaby] It's not that temporary as we are dragging this for quite some
  time in master. The reason is that this can happen any time again, so
  let's have this in packaging instead.
- commit 52a1ad7
* Sun Feb 28 2021 schwab@suse.de
- config: riscv64: enable EFI_STUB for vanilla
- commit f4061c5
* Fri Feb 26 2021 kbuild@suse.de
- Automatically updated to 5.11-next-20210226
- commit 270ee48
* Fri Feb 26 2021 mkubecek@suse.cz
- config: refresh
- fix misspelled USB gadget debugging options
- commit 760e876
* Thu Feb 25 2021 kbuild@suse.de
- Automatically updated to 5.11-next-20210225
- commit 782e7b1
* Wed Feb 24 2021 oneukum@suse.com
- Update config files. Update config files. Enable USB_GADGET(jsc#SLE-14042)
- supported.conf:
  After discussion what the feature request implied, it was
  decided that gadget mode is also needed on x86_64
- commit 6ee24b8
* Wed Feb 24 2021 msuchanek@suse.de
- macros.kernel-source: Use spec_install_pre for certificate installation (boo#1182672).
  Since rpm 4.16 files installed during build phase are lost.
- commit d0b887e
* Wed Feb 24 2021 kbuild@suse.de
- Automatically updated to 5.11-next-20210224
- commit 0a81e91
* Tue Feb 23 2021 msuchanek@suse.de
- Refresh patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
- commit c4c8f9a
* Tue Feb 23 2021 kbuild@suse.de
- Automatically updated to 5.11-next-20210223
- commit c5e2084
* Mon Feb 22 2021 mbrugger@suse.com
- arm: Update config files.
  Set CONFIG_WATCHDOG_SYSFS to true (bsc#1182560)
- commit 5515747
* Mon Feb 22 2021 kbuild@suse.de
- Automatically updated to 5.11-next-20210222
- commit c1fef5c
* Mon Feb 22 2021 msuchanek@suse.de
- rpm/kernel-subpackage-build: Workaround broken bot
  (https://github.com/openSUSE/openSUSE-release-tools/issues/2439)
- commit b74d860
* Fri Feb 19 2021 kbuild@suse.de
- Automatically updated to 5.11-next-20210219
- commit afe1e99
* Thu Feb 18 2021 kbuild@suse.de
- Automatically updated to 5.11-next-20210218
- commit d0d0b50
* Wed Feb 17 2021 nsaenzjulienne@suse.de
- Update config files: Set reset-raspberrypi as builtin (bsc#1180336)
  This driver is needed in order to boot through USB. Ideally the kernel
  module should be selected by dracut, but it's not. So make it builtin
  until the relevant dracut fixes are available.
- commit f22d9c0
* Tue Feb 16 2021 kbuild@suse.de
- Automatically updated to 5.11-next-20210216
- commit a477133
* Mon Feb 15 2021 msuchanek@suse.de
- kernel-binary.spec: Add back initrd and image symlink ghosts to
  filelist (bsc#1182140).
  Fixes: 76a9256314c3 ("rpm/kernel-{source,binary}.spec: do not include ghost symlinks (boo#1179082).")
- commit 606c9d1
* Mon Feb 15 2021 tiwai@suse.de
- rpm/post.sh: Avoid purge-kernel for the first installed kernel (bsc#1180058)
- commit c29e77d
* Mon Feb 15 2021 kbuild@suse.de
- Automatically updated to 5.11-rc7-next-20210215
- commit 6b13f43
* Mon Feb 15 2021 mkubecek@suse.cz
- Update to 5.11 final
- refresh configs
- commit a2424cb
* Sat Feb 13 2021 kbuild@suse.de
- Automatically updated to 5.11-rc7-next-20210212
- commit 160014a
* Fri Feb 12 2021 tiwai@suse.de
- Update config files: enable CONFIG_SERIAL_DEV_CTRL_TTYPORT on x86 (bsc#1182035)
  For supporting MS Surface devices. This required CONFIG_SERIAL_DEV_BUS
  to be built-in. Also this allowed CONFIG_BT_HCIUART_BCM=y as well.
- commit 10e85d0
* Fri Feb 12 2021 kbuild@suse.de
- Automatically updated to 5.11-rc7-next-20210211
- commit d8ced14
* Fri Feb 12 2021 nsaenzjulienne@suse.de
- Update config files: armv7hl: Set ledtrig-default-on as builtin (bsc#1182128)
- commit b1447e0
* Thu Feb 11 2021 nsaenzjulienne@suse.de
- Update config files: Set ledtrig-default-on as builtin (bsc#1182128)
- commit 55dd026
* Thu Feb 11 2021 oneukum@suse.com
- Update config files. Enable DWC3 on x86_64
  DWC3 is now needed on x86_64, too, with the added benefit
  of making x86_64 and ARM64 closer (jsc#SLE-14042)
- commit 9fe3ed1
* Thu Feb 11 2021 kbuild@suse.de
- Automatically updated to 5.11-rc7-next-20210210
- commit f37f787
* Wed Feb 10 2021 kbuild@suse.de
- Automatically updated to 5.11-rc7-next-20210209
- commit 81ec7a9
* Tue Feb  9 2021 kbuild@suse.de
- Automatically updated to 5.11-rc6-next-20210208
- commit 3603eeb
* Mon Feb  8 2021 matwey.kornilov@gmail.com
- config: arm64: Use y for CLK_RK3399
  This is to fix booting on RK3399 systems (JeOS-rockpi4)
  When compiled as 'm' there are lots of errors related to clk and no host mmc
  controler initialized.
- commit 600ddf3
* Mon Feb  8 2021 mkubecek@suse.cz
- Update to 5.11-rc7
- refresh configs
- commit 49b8db6
* Fri Feb  5 2021 kbuild@suse.de
- Automatically updated to 5.11-rc6-next-20210205
- commit 507111f
* Thu Feb  4 2021 kbuild@suse.de
- Automatically updated to 5.11-rc6-next-20210204
- commit 44fe69a
* Wed Feb  3 2021 tiwai@suse.de
- rpm/kernel-binary.spec.in: Correct Supplements in optional subpkg (jsc#SLE-11796)
  The product string was changed from openSUSE to Leap.
- commit 3cb7943
* Wed Feb  3 2021 kbuild@suse.de
- Automatically updated to 5.11-rc6-next-20210203
- commit 1187b32
* Tue Feb  2 2021 kbuild@suse.de
- Automatically updated to 5.11-rc6-next-20210202
- commit 0a781f4
* Mon Feb  1 2021 kbuild@suse.de
- Automatically updated to 5.11-rc6-next-20210201
- commit db4478c
* Mon Feb  1 2021 mkubecek@suse.cz
- Update to 5.11-rc6
- eliminated 1 patch
  - patches.suse/iwlwifi-dbg-Don-t-touch-the-tlv-data.patch
- refresh
  - patches.suse/acpi_thermal_passive_blacklist.patch
- update configs
  - LEDS_RT8515=m
- commit 48b9395
* Sat Jan 30 2021 afaerber@suse.com
- config: arm64: Enable Arm SP805 hardware watchdog (boo#1181607)
  The Ten64 board with NXP LS1088A SoC is documented to have Arm SP805 based
  watchdogs, so let's enable the driver for it.
- commit d375c27
* Fri Jan 29 2021 kbuild@suse.de
- Automatically updated to 5.11-rc5-next-20210129
- commit 62e9f0d
* Thu Jan 28 2021 kbuild@suse.de
- Automatically updated to 5.11-rc5-next-20210128
- commit 7040252
* Mon Jan 25 2021 kbuild@suse.de
- Automatically updated to 5.11-rc4-next-20210125
- commit da05141
* Mon Jan 25 2021 mkubecek@suse.cz
- Update to 5.11-rc5
- eliminated 3 patches
  - patches.suse/fs-cachefs-Drop-superfluous-readpages-aops-NULL-chec.patch
  - patches.suse/irq-export-irq_check_status_bit-symbol.patch
  - patches.suse/x86-xen-fix-nopvspin-build-error.patch
- refresh configs
- commit 22a4d9b
* Fri Jan 22 2021 kbuild@suse.de
- Automatically updated to 5.11-rc4-next-20210122
- commit 0d909cb
* Thu Jan 21 2021 kbuild@suse.de
- Automatically updated to 5.11-rc4-next-20210121
- commit 698458c
* Wed Jan 20 2021 msuchanek@suse.de
- Exclude Symbols.list again.
  Removing the exclude builds vanilla/linux-next builds.
  Fixes: 55877625c800 ("kernel-binary.spec.in: Package the obj_install_dir as explicit filelist.")
- commit a1728f2
* Wed Jan 20 2021 kbuild@suse.de
- Automatically updated to 5.11-rc4-next-20210120
- commit ba89f90
* Tue Jan 19 2021 kbuild@suse.de
- Automatically updated to 5.11-rc4-next-20210119
- commit b665ed4
* Mon Jan 18 2021 kbuild@suse.de
- Automatically updated to 5.11-rc3-next-20210118
- commit 8f41d17
* Mon Jan 18 2021 mkubecek@suse.cz
- Update to 5.11-rc4
- update configs
  - KPROBE_EVENTS_ON_NOTRACE=n (new on arm*, ppc64)
- commit 2483e00
* Fri Jan 15 2021 kbuild@suse.de
- Automatically updated to 5.11-rc3-next-20210115
- commit 0c4a499
* Thu Jan 14 2021 dmueller@suse.com
- arm*: config: Disable CONFIG_CRYPTO_USER_API_ENABLE_OBSOLETE (bsc#1180928)
  We don't need those deprecated ciphers to be enabled, as nothing
  should be using them
- commit a2c5d88
* Thu Jan 14 2021 kbuild@suse.de
- Automatically updated to 5.11-rc3-next-20210114
- commit 7093011
* Wed Jan 13 2021 msuchanek@suse.de
- Refresh patches.rpmify/Add-ksym-provides-tool.patch.
- commit c625711
* Wed Jan 13 2021 nsaenzjulienne@suse.de
- nvmem: Add driver to expose reserved memory as nvmem (jsc#SLE-SLE-16616).
- Update config files: Enable nvmem-rmem as module on arm64 & armv7+lpae, disable it otherwise
  This is needed early to get boot-loader configuration working on RPi4;
  an essential feature.
- commit c7beade
* Wed Jan 13 2021 nsaenzjulienne@suse.de
- Update config files: Enable i2c_mux_pinctrl (jsc#SLE-15318)
- commit 4059af1
* Wed Jan 13 2021 kbuild@suse.de
- Automatically updated to 5.11-rc3-next-20210113
- commit e425c94
* Tue Jan 12 2021 kbuild@suse.de
- Automatically updated to 5.11-rc3-next-20210112
- commit 345bd35
* Mon Jan 11 2021 kbuild@suse.de
- Automatically updated to 5.11-rc2-next-20210111
- commit fc2109d
* Mon Jan 11 2021 mkubecek@suse.cz
- Update to 5.11-rc3
- update configs
  - NULL_TTY=m
  - AQTION=m (also on other architectures than x86_64 and arm64)
- commit befa0c7
* Fri Jan  8 2021 kbuild@suse.de
- Automatically updated to 5.11-rc2-next-20210108
- commit a55cae7
* Thu Jan  7 2021 kbuild@suse.de
- Automatically updated to 5.11-rc2-next-20210107
- commit 7158f7c
* Thu Jan  7 2021 mkubecek@suse.cz
- config: refresh arm configs
- now available: DEBUG_INFO_BTF_MODULES=y
- commit 46fce45
* Wed Jan  6 2021 kbuild@suse.de
- Automatically updated to 5.11-rc2-next-20210106
- commit 1a76463
* Wed Jan  6 2021 dmueller@suse.com
- config.conf: Reenable armv6hl/armv7hl/arm64
- Update config files:
  * Settings copied from x86_64 update
  * arm specific options are =m except if debug or test, =y otherwise
- commit 9813e66
* Tue Jan  5 2021 msuchanek@suse.de
- Refresh patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
- commit 6a54622
* Tue Jan  5 2021 kbuild@suse.de
- Automatically updated to 5.11-rc2-next-20210105
- commit 1028405
* Mon Jan  4 2021 kbuild@suse.de
- Automatically updated to 5.11-rc1-next-20210104
- commit ff95b55
* Mon Dec 28 2020 mkubecek@suse.cz
- Update to 5.11-rc1
- eliminated 63 patches (61 stable, 2 other)
  - patches.kernel.org/*
  - patches.suse/clk-bcm-dvp-add-module_device_table.patch
  - patches.suse/drm-amdgpu-only-set-DP-subconnector-type-on-DP-and-e.patch
- disable ARM architectures (need config update)
- refresh
  - patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  - patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
    (renamed to patches.suse/btrfs-use-the-new-VFS-super_block_dev.patch
    to ease frequent refreshes)
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/supported-flag
- new config options:
  - Processor type and features
  - CONFIG_XEN_PVHVM_GUEST=y
  - CONFIG_X86_SGX=n
  - General architecture-dependent options
  - CONFIG_SECCOMP_CACHE_DEBUG=n
  - Memory Management options
  - CONFIG_GUP_TEST=n
  - Networking support
  - CONFIG_NFT_REJECT_NETDEV=n
  - CONFIG_BRIDGE_CFM=n
  - CONFIG_NET_DSA_TAG_HELLCREEK=n
  - CONFIG_CAN_M_CAN_PCI=n
  - CONFIG_NFC_S3FWRN82_UART=n
  - File systems
  - CONFIG_PSTORE_DEFAULT_KMSG_BYTES=10240
  - CONFIG_CIFS_SWN_UPCALL=n
  - Cryptographic API
  - CONFIG_CRYPTO_DEV_QAT_4XXX=n
  - Library routines
  - CONFIG_DMA_MAP_BENCHMARK=n
  - Kernel hacking
  - CONFIG_DEBUG_KMAP_LOCAL_FORCE_MAP=n
  - CONFIG_FTRACE_RECORD_RECURSION=n
  - CONFIG_RING_BUFFER_VALIDATE_TIME_DELTAS=n
  - Memory Technology Device (MTD) support
  - CONFIG_MTD_NAND_ECC_SW_HAMMING=y
  - CONFIG_MTD_SPI_NOR_SWP_DISABLE=n
  - CONFIG_MTD_SPI_NOR_SWP_DISABLE_ON_VOLATILE=y
  - CONFIG_MTD_SPI_NOR_SWP_KEEP=n
  - Block devices
  - CONFIG_DM_MULTIPATH_IOA=n
  - CONFIG_ZRAM_DEF_COMP_LZORLE=y
  - Network device support
  - CONFIG_MHI_NET=n
  - CONFIG_NET_DSA_HIRSCHMANN_HELLCREEK=n
  - CONFIG_USB_RTL8153_ECM=m
  - Input device support
  - CONFIG_INPUT_DA7280_HAPTICS=n
  - CONFIG_AMD_SFH_HID=n
  - Pin controllers
  - CONFIG_PINCTRL_ALDERLAKE=n
  - CONFIG_PINCTRL_ELKHARTLAKE=n
  - CONFIG_PINCTRL_LAKEFIELD=n
  - Hardware Monitoring support
  - CONFIG_SENSORS_CORSAIR_PSU=n
  - CONFIG_SENSORS_LTC2992=n
  - CONFIG_SENSORS_MAX127=n
  - CONFIG_SENSORS_PM6764TR=n
  - CONFIG_SENSORS_Q54SJ108A2=n
  - CONFIG_SENSORS_SBTSI=n
  - Multimedia support
  - CONFIG_VIDEO_OV02A10=n
  - CONFIG_VIDEO_OV9734=n
  - CONFIG_VIDEO_CCS=n
  - Sound card support
  - CONFIG_SND_SOC_ADI=n
  - CONFIG_SND_SOC_FSL_XCVR=n
  - CONFIG_SND_SOC_SOF_BAYTRAIL_SUPPORT=n
  - CONFIG_SND_SOC_SOF_ALDERLAKE_SUPPORT=n
  - CONFIG_SND_SOC_ADAU1372_I2C=n
  - CONFIG_SND_SOC_ADAU1372_SPI=n
  - CONFIG_SND_SOC_PCM5102A=n
  - CONFIG_SND_SOC_SIMPLE_MUX=n
  - CONFIG_SND_SOC_NAU8315=n
  - CONFIG_SND_SOC_LPASS_WSA_MACRO=n
  - CONFIG_SND_SOC_LPASS_VA_MACRO=n
  - CONFIG_SND_SOC_ADI_AXI_I2S=m
  - CONFIG_SND_SOC_ADI_AXI_SPDIF=m
  - X86 Platform Specific Device Drivers
  - CONFIG_UV_SYSFS=n
  - CONFIG_AMD_PMC=n
  - CONFIG_DELL_WMI_SYSMAN=n
  - CONFIG_INTEL_PMT_CLASS=n
  - CONFIG_INTEL_PMT_TELEMETRY=n
  - CONFIG_INTEL_PMT_CRASHLOG=n
  - Misc drivers
  - CONFIG_MHI_BUS_PCI_GENERIC=n
  - CONFIG_SERIAL_BCM63XX=n
  - CONFIG_MIPI_I3C_HCI=n
  - CONFIG_PTP_1588_CLOCK_OCP=n
  - CONFIG_MFD_INTEL_PMT=n
  - CONFIG_EDAC_IGEN6=n
  - CONFIG_INTEL_IDXD_SVM=n
  - CONFIG_LCD2S=n
  - CONFIG_VDPA_SIM_NET=n
  - CONFIG_EXTCON_USBC_TUSB320=n
  - CONFIG_PWM_DWC=n
  - CONFIG_USB4_DMA_TEST=n
  - CONFIG_SURFACE_PLATFORMS=y
  - CONFIG_SURFACE_GPE=n
  - OF dependent drivers (i386, ppc64/ppc64le, riscv64)
  - MTD_NAND_INTEL_LGM=m
  - PINCTRL_MICROCHIP_SGPIO=n
  - REGULATOR_DA9121=m
  - REGULATOR_PF8X00=m
  - DRM_PANEL_ABT_Y030XX067A=n
  - DRM_PANEL_NOVATEK_NT36672A=n
  - DRM_PANEL_SAMSUNG_SOFEF00=n
  - DRM_PANEL_TDO_TL070WSH30=n
  - DRM_LONTIUM_LT9611UXC=n
  - DRM_ANALOGIX_ANX7625=n
  - RTC_DRV_GOLDFISH=m
  - LITEX_SOC_CONTROLLER=n
  - PWM_ATMEL_TCB=m
  - i386
  - PWM_INTEL_LGM=m
  - DEBUG_KMAP_LOCAL=n
  - s390x
  - DEBUG_USER_ASCE=n
  - riscv64
  - IRQ_TIME_ACCOUNTING
  - POWER_RESET_REGULATOR=y
- commit 264c7c2
* Wed Dec 23 2020 kbuild@suse.de
- Automatically updated to 5.10-next-20201223
- commit 436492f
* Tue Dec 22 2020 kbuild@suse.de
- Automatically updated to 5.10-next-20201222
- commit 37eb243
* Mon Dec 21 2020 mkubecek@suse.cz
- config: refresh
- drop USB_SISUSBVGA_CON (no longer accessible)
- commit 29a1cbb
* Mon Dec 21 2020 kbuild@suse.de
- Automatically updated to 5.10-next-20201221
- commit ac0f6b1
* Fri Dec 18 2020 kbuild@suse.de
- Automatically updated to 5.10-next-20201218
- commit 86f87c6
* Thu Dec 17 2020 kbuild@suse.de
- Automatically updated to 5.10-next-20201217
- commit 87c2fcd
* Wed Dec 16 2020 kbuild@suse.de
- Automatically updated to 5.10-next-20201216
- commit 2e15b8e
* Tue Dec 15 2020 kbuild@suse.de
- Automatically updated to 5.10-next-20201215
- commit b353c6e
* Mon Dec 14 2020 guillaume.gardet@arm.com
- lpae: disable CONFIG_QCOM_PIL_INFO to fix build on armv7
- commit a2303d5
* Mon Dec 14 2020 kbuild@suse.de
- Automatically updated to 5.10-rc7-next-20201214
- commit f98034f
* Mon Dec 14 2020 mkubecek@suse.cz
- Update to 5.10 final
- eliminated 1 patch
  - patches.suse/revert-mm-filemap-add-static-for-function-__add_to_p.patch
- update configs
  - NFS_V4_2_READ_PLUS=n (recommended default, unsafe feature)
- commit 498886c
* Sun Dec 13 2020 dmueller@suse.com
- config.conf: Reenable armv6hl/armv7hl/arm64
- Update config files:
  * Settings copied from x86_64 update
  * arm specific options are =m except if debug or test, =y otherwise
- commit a96a921
* Fri Dec 11 2020 kbuild@suse.de
- Automatically updated to 5.10-rc7-next-20201211
- commit f6189c9
* Thu Dec 10 2020 ohering@suse.de
- config: disable IP_PNP
  The kernel IP autoconfiguration can only be used in practice when driver of
  the network device to be configured is also built into vmlinux. As we build
  all network device drivers as modules, there is no point keeping IP_PNP
  enabled.
- commit b76c168
* Thu Dec 10 2020 mkubecek@suse.cz
- config: refresh
- only update CC_VERSION_TEXT after gcc update
- commit f7d2475
* Thu Dec 10 2020 kbuild@suse.de
- Automatically updated to 5.10-rc7-next-20201210
- commit 3f1458b
* Thu Dec 10 2020 mgorman@suse.de
- Update config files to disable CONFIG_DEBUG_SECTION_MISMATCH (bsc#1177403)
- commit 9f69918
* Wed Dec  9 2020 kbuild@suse.de
- Automatically updated to 5.10-rc7-next-20201209
- commit 085ab9e
* Tue Dec  8 2020 kbuild@suse.de
- Automatically updated to 5.10-rc7-next-20201208
- commit 3286619
* Mon Dec  7 2020 kbuild@suse.de
- Automatically updated to 5.10-rc6-next-20201207
- commit ac313e6
* Mon Dec  7 2020 mkubecek@suse.cz
- Update to 5.10-rc7
- refresh
  - patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch
- refresh configs
- commit b810b7a
* Fri Dec  4 2020 kbuild@suse.de
- Automatically updated to 5.10-rc6-next-20201204
- commit 0c9f5aa
* Thu Dec  3 2020 msuchanek@suse.de
- Refresh
  patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
- commit 171868b
* Thu Dec  3 2020 kbuild@suse.de
- Automatically updated to 5.10-rc6-next-20201203
- commit 73ae063
* Tue Dec  1 2020 kbuild@suse.de
- Automatically updated to 5.10-rc6-next-20201201
- commit c450e0b
* Tue Dec  1 2020 msuchanek@suse.de
- rpm/kernel-{source,binary}.spec: do not include ghost symlinks
  (boo#1179082).
- commit 76a9256
* Mon Nov 30 2020 ohering@suse.de
- scripts/lib/SUSE/MyBS.pm: properly close prjconf Macros: section
- commit 965157e
* Mon Nov 30 2020 kbuild@suse.de
- Automatically updated to 5.10-rc5-next-20201130
- commit f1e4c33
* Mon Nov 30 2020 tiwai@suse.de
- Update config files: make CONFIG_SOUNDWIRE=m (bsc#1179201)
  Also turned it off for unrelated platforms
- commit a573e74
* Mon Nov 30 2020 mkubecek@suse.cz
- Update to 5.10-rc6
- eliminated 1 patch
  - patches.suse/btrfs-qgroup-don-t-commit-transaction-when-we-have-a.patch
- refresh configs
  - headers only (Factory updated gcc and binutils)
- commit 11cc781
* Fri Nov 27 2020 jslaby@suse.cz
- Refresh
  patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
  Update to apply after "orphans: Disable CONFIG_LD_ORPHAN_WARN for ld.lld
  10.0.1".
- commit b307ad5
* Fri Nov 27 2020 kbuild@suse.de
- Automatically updated to 5.10-rc5-next-20201127
- commit 721c321
* Thu Nov 26 2020 nsaenzjulienne@suse.de
-  - pwm: Add Raspberry Pi Firmware based PWM bus (jsc#SLE-16543).
  - Update configs: Enable pwm driver on arm64
  - supported.conf: Enable pwm driver
- commit d1749c5
* Thu Nov 26 2020 kbuild@suse.de
- Automatically updated to 5.10-rc5-next-20201126
- commit 6b46afe
* Tue Nov 24 2020 kbuild@suse.de
- Automatically updated to 5.10-rc5-next-20201124
- commit 63a3e34
* Tue Nov 24 2020 jslaby@suse.cz
- Update config files (bsc#1179102).
  Set AMIGA_PARTITION=y wherever AFFS_FS=m. The AMIGA_PARTITION's Kconfig
  help suggests: default y if (AMIGA || AFFS_FS=y). And we enable Amiga FS
  in some configs, but don't enable support for Amiga partitions. That is
  a bit pointless. So fix this.
- commit b90192c
* Mon Nov 23 2020 kbuild@suse.de
- Automatically updated to 5.10-rc4-next-20201123
- commit aeba6e6
* Mon Nov 23 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: use grep -E instead of egrep (bsc#1179045)
  egrep is only a deprecated bash wrapper for "grep -E". So use the latter
  instead.
- commit 63d7072
* Mon Nov 23 2020 jslaby@suse.cz
- kernel-{binary,source}.spec.in: do not create loop symlinks (bsc#1179082)
- commit adf56a8
* Mon Nov 23 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: avoid using more barewords (bsc#1179014)
  %%split_extra still contained two.
- commit d9b4c40
* Mon Nov 23 2020 mkubecek@suse.cz
- Update to 5.10-rc5
- refresh configs
  - DMA_VIRT_OPS and dependecies dropped on i386
- commit f766737
* Fri Nov 20 2020 msuchanek@suse.de
- kernel-source.spec: Fix build with rpm 4.16 (boo#1179015).
  RPM_BUILD_ROOT is cleared before %%%%install. Do the unpack into
  RPM_BUILD_ROOT in %%%%install
- commit 13bd533
* Fri Nov 20 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: avoid using barewords (bsc#1179014)
  Author: Dominique Leuenberger <dimstar@opensuse.org>
- commit 21f8205
* Fri Nov 20 2020 jslaby@suse.cz
- rpm/mkspec: do not build kernel-obs-build on x86_32
  We want to use 64bit kernel due to various bugs (bsc#1178762 to name
  one).
  There is:
  ExportFilter: ^kernel-obs-build.*\.x86_64.rpm$ . i586
  in Factory's prjconf now. No other actively maintained distro (i.e.
  merging packaging branch) builds a x86_32 kernel, hence pushing to
  packaging directly.
- commit 8099b4b
* Fri Nov 20 2020 kbuild@suse.de
- Automatically updated to 5.10-rc4-next-20201120
- commit 6b8a13b
* Thu Nov 19 2020 kbuild@suse.de
- Automatically updated to 5.10-rc4-next-20201119
- commit bde4d30
* Wed Nov 18 2020 kbuild@suse.de
- Automatically updated to 5.10-rc4-next-20201118
- commit e79754a
* Tue Nov 17 2020 kbuild@suse.de
- Automatically updated to 5.10-rc4-next-20201117
- commit 7fcb68c
* Mon Nov 16 2020 kbuild@suse.de
- Automatically updated to 5.10-rc3-next-20201116
- commit 3b03b86
* Fri Nov 13 2020 kbuild@suse.de
- Automatically updated to 5.10-rc3-next-20201113
- commit 54c15a4
* Thu Nov 12 2020 kbuild@suse.de
- Automatically updated to 5.10-rc3-next-20201112
- commit a26fc17
* Wed Nov 11 2020 kbuild@suse.de
- Automatically updated to 5.10-rc3-next-20201111
- commit e4c7398
* Tue Nov 10 2020 dmueller@suse.com
- ARM64: Enable CONFIG_ARM64_SW_TTBR0_PAN
  This can help prevent use-after-free bugs becoming an exploitable
  privilege escalation by ensuring that magic values (such as LIST_POISON)
  will always fault when dereferenced
- commit 69692f1
* Tue Nov 10 2020 kbuild@suse.de
- Automatically updated to 5.10-rc3-next-20201110
- commit 054da15
* Mon Nov  9 2020 kbuild@suse.de
- Automatically updated to 5.10-rc2-next-20201109
- commit fa545b6
* Mon Nov  9 2020 mkubecek@suse.cz
- Update to 5.10-rc3
- eliminated 1 patch
  - patches.suse/tty-make-FONTX-ioctl-use-the-tty-pointer-they-were-a.patch
- refresh configs
  - update headers after Factory binutils update
  - drop options no longer available
- commit 58a5905
* Fri Nov  6 2020 kbuild@suse.de
- Automatically updated to 5.10-rc2-next-20201106
- commit 3fbc3c1
* Thu Nov  5 2020 kbuild@suse.de
- Automatically updated to 5.10-rc2-next-20201105
- commit a1020e6
* Wed Nov  4 2020 kbuild@suse.de
- Automatically updated to 5.10-rc2-next-20201104
- commit bf1ee1b
* Wed Nov  4 2020 tiwai@suse.de
- Updated Copyright line in rpm templates with SUSE LLC
- commit 39a1fcf
* Wed Nov  4 2020 tiwai@suse.de
- rpm/kernel-obs-build.spec.in: Add -q option to modprobe calls (bsc#1178401)
- commit 33ded45
* Tue Nov  3 2020 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix compressed module handling for in-tree KMP (jsc#SLE-10886)
  The in-tree KMP that is built with SLE kernels have a different scriptlet
  that is embedded in kernel-binary.spec.in rather than *.sh files.
- commit e32ee2c
* Tue Nov  3 2020 kbuild@suse.de
- Automatically updated to 5.10-rc2-next-20201103
- commit 9194907
* Mon Nov  2 2020 kbuild@suse.de
- Automatically updated to 5.10-rc1-next-20201102
- commit cd3e935
* Mon Nov  2 2020 mkubecek@suse.cz
- Update to 5.10-rc2
- eliminated 5 patches
  - patches.rpmify/s390-correct-__bootdata-__bootdata_preserved-macros.patch
  - patches.suse/drm-amd-display-Don-t-invoke-kgdb_breakpoint-uncondi.patch
  - patches.suse/drm-amd-display-Fix-kernel-panic-by-dal_gpio_open-er.patch
  - patches.suse/vt_ioctl-fix-GIO_UNIMAP-regression.patch
  - patches.suse/x86-unwind-orc-Fix-inactive-tasks-with-stack-pointer.patch
- refresh configs
  - CPU_FREQ_DEFAULT_GOV_ONDEMAND -> CPU_FREQ_DEFAULT_GOV_SCHEDUTIL (x86)
  - Intel MIC drivers dropped
- commit 17eff2c
* Fri Oct 30 2020 kbuild@suse.de
- Automatically updated to 5.10-rc1-next-20201030
- commit 92cfada
* Thu Oct 29 2020 kbuild@suse.de
- Automatically updated to 5.10-rc1-next-20201029
- commit 1aaa6bd
* Thu Oct 29 2020 tiwai@suse.de
- rpm/kernel-module-subpackage: make Group tag optional (bsc#1163592)
- commit 552ec97
* Wed Oct 28 2020 kbuild@suse.de
- Automatically updated to 5.10-rc1-next-20201028
- commit 5dc0354
* Tue Oct 27 2020 kbuild@suse.de
- Automatically updated to 5.10-rc1-next-20201027
- commit 5737257
* Mon Oct 26 2020 kbuild@suse.de
- Automatically updated to 5.9-next-20201026
- commit 118f9df
* Mon Oct 26 2020 mkubecek@suse.cz
- Update to 5.10-rc1
- eliminated 17 patches (16 stable, 1 other)
  - patches.kernel.org/*
  - patches.suse/coresight-fix-offset-by-one-error-in-counting-ports.patch
- disable ARM architectures (need config update)
- refresh
  - patches.suse/apparmor-compatibility-with-v2.x-net.patch
  - patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  - patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  - patches.suse/readahead-request-tunables.patch
- new config options:
  - General setup
  - CONFIG_BPF_PRELOAD=n
  - Power management and ACPI options
  - CONFIG_ACPI_DPTF=y
  - CONFIG_DPTF_PCH_FIVR=m
  - General architecture-dependent options
  - CONFIG_STATIC_CALL_SELFTEST=n
  - Networking support
  - CONFIG_XFRM_USER_COMPAT=m
  - CONFIG_CAN_ISOTP=m
  - CONFIG_CAN_MCP251XFD=m
  - CONFIG_CAN_MCP251XFD_SANITY=n
  - File systems
  - CONFIG_XFS_SUPPORT_V4=y
  - CONFIG_FUSE_DAX=y
  - CONFIG_NFSD_V4_2_INTER_SSC=y
  - Cryptographic API
  - CONFIG_CRYPTO_SM2=m
  - CONFIG_CRYPTO_USER_API_RNG_CAVP=n
  - CONFIG_CRYPTO_USER_API_ENABLE_OBSOLETE=y
  - Library routines
  - CONFIG_FONT_6x8=y
  - Kernel hacking
  - CONFIG_KGDB_HONOUR_BLOCKLIST=y
  - CONFIG_SCF_TORTURE_TEST=n
  - CONFIG_CSD_LOCK_WAIT_DEBUG=n
  - CONFIG_RCU_SCALE_TEST=m
  - CONFIG_FAULT_INJECTION_USERCOPY=n
  - CONFIG_TEST_FREE_PAGES=n
  - PCI support
  - CONFIG_PCIE_BUS_TUNE_OFF=n
  - CONFIG_PCIE_BUS_DEFAULT=y
  - CONFIG_PCIE_BUS_SAFE=n
  - CONFIG_PCIE_BUS_PERFORMANCE=n
  - CONFIG_PCIE_BUS_PEER2PEER=n
  - Network device support
  - CONFIG_NET_DSA_MSCC_SEVILLE=m
  - CONFIG_CHELSIO_INLINE_CRYPTO=y
  - CONFIG_PRESTERA=m
  - CONFIG_PRESTERA_PCI=m
  - CONFIG_ATH11K=m
  - CONFIG_ATH11K_PCI=m
  - CONFIG_ATH11K_DEBUG=n
  - CONFIG_ATH11K_DEBUGFS=n
  - CONFIG_ATH11K_TRACING=n
  - CONFIG_USB_LGM_PHY=m
  - CONFIG_PHY_INTEL_LGM_EMMC=m
  - Input device support
  - CONFIG_JOYSTICK_ADC=m
  - CONFIG_TOUCHSCREEN_ZINITIX=m
  - CONFIG_RMI4_F3A=y
  - CONFIG_HID_VIVALDI=m
  - Character devices
  - CONFIG_HW_RANDOM_XIPHERA=m
  - GPIO Support
  - CONFIG_GPIO_CDEV=y
  - CONFIG_GPIO_CDEV_V1=y
  - Power management
  - CONFIG_CHARGER_BQ25980=m
  - CONFIG_SENSORS_MR75203=m
  - CONFIG_SENSORS_ADM1266=m
  - CONFIG_SENSORS_MP2975=m
  - ACPI INT340X thermal drivers
  - CONFIG_REGULATOR_RASPBERRYPI_TOUCHSCREEN_ATTINY=m
  - CONFIG_REGULATOR_RT4801=m
  - CONFIG_REGULATOR_RTMV20=m
  - Multifunction device drivers
  - CONFIG_MFD_SL28CPLD=n
  - CONFIG_MFD_INTEL_M10_BMC=n
  - Graphics support
  - CONFIG_DRM_AMD_DC_SI=y
  - CONFIG_BACKLIGHT_KTD253=m
  - CONFIG_VIDEO_ZORAN=m
  - CONFIG_VIDEO_ZORAN_DC30=m
  - CONFIG_VIDEO_ZORAN_ZR36060=m
  - CONFIG_VIDEO_ZORAN_BUZ=m
  - CONFIG_VIDEO_ZORAN_DC10=m
  - CONFIG_VIDEO_ZORAN_LML33=m
  - CONFIG_VIDEO_ZORAN_LML33R10=m
  - CONFIG_VIDEO_ZORAN_AVS6EYES=m
  - Sound card support
  - CONFIG_SND_SOC_INTEL_CATPT=m
  - CONFIG_SND_SOC_SOF_BROADWELL_SUPPORT=y
  - CONFIG_SND_SOC_SOF_INTEL_SOUNDWIRE_LINK=y
  - CONFIG_SND_SOC_INTEL_SOUNDWIRE_SOF_MACH=m
  - CONFIG_SND_SOC_CS4234=n
  - CONFIG_SND_SOC_TAS2764=n
  - CONFIG_SOUNDWIRE_QCOM=m
  - USB support
  - CONFIG_USB_FEW_INIT_RETRIES=n
  - CONFIG_TYPEC_TCPCI_MAXIM=m
  - CONFIG_TYPEC_STUSB160X=m
  - CONFIG_USB4_DEBUGFS_WRITE=n
  - Virtualization
  - CONFIG_NITRO_ENCLAVES=m
  - Industrial I/O support
  - CONFIG_IIO_BUFFER_DMA=m
  - CONFIG_IIO_BUFFER_DMAENGINE=m
  - CONFIG_ADXRS290=n
  - CONFIG_HDC2010=n
  - CONFIG_AS73211=n
  - Misc drivers
  - CONFIG_MHI_BUS_DEBUG=y
  - CONFIG_INTEL_MEI_VIRTIO=m
  - CONFIG_RTC_DRV_RV3032=m
  - CONFIG_LEDS_LP50XX=m
  - CONFIG_SPMI_HISI3670=n
  - CONFIG_MST_IRQ=y
  - OF dependent drivers (i386, ppc64/ppc64le, riscv64)
  - HISI_HIKEY_USB=m
  - DRM_PANEL_MANTIX_MLAF057WE51=n
  - DRM_PANEL_SAMSUNG_S6E63M0_SPI=n
  - DRM_PANEL_SAMSUNG_S6E63M0_DSI=n
  - DRM_LONTIUM_LT9611=n
  - DRM_TOSHIBA_TC358762=n
  - DRM_TOSHIBA_TC358775=n
  - DRM_CDNS_MHDP8546=n
  - MFD_HI6421_SPMI=m
  - REGULATOR_HI6421V600=m
  - i386
  - DRM_PANEL_SAMSUNG_S6E63M0_SPI=m
  - DRM_PANEL_SAMSUNG_S6E63M0_DSI=m
  - PHY_INTEL_LGM_COMBO=y
  - ppc64 / ppc64le
  - PPC_RTAS_FILTER=y
  - I2C_SLAVE_TESTUNIT=n
  - s390x
  - PCS_XPCS=m
  - VFIO_PCI_ZDEV=y
  - ZCRYPT_DEBUG=n
  - DEBUG_WX=n
  - PTDUMP_DEBUGFS=n
  - riscv64
  - EFI=y
  - FIRMWARE_MEMMAP=y
  - GOOGLE_FIRMWARE=n
  - EFI_VARS_PSTORE=m
  - EFI_VARS_PSTORE_DEFAULT_DISABLE=n
  - EFI_BOOTLOADER_CONTROL=m
  - EFI_CAPSULE_LOADER=m
  - EFI_TEST=n
  - RESET_ATTACK_MITIGATION=n
  - EFI_DISABLE_PCI_DMA=n
  - FB_EFI=y
  - MMC_DW=m
  - MMC_DW_PLTFM=m
  - MMC_DW_BLUEFIELD=m
  - MMC_DW_EXYNOS=m
  - MMC_DW_HI3798CV200=m
  - MMC_DW_K3=m
  - MMC_DW_PCI=m
  - RTC_DRV_EFI=m
  - EFIVAR_FS=m
- commit d181a93
* Sun Oct 25 2020 mkubecek@suse.cz
- kernel-binary.spec.in: pack scripts/module.lds into kernel-$flavor-devel
  Since mainline commit 596b0474d3d9 ("kbuild: preprocess module linker
  script") in 5.10-rc1, scripts/module.lds linker script is needed to build
  out of tree modules. Add it into kernel-$flavor-devel subpackage.
- commit fe37c16
* Fri Oct 23 2020 kbuild@suse.de
- Automatically updated to 5.9-next-20201023
- commit fab59b4
* Thu Oct 22 2020 kbuild@suse.de
- Automatically updated to 5.9-next-20201022
- commit 43cc7e8
* Wed Oct 21 2020 kbuild@suse.de
- Automatically updated to 5.9-next-20201021
- commit 6a0d31a
* Mon Oct 19 2020 tiwai@suse.de
- rpm/split-modules: Avoid errors even if Module.* are not present
- commit 752fbc6
* Fri Oct 16 2020 kbuild@suse.de
- Automatically updated to 5.9-next-20201016
- commit 1b88b4f
* Thu Oct 15 2020 kbuild@suse.de
- Automatically updated to 5.9-next-20201015
- commit 7a1594b
* Wed Oct 14 2020 tiwai@suse.de
- Update config files: CONFIG_PINCTRL_AMD=y for fixing dependency (bsc#1177049)
- commit f03ef39
* Tue Oct 13 2020 tiwai@suse.de
- Add the support for kernel-FLAVOR-optional subpackage (jsc#SLE-11796)
  This change allows to create kernel-*-optional subpackage containing
  the modules that are not shipped on SLE but only on Leap.  Those
  modules are marked in the new "-!optional" marker in supported.conf.
  Flip split_optional definition in kernel-binaries.spec.in for the
  branch that needs the splitting.
- commit 1fa25f8
* Tue Oct 13 2020 kbuild@suse.de
- Automatically updated to 5.9-next-20201013
- commit 91caecb
* Mon Oct 12 2020 kbuild@suse.de
- Automatically updated to 5.9-next-20201012
- commit 3609fc7
* Mon Oct 12 2020 mkubecek@suse.cz
- Update to 5.9 final
- eliminated 1 patch
  - patches.suse/bpf-Fix-unresolved-symbol-build-error-with-resolve_b.patch
- update configs
  - MLX5_VDPA=y, MLX5_VDPA_NET=m
  - restore FB_ARMCLCD (y on armv6hl and armv7hl, n on arm64)
- commit b223f8a
* Fri Oct  9 2020 mkubecek@suse.cz
- config: disable DEBUG_INFO_BTF in s390x/zfcpdump
  Even if the build has been fixed, there is little use for BTF debug
  information in kernel-zfcpdump so disable it there.
- commit 1f6913a
* Fri Oct  9 2020 kbuild@suse.de
- Automatically updated to 5.9-rc8-next-20201009
- commit 542b476
* Thu Oct  8 2020 msuchanek@suse.de
- kernel-binary.spec.in: Exclude .config.old from kernel-devel
  - use tar excludes for .kernel-binary.spec.buildenv
- commit 939a79b
* Thu Oct  8 2020 kbuild@suse.de
- Automatically updated to 5.9-rc8-next-20201008
- commit 19ed0d8
* Wed Oct  7 2020 msuchanek@suse.de
- kernel-binary.spec.in: Package the obj_install_dir as explicit filelist.
- commit 5587762
* Wed Oct  7 2020 kbuild@suse.de
- Automatically updated to 5.9-rc8-next-20201007
- commit 9537f59
* Mon Oct  5 2020 afaerber@suse.com
- rpm/mkspec-dtb: Update for 5.9
  arch/arm64/boot/dts/al subdir has been renamed to amazon.
- commit cf26a5c
* Mon Oct  5 2020 mbrugger@suse.com
- pm/mkspec-dtb: alpine DTS are now under amazon/*
- commit 4ca078c
* Mon Oct  5 2020 afaerber@suse.com
- config: armv7hl: Update to 5.9-rc8
- commit 24fa96c
* Mon Oct  5 2020 afaerber@suse.com
- config: armv6hl: Update to 5.9-rc8
- commit 8455720
* Mon Oct  5 2020 afaerber@suse.com
- config: arm64: Update to 5.9-rc8
- commit e1458f5
* Fri Oct  2 2020 mkubecek@suse.cz
- config: disable SECURITY_SELINUX_DISABLE also in arm*/* (bsc#1176923)
  The arm configs (both 64-bit and 32-bit) are currently disabled so that
  they cannot be updated the usual way. Apply the changes manually.
- commit 51a33ed
* Fri Oct  2 2020 kbuild@suse.de
- Automatically updated to 5.9-rc7-next-20201002
- commit 266456a
* Fri Oct  2 2020 mkubecek@suse.cz
- config: disable SECURITY_SELINUX_DISABLE (bsc#1176923)
- commit d42b93d
* Thu Oct  1 2020 kbuild@suse.de
- Automatically updated to 5.9-rc7-next-20200930
- commit 3a3cc6f
* Wed Sep 30 2020 ohering@suse.de
- rpm/constraints.in: recognize also kernel-source-azure (bsc#1176732)
- commit 7214bbe
* Tue Sep 29 2020 kbuild@suse.de
- Automatically updated to 5.9-rc7-next-20200929
- commit a55a770
* Sat Sep 26 2020 kbuild@suse.de
- Automatically updated to 5.9-rc6-next-20200925
- commit 62c9e01
* Fri Sep 25 2020 kbuild@suse.de
- Automatically updated to 5.9-rc6-next-20200924
- commit edf2da2
* Tue Sep 22 2020 kbuild@suse.de
- Automatically updated to 5.9-rc6-next-20200922
- commit 265d64c
* Tue Sep 22 2020 msuchanek@suse.de
- kernel-syms.spec.in: Also use bz compression (boo#1175882).
- commit ecaf78d
* Mon Sep 21 2020 tiwai@suse.de
- Update config files: turn off CONFIG_SND_CTL_VALIDATION again (bsc#1176200)
  This causes errors on ASoC SOF driver.
- commit 09079a3
* Mon Sep 21 2020 kbuild@suse.de
- Automatically updated to 5.9-rc5-next-20200921
- commit e385e29
* Mon Sep 21 2020 mkubecek@suse.cz
- Update to 5.9-rc6
- refresh configs
  - drop VGACON_SOFT_SCROLLBACK and related
- commit 0e9fee4
* Mon Sep 21 2020 glin@suse.com
- rpm/kernel-cert-subpackage: add CA check on key enrollment (bsc#1173115)
  To avoid the unnecessary key enrollment, when enrolling the signing key
  of the kernel package, "--ca-check" is added to mokutil so that mokutil
  will ignore the request if the CA of the signing key already exists in
  MokList or UEFI db.
  Since the macro, %%_suse_kernel_module_subpackage, is only defined in a
  kernel module package (KMP), it's used to determine whether the %%post
  script is running in a kernel package, or a kernel module package.
- commit b15c9bf
* Fri Sep 18 2020 kbuild@suse.de
- Automatically updated to 5.9-rc5-next-20200918
- commit dc3e708
* Fri Sep 18 2020 glin@suse.com
- rpm/macros.kernel-source: pass -c proerly in kernel module package (bsc#1176698)
  The "-c" option wasn't passed down to %%_kernel_module_package so the
  ueficert subpackage wasn't generated even if the certificate is
  specified in the spec file.
- commit 34808fb
* Wed Sep 16 2020 kbuild@suse.de
- Automatically updated to 5.9-rc5-next-20200916
- commit 8d907b9
* Tue Sep 15 2020 kbuild@suse.de
- Automatically updated to 5.9-rc5-next-20200915
- commit 709b02b
* Fri Sep 11 2020 kbuild@suse.de
- Automatically updated to 5.9-rc4-next-20200911
- commit 6c93b6c
* Thu Sep 10 2020 kbuild@suse.de
- Automatically updated to 5.9-rc4-next-20200910
- commit 87360a1
* Tue Sep  8 2020 mbenes@suse.cz
- rpm/kernel-binary.spec.in: pack .ipa-clones files for live patching
  When -fdump-ipa-clones option is enabled, GCC reports about its cloning
  operation during IPA optimizations. We use the information for live
  patches preparation, because it is crucial to know if and how functions
  are optimized.
  Currently, we create the needed .ipa-clones dump files manually. It is
  unnecessary, because the files may be created automatically during our
  kernel build. Prepare for the step and provide the resulting files in
  - livepatch-devel package.
- commit 98e5a9d
* Tue Sep  8 2020 kbuild@suse.de
- Automatically updated to 5.9-rc4-next-20200908
- commit 3e6b7fe
* Mon Sep  7 2020 msuchanek@suse.de
- rpm/kernel-source.spec.in: Also use bz compression (boo#1175882).
- commit 375ec84
* Mon Sep  7 2020 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also sign ppc64 kernels (jsc#SLE-15857
  jsc#SLE-13618).
- commit 971fc3d
* Mon Sep  7 2020 tiwai@suse.de
- Update config files: add CONFIG_GCOV_KENREL=n
  Define this explicitly as kbuild bot still uses gcc9 for testing
- commit 1714c8e
* Mon Sep  7 2020 tiwai@suse.de
- Update config files: enable a few missing Intel SOF and SST ASoC entries (bsc#1176200)
- commit 258e365
* Mon Sep  7 2020 mkubecek@suse.cz
- Update to 5.9-rc4
- eliminated 1 patch
  - patches.suse/net-packet-fix-overflow-in-tpacket_rcv.patch
- update configs
  - new config option:
  - XEN_UNPOPULATED_ALLOC=y (x86_64 only)
- commit dc2f6b0
* Thu Sep  3 2020 kbuild@suse.de
- Automatically updated to 5.9-rc3-next-20200903
- commit e9f8561
* Wed Sep  2 2020 kbuild@suse.de
- Automatically updated to 5.9-rc3-next-20200902
- commit f1c2236
* Mon Aug 31 2020 mkubecek@suse.cz
- Update to 5.9-rc3
- eliminated 1 patch
  - patches.suse/Revert-HID-usbhid-do-not-sleep-when-opening-device.patch
- update configs
  - new config option:
  - PPC_PROT_SAO_LPAR=n (ppc64 and ppc64le)
- commit 2b3d91a
* Fri Aug 28 2020 msuchanek@suse.de
- obsolete_kmp: provide newer version than the obsoleted one
  (boo#1170232).
- commit c5ecb27
* Fri Aug 28 2020 kbuild@suse.de
- Automatically updated to 5.9-rc2-next-20200828
- commit 89fffdd
* Thu Aug 27 2020 kbuild@suse.de
- Automatically updated to 5.9-rc2-next-20200827
- commit 9b8454a
* Wed Aug 26 2020 alnovak@suse.cz
- Mark the kernel properly released.
  There perhaps was a typo, when SUSE_KERNEL_RELEASED missed the trailing
  "D" - this leads to our kernels being marked as "Unreleased kernel".
  SUSE_KERNEL_RELEASED is defined in rpm/kernel-binary.spec.in.
  To fix that, it should be enough to switch from SUSE_KERNEL_RELEASE to
  SUSE_KERNEL_RELEASED.
- commit 45e2059
* Wed Aug 26 2020 kbuild@suse.de
- Automatically updated to 5.9-rc2-next-20200826
- commit b8336a3
* Tue Aug 25 2020 kbuild@suse.de
- Automatically updated to 5.9-rc2-next-20200825
- commit 3732c6e
* Mon Aug 24 2020 kbuild@suse.de
- Automatically updated to 5.9-rc2-next-20200824
- commit e5bbd37
* Mon Aug 24 2020 mkubecek@suse.cz
- Update to 5.9-rc2
- eliminated 1 patch
  - patches.suse/squashfs-avoid-bio_alloc-failure-with-1Mbyte-blocks.patch
- refresh configs
- commit c1e2b83
* Fri Aug 21 2020 kbuild@suse.de
- Automatically updated to 5.9-rc1-next-20200821
- commit 91de17f
* Thu Aug 20 2020 kbuild@suse.de
- Automatically updated to 5.9-rc1-next-20200820
- commit 9ef628f
* Wed Aug 19 2020 kbuild@suse.de
- Automatically updated to 5.9-rc1-next-20200819
- commit daba1e3
* Wed Aug 19 2020 nstange@suse.de
- rpm/kernel-binary.spec.in: restrict livepatch metapackage to default flavor
  It has been reported that the kernel-*-livepatch metapackage got
  erroneously enabled for SLE15-SP3's new -preempt flavor, leading to a
  unresolvable dependency to a non-existing kernel-livepatch-x.y.z-preempt
  package.
  As SLE12 and SLE12-SP1 have run out of livepatching support, the need to
  build said metapackage for the -xen flavor is gone and the only remaining
  flavor for which they're still wanted is -default.
  Restrict the build of the kernel-*-livepatch metapackage to the -default
  flavor.
- commit 58949f3
* Tue Aug 18 2020 kbuild@suse.de
- Automatically updated to 5.9-rc1-next-20200818
- commit f03d51d
* Tue Aug 18 2020 mkubecek@suse.cz
- config: restore PHYLIB=m in */vanilla
  As the PHYLIB/ETHTOOL_NETLINK dependency fix is now in 5.9-rc1 tarball,
  we can apply the changes from commit 4756d9edf730 ("config: restore
  PHYLIB=m") also to vanilla configs.
- commit edbf9c7
* Tue Aug 18 2020 mkubecek@suse.cz
- Update to 5.9-rc1
- eliminated 50 patches (39 stable, 11 other)
- disable ARM architectures (need config update)
- disable (needs update)
  - patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
- refresh
  - patches.rpmify/Add-ksym-provides-tool.patch
  - patches.suse/acpi_thermal_passive_blacklist.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/apparmor-compatibility-with-v2.x-net.patch
  - patches.suse/b43-missing-firmware-info.patch
  - patches.suse/dm-mpath-no-partitions-feature
  - patches.suse/vfs-add-super_operations-get_inode_dev
- new config options:
  - General setup
  - KERNEL_ZSTD=n
  - RD_ZSTD=y
  - File systems
  - FS_ENCRYPTION_INLINE_CRYPT=y
  - TMPFS_INODE64=y
  - Kernel hacking
  - DEBUG_FORCE_FUNCTION_ALIGN_32B=n
  - DEBUG_FS_ALLOW_ALL=y
  - DEBUG_FS_DISALLOW_MOUNT=n
  - DEBUG_FS_ALLOW_NONE=n
  - RCU_REF_SCALE_TEST=n
  - TEST_FPU=n
  - PCI support
  - PCI_J721E_HOST=n
  - PCI_J721E_EP=n
  - Storage
  - NVME_TARGET_PASSTHRU=n
  - SCSI_UFS_CRYPTO=y
  - BCACHE_ASYNC_REGISTRATION=y
  - Network device support
  - MLX5_IPSEC=y
  - MT7663S=m
  - WLAN_VENDOR_MICROCHIP=y
  - RTW88_8821CE=m
  - Character devices
  - HW_RANDOM_BA431=m
  - SERIAL_IMX_EARLYCON=n
  - Power management
  - CHARGER_BQ2515X=m
  - SENSORS_CORSAIR_CPRO=m
  - THERMAL_NETLINK=y
  - REGULATOR_PCA9450=m
  - REGULATOR_QCOM_USB_VBUS=m
  - REGULATOR_QCOM_LABIBB=m
  - REGULATOR_FAN53880=m
  - REGULATOR_SY8827N=m
  - Multimedia support
  - VIDEO_RDACM20=m
  - VIDEO_DW9768=m
  - VIDEO_MAX9286=m
  - Graphics support
  - DRM_AMD_DC_DCN3_0=y
  - NOUVEAU_DEBUG_PUSH=n
  - DRM_PANEL_SITRONIX_ST7703=n
  - Sound card support
  - SND_HDA_INTEL_HDMI_SILENT_STREAM=y
  - SND_SOC_MAX98373_SDW=m
  - USB support
  - USB_OTG_PRODUCTLIST=n
  - USB_OTG_DISABLE_EXTERNAL_HUB=n
  - X86 Platform Specific Device Drivers
  - INTEL_ATOMISP2_LED=m
  - Industrial I/O support
  - SCD30_CORE=n
  - INV_ICM42600_I2C=n
  - INV_ICM42600_SPI=n
  - Misc drivers
  - SPI_LANTIQ_SSC=n
  - PINCTRL_EMMITSBURG=m
  - GPIO_PCA9570=m
  - IR_TOY=m
  - CEC_CH7322=m
  - LEDS_CLASS_MULTICOLOR=m
  - XILINX_ZYNQMP_DPDMA=m
  - MLX5_VDPA=n
  - CLK_HSDK=n
  - i386
  - REGULATOR_CROS_EC=m
  - ppc
  - PPC_QUEUED_SPINLOCKS=y
  - s390x
  - BPF_KPROBE_OVERRIDE=n
  - FAIL_FUNCTION=n
  - riscv64
  - NO_HZ_IDLE=y
  - VIRT_CPU_ACCOUNTING_GEN=y
  - JUMP_LABEL=y
  - STATIC_KEYS_SELFTEST=n
  - STACKPROTECTOR=y
  - STACKPROTECTOR_STRONG=y
  - SND_SOC_MAX98373_I2C=m
  - DEBUG_KMEMLEAK=n
  - DEBUG_VM_PGTABLE=n
  - PROVE_LOCKING=n
  - LOCK_STAT=n
  - DEBUG_WW_MUTEX_SLOWPATH=n
  - DEBUG_LOCK_ALLOC=n
  - KCOV=n
  - CONTEXT_TRACKING_FORCE=n
- commit 0102d52
* Mon Aug 17 2020 kbuild@suse.de
- Automatically updated to 5.9-rc1-next-20200817
- commit 4cd8c89
* Fri Aug 14 2020 kbuild@suse.de
- Automatically updated to 5.8-next-20200814
- commit e8e0e5c
* Thu Aug 13 2020 kbuild@suse.de
- Automatically updated to 5.8-next-20200813
- commit b0144b2
* Wed Aug 12 2020 kbuild@suse.de
- Automatically updated to 5.8-next-20200812
- commit 90f1f9c
* Wed Aug 12 2020 jslaby@suse.cz
- Update config files (bsc#1174058).
  Enable GENERIC_IRQ_DEBUGFS.
  This (automatically) sets GENERIC_IRQ_INJECTION=y on some platforms and
  aligns them with x86.
- commit ebab12c
* Tue Aug 11 2020 kbuild@suse.de
- Automatically updated to 5.8-next-20200811
- commit 70e92db
* Mon Aug 10 2020 kbuild@suse.de
- Automatically updated to 5.8-next-20200810
- commit 3a6a60f
* Sun Aug  9 2020 mkubecek@suse.cz
- config: refresh
- only headers update (gcc 10.1.1 -> 10.2.1)
- commit e835e02
* Fri Aug  7 2020 kbuild@suse.de
- Automatically updated to 5.8-next-20200807
- commit db95196
* Thu Aug  6 2020 kbuild@suse.de
- Automatically updated to 5.8-next-20200806
- commit 7d5a8d6
* Wed Aug  5 2020 msuchanek@suse.de
- Refresh patches.rpmify/Add-ksym-provides-tool.patch.
- commit 32ad3c1
* Wed Aug  5 2020 kbuild@suse.de
- Automatically updated to 5.8-next-20200805
- commit 142eb50
* Tue Aug  4 2020 kbuild@suse.de
- Automatically updated to 5.8-next-20200804
- commit 61bd5d5
* Mon Aug  3 2020 afaerber@suse.com
- config: armv7hl: Update to 5.8
- commit 56f55c9
* Mon Aug  3 2020 afaerber@suse.com
- config: armv6hl: Update to 5.8
- commit eff80b8
* Mon Aug  3 2020 schwab@suse.de
- config: refresh riscv64/default
- commit 753d19c
* Mon Aug  3 2020 mkubecek@suse.cz
- Update to 5.8 final
- refresh configs (headers only)
- commit 58a33d0
* Sat Aug  1 2020 kbuild@suse.de
- Automatically updated to 5.8-rc7-next-20200731
- commit 1ed7a54
* Fri Jul 31 2020 kbuild@suse.de
- Automatically updated to 5.8-rc7-next-20200730
- commit 08a56fa
* Thu Jul 30 2020 kbuild@suse.de
- Automatically updated to 5.8-rc7-next-20200729
- commit cd530f4
* Wed Jul 29 2020 kbuild@suse.de
- Automatically updated to 5.8-rc7-next-20200728
- commit 0404c4c
* Tue Jul 28 2020 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Require python3 for build.
  GEN
  /home/abuild/rpmbuild/BUILD/kernel-vanilla-5.8.rc7.next.20200727/linux-5.8-rc7-next-20200727/linux-obj/tools/bpf/resolve_btfids/bpf_helper_defs.h
  /usr/bin/env: 'python3': No such file or directory
- commit 86973bf
* Tue Jul 28 2020 kbuild@suse.de
- Automatically updated to 5.8-rc7-next-20200727
- commit 4615a00
* Tue Jul 28 2020 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: Enable overlayfs
  Overlayfs is needed for podman or docker builds when no more specific
  driver can be used (like lvm or btrfs). As the default build fs is ext4
  currently, we need overlayfs kernel modules to be available.
- commit 29474aa
* Sat Jul 25 2020 kbuild@suse.de
- Automatically updated to 5.8-rc6-next-20200724
- commit deac8c8
* Fri Jul 24 2020 kbuild@suse.de
- Automatically updated to 5.8-rc6-next-20200723
- commit c1b2efb
* Thu Jul 23 2020 kbuild@suse.de
- Automatically updated to 5.8-rc6-next-20200722
- commit 19f8065
* Wed Jul 22 2020 kbuild@suse.de
- Automatically updated to 5.8-rc6-next-20200721
- commit 4f4ef95
* Mon Jul 20 2020 kbuild@suse.de
- Automatically updated to 5.8-rc6-next-20200720
- commit 60b96d0
* Mon Jul 20 2020 mkubecek@suse.cz
- Update to 5.8-rc6
- eliminated 2 patches
- refresh config files
- commit 5304ce8
* Sat Jul 18 2020 kbuild@suse.de
- Automatically updated to 5.8-rc5-next-20200717
- commit 171281a
* Fri Jul 17 2020 mkubecek@suse.cz
- config: restore PHYLIB=m
  This essentially reverts kernel-source commit fcc47b444be6 ("config:
  enable PHYLIB=y and ETHTOOL_NETLINK=y") which responded to upstream
  change not allowing ETHTOOL_NETLINK=y with PHYLIB=m. There are two
  exceptions:
  - vanilla flavors keep PHYLIB=y as patches fixing the dependency are
    not applied to */vanilla (will be fixed with 5.9-rc1 update)
  - we preserve ETHTOOL_NETLINK=y which was previously lost in 5.8-rc1
    update
- commit dbbb633
* Thu Jul 16 2020 kbuild@suse.de
- Automatically updated to 5.8-rc5-next-20200716
- commit a1a168e
* Thu Jul 16 2020 jslaby@suse.cz
- Refresh
  patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
- Update config files.
  Sync with master branch.
- commit c45e949
* Wed Jul 15 2020 kbuild@suse.de
- Automatically updated to 5.8-rc5-next-20200715
- commit 16c8fb3
* Tue Jul 14 2020 afaerber@suse.com
- config: arm64: Update to 5.8-rc5
- commit 9c26dba
* Tue Jul 14 2020 kbuild@suse.de
- Automatically updated to 5.8-rc5-next-20200714
- commit 71d2d5e
* Mon Jul 13 2020 kbuild@suse.de
- Automatically updated to 5.8-rc4-next-20200713
- commit 00291e8
* Mon Jul 13 2020 mkubecek@suse.cz
- Update to 5.8-rc5
- refresh riscv64 configs
- commit f799c9a
* Fri Jul 10 2020 kbuild@suse.de
- Automatically updated to 5.8-rc4-next-20200710
- commit ee83bb1
* Thu Jul  9 2020 kbuild@suse.de
- Automatically updated to 5.8-rc4-next-20200709
- commit c168941
* Tue Jul  7 2020 kbuild@suse.de
- Automatically updated to 5.8-rc4-next-20200707
- commit a134176
* Mon Jul  6 2020 kbuild@suse.de
- Automatically updated to 5.8-rc3-next-20200706
- commit 8237bbc
* Fri Jul  3 2020 kbuild@suse.de
- Automatically updated to 5.8-rc3-next-20200703
- commit dc8876c
* Thu Jul  2 2020 kbuild@suse.de
- Automatically updated to 5.8-rc3-next-20200702
- commit 5c8f920
* Thu Jul  2 2020 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: do not run klp-symbols for configs with no modules
  Starting with 5.8-rc1, s390x/zfcpdump builds fail because rpm/klp-symbols
  script does not find .tmp_versions directory. This is missing because
  s390x/zfcpdump is built without modules (CONFIG_MODULES disabled).
  As livepatching cannot work without modules, the cleanest solution is
  setting %%klp_symbols to 0 if CONFIG_MODULES is disabled. (We cannot simply
  add another condition to the place where %%klp_symbols is set as it can be
  already set to 1 from prjconf.)
- commit a048c4b
* Thu Jul  2 2020 mkubecek@suse.cz
- config: refresh riscv64/default
- commit 0a754d9
* Wed Jul  1 2020 rgoldwyn@suse.com
- Re-enable F2FS (boo#1173546)
  Since the changes of blacklisting landed)boo#1109665), we can re-enable
  F2FS for opensuse kernels. For SLE, it will land in
  kernel-default-extra
- commit 5b5ff33
* Wed Jul  1 2020 mkubecek@suse.cz
- Update
  patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
- we faked also CC_CAN_LINK_STATIC temporarily to work around the
  bpfilter_umh build breakage but that is no longer needed so we no longer
  need to pretend we can do static linkage on build
- refresh config files to reflect the change
- commit 553444c
* Wed Jul  1 2020 kbuild@suse.de
- Automatically updated to 5.8-rc3-next-20200701
- commit 880d6b2
* Tue Jun 30 2020 kbuild@suse.de
- Automatically updated to 5.8-rc3-next-20200630
- commit df90ea6
* Mon Jun 29 2020 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Require dwarves for DEBUG_INFO_BTF
- commit be95ef6
* Mon Jun 29 2020 kbuild@suse.de
- Automatically updated to 5.8-rc3-next-20200629
- commit f6ba841
* Mon Jun 29 2020 mkubecek@suse.cz
- Update to 5.8-rc3
- eliminated 2 patches
- refresh
  patches.suse/suse-hv-guest-os-id.patch
- update configs
  - EFI_CUSTOM_SSDT_OVERLAYS=y
- commit 9acc0eb
* Mon Jun 22 2020 mkubecek@suse.cz
- Update to 5.8-rc2
- refresh configs
- commit a7b343b
* Wed Jun 17 2020 kbuild@suse.de
- Automatically updated to 5.8-rc1-next-20200617
- commit 1c5bbfc
* Tue Jun 16 2020 kbuild@suse.de
- Automatically updated to 5.8-rc1-next-20200616
- commit 31c6cb5
* Mon Jun 15 2020 mkubecek@suse.cz
- config: disable BPFILTER_UMH on i386
  It does not build currently.
- commit f1de243
* Mon Jun 15 2020 kbuild@suse.de
- Automatically updated to 5.8-rc1-next-20200615
- commit 0f66aba
* Mon Jun 15 2020 mkubecek@suse.cz
- config: enable PHYLIB=y and ETHTOOL_NETLINK=y
  As an unfortunate side effect of ethtool cable diagnostic support,
  ETHTOOL_NETLINK now depends on PHYLIB and the dependency is implemented in
  a way making "make oldconfig" drops ETHTOOL_NETLINK if PHYLIB=m.
  Until this issue is resolved in upstream, set PHYLIB=y so that
  ETHTOOL_NETLINK can be enabled again.
- commit 0cb8849
* Mon Jun 15 2020 mkubecek@suse.cz
- rpm: drop execute permissions on source files
  Sometimes a source file with execute permission appears in upstream
  repository and makes it into our kernel-source packages. This is caught by
  OBS build checks and may even result in build failures.
  Sanitize the source tree by removing execute permissions from all C source
  and header files.
- commit 771e293
* Mon Jun 15 2020 mkubecek@suse.cz
- Update to 5.8-rc1
- eliminated 48 patches (40 stable, 8 other)
- disable ARM architectures (need config update)
- refresh
  patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch
  patches.suse/apparmor-compatibility-with-v2.x-net.patch
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  patches.suse/dm-mpath-leastpending-path-update
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/pstore_disable_efi_backend_by_default.patch
  patches.suse/readahead-request-tunables.patch
  patches.suse/supported-flag
  patches.suse/supported-flag-external
  patches.suse/supported-flag-modverdir
  patches.suse/suse-hv-guest-os-id.patch
- fix build with BPFILTER_UMH=m
  patches.rpmify/bpfilter-only-build-bpfilter_umh-as-static-when-BPFI.patch
- new config options:
  - General setup
  - CONFIG_DEFAULT_INIT=""
  - CONFIG_WATCH_QUEUE=y
  - Power management and ACPI options
  - CONFIG_HIBERNATION_SNAPSHOT_DEV=y
  - Enable the block layer
  - CONFIG_BLK_INLINE_ENCRYPTION=y
  - CONFIG_BLK_INLINE_ENCRYPTION_FALLBACK=y
  - CONFIG_BLK_DEV_RNBD_CLIENT=m
  - CONFIG_BLK_DEV_RNBD_SERVER=m
  - Memory Management options
  - CONFIG_ZSMALLOC_PGTABLE_MAPPING=n
  - Networking support
  - CONFIG_INET6_ESPINTCP=y
  - CONFIG_BRIDGE_MRP=y
  - CONFIG_NET_ACT_GATE=m
  - CONFIG_QRTR=m
  - CONFIG_QRTR_SMD=m
  - CONFIG_QRTR_TUN=m
  - CONFIG_QRTR_MHI=m
  - CONFIG_BT_MSFTEXT=n
  - File systems
  - CONFIG_PSTORE_BLK=m
  - Library routines
  - CONFIG_PRIME_NUMBERS=n
  - CONFIG_DEBUG_INFO_COMPRESSED=n
  - CONFIG_DEBUG_VM_PGTABLE=n
  - CONFIG_HIST_TRIGGERS_DEBUG=n
  - CONFIG_TEST_BITOPS=n
  - CONFIG_TEST_HMM=n
  - Multiple devices driver support (RAID and LVM)
  - CONFIG_BCACHE_ASYNC_REGISTRAION=n
  - CONFIG_DM_EBS=m
  - CONFIG_DM_MULTIPATH_HST=m
  - Network device support
  - CONFIG_NET_DSA_SJA1105_VL=y
  - CONFIG_MLX5_CLS_ACT=y
  - CONFIG_BCM54140_PHY=m
  - CONFIG_MT7663U=m
  - CONFIG_MT7915E=m
  - CONFIG_RTW88_8723DE=m
  - Input device support
  - CONFIG_TOUCHSCREEN_CY8CTMA140=m
  - CONFIG_INPUT_IQS269A=m
  - Character devices
  - CONFIG_SERIAL_LANTIQ=m
  - Multifunction device drivers
  - CONFIG_MFD_MP2629=n
  - CONFIG_MFD_INTEL_PMC_BXT=m
  - CONFIG_INTEL_SOC_PMIC_MRFLD=m
  - CONFIG_INTEL_MRFLD_PWRBTN=m
  - CONFIG_EXTCON_INTEL_MRFLD=m
  - CONFIG_INTEL_MRFLD_ADC=n
  - CONFIG_MFD_INTEL_MSIC=n
  - CONFIG_MFD_MT6360=n
  - Multimedia support
  - CONFIG_MEDIA_SUPPORT_FILTER=y
  - CONFIG_MEDIA_PLATFORM_SUPPORT=n
  - CONFIG_MEDIA_TEST_SUPPORT=n
  - CONFIG_VIDEO_OV2740=m
  - CONFIG_INTEL_ATOMISP=y
  - CONFIG_VIDEO_ATOMISP=m
  - CONFIG_VIDEO_ATOMISP_ISP2401=y
  - CONFIG_VIDEO_ATOMISP_OV5693=m
  - CONFIG_VIDEO_ATOMISP_OV2722=m
  - CONFIG_VIDEO_ATOMISP_GC2235=m
  - CONFIG_VIDEO_ATOMISP_MSRLIST_HELPER=m
  - CONFIG_VIDEO_ATOMISP_MT9M114=m
  - CONFIG_VIDEO_ATOMISP_GC0310=m
  - CONFIG_VIDEO_ATOMISP_OV2680=m
  - CONFIG_VIDEO_ATOMISP_LM3554=m
  - CONFIG_CEC_CROS_EC=m
  - CONFIG_CEC_SECO=m
  - CONFIG_CEC_SECO_RC=n
  - Graphics support
  - CONFIG_DRM_I915_FENCE_TIMEOUT=10000
  - Sound card support
  - CONFIG_SND_SOC_AMD_RENOIR=m
  - CONFIG_SND_SOC_AMD_RENOIR_MACH=m
  - CONFIG_SND_SOC_INTEL_SOF_WM8804_MACH=m
  - CONFIG_SND_SOC_INTEL_EHL_RT5660_MACH=m
  - CONFIG_SND_SOC_MAX98390=m
  - CONFIG_SND_SOC_ZL38060=n
  - USB support
  - CONFIG_USB_XHCI_PCI_RENESAS=m
  - InfiniBand support
  - CONFIG_INFINIBAND_RTRS_CLIENT=m
  - CONFIG_INFINIBAND_RTRS_SERVER=m
  - Virtio drivers
  - CONFIG_VIRTIO_MEM=m
  - X86 Platform Specific Device Drivers
  - CONFIG_INTEL_WMI_SBL_FW_UPDATE=m
  - CONFIG_INTEL_SCU_PCI=y
  - CONFIG_INTEL_SCU_PLATFORM=m
  - CONFIG_INTEL_MID_POWER_BUTTON=m
  - CONFIG_INTEL_SCU_IPC_UTIL=m
  - Industrial I/O support
  - CONFIG_AD9467=n
  - CONFIG_ADI_AXI_ADC=n
  - CONFIG_MAX1241=n
  - CONFIG_ATLAS_EZO_SENSOR=n
  - CONFIG_ADIS16475=n
  - CONFIG_SX9310=n
  - CONFIG_VCNL3020=n
  - Misc drivers
  - CONFIG_MTD_NAND_ARASAN=m
  - CONFIG_MTD_PSTORE=m
  - CONFIG_INTERCONNECT=n
  - CONFIG_SPI_AMD=n
  - CONFIG_PINCTRL_JASPERLAKE=m
  - CONFIG_GPIO_PCA953X_IRQ=y
  - CONFIG_GPIO_AGGREGATOR=m
  - CONFIG_BATTERY_CW2015=m
  - CONFIG_CHARGER_BD99954=m
  - CONFIG_SENSORS_AMD_ENERGY=m
  - CONFIG_SENSORS_MAX16601=m
  - ACPI INT340X thermal drivers
  - CONFIG_REGULATOR_MAX77826=m
  - CONFIG_LEDS_SGM3140=m
  - CONFIG_PWM_IQS620A=m
  - i386 / ppc64 / ppc64le
  - MDIO_IPQ4019=m
  - HW_RANDOM_CCTRNG=n
  - MFD_GATEWORKS_GSC=m
  - DRM_PANEL_ASUS_Z00T_TM5P5_NT35596=n
  - DRM_PANEL_LEADTEK_LTK050H3146W=n
  - DRM_PANEL_VISIONOX_RM69299=n
  - DRM_CHRONTEL_CH7033=n
  - DRM_NWL_MIPI_DSI=n
  - LEDS_AW2013=m
  - CLK_LGM_CGU=y
  - PHY_CADENCE_SALVO=m
  - PHY_INTEL_COMBO=y
  - PHY_OCELOT_SERDES=m
  - MTD_PHYSMAP_VERSATILE=y
  - MTD_PHYSMAP_GEMINI=y
  - MDIO_IPQ8064=m
  - SERIAL_8250_ASPEED_VUART=n
  - GPIO_LOGICVC=n
  - GPIO_SAMA5D2_PIOBU=n
  - GPIO_SYSCON=n
  - SENSORS_GSC=m
  - DRM_PANEL_ARM_VERSATILE=n
  - LEDS_SYSCON=y
- commit 82928b1
* Sun Jun 14 2020 kbuild@suse.de
- Automatically updated to 5.7-next-20200614
- commit 037864b
* Sat Jun 13 2020 kbuild@suse.de
- Automatically updated to 5.7-next-20200613
- commit 233ecef
* Fri Jun 12 2020 kbuild@suse.de
- Automatically updated to 5.7-next-20200612
- commit e8551bc
* Thu Jun 11 2020 kbuild@suse.de
- Automatically updated to 5.7-next-20200611
- commit 11ab1dd
* Wed Jun 10 2020 kbuild@suse.de
- Automatically updated to 5.7-next-20200610
- commit b7c71e1
* Tue Jun  9 2020 kbuild@suse.de
- Automatically updated to 5.7-next-20200609
- commit ec1f43c
* Tue Jun  9 2020 dmueller@suse.com
- armv7/ararch64: Update config files.
  Enable IOMMU_DEFAULT_PASSTHROUGH; per jsc#SLE-5568 this should be on by
  default, like on x86_64.
- commit d3e5dc3
* Mon Jun  8 2020 kbuild@suse.de
- Automatically updated to 5.7-next-20200608
- commit 5fb7a9d
* Fri Jun  5 2020 kbuild@suse.de
- Automatically updated to 5.7-next-20200605
- commit e2fea7c
* Thu Jun  4 2020 mkubecek@suse.cz
- config: refresh with gcc10
  gcc10 is default in Tumbleweed now.
- commit d4028c2
* Thu Jun  4 2020 kbuild@suse.de
- Automatically updated to 5.7-next-20200604
- commit 1c60103
* Wed Jun  3 2020 kbuild@suse.de
- Automatically updated to 5.7-next-20200603
- commit 7f10357
* Wed Jun  3 2020 jslaby@suse.cz
- Revert "Update config files."
  This reverts commit 34be040b91701c047e592935bc2dbb46a3947a56. We now
  have a fix (previous commit) in place, so change the configuration back
  (bsc#1156053).
- commit 9fb5ece
* Tue Jun  2 2020 kbuild@suse.de
- Automatically updated to 5.7-next-20200602
- commit 20b82a9
* Mon Jun  1 2020 mkubecek@suse.cz
- config: enable DEBUG_INFO_BTF
  This was disabled when the option was introduced in 5.2-rc1 but it turned
  out there are interesting use cases for having it enabled.
  Add pahole to build time dependencies as it is used to extracth the BTF
  data. Once we figure out how to make it conditional (only if DEBUG_INFO_BTF
  exists and is enabled), it should be done in packaging branch.
- commit 3f2b1de
* Mon Jun  1 2020 mkubecek@suse.cz
- Updated to 5.7 final
- refresh configs
- commit 21ca3aa
* Fri May 29 2020 kbuild@suse.de
- Automatically updated to 5.7-rc7-next-20200529
- commit 9e1912f
* Thu May 28 2020 kbuild@suse.de
- Automatically updated to 5.7-rc7-next-20200528
- commit 0c90c3d
* Tue May 26 2020 kbuild@suse.de
- Automatically updated to 5.7-rc7-next-20200526
- commit 3f79a08
* Tue May 26 2020 trenn@suse.com
- Update config files.
  Remove ACPI_PROCFS_POWER
  This should all be in sysfs nowadays. If this is in Tumbleweed for a while,
  a patch to totally remove this code will be sent mainline.
  Related to bsc#1160977
- commit 3d4a7dc
* Tue May 26 2020 msuchanek@suse.de
- rpm/kernel-source.spec.in: Add obsolete_rebuilds (boo#1172073).
- commit 6524463
* Mon May 25 2020 kbuild@suse.de
- Automatically updated to 5.7-rc7-next-20200525
- commit cfb9c3a
* Mon May 25 2020 mkubecek@suse.cz
- Update to 5.7-rc7
- refresh configs (ARCH_HAS_STRICT_KERNEL_RWX=n on ppc64/ppc64le)
- commit f5899f1
* Fri May 22 2020 kbuild@suse.de
- Automatically updated to 5.7-rc6-next-20200522
- commit a0bc0d9
* Thu May 21 2020 kbuild@suse.de
- Automatically updated to 5.7-rc6-next-20200521
- commit 59fc611
* Tue May 19 2020 kbuild@suse.de
- Automatically updated to 5.7-rc6-next-20200519
- commit af79f84
* Tue May 19 2020 afaerber@suse.com
- config: armv7hl: Update to 5.7-rc6
- commit 5783690
* Mon May 18 2020 kbuild@suse.de
- Automatically updated to 5.7-rc6-next-20200518
- commit c430575
* Mon May 18 2020 mkubecek@suse.cz
- Update to 5.7-rc6
- eliminated 2 patches
- refresh configs
- commit c905e27
* Sun May 17 2020 afaerber@suse.com
- config: armv6hl: Update to 5.7-rc5
- commit 7fea560
* Fri May 15 2020 kbuild@suse.de
- Automatically updated to 5.7-rc5-next-20200515
- commit eb5774f
* Thu May 14 2020 kbuild@suse.de
- Automatically updated to 5.7-rc5-next-20200514
- commit 8569e9e
* Thu May 14 2020 msuchanek@suse.de
- rpm/check-for-config-changes: Ignore CONFIG_CC_VERSION_TEXT
- commit 8e6b05f
* Tue May 12 2020 kbuild@suse.de
- Automatically updated to 5.7-rc5-next-20200512
- commit 94b74fe
* Mon May 11 2020 kbuild@suse.de
- Automatically updated to 5.7-rc5-next-20200511
- commit a234b0b
* Mon May 11 2020 mkubecek@suse.cz
- Update to 5.7-rc5
- refresh configs
- commit 710520a
* Fri May  8 2020 kbuild@suse.de
- Automatically updated to 5.7-rc4-next-20200508
- commit 5d25429
* Thu May  7 2020 afaerber@suse.com
- config: arm64: Update to 5.7-rc4
- commit 0a74643
* Thu May  7 2020 jzerebecki@suse.com
- kernel-docs: Change Requires on python-Sphinx to earlier than version 3
  References: bsc#1166965
  From 3 on the internal API that the build system uses was rewritten in
  an incompatible way.
  See https://github.com/sphinx-doc/sphinx/issues/7421 and
  https://bugzilla.suse.com/show_bug.cgi?id=1166965#c16 for some details.
- commit cf60b5c
* Thu May  7 2020 kbuild@suse.de
- Automatically updated to 5.7-rc4-next-20200507
- commit eee8a4a
* Tue May  5 2020 kbuild@suse.de
- Automatically updated to 5.7-rc4-next-20200505
- commit a7ad5a9
* Mon May  4 2020 kbuild@suse.de
- Automatically updated to 5.7-rc4-next-20200504
- commit eed60f3
* Fri May  1 2020 kbuild@suse.de
- Automatically updated to 5.7-rc3-next-20200501
- commit dd0052c
* Thu Apr 30 2020 kbuild@suse.de
- Automatically updated to 5.7-rc3-next-20200430
- commit bda70f0
* Wed Apr 29 2020 ykaukab@suse.de
- config: arm64: enable coresight support
  Coresight is already enabled in armv7hl
- commit 8bad7da
* Wed Apr 29 2020 kbuild@suse.de
- Automatically updated to 5.7-rc3-next-20200429
- commit 6e12e70
* Tue Apr 28 2020 kbuild@suse.de
- Automatically updated to 5.7-rc3-next-20200428
- commit 0bce566
* Mon Apr 27 2020 mkubecek@suse.cz
- Update to 5.7-rc3
- eliminated 1 patch
- refresh configs
- commit 40638f7
* Fri Apr 24 2020 kbuild@suse.de
- Automatically updated to 5.7-rc2-next-20200424
- commit 3da89ac
* Thu Apr 23 2020 kbuild@suse.de
- Automatically updated to 5.7-rc2-next-20200423
- commit a19a7f0
* Wed Apr 22 2020 kbuild@suse.de
- Automatically updated to 5.7-rc2-next-20200422
- commit 3d8ad72
* Tue Apr 21 2020 schwab@suse.de
- config: riscv64: enable left out config options
  Enable some config options to reduce difference with x86 config
- commit a2fb960
* Tue Apr 21 2020 kbuild@suse.de
- Automatically updated to 5.7-rc2-next-20200421
- commit 8e81e5a
* Mon Apr 20 2020 tiwai@suse.de
- Update config files: revert CONFIG_SND_HDA_PREALLOC_SIZE changes (bsc#1169471)
- commit a5a4188
* Mon Apr 20 2020 kbuild@suse.de
- Automatically updated to 5.7-rc2-next-20200420
- commit 9661a50
* Mon Apr 20 2020 mkubecek@suse.cz
- config: enable PCIE_EDR (bsc#1169263)
  (x86 only)
- commit 4aed991
* Mon Apr 20 2020 mbrugger@suse.com
- armv7hl: Update config files.
  Build MediaTek watchdog as built-in.
- commit dfddf0a
* Fri Apr 17 2020 kbuild@suse.de
- Automatically updated to 5.7-rc1-next-20200417
- commit 79ee7fb
* Thu Apr 16 2020 kbuild@suse.de
- Automatically updated to 5.7-rc1-next-20200416
- commit cfa1a2c
* Wed Apr 15 2020 kbuild@suse.de
- Automatically updated to 5.7-rc1-next-20200415
- commit aac9932
* Wed Apr 15 2020 msuchanek@suse.de
- rpm/check-for-config-changes: Ignore CONFIG_LD_VERSION
- commit e60242e
* Tue Apr 14 2020 schwab@suse.de
- Add config files for riscv64
- commit e5033da
* Tue Apr 14 2020 kbuild@suse.de
- Automatically updated to 5.7-rc1-next-20200414
- commit 2aacca4
* Mon Apr 13 2020 kbuild@suse.de
- Automatically updated to 5.7-rc1-next-20200413
- commit a938053
* Mon Apr 13 2020 mkubecek@suse.cz
- Update to 5.7-rc1
- eliminated 70 patches (66 stable, 4 other)
- disable ARM architectures (need config update)
- refresh
  - patches.suse/supported-flag
  - patches.suse/supported-flag-external
  - patches.suse/supported-flag-modverdir
  - patches.suse/vfs-add-super_operations-get_inode_dev
  - patches.suse/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch
  - patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
- fix s390x build:
  patches.suse/tty-sysrq-Export-sysrq_mask.patch
- new config options:
- General setup
  - CONFIG_SCHED_THERMAL_PRESSURE=y
  - CONFIG_BPF_LSM=y
- Power management and ACPI options
  - CONFIG_ACPI_TINY_POWER_BUTTON=m
  - CONFIG_ACPI_TINY_POWER_BUTTON_SIGNAL=38
- Memory Management options
  - CONFIG_ZSWAP_COMPRESSOR_DEFAULT_LZO=y
  - CONFIG_ZSWAP_ZPOOL_DEFAULT_ZBUD=y
  - CONFIG_ZSWAP_DEFAULT_ON=n
- Networking support
  - CONFIG_IPV6_RPL_LWTUNNEL=y
- File systems
  - CONFIG_EXFAT_FS=m
  - CONFIG_EXFAT_DEFAULT_IOCHARSET="utf8"
- Cryptographic API
  - CONFIG_CHELSIO_TLS_DEVICE=y
- Kernel hacking
  - CONFIG_MAGIC_SYSRQ_SERIAL_SEQUENCE=""
  - CONFIG_TEST_LOCKUP=n
  - CONFIG_TEST_MIN_HEAP=n
- PCI
  - CONFIG_PCIE_EDR=n
- Network device drivers
  - CONFIG_BAREUDP=m
  - CONFIG_MLX5_TC_CT=y
  - CONFIG_DWMAC_INTEL=m
  - CONFIG_MDIO_MVUSB=m
  - CONFIG_BCM84881_PHY=m
  - PHY_CADENCE_TORRENT=m (i386, ppc64(le))
- PTP clock support
  - CONFIG_PTP_1588_CLOCK_IDT82P33=m
  - CONFIG_PTP_1588_CLOCK_VMW=m
- Graphics
  - CONFIG_DRM_I915_MAX_REQUEST_BUSYWAIT=8000
  - CONFIG_TINYDRM_ILI9486=n
  - DRM_PANEL_BOE_TV101WUM_NL6=n
  - DRM_PANEL_ELIDA_KD35T133=n
  - DRM_PANEL_FEIXIN_K101_IM2BA02=n
  - DRM_PANEL_NOVATEK_NT35510=n
  - DRM_PANEL_SAMSUNG_S6E88A0_AMS452EF01=n
  - DRM_DISPLAY_CONNECTOR=n
  - DRM_PARADE_PS8640=n
  - DRM_SIMPLE_BRIDGE=n
  - DRM_TOSHIBA_TC358768=n
  - DRM_TI_TPD12S015=n
- Sound
  - CONFIG_SND_SOC_AMD_RV_RT5682_MACH=m
  - CONFIG_SND_BCM63XX_I2S_WHISTLER=n
  - CONFIG_SND_SOC_INTEL_SOF_PCM512x_MACH=m
  - CONFIG_SND_SOC_SOF_DEBUG_PROBES=n
  - CONFIG_SND_SOC_RT5682_SDW=n
  - CONFIG_SND_SOC_TLV320ADCX140=n
- Input
  - CONFIG_HID_GLORIOUS=m
  - CONFIG_HID_MCP2221=m
  - CONFIG_KEYBOARD_IQS62X=m
- USB
  - CONFIG_APPLE_MFI_FASTCHARGE=m
  - CONFIG_TYPEC_MUX_INTEL_PMC=m
- Virtio drivers
  - CONFIG_VIRTIO_VDPA=m
  - CONFIG_VDPA_MENU=y
  - CONFIG_VDPA_SIM=m
  - CONFIG_IFCVF=m
  - CONFIG_VHOST_MENU=y
  - CONFIG_VHOST_VDPA=m
- Platform drivers
  - CONFIG_SURFACE_3_POWER_OPREGION=m
  - CONFIG_CROS_EC_TYPEC=m
  - CONFIG_CROS_USBPD_NOTIFY=m
- Industrial I/O
  - CONFIG_HMC425=n
  - CONFIG_AD5770R=n
  - CONFIG_AL3010=n
  - CONFIG_GP2AP002=n
  - CONFIG_ICP10100=n
  - CONFIG_IQS621_ALS=n
  - CONFIG_IQS624_POS=n
  - CONFIG_IQS620AT_TEMP=n
- Misc drivers
  - CONFIG_MHI_BUS=m
  - CONFIG_UACCE=m
  - CONFIG_ATA_FORCE=y
  - CONFIG_SERIAL_SPRD=m
  - CONFIG_SPI_MUX=m
  - CONFIG_PINCTRL_DA9062=m
  - CONFIG_SENSORS_AXI_FAN_CONTROL=m
  - CONFIG_MFD_IQS62X=m
  - CONFIG_VIDEO_IMX219=m
  - CONFIG_MMC_HSQ=m
  - CONFIG_DMABUF_MOVE_NOTIFY=n
  - CONFIG_PWM_DEBUG=n
  - CONFIG_MUX_ADG792A=n
  - CONFIG_MUX_ADGS1408=n
  - CONFIG_MUX_GPIO=n
- i386
  - REGULATOR_MP541=m
  - REGULATOR_MP886X=m
- ppc64
  - PMU_SYSFS=y
  - FSL_ENETC=m
  - FSL_ENETC_VF=m
  - FSL_ENETC_PTP_CLOCK=m
  - FSL_ENETC_QOS=y
  - SPI_FSI=m
  - REGULATOR_MP5416=m
  - REGULATOR_MP886X=m
- s390x
  - XILINX_LL_TEMAC=m
  - MDIO_XPCS=m
  - QETH_OSN=y
  - QETH_OSX=y
- commit 3a02548
* Sun Apr 12 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200412
- commit 324cec2
* Sun Apr 12 2020 mkubecek@suse.cz
- constrants: fix malformed XML
  Closing tag of an element is "</foo>", not "<foo/>".
  Fixes: 8b37de2eb835 ("rpm/constraints.in: Increase memory for kernel-docs")
- commit 4a8ca28
* Sat Apr 11 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200411
- commit cc05939
* Fri Apr 10 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200410
- commit 35b14db
* Thu Apr  9 2020 mgorman@suse.de
- Update config files to disable CONFIG_TRACE_IRQFLAGS (bsc#1169078).
- commit 00930e8
* Thu Apr  9 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200409
- commit b4302d3
* Thu Apr  9 2020 msuchanek@suse.de
- rpm/constraints.in: Increase memory for kernel-docs
  References: https://build.opensuse.org/request/show/792664
- commit 8b37de2
* Wed Apr  8 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200408
- commit 0787359
* Tue Apr  7 2020 msuchanek@suse.de
- s390x: zfcpdump: disable CONFIG_RELOCATABLE (bsc#1168847).
- commit 4af6346
* Tue Apr  7 2020 mgorman@suse.de
- Update config files to disable CONFIG_UCLAMP_TASK (bsc#1168888).
- commit 63410a2
* Tue Apr  7 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200407
- commit 90b07e8
* Mon Apr  6 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200406
- commit 9ab479d
* Sun Apr  5 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200405
- commit 396d5b3
* Sat Apr  4 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200404
- commit 7af03e7
* Fri Apr  3 2020 msuchanek@suse.de
- Delete patches.rpmify/powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch.
- commit f8957e3
* Fri Apr  3 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200403
- commit 8fa8475
* Fri Apr  3 2020 yousaf.kaukab@suse.com
- config: arm64: enable cpufreq driver for Jetson Nano and Jetson TX1
- commit 1ab20aa
* Thu Apr  2 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200402
- commit 3454a85
* Wed Apr  1 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200401
- commit 7c293a6
* Tue Mar 31 2020 kbuild@suse.de
- Automatically updated to 5.6-next-20200331
- commit 41725cf
* Mon Mar 30 2020 kbuild@suse.de
- Automatically updated to 5.6-rc7-next-20200330
- commit 3d6a959
* Mon Mar 30 2020 mkubecek@suse.cz
- Update to 5.6 final
- refresh configs
- commit de1bbe5
* Fri Mar 27 2020 kbuild@suse.de
- Automatically updated to 5.6-rc7-next-20200327
- commit a739e29
* Thu Mar 26 2020 kbuild@suse.de
- Automatically updated to 5.6-rc7-next-20200326
- commit a5a4c38
* Wed Mar 25 2020 kbuild@suse.de
- Automatically updated to 5.6-rc7-next-20200325
- commit 0f974de
* Tue Mar 24 2020 kbuild@suse.de
- Automatically updated to 5.6-rc7-next-20200324
- commit 7f580ef
* Mon Mar 23 2020 kbuild@suse.de
- Automatically updated to 5.6-rc7-next-20200323
- commit 530e200
* Mon Mar 23 2020 mkubecek@suse.cz
- Update to 5.6-rc7
- refresh
  patches.suse/supported-flag
- refresh config files:
  - CC_HAS_INT128=n on 32-bit architectures (was =y on i386)
- commit 6b0e9bd
* Fri Mar 20 2020 kbuild@suse.de
- Automatically updated to 5.6-rc6-next-20200320
- commit 7b303db
* Thu Mar 19 2020 yousaf.kaukab@suse.com
- config: arm64: enable CONFIG_MTD_PHYSMAP_OF
  Get rid of CONFIG_MTD_PHYSMAP_COMPAT and enable CONFIG_MTD_PHYSMAP_OF.
  Compat maps of zero length (CONFIG_MTD_PHYSMAP_LEN=0x0) doesn't make
  sense and driver initialization is bound to fail. So use device-tree
  based initialization.
- commit add4d65
* Thu Mar 19 2020 kbuild@suse.de
- Automatically updated to 5.6-rc6-next-20200319
- commit 3acc8e8
* Wed Mar 18 2020 kbuild@suse.de
- Automatically updated to 5.6-rc6-next-20200318
- commit 238ad3f
* Tue Mar 17 2020 kbuild@suse.de
- Automatically updated to 5.6-rc6-next-20200317
- commit c34b722
* Mon Mar 16 2020 kbuild@suse.de
- Automatically updated to 5.6-rc5-next-20200316
- commit 896f25a
* Mon Mar 16 2020 mkubecek@suse.cz
- Update to 5.6-rc6
- refresh config files
- commit 894a877
* Fri Mar 13 2020 kbuild@suse.de
- Automatically updated to 5.6-rc5-next-20200313
- commit a25025f
* Thu Mar 12 2020 tiwai@suse.de
- Update config files: disable CONFIG_OABI_COMPAT for 32bit Arm (bsc#1165462)
  It enables CONFIG_SECCOMP_FILTER.
- commit 5c2830d
* Thu Mar 12 2020 tiwai@suse.de
- Update config files: enable CONFIG_EROFS_FS_ZIP=y
  Requested for supporting EROFS compressed files:
  https://lists.opensuse.org/opensuse-kernel/2020-02/msg00007.html
- commit 67b39a1
* Thu Mar 12 2020 kbuild@suse.de
- Automatically updated to 5.6-rc5-next-20200312
- commit fbed8eb
* Wed Mar 11 2020 kbuild@suse.de
- Automatically updated to 5.6-rc5-next-20200311
- commit d1ac9a5
* Tue Mar 10 2020 kbuild@suse.de
- Automatically updated to 5.6-rc5-next-20200310
- commit 2865dd2
* Mon Mar  9 2020 jeyu@suse.de
- rpm/kabi.pl: account for namespace field being moved last
  Upstream is moving the namespace field in Module.symvers last in order to
  preserve backwards compatibility with kmod tools (depmod, etc). Fix the kabi.pl
  script to expect the namespace field last. Since split() ignores trailing empty
  fields and delimeters, switch to using tr to count how many fields/tabs are in
  a line. Also, in load_symvers(), pass LIMIT of -1 to split() so it does not
  strip trailing empty fields, as namespace is an optional field.
- commit a3bb253
* Mon Mar  9 2020 mkubecek@suse.cz
- Update to 5.6-rc5
- new config options:
  - BACKLIGHT_LED=m
- commit c46c4c1
* Fri Mar  6 2020 kbuild@suse.de
- Automatically updated to 5.6-rc4-next-20200306
- commit c790a53
* Thu Mar  5 2020 kbuild@suse.de
- Automatically updated to 5.6-rc4-next-20200305
- commit 1f4ad99
* Wed Mar  4 2020 jeffm@suse.com
- config: re-enable NLS_ISO8859_1 for kvmsmall
  The EFI partition wants NLS_ISO8859_1 and will fail to mount without it.
- commit 9aa72b3
* Wed Mar  4 2020 kbuild@suse.de
- Automatically updated to 5.6-rc4-next-20200304
- commit 754f774
* Tue Mar  3 2020 kbuild@suse.de
- Automatically updated to 5.6-rc4-next-20200303
- commit ccf0422
* Mon Mar  2 2020 kbuild@suse.de
- Automatically updated to 5.6-rc3-next-20200302
- commit 5218213
* Mon Mar  2 2020 mkubecek@suse.cz
- Update to 5.6-rc4
- eliminated 3 patches
- new config options:
  - KVM_WERROR=n (x86)
- commit 44b56b5
* Sun Mar  1 2020 msuchanek@suse.de
- Update config files.
- commit a90fb26
* Sun Mar  1 2020 msuchanek@suse.de
- Update config files.
- commit c57972f
* Fri Feb 28 2020 kbuild@suse.de
- Automatically updated to 5.6-rc3-next-20200228
- commit 6c4b316
* Thu Feb 27 2020 kbuild@suse.de
- Automatically updated to 5.6-rc3-next-20200227
- commit b4acd7c
* Wed Feb 26 2020 msuchanek@suse.de
- rpm/package-descriptions: garbege collection
  remove old ARM and Xen flavors.
- commit bda0360
* Wed Feb 26 2020 mhocko@suse.com
- Created new preempt kernel flavor (jsc#SLE-11309)
  Configs are cloned from the respective $arch/default configs. All
  changed configs appart from CONFIG_PREEMPT->y are a result of
  dependencies, namely many lock/unlock primitives are no longer
  inlined in the preempt kernel. TREE_RCU has been also changed to
  PREEMPT_RCU which is the default implementation for PREEMPT kernel.
- commit f994874
* Wed Feb 26 2020 kbuild@suse.de
- Automatically updated to 5.6-rc3-next-20200226
- commit b7eb52a
* Tue Feb 25 2020 kbuild@suse.de
- Automatically updated to 5.6-rc3-next-20200225
- commit 1d6d442
* Tue Feb 25 2020 meissner@suse.de
- sign also s390x kernel images (bsc#1163524)
- commit b38b611
* Mon Feb 24 2020 msuchanek@suse.de
- Enable CONFIG_BLK_DEV_SR_VENDOR (boo#1164632).
- commit 7850b22
* Mon Feb 24 2020 kbuild@suse.de
- Automatically updated to 5.6-rc2-next-20200224
- commit 6cd585a
* Fri Feb 21 2020 mkubecek@suse.cz
- config: fix config options added with 5.5-rc1
  Due to a mistake on my side, some config options introduced in 5.5-rc1 got
  different values than the commit message claimed (and, more important, than
  intended). Thanks to Jean Delvare for catching this.
- restored config option values:
  - BACKLIGHT_QCOM_WLED=m
  - BYTCRC_PMIC_OPREGION=y
  - CAIF_DRIVERS=y
  - CHTCRC_PMIC_OPREGION=y
  - CRYPTO_BLAKE2S=m
  - CRYPTO_CURVE25519=m
  - CRYPTO_DEV_AMLOGIC_GXL=m
  - DP83869_PHY=m
  - DRM_AMD_DC_HDCP=y
  - NET_DSA_MSCC_FELIX=m
  - NET_DSA_TAG_OCELOT=m
  - NFC_PN532_UART=m
  - PINCTRL_EQUILIBRIUM=m
  - PINCTRL_TIGERLAKE=m
  - PTP_1588_CLOCK_IDTCM=m
  - SENSORS_BEL_PFE=m
  - SENSORS_LTC2947_I2C=m
  - SENSORS_LTC2947_SPI=m
  - SENSORS_TMP513=m
  - SF_PDMA=m
  - SYSTEM76_ACPI=m
  - TCG_TIS_SPI_CR50=y
  - TYPEC_HD3SS3220=m
  - VIDEO_HI556=m
  - VIDEO_IMX290=m
  - W1_SLAVE_DS2430=m
  - WFX=m
- new config options visible after the changes above:
  - CAIF_TTY=m
  - CAIF_SPI_SLAVE=m
  - CAIF_SPI_SYNC=n
  - CAIF_HSI=m
  - CAIF_VIRTIO=m
  - CRYPTO_DEV_AMLOGIC_GXL_DEBUG=n
- commit 552fa59
* Fri Feb 21 2020 kbuild@suse.de
- Automatically updated to 5.6-rc2-next-20200221
- commit 7b75d9b
* Fri Feb 21 2020 jslaby@suse.cz
- Update config files (bnc#1163396).
  Disable CONFIG_RESET_ATTACK_MITIGATION as we don't have the userspace
  part and it causes problems during reboot. The config description
  states:
  This should only be enabled when userland is configured to clear the
  MemoryOverwriteRequest flag on clean shutdown after secrets have been
  evicted, since otherwise it will trigger even on clean reboots.
- commit cf47ace
* Fri Feb 21 2020 jslaby@suse.cz
- Refresh patches.rpmify/Add-ksym-provides-tool.patch.
  Do:
  git checkout origin/master patches.rpmify/Add-ksym-provides-tool.patch
- commit b3af512
* Thu Feb 20 2020 kbuild@suse.de
- Automatically updated to 5.6-rc2-next-20200220
- commit 0e2968b
* Wed Feb 19 2020 msuchanek@suse.de
- Refresh patches.rpmify/Add-ksym-provides-tool.patch.
- commit 99be3e6
* Wed Feb 19 2020 kbuild@suse.de
- Automatically updated to 5.6-rc2-next-20200219
- commit a494f45
* Wed Feb 19 2020 jslaby@suse.cz
- Update config files (bnc#1161832).
  Disable CONFIG_MODULE_SIG on i386. We don't run pesign on i386 builds,
  hence the modules are not signed at all. This results in module
  verification failures and warnings.
  CONFIG_SECURITY_LOCKDOWN_LSM depends on (selects) CONFIG_MODULE_SIG, so
  we have to disable it too. But it makes no sense to lockdown without
  module signature anyway.
- commit e91686e
* Tue Feb 18 2020 kbuild@suse.de
- Automatically updated to 5.6-rc2-next-20200218
- commit ddfd6d3
* Mon Feb 17 2020 kbuild@suse.de
- Automatically updated to 5.6-rc2-next-20200217
- commit 77d0af4
* Mon Feb 17 2020 mkubecek@suse.cz
- Update to 5.6-rc2
- refresh configs (drop LIBXBC)
- commit 51803de
* Fri Feb 14 2020 kbuild@suse.de
- Automatically updated to 5.6-rc1-next-20200214
- commit 3a83bd1
* Thu Feb 13 2020 tiwai@suse.de
- Update config files: enable CONFIG_FW_CFG_SYSFS for arm64 (bsc#1163521)
- commit 84318f8
* Thu Feb 13 2020 kbuild@suse.de
- Automatically updated to 5.6-rc1-next-20200213
- commit 560ffa4
* Wed Feb 12 2020 kbuild@suse.de
- Automatically updated to 5.6-rc1-next-20200212
- commit 3a4adfa
* Wed Feb 12 2020 jdelvare@suse.de
- Update config files: CONFIG_NVME_HWMON=y
  When the config files were updated for kernel v5.5, the commit
  message claimed CONFIG_NVME_HWMON was to be enabled, however the
  configuration files themselves had the option disabled. We definitely
  want hardware monitoring enabled on NVME devices, so fix the
  configuration files to match the original intent.
- commit 2af25da
* Tue Feb 11 2020 afaerber@suse.com
- config: armv7hl: Update to 5.6-rc1
- commit 3295de2
* Tue Feb 11 2020 afaerber@suse.com
- config: armv6hl: Update to 5.6-rc1
- commit c95104d
* Tue Feb 11 2020 afaerber@suse.com
- config: arm64: Update to 5.6-rc1
- commit de36f7c
* Tue Feb 11 2020 kbuild@suse.de
- Automatically updated to 5.6-rc1-next-20200211
- commit ae98832
* Mon Feb 10 2020 kbuild@suse.de
- Automatically updated to 5.5-next-20200210
- commit 451a9fe
* Mon Feb 10 2020 mkubecek@suse.cz
- Update to 5.6-rc1
- eliminated 95 patches (70 stable, 25 other)
- disable ARM architectures (need config update)
- refresh
  - patches.rpmify/Add-ksym-provides-tool.patch
  - patches.suse/acpi_thermal_passive_blacklist.patch
- new config options :
  - General setup
  - TIME_NS=y
  - BOOT_CONFIG=y
  - Firmware Drivers
  - EFI_DISABLE_PCI_DMA=n
  - Networking core
  - INET_ESPINTCP=y
  - MPTCP=y
  - MPTCP_IPV6=y
  - MPTCP_HMAC_TEST=n
  - NET_DSA_TAG_AR9331=m
  - NET_SCH_FQ_PIE=m
  - NET_SCH_ETS=m
  - VSOCKETS_LOOPBACK=m
  - ETHTOOL_NETLINK=y
  - WIREGUARD=m
  - WIREGUARD_DEBUG=n
  - File systems
  - ZONEFS_FS=m
  - VBOXSF_FS=m
  - NFS_DISABLE_UDP_SUPPORT=n
  - NFSD_V4_2_INTER_SSC=y
  - Security options
  - SECURITY_SELINUX_SIDTAB_HASH_BITS=9
  - SECURITY_SELINUX_SID2STR_CACHE_SIZE=256
  - TEE=m
  - AMDTEE=m
  - Kernel hacking
  - PTDUMP_DEBUGFS=n
  - BOOTTIME_TRACING=y
  - SYNTH_EVENT_GEN_TEST=n
  - KPROBE_EVENT_GEN_TEST=n
  - Networking drivers
  - NET_DSA_AR9331=m
  - NET_DSA_VITESSE_VSC73XX_SPI=m
  - NET_DSA_VITESSE_VSC73XX_PLATFORM=m
  - PHY_INTEL_EMMC=m
  - Hardware Monitoring support
  - SENSORS_ADM1177=m
  - SENSORS_DRIVETEMP=m
  - SENSORS_MAX31730=m
  - SENSORS_MAX20730=m
  - SENSORS_XDPE122=m
  - Sound
  - SND_CTL_VALIDATION=n
  - SND_SOC_INTEL_USER_FRIENDLY_LONG_NAMES=n
  - SND_SOC_INTEL_BDW_RT5650_MACH=m
  - SND_SOC_INTEL_SOF_DA7219_MAX98373_MACH=m
  - SND_SOC_RT1308_SDW=n
  - SND_SOC_RT700_SDW=n
  - SND_SOC_RT711_SDW=n
  - SND_SOC_RT715_SDW=n
  - SND_SOC_WSA881X=n
  - SND_SOC_MT6660=n
  - Graphics
  - DRM_PANEL_BOE_HIMAX8279D=n
  - DRM_PANEL_LEADTEK_LTK500HD1829=n
  - DRM_PANEL_SONY_ACX424AKP=n
  - DRM_PANEL_XINPENG_XPP055C272=n
  - DRM_LVDS_CODEC=m
  - DRM_ANALOGIX_ANX6345=n
  - Industrial I/O support
  - BMA400=n
  - AD7091R5=n
  - LTC2496=n
  - DLHL60D=n
  - PING=n
  - USB
  - USB4_NET=m
  - USB4=m
  - Misc drivers
  - SERIAL_8250_16550A_VARIANTS=n
  - PINCTRL_LYNXPOINT=m
  - INTEL_IDXD=m
  - PLX_DMA=m
  - QCOM_CPR=m
  - REGULATOR_MP8859=m
  - MFD_ROHM_BD71828=n
  - MEDIA_CEC_RC=y
  - NVMEM_SPMI_SDAM=m
  - DMABUF_HEAPS=n
  - RESET_BRCMSTB_RESCAL=n
  - INTEL_IOMMU_SCALABLE_MODE_DEFAULT_ON=n
  - GPIO_SIFIVE=n
  - x86
  - INTEL_UNCORE_FREQ_CONTROL=m
  - i386
  - PCIE_INTEL_GW=n
  - CPU_FREQ_THERMAL=y
  - CPU_IDLE_THERMAL=y
  - MICROCHIP_PIT64B=y
  - RESET_INTEL_GW=n
  - powerpc
  - STRICT_KERNEL_RWX=y
  - CPU_FREQ_THERMAL=y
  - MICROCHIP_PIT64B=y
  - RESET_INTEL_GW=n
  - DEBUG_RODATA_TEST=n
  - QUICC_ENGINE=y
  - QE_GPIO=y
  - FSL_PQ_MDIO=m
  - FSL_XGMAC_MDIO=m
  - GIANFAR=m
  - SERIAL_QE=m
  - PTP_1588_CLOCK_QORIQ=m
  - USB_FHCI_HCD=m
  - FHCI_DEBUG=n
  - s390x
  - ZLIB_DFLTCC=y
  - KPROBE_EVENTS_ON_NOTRACE=n
- commit f9b57e6
* Fri Feb  7 2020 kbuild@suse.de
- Automatically updated to 5.5-next-20200207
- commit cc8cac5
* Thu Feb  6 2020 chrubis@suse.cz
- rpm/kernel-binary.spec.in: Replace Novell with SUSE
- commit 8719d69
* Thu Feb  6 2020 kbuild@suse.de
- Automatically updated to 5.5-next-20200206
- commit daa262b
* Wed Feb  5 2020 kbuild@suse.de
- Automatically updated to 5.5-next-20200205
- commit 9efbe26
* Tue Feb  4 2020 kbuild@suse.de
- Automatically updated to 5.5-next-20200204
- commit c0d9541
* Mon Feb  3 2020 kbuild@suse.de
- Automatically updated to 5.5-next-20200203
- commit 33f3001
* Fri Jan 31 2020 kbuild@suse.de
- Automatically updated to 5.5-next-20200131
- commit 516e7dc
* Fri Jan 31 2020 yousaf.kaukab@suse.com
- config: armv7lpae: Update to 5.5
- commit 62aa8dd
* Fri Jan 31 2020 yousaf.kaukab@suse.com
- config: armv7hl: Update to 5.5
- commit 61da310
* Fri Jan 31 2020 yousaf.kaukab@suse.com
- config: armv6hl: Update to 5.5
- commit 4c68e19
* Thu Jan 30 2020 kbuild@suse.de
- Automatically updated to 5.5-next-20200130
- commit a0228ed
* Wed Jan 29 2020 kbuild@suse.de
- Automatically updated to 5.5-next-20200129
- commit c9c7d66
* Tue Jan 28 2020 kbuild@suse.de
- Automatically updated to 5.5-next-20200128
- commit 7917df3
* Mon Jan 27 2020 jeyu@suse.de
- rpm/kabi.pl: support new (>=5.4) Module.symvers format (new symbol namespace field)
- commit eecbd97
* Mon Jan 27 2020 mkubecek@suse.cz
- Update to 5.5 final
- refresh configs
- commit 65a8a48
* Fri Jan 24 2020 kbuild@suse.de
- Automatically updated to 5.5-rc7-next-20200124
- commit c96b7c7
* Fri Jan 24 2020 mkubecek@suse.cz
- config: refresh
  Only update headers.
- commit b854979
* Thu Jan 23 2020 kbuild@suse.de
- Automatically updated to 5.5-rc7-next-20200123
- commit 112cd1c
* Wed Jan 22 2020 afaerber@suse.com
- config: arm64: Update to 5.5-rc7
- commit bbf3353
* Wed Jan 22 2020 kbuild@suse.de
- Automatically updated to 5.5-rc7-next-20200122
- commit 7360928
* Tue Jan 21 2020 tiwai@suse.de
- Update config files: Update config files: adjust Intel ASoC audio items (bsc#1161463)
  Adjust the Kconfigs for Intel ASoC SOF/SST drivers more appropriately.
  Disable unrecommended items:
  CONFIG_SND_SOC_INTEL_SKYLAKE_HDAUDIO_CODEC=n
  CONFIG_SND_SST_ATOM_HIFI2_PLATFORM_PCI=n
  CONFIG_SND_SOC_SOF_MERRIFIELD_SUPPORT=n
  CONFIG_SND_SOC_INTEL_BYT_CHT_NOCODEC_MACH=n
  Enable the other ones:
  CONFIG_SND_SOC_INTEL_SKL_RT286_MACH=m
  CONFIG_SND_SOC_INTEL_SKL_NAU88L25_SSM4567_MACH=m
  CONFIG_SND_SOC_INTEL_SKL_NAU88L25_MAX98357A_MACH=m
  CONFIG_SND_SOC_INTEL_BXT_DA7219_MAX98357A_MACH=m
  CONFIG_SND_SOC_INTEL_BXT_RT298_MACH=m
  CONFIG_SND_SOC_INTEL_GLK_DA7219_MAX98357A_MACH=m
  CONFIG_SND_SOC_INTEL_SOF_CML_RT1011_RT5682_MACH=m
- commit dc3a479
* Tue Jan 21 2020 kbuild@suse.de
- Automatically updated to 5.5-rc7-next-20200121
- commit a295964
* Mon Jan 20 2020 msuchanek@suse.de
- kernel-binary.spec.in: do not recommend firmware for kvmsmall and azure
  flavor (boo#1161360).
- commit dbe7b27
* Mon Jan 20 2020 msuchanek@suse.de
- config/x86_64/kvmsmall: Enable UINPUT (boo#1161305).
- commit d7cc336
* Mon Jan 20 2020 kbuild@suse.de
- Automatically updated to 5.5-rc6-next-20200120
- commit f8a74ce
* Fri Jan 17 2020 kbuild@suse.de
- Automatically updated to 5.5-rc6-next-20200117
- commit 6ed6e12
* Thu Jan 16 2020 kbuild@suse.de
- Automatically updated to 5.5-rc6-next-20200116
- commit 7032ebe
* Wed Jan 15 2020 kbuild@suse.de
- Automatically updated to 5.5-rc6-next-20200115
- commit e2a8824
* Tue Jan 14 2020 kbuild@suse.de
- Automatically updated to 5.5-rc6-next-20200114
- commit d8028d7
* Tue Jan 14 2020 tiwai@suse.de
- Update config files: enable forgotten configs for SOF (bsc#1160819)
  The configs have been forgotten to be enabled:
  CONFIG_SND_SOC_SOF_HDA_COMMON_HDMI_CODEC=y
  CONFIG_SND_SOC_SOF_JASPERLAKE_SUPPORT=y
  CONFIG_SND_SOC_SOF_JASPERLAKE=m
- commit a8fd8cd
* Mon Jan 13 2020 kbuild@suse.de
- Automatically updated to 5.5-rc5-next-20200113
- commit dc20f90
* Fri Jan 10 2020 kbuild@suse.de
- Automatically updated to 5.5-rc5-next-20200110
- commit dc4df33
* Thu Jan  9 2020 kbuild@suse.de
- Automatically updated to 5.5-rc5-next-20200109
- commit 9c67456
* Wed Jan  8 2020 kbuild@suse.de
- Automatically updated to 5.5-rc5-next-20200108
- commit dc891bd
* Wed Jan  8 2020 tiwai@suse.de
- rpm/kernel-docs.spec.in: pass PYTHON=python3 to fix build error (bsc#1160435)
- commit 09c08fb
* Wed Jan  8 2020 mkubecek@suse.cz
- config: fix pstore default compression options on 32-bit ARM
  Previous commit did not update arvm7hl and armv6hl configs properly and
  run_oldconfig.sh did not catch it as these architectures are disabled at
  the moment.
- commit aa00533
* Tue Jan  7 2020 msuchanek@suse.de
- Make lzo the default pstore compression method (bsc#1159986).
  Pstore has compression enabled, pstore is built-in, pstore default
  compression is deflate, deflate is modular -> pstore initialization
  fails on boot. Switch default compression to lzo which is built-in and
  the only built-in method on SLE15.
- commit 142e2b8
* Tue Jan  7 2020 kbuild@suse.de
- Automatically updated to 5.5-rc5-next-20200107
- commit 442e843
* Mon Jan  6 2020 kbuild@suse.de
- Automatically updated to 5.5-rc4-next-20200106
- commit b130f32
* Fri Jan  3 2020 jslaby@suse.cz
- Update config files.
  Turn off CONFIG_HARDENED_USERCOPY as it causes issues on s390
  (bnc#1156053). Until this gets resolved upstream...
- commit 75270d5
* Sun Dec 29 2019 mkubecek@suse.cz
- config: refresh
  Refresh with a new gcc version.
- commit 07c4d55
* Sat Dec 28 2019 mbrugger@suse.com
- arm64: Add Allwinner crypto modules to config
  Enabel SUN4I and SUN8I based HW crypto blocks.
- commit a7d3577
* Mon Dec 23 2019 mkubecek@suse.cz
- Update to 5.5-rc3
- refresh configs
- commit 3131f3d
* Fri Dec 20 2019 kbuild@suse.de
- Automatically updated to 5.5-rc2-next-20191220
- commit aeea840
* Thu Dec 19 2019 mkubecek@suse.cz
- rpm/kernel-subpackage-spec: fix kernel-default-base build
  There were some issues with recent changes to subpackage dependencies handling:
- a typo in %%kernel_base_conflicts macro name
- copy/pasted "Recommends:" instead of "Provides:", "Obsoletes:" and
  "Conflicts:
- missing escaping of backslashes in macro expansions
  Fixes: f3b74b0ae86b ("rpm/kernel-subpackage-spec: Unify dependency handling.")
  Fixes: 3fd22e219f77 ("rpm/kernel-subpackage-spec: Fix empty Recommends tag (bsc#1143959)")
- commit 762fd66
* Thu Dec 19 2019 kbuild@suse.de
- Automatically updated to 5.5-rc2-next-20191219
- commit 44baacc
* Wed Dec 18 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: Unify dependency handling.
- commit f3b74b0
* Wed Dec 18 2019 kbuild@suse.de
- Automatically updated to 5.5-rc2-next-20191218
- commit 7962636
* Tue Dec 17 2019 kbuild@suse.de
- Automatically updated to 5.5-rc2-next-20191217
- commit f049d29
* Mon Dec 16 2019 tiwai@suse.de
- rpm/kernel-subpackage-spec: Fix empty Recommends tag (bsc#1143959)
- commit 3fd22e2
* Mon Dec 16 2019 kbuild@suse.de
- Automatically updated to 5.5-rc2-next-20191216
- commit 2ad4ecb
* Mon Dec 16 2019 mkubecek@suse.cz
- Update to 5.5-rc2
- update configs
  - CRYPTO_BLAKE2B=m
- commit 124da7a
* Fri Dec 13 2019 kbuild@suse.de
- Automatically updated to 5.5-rc1-next-20191213
- commit f95c8ff
* Thu Dec 12 2019 kbuild@suse.de
- Automatically updated to 5.5-rc1-next-20191212
- commit f74594b
* Wed Dec 11 2019 kbuild@suse.de
- Automatically updated to 5.5-rc1-next-20191211
- commit c393313
* Tue Dec 10 2019 kbuild@suse.de
- Automatically updated to 5.5-rc1-next-20191210
- commit 9f67b96
* Mon Dec  9 2019 kbuild@suse.de
- Automatically updated to 5.5-rc1-next-20191209
- commit 18bff82
* Mon Dec  9 2019 mkubecek@suse.cz
- Update to 5.5-rc1
- eliminated 175 patches (114 stable, 61 other)
- ARM configs need update
- refresh
  patches.suse/0001-usb-Add-Xen-pvUSB-protocol-description.patch
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/linux-log2-h-add-roundup-rounddown_pow_two64-family-of-functions.patch
  patches.suse/setuid-dumpable-wrongdir
  patches.suse/supported-flag
  patches.suse/supported-flag-external
- new config options:
  - Processor type and features
  - X86_IOPL_IOPERM=y
  - X86_UMIP=y
  - Power management
  - BYTCRC_PMIC_OPREGION=y
  - CHTCRC_PMIC_OPREGION=y
  - Networking
  - TLS_TOE=n
  - TIPC_CRYPTO=y
  - NET_DSA_TAG_OCELOT=m
  - NFC_PN532_UART=m
  - Cryptographic API
  - CRYPTO_CURVE25519=m
  - CRYPTO_CURVE25519_X86=m
  - CRYPTO_BLAKE2B=m
  - CRYPTO_BLAKE2S=m
  - CRYPTO_BLAKE2S_X86=m
  - CRYPTO_LIB_BLAKE2S=m
  - CRYPTO_LIB_CHACHA=m
  - CRYPTO_LIB_CURVE25519=m
  - CRYPTO_LIB_POLY1305=m
  - CRYPTO_LIB_CHACHA20POLY1305=m
  - CRYPTO_DEV_AMLOGIC_GXL=m
  - Kernel hacking
  - SYMBOLIC_ERRNAME=y
  - TRACE_EVENT_INJECT=n
  - KUNIT=n
  - Kernel Testing and Coverage
  - HYPERV_TESTING=n
  - Networking drivers
  - CAIF_DRIVERS=y
  - NET_DSA_MSCC_FELIX=m
  - DP83869_PHY=m
  - Hardware Monitoring
  - SENSORS_LTC2947_I2C=m
  - SENSORS_LTC2947_SPI=m
  - SENSORS_BEL_PFE=m
  - SENSORS_TMP513=m
  - Multimedia
  - VIDEO_HI556=m
  - VIDEO_IMX290=m
  - Graphics
  - DRM_DEBUG_DP_MST_TOPOLOGY_REFS=n
  - DRM_AMD_DC_HDCP=y
  - DRM_I915_HEARTBEAT_INTERVAL=2500
  - DRM_I915_PREEMPT_TIMEOUT=640
  - DRM_I915_SPIN_REQUEST=5
  - DRM_I915_STOP_TIMEOUT=100
  - DRM_I915_TIMESLICE_DURATION=1
  - BACKLIGHT_QCOM_WLED=m
  - FB_TFT=n
  - Sound
  - SND_SOC_INTEL_GLK_DA7219_MAX98357A_MACH=m
  - SND_SOC_INTEL_SOF_CML_RT1011_RT5682_MACH=m
  - SND_SOC_SOF_DEVELOPER_SUPPORT=n
  - SND_SOC_SOF_JASPERLAKE_SUPPORT=y
  - SND_SOC_SOF_HDA_COMMON_HDMI_CODEC=y
  - SND_SOC_ADAU7118_HW=n
  - SND_SOC_ADAU7118_I2C=n
  - SND_SOC_TAS2562=n
  - SND_SOC_TAS2770=n
  - USB
  - TYPEC_HD3SS3220=m
  - Industrial I/O
  - AD7292=n
  - FXOS8700_I2C=n
  - FXOS8700_SPI=n
  - ADUX1020=n
  - VEML6030=n
  - LTC2983=n
  - Misc drivers
  - EFI_SOFT_RESERVE=y
  - FW_CACHE=y
  - TCG_TIS_SPI_CR50=y
  - PTP_1588_CLOCK_IDTCM=m
  - PINCTRL_TIGERLAKE=m
  - PINCTRL_EQUILIBRIUM=m
  - W1_SLAVE_DS2430=m
  - SF_PDMA=m
  - NVME_HWMON=y
  - WFX=m
  - SYSTEM76_ACPI=m
  - CROS_EC_SENSORHUB=m
  - DEV_DAX_HMEM=m
  - ppc64(le):
  - PPC_UV=n
  - */debug:
  - TRACE_EVENT_INJECT=y
  - x86_64/debug:
  - HYPERV_TESTING=y
- commit a5d00e2
* Sun Dec  8 2019 kbuild@suse.de
- Automatically updated to 5.4-next-20191208
- commit e0a5ea8
* Sat Dec  7 2019 kbuild@suse.de
- Automatically updated to 5.4-next-20191207
- commit 18e1693
* Thu Dec  5 2019 kbuild@suse.de
- Automatically updated to 5.4-next-20191205
- commit d14000a
* Wed Dec  4 2019 kbuild@suse.de
- Automatically updated to 5.4-next-20191204
- commit d6fe901
* Tue Dec  3 2019 mbrugger@suse.com
- arm64: Update config files.
  Bump CONFIG_NODES_SHIFT from 2 to 6
- commit f16437f
* Tue Dec  3 2019 tiwai@suse.de
- rpm/kernel-subpackage-spec: Exclude kernel-firmware recommends (bsc#1143959)
  For reducing the dependency on kernel-firmware in sub packages
- commit d950271
* Tue Dec  3 2019 kbuild@suse.de
- Automatically updated to 5.4-next-20191203
- commit a185ac6
* Mon Dec  2 2019 kbuild@suse.de
- Automatically updated to 5.4-next-20191202
- commit 8938d83
* Fri Nov 29 2019 msuchanek@suse.de
- Update config files.
  ppc64 is lats architecture without PRINTK_TIME. Align with the rest.
- commit 76ba844
* Fri Nov 29 2019 kbuild@suse.de
- Automatically updated to 5.4-next-20191129
- commit 7b4e490
* Fri Nov 29 2019 ptesarik@suse.cz
- Update config files (bsc#1158055 LTC#182629).
- commit 95e78c1
* Thu Nov 28 2019 kbuild@suse.de
- Automatically updated to 5.4-next-20191128
- commit df6facf
* Wed Nov 27 2019 nsaenzjulienne@suse.de
- PCI: brcmstb: add Broadcom STB PCIe host controller driver
  (jsc#SLE-7772).
- supported.conf: Add pcie-brcmstb
- Update config files: build pcie-brcmstb as module
- commit 2f2f236
* Wed Nov 27 2019 kbuild@suse.de
- Automatically updated to 5.4-next-20191127
- commit ad5982c
* Tue Nov 26 2019 kbuild@suse.de
- Automatically updated to 5.4-next-20191126
- commit be55b96
* Mon Nov 25 2019 kbuild@suse.de
- Automatically updated to 5.4-rc8-next-20191125
- commit 6e91921
* Mon Nov 25 2019 jslaby@suse.cz
- arm64: use both ZONE_DMA and ZONE_DMA32 (jsc#SLE-7772).
- Update config files.
  Config options taken from commit 4f2941cd44a2.
- commit 949f71d
* Mon Nov 25 2019 mkubecek@suse.cz
- Update to 5.4 final
- refresh configs (only update headers)
- commit ae2d5ec
* Sun Nov 24 2019 mkubecek@suse.cz
- config: disable SECURITY_DMESG_RESTRICT (bsc#1157066)
  Enabling this option which restricts access to dmesg was not intentional
  and happened accidentally as part of a commit aiming to enable features
  which were enabled in SLE. We might restrict dmesg in the future if there
  is a consensus but for now the proper action is to revert this accidental
  change which only affected some architectures anyway.
- commit 48ac954
* Fri Nov 22 2019 kbuild@suse.de
- Automatically updated to 5.4-rc8-next-20191122
- commit a0c23cb
* Thu Nov 21 2019 kbuild@suse.de
- Automatically updated to 5.4-rc8-next-20191121
- commit cac9404
* Wed Nov 20 2019 kbuild@suse.de
- Automatically updated to 5.4-rc8-next-20191120
- commit 8e97fe0
* Tue Nov 19 2019 kbuild@suse.de
- Automatically updated to 5.4-rc8-next-20191119
- commit fd451c0
* Mon Nov 18 2019 kbuild@suse.de
- Automatically updated to 5.4-rc7-next-20191118
- commit 33e7ea6
* Mon Nov 18 2019 mkubecek@suse.cz
- Update to 5.4-rc8
- refresh
  patches.suse/vfs-add-super_operations-get_inode_dev
- update configs
  - add X86_INTEL_TSX_MODE_OFF=y
  - drop VBOXSF_FS (driver dropped for now)
- commit b502560
* Fri Nov 15 2019 kbuild@suse.de
- Automatically updated to 5.4-rc7-next-20191115
- commit 25d6ae2
* Thu Nov 14 2019 kbuild@suse.de
- Automatically updated to 5.4-rc7-next-20191114
- commit 0bd97c3
* Thu Nov 14 2019 guillaume.gardet@arm.com
- arm64: Enable CONFIG_IR_GPIO_CIR (boo#1156748)
- commit 9444ed8
* Thu Nov 14 2019 mbrugger@suse.com
- arm64: Update config files.
  Enable HW_RANDOM_OMAP used by machiattobin (bsc#1156466).
- commit 4c47dca
* Wed Nov 13 2019 kbuild@suse.de
- Automatically updated to 5.4-rc7-next-20191113
- commit f5ce933
* Tue Nov 12 2019 kbuild@suse.de
- Automatically updated to 5.4-rc7-next-20191112
- commit 3aaa2e7
* Mon Nov 11 2019 kbuild@suse.de
- Automatically updated to 5.4-rc6-next-20191111
- commit 7795ab9
* Mon Nov 11 2019 mkubecek@suse.cz
- Update to 5.4-rc7
- eliminated 1 patch
- new config option
  - VBOXSF_FS=m (x86 only)
- commit 87c5dfd
* Fri Nov  8 2019 kbuild@suse.de
- Automatically updated to 5.4-rc6-next-20191108
- commit 9c8762c
* Thu Nov  7 2019 kbuild@suse.de
- Automatically updated to 5.4-rc6-next-20191107
- commit 9475a51
* Wed Nov  6 2019 tiwai@suse.de
- rpm/kernel-source.spec.in: Fix dependency of kernel-devel (bsc#1154043)
- commit ceb9273
* Wed Nov  6 2019 kbuild@suse.de
- Automatically updated to 5.4-rc6-next-20191106
- commit 682c667
* Wed Nov  6 2019 afaerber@suse.com
- config: armv7hl: Update to 5.4-rc6
- commit 1c2717b
* Wed Nov  6 2019 jslaby@suse.cz
- rpm/kernel-binary.spec.in: add COMPRESS_VMLINUX (bnc#1155921)
  Let COMPRESS_VMLINUX determine the compression used for vmlinux. By
  default (historically), it is gz.
- commit c8b2d9f
* Wed Nov  6 2019 mkubecek@suse.cz
- config: refresh armv6hl/vanilla
- commit b96ff57
* Tue Nov  5 2019 afaerber@suse.com
- config: armv6hl: Update to 5.4-rc6
- commit b69ea1c
* Tue Nov  5 2019 mbrugger@suse.com
- rpm/mkspec-dtb: add mt76 based dtb package
- commit 8ff92d0
* Tue Nov  5 2019 kbuild@suse.de
- Automatically updated to 5.4-rc6-next-20191105
- commit da5ec23
* Mon Nov  4 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: Mention debuginfo in the subpackage
  description (bsc#1149119).
- commit 525ec92
* Mon Nov  4 2019 mkubecek@suse.cz
- Update to 5.4-rc6
- eliminated 1 patch
- refresh configs
- commit 9d7d977
* Thu Oct 31 2019 kbuild@suse.de
- Automatically updated to 5.4-rc5-next-20191031
- commit 5f2591e
* Wed Oct 30 2019 kbuild@suse.de
- Automatically updated to 5.4-rc5-next-20191030
- commit 3cfa667
* Wed Oct 30 2019 mkubecek@suse.cz
- config: refresh also arm64/vanilla
- commit 659ccbd
* Wed Oct 30 2019 mkubecek@suse.cz
- config: refresh
- commit f65f57b
* Wed Oct 30 2019 afaerber@suse.de
- config: arm64: Update to 5.4-rc5
- commit a19c46f
* Tue Oct 29 2019 kbuild@suse.de
- Automatically updated to 5.4-rc5-next-20191029
- commit 1d11738
* Mon Oct 28 2019 kbuild@suse.de
- Automatically updated to 5.4-rc5-next-20191028
- commit 878a4f7
* Sun Oct 27 2019 mkubecek@suse.cz
- Update to 4.5-rc5
- New config option:
  - SND_SOC_SOF_HDA_ALWAYS_ENABLE_DMI_L1=n (x86 only)
- commit 3bb4d33
* Fri Oct 25 2019 kbuild@suse.de
- Automatically updated to 5.4-rc4-next-20191025
- commit 55867e3
* Thu Oct 24 2019 kbuild@suse.de
- Automatically updated to 5.4-rc4-next-20191024
- commit ef151a0
* Wed Oct 23 2019 kbuild@suse.de
- Automatically updated to 5.4-rc4-next-20191023
- commit 0eb312d
* Tue Oct 22 2019 kbuild@suse.de
- Automatically updated to 5.4-rc4-next-20191022
- commit 4cb830b
* Tue Oct 22 2019 msuchanek@suse.de
- kernel-binary.spec.in: Fix build of non-modular kernels (boo#1154578).
- commit 7f1e881
* Mon Oct 21 2019 msuchanek@suse.de
- kernel-binary.spec.in: Obsolete kgraft packages only when not building
  them.
- commit 25f7690
* Mon Oct 21 2019 msuchanek@suse.de
- kernel-subpackage-build: create zero size ghost for uncompressed vmlinux
  (bsc#1154354).
  It is not strictly necessary to uncompress it so maybe the ghost file
  can be 0 size in this case.
- commit 4bf73c8
* Mon Oct 21 2019 kbuild@suse.de
- Automatically updated to 5.4-rc4-next-20191021
- commit 5898c2f
* Fri Oct 18 2019 kbuild@suse.de
- Automatically updated to 5.4-rc3-next-20191018
- commit ff15e11
* Thu Oct 17 2019 kbuild@suse.de
- Automatically updated to 5.4-rc3-next-20191017
- commit 2faff3d
* Wed Oct 16 2019 kbuild@suse.de
- Automatically updated to 5.4-rc3-next-20191016
- commit 2eabed9
* Tue Oct 15 2019 jslaby@suse.cz
- Update config files.
  Disable CONFIG_RT_GROUP_SCHED again (bnc#950955 bnc#1153228).
- commit b410f27
* Tue Oct 15 2019 kbuild@suse.de
- Automatically updated to 5.4-rc3-next-20191015
- commit 472521f
* Mon Oct 14 2019 kbuild@suse.de
- Automatically updated to 5.4-rc2-next-20191014
- commit 3e583a9
* Mon Oct 14 2019 mkubecek@suse.cz
- Update to 5.4-rc3
- Refresh configs
- commit 3184b54
* Fri Oct 11 2019 kbuild@suse.de
- Automatically updated to 5.4-rc2-next-20191011
- commit 4fb2366
* Thu Oct 10 2019 kbuild@suse.de
- Automatically updated to 5.4-rc2-next-20191010
- commit 69522fd
* Wed Oct  9 2019 kbuild@suse.de
- Automatically updated to 5.4-rc2-next-20191009
- commit 65a1127
* Tue Oct  8 2019 kbuild@suse.de
- Automatically updated to 5.4-rc2-next-20191008
- commit a31a2cc
* Mon Oct  7 2019 mkubecek@suse.cz
- Update to 5.4-rc2
- Eliminated 2 patches
- Refresh config/i386/default
- commit 4894ee8
* Fri Oct  4 2019 kbuild@suse.de
- Automatically updated to 5.4-rc1-next-20191004
- commit 2dab622
* Fri Oct  4 2019 vbabka@suse.cz
- config: enable DEBUG_PAGEALLOC (jsc#PM-1168, bsc#1144653)
  Build with page allocation debugging (boot with debug_pagealloc=on to enable).
- commit 79e5533
* Thu Oct  3 2019 kbuild@suse.de
- Automatically updated to 5.4-rc1-next-20191003
- commit 2f4a47d
* Wed Oct  2 2019 kbuild@suse.de
- Automatically updated to 5.4-rc1-next-20191002
- commit d5dcd09
* Tue Oct  1 2019 mkubecek@suse.cz
- config: refresh vanilla configs
  Configs for vanilla flavor also need a refresh.
- commit c89f7ba
* Tue Oct  1 2019 mkubecek@suse.cz
- config: enable X86_5LEVEL (jsc#SLE-9308)
  Enable 5-level page tables (x86_64 architecture only).
- commit 967420f
* Tue Oct  1 2019 mkubecek@suse.cz
- Update to 5.4-rc1
- Eliminated 23 patches (22 stable, 1 other)
- ARM configs need update
- Refresh
  patches.rpmify/scripts-mkmakefile-honor-second-argument.patch
  patches.suse/Revert-netfilter-conntrack-remove-helper-hook-again.patch
  patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/supported-flag
  patches.suse/supported-flag-external
  patches.suse/vfs-add-super_operations-get_inode_dev
- fix 32-bit builds:
  patches.rpmify/mlx5-avoid-64-bit-division-in-dr_icm_pool_mr_create.patch
- New config options:
  - General setup
  - UCLAMP_TASK_GROUP=n
  - MODULE_ALLOW_MISSING_NAMESPACE_IMPORTS=n
  - Power management and ACPI options
  - CPU_IDLE_GOV_HALTPOLL=y
  - HALTPOLL_CPUIDLE=m
  - Block layer
  - BLK_CGROUP_IOCOST=y
  - DM_CLONE=m
  - DM_VERITY_VERIFY_ROOTHASH_SIG=n
  - Memory Management
  - READ_ONLY_THP_FOR_FS=y
  - Networking
  - NET_TC_SKB_EXT=y
  - CAN_J1939=m
  - CAN_KVASER_PCIEFD=m
  - CAN_M_CAN_PLATFORM=m
  - CAN_M_CAN_TCAN4X5X=m
  - CAN_F81601=m
  - NET_DSA_MICROCHIP_KSZ9477_I2C=m
  - NET_DSA_MICROCHIP_KSZ8795=m
  - NET_DSA_MICROCHIP_KSZ8795_SPI=m
  - NET_DSA_SJA1105_TAS=y
  - MLX5_SW_STEERING=y
  - NET_VENDOR_PENSANDO=y
  - IONIC=m
  - ADIN_PHY=m
  - ATH9K_PCI_NO_EEPROM=m
  - Power management
  - SENSORS_AS370=m
  - SENSORS_INSPUR_IPSPS=m
  - REGULATOR_SY8824X=m
  - Graphics
  - DRM_AMD_DC_DCN2_1=y
  - DRM_GM12U320=m
  - Sound
  - SND_HDA_INTEL_DETECT_DMIC=y
  - SND_SOC_INTEL_CML_LP_DA7219_MAX98357A_MACH=m
  - SND_SOC_SOF_TIGERLAKE_SUPPORT=y
  - SND_SOC_SOF_ELKHARTLAKE_SUPPORT=y
  - SND_SOC_UDA1334=n
  - SND_SOC_SOF_OF=m
  - USB
  - USB_CONN_GPIO=m
  - USB_CDNS3=m
  - USB_CDNS3_HOST=y
  - USB_CDNS3_PCI_WRAP=m
  - Platform support
  - CROS_EC=m
  - CROS_EC_CHARDEV=m
  - CROS_EC_LIGHTBAR=m
  - CROS_EC_DEBUGFS=m
  - CROS_EC_SYSFS=m
  - CROS_EC_VBC=m
  - Industrial I/O
  - ADIS16460=n
  - NOA1305=n
  - MAX5432=n
  - Misc drivers
  - EFI_RCI2_TABLE=n
  - MTD_NAND_MXIC=m
  - JOYSTICK_FSIA6B=m
  - REMOTEPROC=n
  - SERIAL_FSL_LINFLEXUART=m
  - MFD_CROS_EC_DEV=m
  - W1_MASTER_SGI=m
  - W1_SLAVE_DS250X=m
  - VIDEO_OV5675=m
  - HID_CREATIVE_SB0540=m
  - DMABUF_SELFTESTS=n
  - MOXTET=n
  - File systems
  - FS_VERITY=y
  - FS_VERITY_DEBUG=n
  - FS_VERITY_BUILTIN_SIGNATURES=n
  - VIRTIO_FS=m
  - EXFAT_FS=m
  - EXFAT_DONT_MOUNT_VFAT=y
  - EXFAT_DISCARD=y
  - EXFAT_DELAYED_SYNC=n
  - EXFAT_KERNEL_DEBUG=n
  - EXFAT_DEBUG_MSG=n
  - EXFAT_DEFAULT_CODEPAGE=437
  - EXFAT_DEFAULT_IOCHARSET="utf8"
  - Security
  - SECURITY_LOCKDOWN_LSM=y
  - SECURITY_LOCKDOWN_LSM_EARLY=y
  - LOCK_DOWN_KERNEL_FORCE_NONE=y
  - IMA_DEFAULT_HASH_SHA512=n
  - IMA_APPRAISE_MODSIG=y
  - RANDOM_TRUST_BOOTLOADER=y
  - KEXEC_SIG=y
  - KEXEC_SIG_FORCE=n
  - KEXEC_BZIMAGE_VERIFY_SIG=y
  - Cryptographic API
  - CRYPTO_ESSIV=m
  - CRYPTO_DEV_CCP_DEBUGFS=n
  - CRYPTO_DEV_SAFEXCEL=m
  - PowerPC
  - PPC_SVM=y
  - OPAL_CORE=n
  - S/390
  - CRYPTO_SHA3_256_S390=m
  - CRYPTO_SHA3_512_S390=m
- commit 48c71ae
* Tue Oct  1 2019 kbuild@suse.de
- Automatically updated to 5.4-rc1-next-20191001
- commit ea247d8
* Mon Sep 30 2019 kbuild@suse.de
- Automatically updated to 5.3-next-20190930
- commit cc5c07d
* Fri Sep 27 2019 kbuild@suse.de
- Automatically updated to 5.3-next-20190926
- commit 11e6a13
* Thu Sep 26 2019 kbuild@suse.de
- Automatically updated to 5.3-next-20190925
- commit c704867
* Wed Sep 25 2019 kbuild@suse.de
- Automatically updated to 5.3-next-20190924
- commit bcf242b
* Wed Sep 25 2019 fvogt@suse.com
- config: Enable dual-role modes for DWC on arm64 as well
- CONFIG_USB_DWC2_DUAL_ROLE=y and CONFIG_USB_DWC3_DUAL_ROLE=y
- Previously that was only enabled on armv6/armv7
- commit 2899106
* Tue Sep 24 2019 hare@suse.de
- Compile nvme.ko as module (bsc#1150846, bsc#1150850, bsc#1161889)
- commit bcb623e
* Sat Sep 21 2019 kbuild@suse.de
- Automatically updated to 5.3-next-20190920
- commit f2fac62
* Fri Sep 20 2019 kbuild@suse.de
- Automatically updated to 5.3-next-20190919
- commit 2836c08
* Thu Sep 19 2019 kbuild@suse.de
- Automatically updated to 5.3-next-20190918
- commit 28089ce
* Wed Sep 18 2019 jroedel@suse.de
- Update config files.
  Disable CONFIG_ARM_SMMU_DISABLE_BYPASS_BY_DEFAULT. Not all drivers are
  ready for this yet, so enabling this config option causes regressions.
  See bsc#1150577 for an example.
- commit bdd810c
* Wed Sep 18 2019 kbuild@suse.de
- Automatically updated to 5.3-next-20190917
- commit bda6086
* Tue Sep 17 2019 kbuild@suse.de
- Automatically updated to 5.3-next-20190916
- commit 02ce23c
* Mon Sep 16 2019 kbuild@suse.de
- Automatically updated to 5.3-rc8-next-20190915
- commit ab07f73
* Mon Sep 16 2019 mkubecek@suse.cz
- Update to 5.3 final
- Eliminated 3 patches
- Refresh configs
  - NF_CONNTRACK_SLP is gone
- commit 0ddb5d4
* Mon Sep  9 2019 mgorman@suse.de
- config: enable SLAB_FREELIST_HARDENED (bsc#1127808)
  Enable SLAB_FREELIST_HARDENED on all architectures. This obscures the
  free object pointer on a per-cache basis making it more difficult to
  locate kernel objects via exploits probing the cache metadata.
  This change was requested by the upstream openSUSE community to make
  the kernel more resistent to slab freelist attacks. Tests conducted
  by the kernel performance teams confirmed that the performance impact
  is detectable but negligible.
- commit b89c877
* Mon Sep  9 2019 guillaume.gardet@arm.com
- rpm/constraints.in: lower disk space required for ARM
  With a requirement of 35GB, only 2 slow workers are usable for ARM.
  Current aarch64 build requires 27G and armv6/7 requires 14G.
  Set requirements respectively to 30GB and 20GB.
- commit f84c163
* Mon Sep  9 2019 mkubecek@suse.cz
- Update to 5.3-rc8
- refresh armv6hl configs (IXP4xx drivers no longer visible)
- commit 63641d2
* Mon Sep  9 2019 mkubecek@suse.cz
- config: enable STACKPROTECTOR_STRONG also on armv6hl
  Recently reenabled armv6hl architecture has STACKPROTECTOR_STRONG disabled,
  enable it here as well.
- commit 2e57a6a
* Thu Sep  5 2019 kbuild@suse.de
- Automatically updated to 5.3-rc7-next-20190904
- commit 0d79e73
* Wed Sep  4 2019 kbuild@suse.de
- Automatically updated to 5.3-rc7-next-20190903
- commit 45103a5
* Tue Sep  3 2019 mkubecek@suse.cz
- config: enable STACKPROTECTOR_STRONG (jsc#SLE-9120 bsc#1130365)
  Enable CONFIG_STACKPROTECTOR_STRONG on all architectures except s390x
  (where the feature is not available). This extends the number of functions
  which are protected by "stack canary" check to catch functions writing past
  their stack frame.
  This change was requested by SUSE security to make our kernels more
  resistant to some types of stack overflow attacks. Tests performed by
  kernel performance teams confirmed that performance impact is acceptable.
- commit 3203ee1
* Tue Sep  3 2019 kbuild@suse.de
- Automatically updated to 5.3-rc6-next-20190902
- commit e1e663d
* Mon Sep  2 2019 mkubecek@suse.cz
- Update to 5.3-rc7
- Refresh configs
  - IXP4xx SoC drivers not visible
  - gcc 9.2.1
- commit e03f2af
* Sun Sep  1 2019 mkubecek@suse.cz
- config: armv7hl: Enable cadence watchdog
  CONFIG_CADENCE_WATCHDOG is required for Zynq-7000 based MIYR Zturn board.
- commit e5dd4da
* Fri Aug 30 2019 msuchanek@suse.de
- Automatically updated to 5.3-rc6-next-20190830
- commit 1f96171
* Fri Aug 30 2019 kbuild@suse.de
- Automatically updated to 5.3-rc6-next-20190829
- commit e4d5a7c
* Fri Aug 30 2019 dmueller@suse.com
- config.conf: Update ARMv6 config files
- commit 882ad6f
* Fri Aug 30 2019 dmueller@suse.com
- config.conf: Reenable ARMv7 config for Kernel 5.3
  All modules plus errata's enabled. Reused other
  values from x86_64 update.
- commit 384649e
* Wed Aug 28 2019 kbuild@suse.de
- Automatically updated to 5.3-rc6-next-20190828
- commit 40e6c2b
* Tue Aug 27 2019 mkubecek@suse.cz
- rpm: raise required disk space for binary packages
  Current disk space constraints (10 GB on s390x, 25 GB on other
  architectures) no longer suffice for 5.3 kernel builds. The statistics
  show ~30 GB of disk consumption on x86_64 and ~11 GB on s390x so raise
  the constraints to 35 GB in general and 14 GB on s390x.
- commit 527cb66
* Tue Aug 27 2019 kbuild@suse.de
- Automatically updated to 5.3-rc6-next-20190827
- commit b61a85c
* Mon Aug 26 2019 jgross@suse.com
- usb: Introduce Xen pvUSB frontend (xen hcd) (fate#315712).
- Update config files.
- commit 1bb219e
* Fri Aug 23 2019 kbuild@suse.de
- Automatically updated to 5.3-rc5-next-20190823
- commit 4844084
* Fri Aug 23 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Fix kernel-livepatch description typo.
- commit 36acf91
* Thu Aug 22 2019 msuchanek@suse.de
- Pull packaging cleanup from mkubecek.
- Parametrize kgraft vs livepatch.
- commit 16f6816
* Thu Aug 22 2019 mkubecek@suse.cz
- config: update from SLE15-SP2
  In general, we want features and drivers from SLE also in openSUSE unless
  we have a good reason not to. Enable most config options which were
  disabled in master but enabled in SLE15-SP2 (inherited from SLE15-SP1).
- commit a55e44c
* Thu Aug 22 2019 kbuild@suse.de
- Automatically updated to 5.3-rc5-next-20190822
- commit f2c85fb
* Wed Aug 21 2019 msuchanek@suse.de
- Refresh config files from master (boo#1146719).
- Refresh config files form master (boo#1146719).
- commit 803f2c8
* Wed Aug 21 2019 msuchanek@suse.de
- Refresh patches.rpmify/powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch.
- Refresh patches.rpmify/scripts-mkmakefile-honor-second-argument.patch.
- commit bcb09b7
* Wed Aug 21 2019 msuchanek@suse.de
- series.conf: cleanup
  Unify patches.rpmify section with master.
- commit 5f3d520
* Wed Aug 21 2019 kbuild@suse.de
- Automatically updated to 5.3-rc5-next-20190821
- commit 4dde031
* Tue Aug 20 2019 kbuild@suse.de
- Automatically updated to 5.3-rc5-next-20190820
- commit ea7e725
* Mon Aug 19 2019 bp@suse.de
- Update config files.
  As per https://jira.suse.com/browse/SLE-7041
  Factory first!
- commit 9c2225f
* Mon Aug 19 2019 kbuild@suse.de
- Automatically updated to 5.3-rc5-next-20190819
- commit a557b82
* Mon Aug 19 2019 mkubecek@suse.cz
- Update to 5.3-rc5
- Refresh configs
  - RDMA_SIW available on i386 (=m)
  - clean up unavailable options
- commit 5eb4f91
* Sun Aug 18 2019 afaerber@suse.de
- config: arm64: Enable I2C_IMX (boo#1146026)
  Needed for Google Coral board.
- commit 3744094
* Sat Aug 17 2019 kbuild@suse.de
- Automatically updated to 5.3-rc4-next-20190816
- commit c306ad8
* Thu Aug 15 2019 kbuild@suse.de
- Automatically updated to 5.3-rc4-next-20190814
- commit d706b74
* Tue Aug 13 2019 kbuild@suse.de
- Automatically updated to 5.3-rc4-next-20190813
- commit 09cfbaf
* Mon Aug 12 2019 msuchanek@suse.de
- rpm/mkspec: Correct tarball URL for rc kernels.
- commit c4ef18d
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/config.sh: Enable building DTBs.
- commit bbd68b0
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/mkspec: Make building DTBs optional.
- commit 7c057c8
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/modflist: Simplify compression support.
- commit fd135a6
* Fri Aug  9 2019 mkubecek@suse.cz
- rpm: support compressed modules
  Some of our scripts and scriptlets in rpm/ do not expect module files not
  ending with ".ko" which currently leads to failure in preuninstall
  scriptlet of cluster-md-kmp-default (and probably also other subpackages).
  Let those which could be run on compressed module files recognize ".ko.xz"
  in addition to ".ko".
- commit 18fcdff
* Fri Aug  9 2019 kbuild@suse.de
- Automatically updated to 5.3-rc3-next-20190809
- commit ff27f24
* Thu Aug  8 2019 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: add dm-crypt for building with cryptsetup
  Co-Authored-By: Adam Spiers <aspiers@suse.com>
- commit 7cf5b9e
* Thu Aug  8 2019 kbuild@suse.de
- Automatically updated to 5.3-rc3-next-20190808
- commit 0f00fd8
* Wed Aug  7 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: support partial rt debug config.
- commit af37821
* Wed Aug  7 2019 afaerber@suse.de
- config: arm64: Update to 5.3-rc3
- commit ec528df
* Wed Aug  7 2019 afaerber@suse.de
- config: Enable SENSORS_GPIO_FAN for all of Arm (boo#1144723)
  We already had it for armv6hl but were lacking it on arm64.
  Add it on armv7hl for consistency while at it.
- commit 49642fc
* Wed Aug  7 2019 kbuild@suse.de
- Automatically updated to 5.3-rc3-next-20190807
- commit 983cde3
* Tue Aug  6 2019 kbuild@suse.de
- Automatically updated to 5.3-rc3-next-20190806
- commit 469d25c
* Mon Aug  5 2019 kbuild@suse.de
- Automatically updated to 5.3-rc2-next-20190805
- commit 038cab7
* Mon Aug  5 2019 mkubecek@suse.cz
- Update to 5.3-rc3
- Eliminated 1 patch
- Refresh
  - patches.suse/supported-flag
  - patches.suse/supported-flag-external
- Refresh configs
- commit 4a5de53
* Fri Aug  2 2019 kbuild@suse.de
- Automatically updated to 5.3-rc2-next-20190802
- commit 36b1833
* Fri Aug  2 2019 bwiedemann@suse.de
- kernel-binary: Drop .kernel-binary.spec.buildenv (boo#1154578).
  Without this patch,
  /usr/src/linux-@VERSION@-@RELEASE_SHORT@-obj/x86_64/vanilla/.kernel-binary.spec.buildenv
  contained rpm %%_smp_mflags in a line like
  export MAKE_ARGS=" --output-sync -j4"
  This made it hard to produce bit-identical builds.
- commit 789d131
* Thu Aug  1 2019 kbuild@suse.de
- Automatically updated to 5.3-rc2-next-20190801
- commit 3193dcd
* Thu Aug  1 2019 mkubecek@suse.cz
- config: refresh x86_64/default
  With HBMC_AM654 disabled, nothing selects MULTIPLEXER any more.
- commit 164710d
* Wed Jul 31 2019 kbuild@suse.de
- Automatically updated to 5.3-rc2-next-20190731
- commit ff21586
* Wed Jul 31 2019 jdelvare@suse.de
- Update config files: CONFIG_HBMC_AM654=n
  The TI AM654 is an ARM64 SoC, so disable the driver on all other
  architectures.
- commit 8199147
* Tue Jul 30 2019 schwab@suse.de
- packaging: add support for riscv64
- commit c2885ea
* Tue Jul 30 2019 kbuild@suse.de
- Automatically updated to 5.3-rc2-next-20190730
- commit 1c2e26f
* Mon Jul 29 2019 kbuild@suse.de
- Automatically updated to 5.3-rc2-next-20190729
- commit 9d24e28
* Sun Jul 28 2019 mkubecek@suse.cz
- Update to 5.3-rc2
- Eliminated 1 patch
  - patches.suse/dma-mapping-use-dma_get_mask-in-dma_addressing_limit.patch
- Refresh
  - patches.suse/netfilter-ip_conntrack_slp.patch
- Config changes
  - NF_TABLES_BRIDGE=m (was =y)
- commit 932dec1
* Sat Jul 27 2019 msuchanek@suse.de
- rpm/macros.kernel-source: KMPs should depend on kmod-compat to build.
  kmod-compat links are used in find-provides.ksyms, find-requires.ksyms,
  and find-supplements.ksyms in rpm-config-SUSE.
- commit f97ca49
* Sat Jul 27 2019 msuchanek@suse.de
- scripts/run_oldconfig.sh: Fix update-vanilla
  When CC is set we want to use it for native only. Cross-compilation
  still needs the crosscompilers.
- commit 3b9fcdb
* Sat Jul 27 2019 msuchanek@suse.de
- Update config files.
- commit 2f51d21
* Fri Jul 26 2019 kbuild@suse.de
- Automatically updated to 5.3-rc1-next-20190726
- commit e26ced2
* Thu Jul 25 2019 kbuild@suse.de
- Automatically updated to 5.3-rc1-next-20190725
- commit 739f17e
* Wed Jul 24 2019 msuchanek@suse.de
- Update config files.
- commit b2d4a0c
* Wed Jul 24 2019 msuchanek@suse.de
- scripts/arch-symbols: add missing link.
- commit ee7c635
* Wed Jul 24 2019 kbuild@suse.de
- Automatically updated to 5.3-rc1-next-20190724
- commit 8b5c5f1
* Tue Jul 23 2019 tiwai@suse.de
- rpm/config.sh: enable kernel module compression (bsc#1135854)
- commit 3e8ca55
* Tue Jul 23 2019 tiwai@suse.de
- Add kernel module compression support (bsc#1135854)
  For enabling the kernel module compress, add the item COMPRESS_MODULES="xz"
  in config.sh, then mkspec will pass it to the spec file.
- commit cdf5806
* Tue Jul 23 2019 msuchanek@suse.de
- Kconfig: make CONFIG_CC_CAN_LINK always true (bsc#1127188).
- commit 54d8ddd
* Tue Jul 23 2019 msuchanek@suse.de
- config.conf: Add ppc64 kvmsmall config (bsc#1137361).
- Remove superfluous i2c drivers from ppc64 config
  - CONFIG_I2C_ALGOPCA=m
  - CONFIG_I2C_AMD8111=m
  - CONFIG_I2C_CBUS_GPIO=m
  - CONFIG_I2C_DESIGNWARE_CORE=y
  - CONFIG_I2C_DESIGNWARE_PLATFORM=y
  - CONFIG_I2C_DESIGNWARE_PCI=m
  - CONFIG_I2C_OCORES=m
  - CONFIG_I2C_PCA_PLATFORM=m
  Can't get rid of i2c in kvmsmall anyway but at least the DW i2c is gone.
- commit ff138b1
* Tue Jul 23 2019 kbuild@suse.de
- Automatically updated to 5.3-rc1-next-20190723
- commit 52f419d
* Tue Jul 23 2019 jeffm@suse.com
- config: enable PPPoE for kvmsmall (bsc#1133945).
- commit 4f6f564
* Mon Jul 22 2019 jeffm@suse.com
- config: remove unnecessary drivers from kvmsmall
  The initial merge was incomplete and needed revisiting, which didn't really
  happen.  Since then, new options have been added and not removed from
  kvmsmall, leading to grow in size.
  This commit uses the following blacklist:
  _(BT|CHARGER|CHROMEOS|CROS|DVB|DW|EDAC|FPGA|GPIO|GNSS|HID|INFINIBAND|IR|JOYSTICK|LEDS|MFD|PINCTRL|REGULATOR|RTC|SENSORS|SND_SOC|STAGING|TOUCHSCREEN|VIDEO|XEN|XILINX)[_=]
  ... along with some manual removal of NET_VENDORs with no relevant drivers.
- commit 5387d4c
* Mon Jul 22 2019 mkubecek@suse.cz
- rpm/klp-symbols: update to work with kernel >= 5.3
  Since mainline commit b7dca6dd1e59 ("kbuild: create *.mod with full
  directory path and remove MODVERDIR") in v5.3-rc1, *.mod files are created
  in the build tree rather than in a single directory .tmp_versions
  ($MODVERDIR). They also do not provide path to the *.ko module file on
  their first line as the path is the same (except for the suffix).
  Update klp-symbols script to handle this new layout and format of *.mod
  files to fix build of 5.3-rc1 and newer kernel.
  Note: this is a quick band-aid to fix master branch build without risk of
  breaking any other branch. A more proper cleanup will follow.
- commit c32f8e7
* Mon Jul 22 2019 mkubecek@suse.cz
- Update to 5.3-rc1
- Eliminated 89 patches (83 stable, 6 other)
- ARM configs need update
- Refresh
  patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/netfilter-ip_conntrack_slp.patch
  patches.suse/rpm-kernel-config
  patches.suse/supported-flag
  patches.suse/vfs-add-super_operations-get_inode_dev
- replace patches.rpmify/BPF-UMH-do-not-detect-if-compiler-can-link-userspace.patch
  with patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch
- New config options:
  - General setup
  - HEADER_TEST=y
  - KERNEL_HEADER_TEST=y
  - PREEMPT_LL=n
  - UCLAMP_TASK=y
  - UCLAMP_BUCKETS_COUNT=5
  - Processor type and features
  - ACRN_GUEST=y
  - LEGACY_VSYSCALL_XONLY=y
  - IO Schedulers
  - BFQ_CGROUP_DEBUG=n (=y in */debug)
  - Networking
  - NFT_SYNPROXY=m
  - NFT_BRIDGE_META=m
  - NF_CONNTRACK_BRIDGE=m
  - NET_ACT_MPLS=m
  - NET_ACT_CTINFO=m
  - NET_ACT_CT=m
  - BT_HCIBTUSB_MTK=y
  - GVE=m
  - MLX5_FPGA_IPSEC=y
  - MLX5_FPGA_TLS=y
  - MLX5_TLS=y
  - STMMAC_SELFTESTS=n
  - XILINX_AXI_EMAC=m
  - SFP=m
  - NXP_TJA11XX_PHY=m
  - PHY_MIXEL_MIPI_DPHY=m
  - File systems
  - UBIFS_FS_ZSTD=y
  - SUNRPC_DISABLE_INSECURE_ENCTYPES=n
  - CEPH_FS_SECURITY_LABEL=y
  - Generic driver options
  - FW_LOADER_COMPRESS=y
  - Storage
  - SCSI_FDOMAIN_PCI=m
  - SCSI_FDOMAIN_ISA=n
  - PCMCIA_FDOMAIN=n
  - Input
  - KEYBOARD_APPLESPI=m
  - Power supply and hardware monitoring
  - POWER_SUPPLY_HWMON=y
  - CHARGER_WILCO=m
  - SENSORS_IRPS5401=m
  - SENSORS_PXE1610=m
  - REGULATOR_ARIZONA_LDO1=m
  - REGULATOR_ARIZONA_MICSUPP=m
  - REGULATOR_SLG51000=m
  - Multimedia
  - DVB_USB_CXUSB_ANALOG=y
  - VIDEO_TDA1997X=m
  - VIDEO_TLV320AIC23B=m
  - VIDEO_ADV7180=m
  - VIDEO_ADV7183=m
  - VIDEO_ADV7604=m
  - VIDEO_ADV7604_CEC=y
  - VIDEO_ADV7842=m
  - VIDEO_ADV7842_CEC=y
  - VIDEO_BT819=m
  - VIDEO_BT856=m
  - VIDEO_BT866=m
  - VIDEO_KS0127=m
  - VIDEO_ML86V7667=m
  - VIDEO_SAA7110=m
  - VIDEO_TC358743=m
  - VIDEO_TC358743_CEC=y
  - VIDEO_TVP514X=m
  - VIDEO_TVP7002=m
  - VIDEO_TW9910=m
  - VIDEO_VPX3220=m
  - VIDEO_SAA7185=m
  - VIDEO_ADV7170=m
  - VIDEO_ADV7175=m
  - VIDEO_ADV7343=m
  - VIDEO_ADV7393=m
  - VIDEO_ADV7511=m
  - VIDEO_ADV7511_CEC=y
  - VIDEO_AD9389B=m
  - VIDEO_AK881X=m
  - VIDEO_THS8200=m
  - VIDEO_IMX214=m
  - VIDEO_IMX258=m
  - VIDEO_IMX274=m
  - VIDEO_IMX319=m
  - VIDEO_IMX355=m
  - VIDEO_OV2659=m
  - VIDEO_OV2680=m
  - VIDEO_OV2685=m
  - VIDEO_OV5647=m
  - VIDEO_OV6650=m
  - VIDEO_OV5670=m
  - VIDEO_OV5695=m
  - VIDEO_OV7251=m
  - VIDEO_OV772X=m
  - VIDEO_OV7740=m
  - VIDEO_OV8856=m
  - VIDEO_OV9640=m
  - VIDEO_OV9650=m
  - VIDEO_OV13858=m
  - VIDEO_VS6624=m
  - VIDEO_MT9M001=m
  - VIDEO_MT9M032=m
  - VIDEO_MT9M111=m
  - VIDEO_MT9P031=m
  - VIDEO_MT9T001=m
  - VIDEO_MT9T112=m
  - VIDEO_MT9V032=m
  - VIDEO_MT9V111=m
  - VIDEO_SR030PC30=m
  - VIDEO_NOON010PC30=m
  - VIDEO_M5MOLS=m
  - VIDEO_RJ54N1=m
  - VIDEO_S5K6AA=m
  - VIDEO_S5K6A3=m
  - VIDEO_S5K4ECGX=m
  - VIDEO_S5K5BAF=m
  - VIDEO_SMIAPP=m
  - VIDEO_ET8EK8=m
  - VIDEO_S5C73M3=m
  - VIDEO_AD5820=m
  - VIDEO_AK7375=m
  - VIDEO_DW9714=m
  - VIDEO_DW9807_VCM=m
  - VIDEO_ADP1653=m
  - VIDEO_LM3560=m
  - VIDEO_LM3646=m
  - SDR_MAX2175=m
  - VIDEO_THS7303=m
  - VIDEO_I2C=m
  - VIDEO_ST_MIPID02=n
  - VIDEO_GS1662=m
  - DVB_S5H1432=m
  - DVB_DIB9000=m
  - DVB_CXD2880=m
  - DVB_MN88443X=m
  - DVB_LNBH29=m
  - DVB_LGS8GL5=m
  - Graphics
  - DRM_AMD_DC_DCN2_0=y
  - DRM_AMD_DC_DSC_SUPPORT=y
  - DRM_I915_FORCE_PROBE=""
  - DRM_I915_DEBUG_MMIO=n
  - DRM_I915_USERFAULT_AUTOSUSPEND=250
  - DRM_I915_SPIN_REQUEST=5
  - DRM_PANEL_OSD_OSD101T2587_53TS=m
  - DRM_PANEL_SAMSUNG_S6E63M0=m
  - Sound
  - SND_SOC_INTEL_CML_H=m
  - SND_SOC_INTEL_CML_LP=m
  - SND_SOC_INTEL_BYT_CHT_CX2072X_MACH=m
  - SND_SOC_SOF_COMETLAKE_LP_SUPPORT=y
  - SND_SOC_SOF_COMETLAKE_H_SUPPORT=y
  - SND_SOC_CX2072X=m
  - InfiniBand
  - RDMA_SIW=m
  - Platform specific drivers
  - XIAOMI_WMI=m
  - ACPI_CMPC=m
  - SAMSUNG_Q10=m
  - INTEL_SPEED_SELECT_INTERFACE=m
  - CROS_EC_ISHTP=m
  - WILCO_EC_EVENTS=m
  - WILCO_EC_TELEMETRY=m
  - Industrial I/O
  - XILINX_XADC=n
  - ADF4371=n
  - DPS310=n
  - LEDs
  - LEDS_SPI_BYTE=m
  - LEDS_TI_LMU_COMMON=m
  - LEDS_LM3697=m
  - LEDS_LM36274=m
  - Other drivers
  - MTD_HYPERBUS=m
  - HBMC_AM654=m
  - XILINX_SDFEC=n
  - GPIO_XILINX=m
  - WATCHDOG_OPEN_TIMEOUT=0
  - MFD_CS47L15=y
  - MFD_CS47L92=y
  - MFD_ROHM_BD70528=n
  - RTC_DRV_BD70528=m
  - DW_EDMA=m
  - DW_EDMA_PCIE=m
  - COMMON_CLK_SI5341=m
  - EXTCON_FSA9480=m
  - NTB_MSI=y
  - NTB_MSI_TEST=n
  - RAS_CEC_DEBUG=n
  - AL_FIC=n
  - Virtualization
  - VIRTIO_PMEM=m
  - Security options
  - KEYS_REQUEST_CACHE=y
  - Kernel hardening options
  - INIT_ON_ALLOC_DEFAULT_ON=n
  - INIT_ON_FREE_DEFAULT_ON=n
  - Cryptographic API
  - CRYPTO_XXHASH=n
  - CRYPTO_DEV_ATMEL_ECC=m
  - CRYPTO_DEV_ATMEL_SHA204A=m
  - Kernel hacking
  - HEADERS_INSTALL=n
  - REED_SOLOMON_TEST=n
  - TEST_BLACKHOLE_DEV=n
  - TEST_MEMINIT=n
- commit 17d90dd
* Mon Jul 22 2019 kbuild@suse.de
- Automatically updated to 5.3-rc1-next-20190722
- commit 4dc8ea9
* Fri Jul 19 2019 kbuild@suse.de
- Automatically updated to 5.2-next-20190719
- commit 52035aa
* Thu Jul 18 2019 kbuild@suse.de
- Automatically updated to 5.2-next-20190718
- commit 469421c
* Wed Jul 17 2019 kbuild@suse.de
- Automatically updated to 5.2-next-20190717
- commit ef08445
* Tue Jul 16 2019 lpechacek@suse.com
- rpm/kernel-binary.spec.in: build kernel-*-kgraft only for default SLE kernel
  RT and Azure variants are excluded for the moment. (bsc#1141600)
- commit 620816f
* Tue Jul 16 2019 kbuild@suse.de
- Automatically updated to 5.2-next-20190716
- commit 3c5f471
* Mon Jul 15 2019 kbuild@suse.de
- Automatically updated to 5.2-next-20190715
- commit 03a14a4
* Fri Jul 12 2019 kbuild@suse.de
- Automatically updated to 5.2-next-20190712
- commit 8f6d62c
* Thu Jul 11 2019 kbuild@suse.de
- Automatically updated to 5.2-next-20190711
- commit 46c6017
* Wed Jul 10 2019 kbuild@suse.de
- Automatically updated to 5.2-next-20190709
- commit 803d5fb
* Wed Jul 10 2019 jslaby@suse.cz
- rpm/kernel-binary.spec.in: handle modules.builtin.modinfo
  It was added in 5.2.
- commit eb88df3
* Tue Jul  9 2019 rgoldwyn@suse.com
- Disable CONFIG_OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW in config (bsc#1140494)
- commit 50afa5a
* Tue Jul  9 2019 jslaby@suse.cz
- scripts/guards: add link to rpm/guards
  Every other branch has the link and we don't. This breaks build here.
- commit 8a376b4
* Tue Jul  9 2019 kbuild@suse.de
- Automatically updated to 5.2-next-20190708
- commit 2a76a3c
* Mon Jul  8 2019 mkubecek@suse.cz
- Update to 5.2 final
- Eliminated 1 patch
- commit 0672f8e
* Sat Jul  6 2019 kbuild@suse.de
- Automatically updated to 5.2-rc7-next-20190705
- commit b072e6b
* Fri Jul  5 2019 tiwai@suse.de
- config: align CONFIG_PHYSICAL_START and CONFIG_PHYSICAL_ALIGN to default values
  As suggested in bsc#1067593, our kconfig keeps the old default values
  while the upstream took different (actually swapped) values for x86
  CONFIG_PHYSICAL_START and CONFIG_PHYSICAL_ALIGN.   Let's follow the
  upstream default now.
- commit ed6b564
* Fri Jul  5 2019 kbuild@suse.de
- Automatically updated to 5.2-rc7-next-20190704
- commit 105e9c1
* Thu Jul  4 2019 kbuild@suse.de
- Automatically updated to 5.2-rc7-next-20190703
- commit 06eeb6a
* Wed Jul  3 2019 schwab@suse.de
- rpm/dtb.spec.in.in: don't make dtb directory inaccessible
  There is no reason to lock down the dtb directory for ordinary users.
- commit a69437a
* Wed Jul  3 2019 jslaby@suse.cz
- Update config files.
  Set CONFIG_SCSI_SCAN_ASYNC=y (bnc#1137686).
- commit 22fd19c
* Wed Jul  3 2019 mkubecek@suse.cz
- config: switch to SLUB allocator (Jira:PM-1158)
- new config options:
  - SLUB=y
  - SLUB_DEBUG=y
  - SLUB_MEMCG_SYSFS_ON=y
  - SLAB_FREELIST_HARDENED=n
  - SLUB_CPU_PARTIAL=y
  - SLUB_DEBUG_ON=n
  - SLUB_STATS=n
- commit cc6c195
* Tue Jul  2 2019 kbuild@suse.de
- Automatically updated to 5.2-rc7-next-20190702
- commit 8522950
* Sun Jun 30 2019 mkubecek@suse.cz
- Update to 5.2-rc7
- Refresh configs
- commit f87ce86
* Sun Jun 30 2019 msuchanek@suse.de
- Delete patches.rpmify/BPF-UMH-do-not-detect-if-compiler-can-link-userspace.patch.
  Obsoleted by the gcc9 cross-compilers with libc.
- commit 60b7ba2
* Sat Jun 29 2019 kbuild@suse.de
- Automatically updated to 5.2-rc6-next-20190628
- commit 0ce8a7d
* Fri Jun 28 2019 kbuild@suse.de
- Automatically updated to 5.2-rc6-next-20190627
- commit 2d29b34
* Thu Jun 27 2019 msuchanek@suse.de
- Update config files
  - Add core options from SLE15 which are not enabled on master for no
  obvious reason
  - Add core option from x86 which are not enabled on non-x86 for no
  obvious reason
  - Enable fadump
  Changes:
  Scheduling:
    +CONFIG_CONTEXT_TRACKING=y
  - CONFIG_TICK_CPU_ACCOUNTING=y
    +CONFIG_VIRT_CPU_ACCOUNTING_GEN=y
    +CONFIG_VIRT_CPU_ACCOUNTING=y
    +CONFIG_IRQ_TIME_ACCOUNTING=y
    +CONFIG_TASKS_RCU=y
    +CONFIG_RT_GROUP_SCHED=y
  mm:
    +# CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS is not set
    +CONFIG_TRANSPARENT_HUGEPAGE_MADVISE=y
    +CONFIG_FRONTSWAP=y
    +CONFIG_ZSWAP=y
  arc/ppc:
    +CONFIG_FA_DUMP=y
  fs:
    +CONFIG_9P_FSCACHE=y
  net:
    +CONFIG_TIPC=m
    +CONFIG_TIPC_DIAG=m
    +CONFIG_TIPC_MEDIA_UDP=y
  misc:
  - CONFIG_SERIAL_SIFIVE=m
    +CONFIG_SYSCTL_SYSCALL=y
  debug&test:
    +CONFIG_PAGE_EXTENSION=y
    +CONFIG_PAGE_OWNER=y
    +CONFIG_DEBUG_MISC=y
    +CONFIG_RCU_TRACE=y
    +CONFIG_KGDB_SERIAL_CONSOLE=y
    +CONFIG_SCOM_DEBUGFS=y
    +CONFIG_CRYPTO_TEST=m
    +CONFIG_RCU_TORTURE_TEST=m
    +CONFIG_TEST_FIRMWARE=m
    +CONFIG_TEST_LIVEPATCH=m
    +CONFIG_TEST_LKM=m
    +CONFIG_TEST_SYSCTL=m
    +CONFIG_TORTURE_TEST=m
- commit 5b852cf
* Thu Jun 27 2019 kbuild@suse.de
- Automatically updated to 5.2-rc6-next-20190626
- commit 8f9fe73
* Wed Jun 26 2019 kbuild@suse.de
- Automatically updated to 5.2-rc6-next-20190625
- commit 394284f
* Tue Jun 25 2019 msuchanek@suse.de
- Update config files.
- commit 31a6429
* Tue Jun 25 2019 kbuild@suse.de
- Automatically updated to 5.2-rc6-next-20190624
- commit f4e4cb4
* Sat Jun 22 2019 msuchanek@suse.de
- Update config files.
- commit c81d20e
* Sat Jun 22 2019 kbuild@suse.de
- Automatically updated to 5.2-rc5-next-20190621
- commit 2e73df1
* Fri Jun 21 2019 kbuild@suse.de
- Automatically updated to 5.2-rc5-next-20190620
- commit dfada4b
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: rpm does not support multiline condition
- commit aceae50
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: Use -c grep option in klp project detection.
- commit 5def2a2
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: fix missing \
- commit 8325214
* Thu Jun 20 2019 kbuild@suse.de
- Automatically updated to 5.2-rc5-next-20190619
- commit 9de4799
* Wed Jun 19 2019 mkubecek@suse.cz
- config: refresh i386/default
- commit 37b6b5d
* Wed Jun 19 2019 kbuild@suse.de
- Automatically updated to 5.2-rc5-next-20190618
- commit 759f68a
* Wed Jun 19 2019 jslaby@suse.cz
- Update config files.
  Enable SECURITY_YAMA to allow protection against ptrace attacks
  (bnc#1128245).
- commit 113b913
* Tue Jun 18 2019 jslaby@suse.cz
- Update config files.
  Set HARDENED_USERCOPY=y (bnc#1127808). This can be disabled on the
  commandline using hardened_usercopy=n.
- commit 3c72d04
* Tue Jun 18 2019 tiwai@suse.de
- config: enable CONFIG_FONT_TER16x32 for HiDPI monitors (boo#1138496)
- commit cee20e7
* Mon Jun 17 2019 kbuild@suse.de
- Automatically updated to 5.2-rc5-next-20190617
- commit 68abff4
* Sun Jun 16 2019 mkubecek@suse.cz
- Update to 5.2-rc5
- Config changes:
  - Sound:
  - SND_SOC_SOF_NOCODEC_SUPPORT=n on x86, =y on ARM
  - Storage:
  - MQ_IOSCHED_DEADLINE m -> y on arm64
- commit 45a8b99
* Sat Jun 15 2019 kbuild@suse.de
- Automatically updated to 5.2-rc4-next-20190614
- commit 7108823
* Thu Jun 13 2019 msuchanek@suse.de
- Build klp-symbols in kernel devel projects.
- commit ffd0ed9
* Thu Jun 13 2019 kbuild@suse.de
- Automatically updated to 5.2-rc4-next-20190613
- commit 03bbea2
* Wed Jun 12 2019 kbuild@suse.de
- Automatically updated to 5.2-rc4-next-20190612
- commit dc92426
* Tue Jun 11 2019 kbuild@suse.de
- Automatically updated to 5.2-rc4-next-20190611
- commit 2a3cfde
* Mon Jun 10 2019 mkubecek@suse.cz
- Update to 5.2-rc4
- Eliminated 1 patch
  - patches.rpmify/mlx5-avoid-64-bit-division.patch
- Refresh configs
  - IKHEADERS_PROC -> IKHEADERS
- commit bc1a041
* Fri Jun  7 2019 mvedovati@suse.com
- rpm/post.sh: correct typo in err msg (bsc#1137625)
- commit 9fe85cc
* Fri Jun  7 2019 kbuild@suse.de
- Automatically updated to 5.2-rc3-next-20190607
- commit bd5a7b2
* Thu Jun  6 2019 kbuild@suse.de
- Automatically updated to 5.2-rc3-next-20190606
- commit bbd2ff4
* Wed Jun  5 2019 mvedovati@suse.com
- Enhance kvmsmall configuration (bsc#1137361)
  Add a minimal set of modules to  kvmsmall, to make this config usable
  to set up guest VMs interacting with the host.
- commit 71b1001
* Wed Jun  5 2019 kbuild@suse.de
- Automatically updated to 5.2-rc3-next-20190605
- commit e1102c0
* Wed Jun  5 2019 mkubecek@suse.cz
- config: refresh configs
  No functional change.
- commit 8ed0ad4
* Tue Jun  4 2019 kbuild@suse.de
- Automatically updated to 5.2-rc3-next-20190604
- commit 387daa9
* Tue Jun  4 2019 jslaby@suse.cz
- Update config files.
  Enable CRASH_DUMP and RELOCATABLE on ppc64le to be on par with the
  other archs and to allow for kdump (bnc#1135217).
- commit 1762ca8
* Mon Jun  3 2019 kbuild@suse.de
- Automatically updated to 5.2-rc3-next-20190603
- commit ff49684
* Fri May 31 2019 kbuild@suse.de
- Automatically updated to 5.2-rc2-next-20190531
- commit c2024de
* Thu May 30 2019 kbuild@suse.de
- Automatically updated to 5.2-rc2-next-20190530
- commit 71e4a3e
* Wed May 29 2019 mkubecek@suse.cz
- config: refresh vanilla configs
- commit 15a48ad
* Wed May 29 2019 mkubecek@suse.cz
- refresh configs after Tumbleweed switch to gcc9 as default
- commit 92c3741
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv7hl: lpae: Update to v5.2.0-rc2
- commit 408b7f2
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv7hl: Update to v5.2.0-rc2
- commit 1e90b2b
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv6hl: Update to v5.2.0-rc2
- commit 865ac31
* Wed May 29 2019 kbuild@suse.de
- Automatically updated to 5.2-rc2-next-20190529
- commit 228a296
* Tue May 28 2019 yousaf.kaukab@suse.com
- config: arm64: Update to v5.2.0-rc2
- commit e3717c7
* Tue May 28 2019 kbuild@suse.de
- Automatically updated to 5.2-rc2-next-20190528
- commit d7b871b
* Fri May 24 2019 kbuild@suse.de
- Automatically updated to 5.2-rc1-next-20190524
- commit 06b16ec
* Thu May 23 2019 kbuild@suse.de
- Automatically updated to 5.2-rc1-next-20190523
- commit f3565e2
* Wed May 22 2019 kbuild@suse.de
- Automatically updated to 5.2-rc1-next-20190522
- commit 79505cf
* Tue May 21 2019 kbuild@suse.de
- Automatically updated to 5.2-rc1-next-20190521
- commit 1e055e4
* Mon May 20 2019 mkubecek@suse.cz
- config: refresh vanilla configs
- commit d6b435c
* Mon May 20 2019 mkubecek@suse.cz
- net: phy: rename Asix Electronics PHY driver.
  Fix duplicate module name asix by renaming phy driver to ax88796b.
- Update config files.
- commit 56231a0
* Mon May 20 2019 kbuild@suse.de
- Automatically updated to 5.1-next-20190520
- commit eb51980
* Mon May 20 2019 mkubecek@suse.cz
- Update to 5.2-rc1
- Eliminated 106 patches (105 stable, 1 other)
- ARM configs need update
- Refresh
  patches.rpmify/scripts-mkmakefile-honor-second-argument.patch
  patches.suse/dm-mpath-leastpending-path-update
  patches.suse/supported-flag
  patches.suse/supported-flag-external
  patches.suse/vfs-add-super_operations-get_inode_dev
- New config options:
  - General setup
  - IKHEADERS_PROC=n
  - SHUFFLE_PAGE_ALLOCATOR=y
  - Security
  - SECURITY_TOMOYO_INSECURE_BUILTIN_SETTING=n
  - Filesystems
  - UNICODE=y
  - UNICODE_NORMALIZATION_SELFTEST=n
  - Crypto
  - CRYPTO_ECRDSA=m
  - Networking
  - BATMAN_ADV_SYSFS=y
  - BT_MTKSDIO=m
  - XILINX_LL_TEMAC=m
  - MT7615E=m
  - RTW88=m
  - RTW88_8822BE=y
  - RTW88_8822CE=y
  - RTW88_DEBUG=n
  - RTW88_DEBUGFS=n
  - INFINIBAND_EFA=m
  - Storage
  - DM_DUST=m
  - MTD drivers
  - MTD_RAW_NAND=m
  - MTD_NAND_ECC_SW_BCH=y
  - MTD_NAND_ECC_SW_HAMMING_SMC=n
  - Input
  - KEYBOARD_QT1050=m
  - TOUCHSCREEN_IQS5XX=m
  - INPUT_GPIO_VIBRA=n
  - INPUT_REGULATOR_HAPTIC=m
  - HID_MACALLY=m
  - HID_U2FZERO=m
  - INPUT_MAX77650_ONKEY=m
  - Serial
  - NULL_TTY=m
  - SERIAL_SIFIVE=m
  - Power management
  - CHARGER_MANAGER=y
  - CHARGER_LT3651=m
  - CHARGER_UCS1002=m
  - SENSORS_IR38064=m
  - SENSORS_ISL68137=m
  - SENSORS_LTC2978_REGULATOR=y
  - THERMAL_MMIO=m
  - MFD_MAX77650=m
  - MFD_STMFX=m
  - REGULATOR_DEBUG=n
  - REGULATOR_FIXED_VOLTAGE=m
  - REGULATOR_VIRTUAL_CONSUMER=m
  - REGULATOR_USERSPACE_CONSUMER=m
  - REGULATOR_88PG86X=m
  - REGULATOR_ACT8865=m
  - REGULATOR_AD5398=m
  - REGULATOR_AXP20X=m
  - REGULATOR_DA9062=m
  - REGULATOR_DA9210=m
  - REGULATOR_DA9211=m
  - REGULATOR_FAN53555=m
  - REGULATOR_GPIO=m
  - REGULATOR_ISL9305=m
  - REGULATOR_ISL6271A=m
  - REGULATOR_LM363X=m
  - REGULATOR_LP3971=m
  - REGULATOR_LP3972=m
  - REGULATOR_LP872X=m
  - REGULATOR_LP8755=m
  - REGULATOR_LTC3589=m
  - REGULATOR_LTC3676=m
  - REGULATOR_MAX1586=m
  - REGULATOR_MAX77650=m
  - REGULATOR_MAX8649=m
  - REGULATOR_MAX8660=m
  - REGULATOR_MAX8907=m
  - REGULATOR_MAX8952=m
  - REGULATOR_MAX8973=m
  - REGULATOR_MCP16502=m
  - REGULATOR_MT6311=m
  - REGULATOR_PFUZE100=m
  - REGULATOR_PV88060=m
  - REGULATOR_PV88080=m
  - REGULATOR_PV88090=m
  - REGULATOR_PWM=m
  - REGULATOR_QCOM_SPMI=m
  - REGULATOR_SY8106A=m
  - REGULATOR_TPS51632=m
  - REGULATOR_TPS62360=m
  - REGULATOR_TPS65023=m
  - REGULATOR_TPS6507X=m
  - REGULATOR_TPS65132=m
  - REGULATOR_TPS6524X=m
  - REGULATOR_VCTRL=m
  - CHARGER_MAX77650=m
  - Media
  - MEDIA_CONTROLLER_REQUEST_API=y
  - VIDEO_V4L2_SUBDEV_API=y
  - V4L2_FLASH_LED_CLASS=m
  - VIDEO_COBALT=n
  - VIDEO_IPU3_CIO2=m
  - VIDEO_CADENCE_CSI2RX=m
  - VIDEO_CADENCE_CSI2TX=m
  - VIDEO_MUX=m
  - VIDEO_XILINX=m
  - VIDEO_XILINX_TPG=m
  - VIDEO_VIMC=m
  - VIDEO_IPU3_IMGU=m
  - DRM
  - NOUVEAU_LEGACY_CTX_SUPPORT=n
  - DRM_PANEL_FEIYANG_FY07024DI26A30D=n
  - DRM_PANEL_ROCKTECH_JH057N00900=n
  - DRM_PANEL_RONBO_RB070D30=n
  - Sound
  - SND_SOC_FSL_AUDMIX=n
  - SND_SOC_SOF_TOPLEVEL=y
  - SND_SOC_SOF_PCI=m
  - SND_SOC_SOF_ACPI=m
  - SND_SOC_SOF_NOCODEC=n
  - SND_SOC_SOF_STRICT_ABI_CHECKS=n
  - SND_SOC_SOF_DEBUG=n
  - SND_SOC_SOF_INTEL_TOPLEVEL=y
  - SND_SOC_SOF_BAYTRAIL_SUPPORT=y
  - SND_SOC_SOF_BROADWELL_SUPPORT=y
  - SND_SOC_SOF_MERRIFIELD_SUPPORT=y
  - SND_SOC_SOF_APOLLOLAKE_SUPPORT=y
  - SND_SOC_SOF_GEMINILAKE_SUPPORT=y
  - SND_SOC_SOF_CANNONLAKE_SUPPORT=y
  - SND_SOC_SOF_COFFEELAKE_SUPPORT=y
  - SND_SOC_SOF_ICELAKE_SUPPORT=y
  - SND_SOC_SOF_HDA_LINK=y
  - SND_SOC_SOF_HDA_AUDIO_CODEC=y
  - SND_SOC_INTEL_SOF_RT5682_MACH=m
  - USB
  - TYPEC_NVIDIA_ALTMODE=m
  - LEDS
  - LEDS_LM3532=m
  - LEDS_REGULATOR=m
  - LEDS_MAX77650=m
  - Platform
  - CROS_EC_RPMSG=m
  - CROS_USBPD_LOGGER=m
  - CLK_SIFIVE=n
  - IXP4XX_QMGR=n
  - IXP4XX_NPE=m
  - IIO
  - CC10001_ADC=n
  - TI_ADS8344=n
  - FXAS21002C=n
  - MB1232=n
  - MAX31856=m
  - Misc drivers
  - I2C_AMD_MP2=m
  - PINCTRL_STMFX=n
  - FIELDBUS_DEV=n
  - KPC2000=n
  - NVMEM_SYSFS=y
  - COUNTER=n
  - GPIO_MAX77650=m
  - Library
  - PACKING=n
  - Debugging and testing
  - DEBUG_INFO_BTF=n
  - DEBUG_MISC=n
  - DEBUG_PLIST=n
  - TEST_STRSCPY=n
  - x86
  - ACPI_HMAT=y
  - INTEL_CHT_INT33FE=m
  - INTEL_ISH_FIRMWARE_DOWNLOADER=m
  - i386
  - MEMORY_HOTPLUG=y
  - MEMORY_HOTPLUG_DEFAULT_ONLINE=n
  - MEMORY_HOTREMOVE
  - XEN_BALLOON_MEMORY_HOTPLUG=y
  - XEN_BALLOON_MEMORY_HOTPLUG_LIMIT=4
  - DEV_DAX_KMEM=m
  - MEMORY_NOTIFIER_ERROR_INJECT=m
  - ACPI_HOTPLUG_MEMORY=y
  - ppc64 / ppc64le
  - PPC_KUEP=y
  - PPC_KUAP=y
  - PPC_KUAP_DEBUG=n
  - MTD_NAND_DENALI_PCI=m
  - MTD_NAND_CAFE=m
  - MTD_NAND_GPIO=m
  - MTD_NAND_PLATFORM=m
  - MTD_NAND_NANDSIM=m
  - MTD_NAND_RICOH=m
  - MTD_NAND_DISKONCHIP=m
  - MTD_NAND_DISKONCHIP_PROBE_ADVANCED=n
  - MTD_NAND_DISKONCHIP_BBTWRITE=n
  - INTEGRITY_PLATFORM_KEYRING=y
  - OPTIMIZE_INLINING=y
  - XMON_DEFAULT_RO_MODE=y
  - s390x
  - KEXEC_VERIFY_SIG=n
  - RELOCATABLE=y
  - RANDOMIZE_BASE=y
  - PROTECTED_VIRTUALIZATION_GUEST=y
  - LCD_CLASS_DEVICE=n
  - BACKLIGHT_CLASS_DEVICE=n
  - INTEGRITY_PLATFORM_KEYRING=y
  - OPTIMIZE_INLINING=n
- commit 8193b07
* Fri May 17 2019 kbuild@suse.de
- Automatically updated to 5.1-next-20190517
- commit c6935f9
* Thu May 16 2019 mwilck@suse.com
- Update config files: disable CONFIG_IDE for ppc64/ppc64le (bsc#1135333)
- commit a8ef7bf
* Thu May 16 2019 kbuild@suse.de
- Automatically updated to 5.1-next-20190516
- commit 7dde63b
* Wed May 15 2019 kbuild@suse.de
- Automatically updated to 5.1-next-20190515
- commit dc5346a
* Tue May 14 2019 kbuild@suse.de
- Automatically updated to 5.1-next-20190514
- commit 6340c17
* Tue May 14 2019 mkubecek@suse.cz
- config: keep LSM empty in s390x/zfcpdump
  This config doesn't really build AppArmor and always had
  DEFAULT_SECURITY_DAC so it seems more consistent to keep LSM list empty.
- commit ab50d17
* Tue May 14 2019 mkubecek@suse.cz
- config: enable AppArmor by default again (bsc#1134906)
  AppArmor used to be enabled in kernel by default by after the recent
  introduction of CONFIG_LSM, we disabled all LSM modules. Enable AppArmor
  again.
- commit c5370e2
* Mon May 13 2019 kbuild@suse.de
- Automatically updated to 5.1-next-20190513
- commit 44a17b8
* Fri May 10 2019 kbuild@suse.de
- Automatically updated to 5.1-next-20190510
- commit 0572ad4
* Thu May  9 2019 kbuild@suse.de
- Automatically updated to 5.1-next-20190509
- commit 4ea66bd
* Thu May  9 2019 guillaume.gardet@free.fr
- Sign non-x86 kernels when possible (boo#1134303)
- commit bac621c
* Wed May  8 2019 kbuild@suse.de
- Automatically updated to 5.1-next-20190508
- commit df167b0
* Tue May  7 2019 kbuild@suse.de
- Automatically updated to 5.1-next-20190507
- commit 63a281a
* Mon May  6 2019 mkubecek@suse.cz
- Update to 5.1 final
- Eliminated 1 patch
- New config options:
  - PCI:
  - PCIE_BW=n (recommended default)
- commit 22bde20
* Fri May  3 2019 kbuild@suse.de
- Automatically updated to 5.1-rc7-next-20190503
- commit 8234f47
* Thu May  2 2019 kbuild@suse.de
- Automatically updated to 5.1-rc7-next-20190501
- commit 1c53217
* Wed May  1 2019 kbuild@suse.de
- Automatically updated to 5.1-rc7-next-20190430
- commit ea46462
* Mon Apr 29 2019 kbuild@suse.de
- Automatically updated to 5.1-rc6-next-20190429
- commit 148d2dc
* Mon Apr 29 2019 mkubecek@suse.cz
- Update to 5.1-rc7
- add patches.suse/rdma-fix-argument-of-ZERO_PAGE-in-rdma_umap_fault.patch
  (tentative s390x build fix)
- New config options:
  - ARM:
  - KEYBOARD_SNVS_PWRKEY=m
  - armv7hl:
  - FRAME_POINTER=y
  - UNWINDER_FRAME_POINTER=y
- commit 4c14eee
* Fri Apr 26 2019 kbuild@suse.de
- Automatically updated to 5.1-rc6-next-20190426
- commit 091b12c
* Wed Apr 24 2019 kbuild@suse.de
- Automatically updated to 5.1-rc6-next-20190424
- commit d234257
* Sun Apr 21 2019 mkubecek@suse.cz
- Update to v5.1-rc6
- New config options:
  - IIO:
  - SENSIRION_SGP30=n
- commit 3cae807
* Thu Apr 18 2019 kbuild@suse.de
- Automatically updated to 5.1-rc5-next-20190418
- commit 72687ee
* Wed Apr 17 2019 kbuild@suse.de
- Automatically updated to 5.1-rc5-next-20190417
- commit b37bf81
* Tue Apr 16 2019 kbuild@suse.de
- Automatically updated to 5.1-rc5-next-20190416
- commit 65627b5
* Mon Apr 15 2019 kbuild@suse.de
- Automatically updated to 5.1-rc4-next-20190415
- commit c6bca36
* Fri Apr 12 2019 kbuild@suse.de
- Automatically updated to 5.1-rc4-next-20190412
- commit 52eba00
* Thu Apr 11 2019 msuchanek@suse.de
- Do not provide kernel-default from kernel-default-base (boo#1132154, bsc#1106751).
- commit 0e54e61
* Thu Apr 11 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: only provide firmware actually present in
  subpackage.
- commit 839debd
* Thu Apr 11 2019 kbuild@suse.de
- Automatically updated to 5.1-rc4-next-20190411
- commit db5dbae
* Wed Apr 10 2019 msuchanek@suse.de
- kernel-subpackage-spec: Add dummy package to ensure subpackages are
  rebuilt with kernel update (bsc#1106751).
  In factory packages are not rebuilt automatically so a dependency is
  needed on the old kernel to get a rebuild with the new kernel. THe
  subpackage itself cannot depend on the kernel so add another empty
  pacakge that does depend on it.
- commit 6d14837
* Wed Apr 10 2019 kbuild@suse.de
- Automatically updated to 5.1-rc4-next-20190410
- commit c25af36
* Tue Apr  9 2019 jdelvare@suse.de
- Disable CONFIG_SERIO_OLPC_APSP on all but armv7
  This driver is only used by ARMv7-based OLPC laptops.
- commit 9710914
* Tue Apr  9 2019 jdelvare@suse.de
- Disable CONFIG_SENSORS_OCC_*
  These drivers are running on the BMC of PowerPC servers. The BMC runs
  OpenBMC and is not a target for SUSE distributions.
- commit b17982d
* Tue Apr  9 2019 kbuild@suse.de
- Automatically updated to 5.1-rc4-next-20190409
- commit f9aaf31
* Mon Apr  8 2019 kbuild@suse.de
- Automatically updated to 5.1-rc3-next-20190408
- commit 72266ca
* Mon Apr  8 2019 mkubecek@suse.cz
- config: disable DEVKMEM (bsc#1128045)
- commit 9121e61
* Mon Apr  8 2019 mkubecek@suse.cz
- Update to 5.1-rc4
- Refresh configs
- commit 50e7bc2
* Fri Apr  5 2019 kbuild@suse.de
- Automatically updated to 5.1-rc3-next-20190405
- commit 0cd5e96
* Thu Apr  4 2019 kbuild@suse.de
- Automatically updated to 5.1-rc3-next-20190404
- commit 8fadef5
* Wed Apr  3 2019 kbuild@suse.de
- Automatically updated to 5.1-rc3-next-20190403
- commit b7835d8
* Tue Apr  2 2019 kbuild@suse.de
- Automatically updated to 5.1-rc3-next-20190402
- commit 7839336
* Mon Apr  1 2019 kbuild@suse.de
- Automatically updated to 5.1-rc2-next-20190401
- commit 44be6bf
* Mon Apr  1 2019 mkubecek@suse.cz
- Update to 5.1-rc3
- Eliminated 1 patch
- Config changes:
  - SECURITY_DEFAULT_* are back
  - enable CONFIG_OF in i386/pae and copy dependent options from default
- commit f915b91
* Fri Mar 29 2019 kbuild@suse.de
- Automatically updated to 5.1-rc2-next-20190329
- commit b5f9bf8
* Thu Mar 28 2019 yousaf.kaukab@suse.com
- config: arm64: enable CPPC support
- commit 5bf3ae1
* Thu Mar 28 2019 kbuild@suse.de
- Automatically updated to 5.1-rc2-next-20190328
- commit b4603ec
* Wed Mar 27 2019 kbuild@suse.de
- Automatically updated to 5.1-rc2-next-20190327
- commit 87155dc
* Tue Mar 26 2019 kbuild@suse.de
- Automatically updated to 5.1-rc2-next-20190326
- commit 7f59dc8
* Mon Mar 25 2019 kbuild@suse.de
- Automatically updated to 5.1-rc2-next-20190325
- commit 0927257
* Mon Mar 25 2019 mkubecek@suse.cz
- Update to 5.1-rc2
- New config options:
  - CHARLCD_BL_FLASH=y
  - PARPORT_PANEL=m (renamed from PANEL)
  - PANEL=m
- commit 4cd2cd2
* Fri Mar 22 2019 msuchanek@suse.de
- Do not provide kernel-default-srchash from kernel-default-base.
- commit d6c71ce
* Fri Mar 22 2019 kbuild@suse.de
- Automatically updated to 5.1-rc1-next-20190322
- commit 1c24013
* Thu Mar 21 2019 kbuild@suse.de
- Automatically updated to 5.1-rc1-next-20190321
- commit 85f2fe1
* Thu Mar 21 2019 mkubecek@suse.cz
- config: apply recent changes to ARM configs
- CONFIG_PREEMPT_VOLUNTARY=y
- disable CONFIG_IMA_ARCH_POLICY
- enable CONFIG_IMA_APPRAISE_BOOTPARAM
- CONFIG_LSM=""
- commit a090760
* Wed Mar 20 2019 yousaf.kaukab@suse.com
- config: arm64: Update to v5.1-rc1
- commit a1e1694
* Wed Mar 20 2019 msuchanek@suse.de
- rpm/kernel-subpackage-build: handle arm kernel zImage.
- commit 81a63c3
* Wed Mar 20 2019 jslaby@suse.cz
- config: disable IMA_ARCH_POLICY for now
  When IMA_ARCH_POLICY was enabled during the 5.0-rc* stage, IMA causes
  kdump load to fail:
  kexec_file_load failed: Permission denied
  ima: impossible to appraise a kernel image without a file descriptor; try using kexec_file_load syscall.
  We have to fix kexec tooling before enabling IMA for everyone.
  BTW IMA_APPRAISE_BOOTPARAM was disabled by IMA_ARCH_POLICY=y. So
  restore the original state (and functionality).
- commit 4d2e574
* Wed Mar 20 2019 kbuild@suse.de
- Automatically updated to 5.1-rc1-next-20190320
- commit d76c432
* Wed Mar 20 2019 yousaf.kaukab@suse.com
- config: armv6hl: Update to v5.1-rc1
  CONFIG_BPFILTER_UMH is disabled due to bsc#1127188
- commit d26f160
* Tue Mar 19 2019 yousaf.kaukab@suse.com
- config: armv7hl: Update to v5.1-rc1
  CONFIG_BPFILTER_UMH is disabled due to bsc#1127188
- commit e95003a
* Tue Mar 19 2019 kbuild@suse.de
- Automatically updated to 5.1-rc1-next-20190319
- commit 60ca82c
* Mon Mar 18 2019 mkubecek@suse.cz
- Update to 5.1-rc1
- Eliminated 74 patches (73 stable, 1 other)
- ARM configs need update
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  patches.suse/genksyms-add-override-flag.diff
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/readahead-request-tunables.patch
  patches.suse/supported-flag
  patches.suse/vfs-add-super_operations-get_inode_dev
- New config options:
  - General:
  - IO_URING=y
  - PRINTK_CALLER=n
  - File systems:
  - CONFIG_SUNRPC_DISABLE_INSECURE_ENCTYPES=n
  - VALIDATE_FS_PARSER=n
  - Networking:
  - NET_DEVLINK=y
  - XDP_SOCKETS_DIAG=m
  - MT7603E=m
  - TI_CPSW_PHY_SEL=n
  - Power management:
  - CPU_IDLE_GOV_TEO=y
  - DAX:
  - DEV_DAX_KMEM=m
  - DEV_DAX_PMEM_COMPAT=m
  - USB:
  - USB_AUTOSUSPEND_DELAY=2
  - USB_EHCI_FSL=m
  - Graphics:
  - DRM_ETNAVIV=n
  - DRM_NOUVEAU_SVM=n
  - VIDEO_FB_IVTV_FORCE_PAT=n
  - Sound:
  - SND_SOC_CROS_EC_CODEC=m
  - SND_SOC_CS35L36=m
  - SND_SOC_CS4341=m
  - SND_SOC_FSL_MICFIL=n
  - SND_SOC_MAX98373=m
  - SND_SOC_MT6358=n
  - SND_SOC_MTK_BTCVSD=m
  - SND_SOC_RK3328=n
  - SND_SOC_WM8904=n
  - SND_SOC_XILINX_AUDIO_FORMATTER=n
  - SND_SOC_XILINX_SPDIF=n
  - Input:
  - HID_MALTRON=m
  - HID_VIEWSONIC=m
  - TTY:
  - LDISC_AUTOLOAD=y
  - RTC:
  - RTC_DRV_ABEOZ9=m
  - RTC_DRV_RV3028=m
  - RTC_DRV_SD3078=m
  - RTC_DRV_WILCO_EC=m
  - Industrial IO:
  - AD7606_IFACE_PARALLEL=n
  - AD7606_IFACE_SPI=n
  - AD7768_1=n
  - MAX44009=m
  - PMS7003=n
  - SPS30=n
  - TI_DAC7612=n
  - Misc drivers:
  - ALTERA_FREEZE_BRIDGE=m
  - EDAC_I10NM=m
  - EXTCON_PTN5150=m
  - GNSS_MTK_SERIAL=m
  - GPIO_AMD_FCH=m
  - GPIO_TQMX86=m
  - HABANA_AI=m
  - INPUT_MSM_VIBRATOR=n
  - INTEL_MEI_HDCP=m
  - INTERCONNECT=m
  - IR_RCMM_DECODER=m
  - MFD_TQMX86=m
  - MLX_WDT=m
  - SPI_MTK_QUADSPI=m
  - SPI_NXP_FLEXSPI=n
  - SPI_SIFIVE=n
  - WILCO_EC=m
  - WILCO_EC_DEBUGFS=n
  - Virtualization:
  - HYPERV_IOMMU=y
  - Security:
  - LSM=""
  - SECURITY_SAFESETID=n
  - Testing:
  - TEST_LIVEPATCH=n
  - TEST_STACKINIT=n
  - TEST_VMALLOC=n
  - x86:
  - PCENGINES_APU2=m
  - ppc64/ppc64le:
  - NVRAM=m
  - KCOV=n
  - s390x:
  UID16=y
  DMA_FENCE_TRACE=n
  SCSI_GDTH=n
  UDMABUF=y
  - */debug:
  - PRINTK_CALLER=n
- commit f558da0
* Mon Mar 18 2019 kbuild@suse.de
- Automatically updated to 5.1-rc1-next-20190318
- commit 80b3b21
* Mon Mar 18 2019 msuchanek@suse.de
- Trim build dependencies of sample subpackage spec file (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit 2eae420
* Sun Mar 17 2019 mkubecek@suse.cz
- config: enable RANDOM_TRUST_CPU
  The outcome from mailing list discussion when this config option
  appeared was that it makes more sense to enable it by default and let
  those who do not trust their CPU override it on command line; but then
  I forgot to actually change the value.
- commit bca56eb
* Fri Mar 15 2019 tiwai@suse.de
- Update config files: disable CONFIG_FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER (bsc#1127552)
  The deferred fbcon takeover makes little sense with the current openSUSE
  boot setup, and it's harmful (more glitches, etc).  Disable it for now.
- commit 6214b4f
* Fri Mar 15 2019 msuchanek@suse.de
- Remove the previous subpackage infrastructure.
  This partially reverts commit 9b3ca32c11854156b2f950ff5e26131377d8445e
  ("Add kernel-subpackage-build.spec (FATE#326579).")
- commit a5ee24e
* Fri Mar 15 2019 msuchanek@suse.de
- Add sample kernel-default-base spec file (FATE#326579, jsc#SLE-4117,
  jsc#SLE-3853, bsc#1128910).
- commit 35c4a52
* Thu Mar 14 2019 msuchanek@suse.de
- Install extra rpm scripts for kernel subpackaging (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit ad7c227
* Fri Mar  8 2019 msuchanek@suse.de
- Update config files.
- commit 7461a80
* Thu Mar  7 2019 msuchanek@suse.de
- KMPs: provide and conflict a kernel version specific KMP name
  (bsc#1127155, bsc#1109137).
- commit 5568093
* Wed Mar  6 2019 msuchanek@suse.de
- Revert "Drop multiversion(kernel) from the KMP template (fate#323189)"
  (bsc#1109137).
  This reverts commit 71504d805c1340f68715ad41958e5ef35da2c351.
- commit adade9f
* Wed Mar  6 2019 kbuild@suse.de
- Automatically updated to 5.0-next-20190306
- commit d0238ee
* Tue Mar  5 2019 kbuild@suse.de
- Automatically updated to 5.0-next-20190305
- commit 50fc36d
* Tue Mar  5 2019 mkubecek@suse.cz
- config: disable BPFILTER_UMH on non-x86 architectures (bsc#1127188)
  CONFIG_BPFILTER_UMH depends on ability to compile and link a userspace
  binary so that it currently doesn't work in our kbuild check setups using
  a cross compiler. Disable the option on architectures where cross compiler
  is used (i.e. all except x86_64 and i386).
- commit 57639d9
* Mon Mar  4 2019 msuchanek@suse.de
- KMPs: obsolete older KMPs of the same flavour (bsc#1127155, bsc#1109137).
- commit 821419f
* Mon Mar  4 2019 kbuild@suse.de
- Automatically updated to 5.0-rc8-next-20190304
- commit 7e4cb21
* Mon Mar  4 2019 mkubecek@suse.cz
- Update to 5.0 final
- Refresh configs
- commit 40f2c94
* Fri Mar  1 2019 kbuild@suse.de
- Automatically updated to 5.0-rc8-next-20190301
- commit 3aace10
* Thu Feb 28 2019 msuchanek@suse.de
- Update config files.
- commit 2f04f37
* Thu Feb 28 2019 msuchanek@suse.de
- Update config files.
- commit 5d151bf
* Thu Feb 28 2019 msuchanek@suse.de
- Update ppc64le config file.
  LD_HEAD_STUB_CATCH=y
- commit 4d0b7a5
* Thu Feb 28 2019 kbuild@suse.de
- Automatically updated to 5.0-rc8-next-20190228
- commit a1b11c9
* Wed Feb 27 2019 msuchanek@suse.de
- BPF: UMH: do not detect if compiler can link userspace program
  (boo#1127188).
- commit 2e2350c
* Wed Feb 27 2019 kbuild@suse.de
- Automatically updated to 5.0-rc8-next-20190227
- commit da3d45a
* Tue Feb 26 2019 kbuild@suse.de
- Automatically updated to 5.0-rc8-next-20190226
- commit 8473c94
* Mon Feb 25 2019 kbuild@suse.de
- Automatically updated to 5.0-rc7-next-20190225
- commit 6730ded
* Fri Feb 22 2019 kbuild@suse.de
- Automatically updated to 5.0-rc7-next-20190222
- commit f0576d7
* Fri Feb 22 2019 mkubecek@suse.cz
- config: enable PREEMPT_VOLUNTARY (bsc#1125004)
  Switch to PREEMPT_VOLUNTARY everywhere except s390x/zfcpdump.
- commit 71ac976
* Thu Feb 21 2019 kbuild@suse.de
- Automatically updated to 5.0-rc7-next-20190221
- commit c66bf12
* Wed Feb 20 2019 kbuild@suse.de
- Automatically updated to 5.0-rc7-next-20190220
- commit b735452
* Tue Feb 19 2019 mbenes@suse.cz
- rpm/klp-symbols: Remove the second column in Symbols.list
  Symbols.list file contains also a symbol type next to its name.
  klp-convert cannot handle it well and it is superfluous anyway.
- commit 62a0a00
* Tue Feb 19 2019 kbuild@suse.de
- Automatically updated to 5.0-rc7-next-20190219
- commit 97c9cad
* Mon Feb 18 2019 kbuild@suse.de
- Automatically updated to 5.0-rc6-next-20190218
- commit ffedfa6
* Fri Feb 15 2019 kbuild@suse.de
- Automatically updated to 5.0-rc6-next-20190215
- commit 20a20fd
* Thu Feb 14 2019 kbuild@suse.de
- Automatically updated to 5.0-rc6-next-20190214
- commit 7e8a2d8
* Wed Feb 13 2019 kbuild@suse.de
- Automatically updated to 5.0-rc6-next-20190213
- commit 7fd25e4
* Tue Feb 12 2019 kbuild@suse.de
- Automatically updated to 5.0-rc6-next-20190212
- commit c6395ea
* Mon Feb 11 2019 kbuild@suse.de
- Automatically updated to 5.0-rc5-next-20190211
- commit 6a306f5
* Fri Feb  8 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Build livepatch support in SUSE release
  projects (bsc#1124167).
- commit 7519080
* Fri Feb  8 2019 kbuild@suse.de
- Automatically updated to 5.0-rc5-next-20190208
- commit 67606cf
* Thu Feb  7 2019 kbuild@suse.de
- Automatically updated to 5.0-rc5-next-20190207
- commit 17dc281
* Wed Feb  6 2019 kbuild@suse.de
- Automatically updated to 5.0-rc5-next-20190206
- commit 8b97bd9
* Tue Feb  5 2019 kbuild@suse.de
- Automatically updated to 5.0-rc5-next-20190205
- commit e30f52e
* Mon Feb  4 2019 kbuild@suse.de
- Automatically updated to 5.0-rc4-next-20190204
- commit b430c7e
* Mon Feb  4 2019 mkubecek@suse.cz
- Update to 5.0-rc5
- Config changes:
  - x86:
  - X86_RESCTRL renamed to X86_CPU_RESCTRL
- commit 3a02608
* Fri Feb  1 2019 kbuild@suse.de
- Automatically updated to 5.0-rc4-next-20190201
- commit c18f231
* Thu Jan 31 2019 kbuild@suse.de
- Automatically updated to 5.0-rc4-next-20190131
- commit 1631b61
* Wed Jan 30 2019 mwilck@suse.com
- rpm/kernel-binary.spec.in: fix initrd permissions (bsc#1123697)
  dracut has been using permissions 0600 for the initrd for a long
  time. On SLE15 or higher, that leads to a permission mismatch
  reported by "rpm -V". Set the permissions correctly for our
  ghost file.
- commit 9e5e2a5
* Wed Jan 30 2019 kbuild@suse.de
- Automatically updated to 5.0-rc4-next-20190130
- commit c1798ee
* Tue Jan 29 2019 kbuild@suse.de
- Automatically updated to 5.0-rc4-next-20190129
- commit a78caf2
* Mon Jan 28 2019 tiwai@suse.de
- doc/README.SUSE: Correct description for building a kernel (bsc#1123348)
  The obsoleted make cloneconfig is corrected.  Also the order of make
  scripts and make prepare are corrected as well.
- commit 17a2073
* Mon Jan 28 2019 tiwai@suse.de
- rpm/release-projects: Add SUSE:Maintenance:* for MU kernels (bsc#1123317)
- commit c784b79
* Mon Jan 28 2019 mkubecek@suse.cz
- Update to 5.0-rc4
- commit ebcc582
* Fri Jan 25 2019 kbuild@suse.de
- Automatically updated to 5.0-rc3-next-20190125
- commit 044559b
* Thu Jan 24 2019 kbuild@suse.de
- Automatically updated to 5.0-rc3-next-20190124
- commit b66ee8b
* Thu Jan 24 2019 msuchanek@suse.de
- rpm/kernel-*.spec.in: replace update srchash dependencies (FATE#325312).
  Due to some limitations version cannot be matched so move the hash into
  the provide name.
- commit 219bcec
* Wed Jan 23 2019 kbuild@suse.de
- Automatically updated to 5.0-rc3-next-20190123
- commit 8410a56
* Tue Jan 22 2019 kbuild@suse.de
- Automatically updated to 5.0-rc3-next-20190122
- commit b51e9d2
* Mon Jan 21 2019 kbuild@suse.de
- Automatically updated to 5.0-rc2-next-20190121
- commit 8f05dc9
* Mon Jan 21 2019 mkubecek@suse.cz
- Update to 5.0-rc3
- Config changes:
  - ARM64:
  - HSA_AMD=y
- commit 70f1b4e
* Fri Jan 18 2019 kbuild@suse.de
- Automatically updated to 5.0-rc2-next-20190118
- commit 921b83b
* Thu Jan 17 2019 kbuild@suse.de
- Automatically updated to 5.0-rc2-next-20190117
- commit 539bcc4
* Wed Jan 16 2019 kbuild@suse.de
- Automatically updated to 5.0-rc2-next-20190116
- commit c773b7f
* Tue Jan 15 2019 kbuild@suse.de
- Automatically updated to 5.0-rc2-next-20190115
- commit 4e74265
* Mon Jan 14 2019 kbuild@suse.de
- Automatically updated to 5.0-rc1-next-20190114
- commit e2de14d
* Mon Jan 14 2019 mkubecek@suse.cz
- Update to 5.0-rc2
- Config changes:
  - x86:
  - RESCTRL renamed to X86_RESCTRL
- commit ea08432
* Fri Jan 11 2019 afaerber@suse.de
- config: arm64: Update to 5.0-rc1
- commit 31e9acc
* Fri Jan 11 2019 msuchanek@suse.de
- tar-up.sh: do not copy files ending with ~
- commit aff5480
* Fri Jan 11 2019 kbuild@suse.de
- Automatically updated to 5.0-rc1-next-20190111
- commit d5372de
* Thu Jan 10 2019 kbuild@suse.de
- Automatically updated to 5.0-rc1-next-20190110
- commit 53beadf
* Wed Jan  9 2019 kbuild@suse.de
- Automatically updated to 5.0-rc1-next-20190109
- commit 8590405
* Tue Jan  8 2019 kbuild@suse.de
- Automatically updated to 5.0-rc1-next-20190108
- commit 6fafb0f
* Mon Jan  7 2019 mkubecek@suse.cz
- config: restore accidentally lost BPFILTER_UMH (ppc64, ppc64le, s390x)
- commit e6c2fea
* Mon Jan  7 2019 kbuild@suse.de
- Automatically updated to 4.20-next-20190107
- commit 79768ad
* Mon Jan  7 2019 mkubecek@suse.cz
- Update to 5.0-rc1
- Eliminated 1 patch
- ARM configs need update
- Config changes:
  - PM:
  - ENERGY_MODEL=y
  - Networking:
  - CAN_FLEXCAN=m
  - USB_NET_AQC111=m
  - QTNFMAC_PCIE=m
  - VIRT_WIFI=m
  - PCI:
  - PCI_MESON=n
  - SCSI:
  - SCSI_UFS_CDNS_PLATFORM=m
  - NVME:
  - NVME_TCP=m
  - NVME_TARGET_TCP=m
  - Graphics:
  - DRM_PANEL_OLIMEX_LCD_OLINUXINO=n
  - DRM_PANEL_SAMSUNG_S6D16D0=n
  - DRM_PANEL_TRULY_NT35597_WQXGA=n
  - TINYDRM_HX8357D=n
  - Sound:
  - SND_SOC_AMD_ACP3x=n
  - SND_SOC_INTEL_KBL_RT5660_MACH=m
  - SND_SOC_XILINX_I2S=n
  - SND_SOC_AK4118=n
  - Multimedia:
  - VIDEO_ASPEED=m
  - VIDEO_SECO_CEC=m
  - VIDEO_SECO_RC=y
  - I3C:
  - I3C=m
  - CDNS_I3C_MASTER=m
  - DW_I3C_MASTER=m
  - IIO:
  - AD7124=n
  - AD7949=n
  - TI_DAC7311=n
  - VCNL4035=n
  - SENSORS_RM3100_I2C=n
  - SENSORS_RM3100_SPI=n
  - MCP41010=m
  - PHY:
  - PHY_CADENCE_SIERRA=m
  - PHY_FSL_IMX8MQ_USB=m
  - misc drivers:
  - MTD_PHYSMAP_GPIO_ADDR=y
  - SPI_MXIC=n
  - MISC_ALCOR_PCI=m
  - RC_XBOX_DVD=m
  - PINCTRL_OCELOT=n
  - GPIO_CADENCE=m
  - SENSORS_OCC_P8_I2C=m
  - TQMX86_WDT=m
  - MMC_ALCOR=m
  - MMC_SDHCI_AM654=m
  - LEDS_TRIGGER_AUDIO=m
  - SERIO_OLPC_APSP=m
  - Security:
  - INTEGRITY_PLATFORM_KEYRING=y
  - IMA_ARCH_POLICY=y
  - Crypto:
  - CRYPTO_ADIANTUM=m
  - CRYPTO_STREEBOG=m
  - CRYPTO_STATS=n
  - Library:
  - RAID6_PQ_BENCHMARK=y (preserve current behaviour)
  - Testing:
  - TEST_OBJAGG=n
  - x86:
  - RESCTRL=y
  - HUAWEI_WMI=m
  - i386:
  - PVH=y
  - MTD_PHYSMAP_OF=m
  - ppc*:
  - PVPANIC=m
  - FB_LOGO_CENTER=n
  - FSI_OCC=m
  - DEBUG_VIRTUAL=n
  - SENSORS_OCC_P9_SBE=m
  - s390x:
  - PCCARD=n
  - RAPIDIO
  - other RapidIO options copy other architectures
  - DMADEVICES related options copy other architectures
  - */debug:
  - CRYPTO_STATS=y
  - TTY_PRINTK_LEVEL=6
- commit dff178e
* Thu Jan  3 2019 kbuild@suse.de
- Automatically updated to 4.20-next-20190103
- commit 7d26fea
* Wed Jan  2 2019 kbuild@suse.de
- Automatically updated to 4.20-next-20190102
- commit 5b9226b
* Tue Dec 25 2018 kbuild@suse.de
- Automatically updated to 4.20-rc7-next-20181224
- commit a1129b8
* Mon Dec 24 2018 mkubecek@suse.cz
- Update to 4.20 final
- Eliminated 1 patch
- Refresh configs
- commit 9fd0a76
* Fri Dec 21 2018 kbuild@suse.de
- Automatically updated to 4.20-rc7-next-20181221
- commit 75196e0
* Thu Dec 20 2018 kbuild@suse.de
- Automatically updated to 4.20-rc7-next-20181220
- commit 023b21e
* Wed Dec 19 2018 kbuild@suse.de
- Automatically updated to 4.20-rc7-next-20181219
- commit 618a186
* Tue Dec 18 2018 kbuild@suse.de
- Automatically updated to 4.20-rc7-next-20181218
- commit 18e496c
* Mon Dec 17 2018 kbuild@suse.de
- Automatically updated to 4.20-rc6-next-20181217
- commit d3f1c97
* Mon Dec 17 2018 mkubecek@suse.cz
- Update to 4.20-rc7
- Config changes:
  - ARM:
  - MEDIA_CONTROLLER_REQUEST_API=y
- commit 484f750
* Fri Dec 14 2018 kbuild@suse.de
- Automatically updated to 4.20-rc6-next-20181214
- commit 3ffa3aa
* Thu Dec 13 2018 kbuild@suse.de
- Automatically updated to 4.20-rc6-next-20181213
- commit ecafc9b
* Wed Dec 12 2018 kbuild@suse.de
- Automatically updated to 4.20-rc6-next-20181212
- commit 796c22a
* Tue Dec 11 2018 kbuild@suse.de
- Automatically updated to 4.20-rc6-next-20181211
- commit 2813271
* Mon Dec 10 2018 afaerber@suse.de
- config: arm: Enable EFI support (boo#1104833)
- commit 6235ac9
* Mon Dec 10 2018 afaerber@suse.de
- config: armv7hl: Update to 4.20-rc5
- commit f119d3e
* Mon Dec 10 2018 kbuild@suse.de
- Automatically updated to 4.20-rc6-next-20181210
- commit 0a68e56
* Mon Dec 10 2018 mkubecek@suse.cz
- Update to 4.20-rc6
- Eliminated 1 patch
- Refresh configs
- commit f12c54e
* Sat Dec  8 2018 msuchanek@suse.de
- Include modules.fips in kernel-binary as well as kernel-binary-base
  (FATE#323247).
- commit e42315d
* Fri Dec  7 2018 kbuild@suse.de
- Automatically updated to 4.20-rc5-next-20181207
- commit 2ff37cc
* Thu Dec  6 2018 kbuild@suse.de
- Automatically updated to 4.20-rc5-next-20181206
- commit e0e284e
* Wed Dec  5 2018 kbuild@suse.de
- Automatically updated to 4.20-rc5-next-20181205
- commit 7e826c6
* Tue Dec  4 2018 msuchanek@suse.de
- Refresh patches.rpmify/Add-ksym-provides-tool.patch.
  HOSTLOADLIBES_ -> HOSTLDLIBS_
- commit 0202ee6
* Tue Dec  4 2018 msuchanek@suse.de
- Update config files.
- commit 360d7fb
* Tue Dec  4 2018 msuchanek@suse.de
- Refresh patches.rpmify/Add-ksym-provides-tool.patch.
  linux-next does not have CFLAGS_REMOVE_empty.o so far.
- commit dac5b8d
* Tue Dec  4 2018 kbuild@suse.de
- Automatically updated to 4.20-rc5-next-20181204
- commit 295a26c
* Mon Dec  3 2018 afaerber@suse.de
- config: armv6hl: Update to 4.20-rc5
- commit 6222a9a
* Mon Dec  3 2018 kbuild@suse.de
- Automatically updated to 4.20-rc5-next-20181203
- commit a253632
* Mon Dec  3 2018 guillaume.gardet@free.fr
- config: armv7hl: Build some options as modules (boo#1104833)
  Enable HISI_THERMAL=m while at it.
- commit 1dc0381
* Mon Dec  3 2018 mkubecek@suse.cz
- Update to 4.20-rc5
- Config changes:
  - General:
  - PSI_DEFAULT_DISABLED=y
  - Sound:
  - SND_SOC_INTEL_SKYLAKE_HDAUDIO_CODEC=y
  - ARM:
  - ARM64_ERRATUM_1286807=y
- commit c05e42c
* Fri Nov 30 2018 kbuild@suse.de
- Automatically updated to 4.20-rc4-next-20181130
- commit 6d3498f
* Wed Nov 28 2018 kbuild@suse.de
- Automatically updated to 4.20-rc4-next-20181128
- commit 19b07af
* Tue Nov 27 2018 kbuild@suse.de
- Automatically updated to 4.20-rc4-next-20181127
- commit b7c2b47
* Mon Nov 26 2018 kbuild@suse.de
- Automatically updated to 4.20-rc4-next-20181126
- commit afdae20
* Mon Nov 26 2018 mkubecek@suse.cz
- Update to 4.20-rc4
- Config changes:
  - Networking:
  - MT76_LEDS=y (split from MT76_CORE)
- commit dfaa20e
* Fri Nov 23 2018 msuchanek@suse.de
- Build ppc64le for POWER8+ (FATE#325617).
- commit 3952d52
* Fri Nov 23 2018 kbuild@suse.de
- Automatically updated to 4.20-rc3-next-20181123
- commit 64ab718
* Fri Nov 23 2018 msuchanek@suse.de
- Revert "Remove Cell/PS3 support from ppc64 kernel (boo#1114846)"
  This reverts commit fd6aaf7f98693355e7dcc5e4e1926fb1664d803b.
  Fixed upstream in 43c6494fa149 ("powerpc/io: Fix the IO workarounds code
  to work with Radix")
- commit 7f2660c
* Thu Nov 22 2018 kbuild@suse.de
- Automatically updated to 4.20-rc3-next-20181122
- commit b47113e
* Wed Nov 21 2018 kbuild@suse.de
- Automatically updated to 4.20-rc3-next-20181121
- commit eaacca2
* Tue Nov 20 2018 kbuild@suse.de
- Automatically updated to 4.20-rc3-next-20181120
- commit 312fc17
* Mon Nov 19 2018 kbuild@suse.de
- Automatically updated to 4.20-rc3-next-20181119
- commit 2eba6d8
* Mon Nov 19 2018 mkubecek@suse.cz
- Update to 4.20-rc3
- Refresh configs
- commit f60a009
* Fri Nov 16 2018 kbuild@suse.de
- Automatically updated to 4.20-rc2-next-20181116
- commit dd77b5a
* Thu Nov 15 2018 kbuild@suse.de
- Automatically updated to 4.20-rc2-next-20181115
- commit 2c06769
* Wed Nov 14 2018 kbuild@suse.de
- Automatically updated to 4.20-rc2-next-20181114
- commit 058884b
* Tue Nov 13 2018 msuchanek@suse.de
- Add kernel-subpackage-build.spec (FATE#326579).
  - add kernel-subpackage-build.spec.in and support scripts
  - hook it in mkspec
  - extend the mechanism that copies dependencies inside
  kernel-binary.spec.in from kernel-%%build_flavor to
  kernel-%%build_flavor-base to also handle
  kernel-subpackage-build.spec.in using BINARY DEPS marker.
  - expand %%name in kernel-%%build_flavor so the dependencies are expanded
  correctly in kernel-subpackage-build.spec.in
- commit 9b3ca32
* Tue Nov 13 2018 kbuild@suse.de
- Automatically updated to 4.20-rc2-next-20181113
- commit 0b76eb3
* Mon Nov 12 2018 kbuild@suse.de
- Automatically updated to 4.20-rc2-next-20181112
- commit ff3d74a
* Mon Nov 12 2018 mkubecek@suse.cz
- Update to 4.20-rc2
- Eliminated 1 patch
- Config changes:
  - I2C:
    I2C_NVIDIA_GPU=m
  - USB:
    UCSI_CCG=m
- commit 6fa07fa
* Sun Nov 11 2018 afaerber@suse.de
- config: arm64: Update to 4.20-rc1
- commit af7ccce
* Fri Nov  9 2018 kbuild@suse.de
- Automatically updated to 4.20-rc1-next-20181109
- commit 5203fdb
* Thu Nov  8 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: Add patches.drm for moved DRM patches
- commit 8592674
* Thu Nov  8 2018 kbuild@suse.de
- Automatically updated to 4.20-rc1-next-20181108
- commit 3945ad6
* Thu Nov  8 2018 jslaby@suse.cz
- doc/README.SUSE: correct GIT url
  No more gitorious, github we use.
- commit 31864f3
* Wed Nov  7 2018 kbuild@suse.de
- Automatically updated to 4.20-rc1-next-20181107
- commit b7c4827
* Tue Nov  6 2018 mkubecek@suse.cz
- config: reenable BPFILTER_UMH on ppc64
- commit 7c45a2f
* Tue Nov  6 2018 agraf@suse.de
- Remove Cell/PS3 support from ppc64 kernel (boo#1114846)
- commit dcf1061
* Tue Nov  6 2018 kbuild@suse.de
- Automatically updated to 4.20-rc1-next-20181106
- commit 82b6f04
* Mon Nov  5 2018 mkubecek@suse.cz
- scripts/mkmakefile: honor second argument.
- commit 9bb8d8c
* Mon Nov  5 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add macros.s into kernel-*-devel
  Starting with 4.20-rc1, file arch/*/kernel/macros.s is needed to build out
  of tree modules. Add it to kernel-${flavor}-devel packages if it exists.
- commit 09d14c8
* Mon Nov  5 2018 kbuild@suse.de
- Automatically updated to 4.20-rc1-next-20181105
- commit fde095c
* Mon Nov  5 2018 mkubecek@suse.cz
- Update to 4.20-rc1
- ARM configs need updating
- disabled (needs refresh):
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch
- Config changes:
  - General:
  - PSI=y
  - Networking:
  - NFT_XFRM=m
  - NET_SCH_TAPRIO=m
  - BATMAN_ADV_TRACING=n
  - NCSI_OEM_CMD_GET_MAC=y
  - EEPROM_EE1004=m
  - SCSI_UFS_BSG=y
  - SCSI_MYRB=m
  - SCSI_MYRS=m
  - IXGBE_IPSEC=y
  - IXGBEVF_IPSEC=y
  - IGC=m
  - NI_XGE_MANAGEMENT_ENET=m
  - MT76x0E=m
  - File systems:
  - EROFS_FS_IO_MAX_RETRIES=5 (default)
  - AFS_DEBUG_CURSOR=n
  - CONFIG_UBIFS_FS_AUTHENTICATION=y
  - Crypto:
  - CRYPTO_OFB=m
  - CRYPTO_STATS=n
  - ASYMMETRIC_TPM_KEY_SUBTYPE=m
  - PKCS8_PRIVATE_KEY_PARSER=m
  - TPM_KEY_PARSER=m
  - Graphics:
  - VIDEO_VICODEC=m
  - DRM_FBDEV_LEAK_PHYS_SMEM=n
  - DRM_I915_DEBUG_RUNTIME_PM=n
  - DRM_TOSHIBA_TC358764=n
  - DRM_TI_SN65DSI86=n
  - Sound:
  - SND_SOC_INTEL_KBL_DA7219_MAX98927_MACH=m
  - SND_SOC_INTEL_SKL_HDA_DSP_GENERIC_MACH=m
  - SND_SOC_MAX98088=n
  - SND_SOC_PCM3060_I2C=n
  - SND_SOC_PCM3060_SPI=n
  - SND_SOC_NAU8822=n
  - Input devices:
  - HID_BIGBEN_FF=m
  - Platform:
  - LG_LAPTOP=m
  - INTEL_ATOMISP2_PM=m
  - IIO:
  - ADXL372_SPI=n
  - ADXL372_I2C=n
  - MCP3911=n
  - QCOM_SPMI_ADC5=n
  - LTC1660=n
  - VL53L0X_I2C=m
  - Misc drivers:
  - UDMABUF=y
  - MFD_AT91_USART=n
  - LEDS_AN30259A=n
  - LEDS_TRIGGER_PATTERN=m
  - PHY_CADENCE_DP=m
  - STM_PROTO_BASIC=m
  - STM_PROTO_SYS_T=m
  - Testing:
  - TEST_XARRAY=n
  - TEST_MEMCAT_P=n
  - x86:
  - X86_CPA_STATISTICS=n (y for -debug)
  - i386:
  - MSCC_OCELOT_SWITCH_OCELOT=m
  - ppc64, ppc64le:
  - PAPR_SCM=m
  - PCI_P2PDMA=y
  - STACKPROTECTOR=y
  - STACKPROTECTOR_STRONG=n
  - BLK_DEV_PMEM=m
  - ND_BLK=m
  - BTT=y
  - NVDIMM_PFN=y
  - NVDIMM_DAX=y
  - OF_PMEM=m
  - DEV_DAX_PMEM=m
  - FAIL_FUNCTION=n
  - ENA_ETHERNET=m
  - s390:
  - VMAP_STACK=y
  - S390_AP_IOMMU=n
  - ZCRYPT_MULTIDEVNODES=y
  - KASAN=n
  - */debug:
  - INTEL_IOMMU_DEBUGFS=y
  - BPF_KPROBE_OVERRIDE=y
  - CONFIG_X86_CPA_STATISTICS=y
  - CONFIG_CRYPTO_STATS=y
- commit 2b5eb8e
* Sun Nov  4 2018 mkubecek@suse.cz
- rpm: use syncconfig instead of silentoldconfig where available
  Since mainline commit 0085b4191f3e ("kconfig: remove silentoldconfig
  target"), "make silentoldconfig" can be no longer used. Use "make
  syncconfig" instead if available.
- commit a239c6e
* Fri Nov  2 2018 mkubecek@suse.cz
- config: enable SCSI_AACRAID on ppc64le and ppc64 (bsc#1114523)
- commit a2061cc
* Fri Nov  2 2018 kbuild@suse.de
- Automatically updated to 4.19-next-20181102
- commit 74391ea
* Thu Nov  1 2018 kbuild@suse.de
- Automatically updated to 4.19-next-20181101
- commit a60b276
* Wed Oct 31 2018 kbuild@suse.de
- Automatically updated to 4.19-next-20181031
- commit fdd30b3
* Tue Oct 30 2018 kbuild@suse.de
- Automatically updated to 4.19-next-20181030
- commit 3796773
* Tue Oct 30 2018 jmoreira@suse.de
- Add version information to KLP_SYMBOLS file
- commit f77f8d2
* Thu Oct 25 2018 mwilck@suse.com
- rpm/kernel-binary.spec.in: allow unsupported modules for -extra
  (bsc#1111183). SLE-15 and later only.
- commit 0d585a8
* Mon Oct 22 2018 mkubecek@suse.cz
- Update to 4.19 final
- Refresh configs
- commit 952a7de
* Fri Oct 19 2018 kbuild@suse.de
- Automatically updated to 4.19-rc8-next-20181019
- commit 313306c
* Thu Oct 18 2018 kbuild@suse.de
- Automatically updated to 4.19-rc8-next-20181018
- commit 71640e8
* Wed Oct 17 2018 kbuild@suse.de
- Automatically updated to 4.19-rc8-next-20181017
- commit 8ecfdb4
* Tue Oct 16 2018 kbuild@suse.de
- Automatically updated to 4.19-rc8-next-20181016
- commit bf1cc47
* Mon Oct 15 2018 kbuild@suse.de
- Automatically updated to 4.19-rc7-next-20181015
- commit 105a036
* Fri Oct 12 2018 kbuild@suse.de
- Automatically updated to 4.19-rc7-next-20181012
- commit a1ea04b
* Fri Oct 12 2018 tzimmermann@suse.de
- README: Clean-up trailing whitespace
- commit 06542f9
* Thu Oct 11 2018 tzimmermann@suse.de
- README: Update documentation wrt. Patch-mainline
  Common practice is to set Patch-mainline to a Linux release tag. More
  than 95%% of all patches follow this convention. The remaining 5%% have
  been fixed accordingly in SLE15.
  The README file is inconsistent wrt. to the content of Patch-mainline.
  In some places it refers to a release tag, in others it refers to a version
  number. With this cleanup, it refers to release tags everywhere.
  This change is a follow-up for commit 1d81d2699cd3.
- commit 57326f5
* Thu Oct 11 2018 kbuild@suse.de
- Automatically updated to 4.19-rc7-next-20181011
- commit ec249d9
* Wed Oct 10 2018 kbuild@suse.de
- Automatically updated to 4.19-rc7-next-20181010
- commit df79097
* Tue Oct  9 2018 kbuild@suse.de
- Automatically updated to 4.19-rc7-next-20181009
- commit e5683bd
* Tue Oct  9 2018 msuchanek@suse.de
- Revert "Limit kernel-source build to architectures for which we build binaries"
  This reverts commit d6435125446d740016904abe30a60611549ae812.
- commit 48b03c4
* Mon Oct  8 2018 kbuild@suse.de
- Automatically updated to 4.19-rc7-next-20181008
- commit 8fe45d5
* Fri Oct  5 2018 kbuild@suse.de
- Automatically updated to 4.19-rc6-next-20181005
- commit 8bf6e4b
* Thu Oct  4 2018 kbuild@suse.de
- Automatically updated to 4.19-rc6-next-20181004
- commit 1249da4
* Thu Oct  4 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1110716)
  Enable ST LPS25H pressure sensor.
- commit a43d330
* Tue Oct  2 2018 kbuild@suse.de
- Automatically updated to 4.19-rc6-next-20181002
- commit 720248b
* Tue Oct  2 2018 nborisov@suse.com
- Update config files. (boo##1109665)
- commit d7972ed
* Mon Oct  1 2018 msuchanek@suse.de
- rpm/mkspec: fix ppc64 kernel-source build.
- commit 85c9272
* Fri Sep 28 2018 kbuild@suse.de
- Automatically updated to 4.19-rc5-next-20180928
- commit cbd64f9
* Thu Sep 27 2018 msuchanek@suse.de
- rpm/mkspec: build dtbs for architectures marked -!needs_updating
- commit 2d47640
* Thu Sep 27 2018 msuchanek@suse.de
- Limit kernel-source build to architectures for which we build binaries
  (bsc#1108281).
- commit d643512
* Thu Sep 27 2018 kbuild@suse.de
- Automatically updated to 4.19-rc5-next-20180927
- commit c1b79d6
* Wed Sep 26 2018 kbuild@suse.de
- Automatically updated to 4.19-rc5-next-20180926
- commit cbade30
* Tue Sep 25 2018 mbrugger@suse.com
- arm64: Update config files.
  Increase NR_CPUS to 480 (fate#325592)
- commit 9c8fef5
* Tue Sep 25 2018 kbuild@suse.de
- Automatically updated to 4.19-rc5-next-20180925
- commit 59e19c6
* Mon Sep 24 2018 kbuild@suse.de
- Automatically updated to 4.19-rc5-next-20180924
- commit 4325789
* Fri Sep 21 2018 kbuild@suse.de
- Automatically updated to 4.19-rc4-next-20180921
- commit ac15630
* Thu Sep 20 2018 kbuild@suse.de
- Automatically updated to 4.19-rc4-next-20180920
- commit 2ee9707
* Wed Sep 19 2018 kbuild@suse.de
- Automatically updated to 4.19-rc4-next-20180919
- commit 5c5438e
* Tue Sep 18 2018 kbuild@suse.de
- Automatically updated to 4.19-rc4-next-20180918
- commit 5119778
* Mon Sep 17 2018 mkubecek@suse.cz
- Update to 4.19-rc4
- Eliminated 1 patch
- Config changes:
  - Filesystems:
  - EROFS_FS=m
  - EROFS_FS_DEBUG=n
  - EROFS_FS_XATTR=y
  - EROFS_FS_POSIX_ACL=y
  - EROFS_FS_SECURITY=y
  - EROFS_FS_USE_VM_MAP_RAM=n
  - EROFS_FAULT_INJECTION=n
  - EROFS_FS_ZIP=n
- commit 3bdc0a3
* Fri Sep 14 2018 msuchanek@suse.de
- doc/README.SUSE: Remove mentions of cloneconfig (bsc#1103636).
- commit 3371adc
* Thu Sep 13 2018 kbuild@suse.de
- Automatically updated to 4.19-rc3-next-20180913
- commit e91fdab
* Wed Sep 12 2018 kbuild@suse.de
- Automatically updated to 4.19-rc3-next-20180912
- commit 4d87936
* Tue Sep 11 2018 kbuild@suse.de
- Automatically updated to 4.19-rc3-next-20180911
- commit 0ce6ca3
* Mon Sep 10 2018 msuchanek@suse.de
- macros.kernel-source: pass -b properly in kernel module package
  (bsc#1107870).
- commit 66709cd
* Mon Sep 10 2018 kbuild@suse.de
- Automatically updated to 4.19-rc2-next-20180910
- commit fac558d
* Mon Sep 10 2018 mkubecek@suse.cz
- Update to 4.19-rc3
- refresh configs
- commit df98ef4
* Fri Sep  7 2018 jeffm@suse.com
- config: disable HFS_FS
  It has no maintainer and has been a source of fuzzer bugs.  hfsplus handles
  the HFS+ file system that became the default on MacOS in 1998.
- commit 4f1e938
* Fri Sep  7 2018 kbuild@suse.de
- Automatically updated to 4.19-rc2-next-20180907
- commit 8fe9994
* Thu Sep  6 2018 kbuild@suse.de
- Automatically updated to 4.19-rc2-next-20180906
- commit 26d85d0
* Wed Sep  5 2018 kbuild@suse.de
- Automatically updated to 4.19-rc2-next-20180905
- commit 02c6547
* Tue Sep  4 2018 kbuild@suse.de
- Automatically updated to 4.19-rc2-next-20180904
- commit faf7c29
* Mon Sep  3 2018 kbuild@suse.de
- Automatically updated to 4.19-rc2-next-20180903
- commit ca5984c
* Mon Sep  3 2018 jslaby@suse.cz
- rpm/kernel-binary.spec.in: fix call of split-modules
  split-modules is called with some parameters depending on config
  options. But since we do not use backslash consistelny, the call to
  split-modules might be evaluated so that also the following cat
  command is appended. Avoid this behaviour by using backslashes
  everywhere and add %%nil to the end.
  This perhaps never happens, but stay on the safe side.
- commit 32df888
* Mon Sep  3 2018 mkubecek@suse.cz
- Update to 4.19-rc2
- refresh configs
- commit a22fa8c
* Sat Sep  1 2018 afaerber@suse.de
- config: arm64: Increase SERIAL_8250_RUNTIME_UARTS to 32 (boo#1073193)
  (cherry picked from commit 0dbc49ba128ef0931ca04cf22ec5c638534f5b23)
- commit ddb64c4
* Sat Sep  1 2018 afaerber@suse.de
- config: Enable SERIAL_SC16IS7XX_SPI on arm and x86 (bsc#1105672, fate#326668)
  (cherry picked from commit cdc9eced6d892ff77abbeef5f0d5eb38c114602c)
- commit b314f5b
* Sat Sep  1 2018 afaerber@suse.de
- config: Consistently increase SERIAL_8250_NR_UARTS to 32 (boo#1073193)
  (cherry picked from commit acb36abf212a3a7428d958798d678d82351f4658)
- commit 099c0c1
* Sat Sep  1 2018 afaerber@suse.de
- config: armv7hl: Update to 4.19-rc1
- commit 0b1c307
* Sat Sep  1 2018 afaerber@suse.de
- config: armv7hl: Update to 4.18.5 (bsc#1012628)
  (cherry picked from commit fa0ebc5508eedec2c9108cafdf854a8c53a28a83)
  [AF: Don't re-enable the configs yet]
- commit fc7614c
* Sat Sep  1 2018 afaerber@suse.de
- config: armv6hl: Update to 4.19-rc1
- commit 5bf544c
* Fri Aug 31 2018 afaerber@suse.de
- config: armv6hl: Update to 4.18.5 (bsc#1012628)
  (cherry picked from commit e9071067714392290f6b0d525c77c8abfa8cf075)
  [AF: Don't re-enable configs yet]
- commit 677660c
* Fri Aug 31 2018 afaerber@suse.de
- config: arm64: Update to 4.19-rc1
- commit 29013ce
* Fri Aug 31 2018 kbuild@suse.de
- Automatically updated to 4.19-rc1-next-20180831
- commit 06ee88e
* Thu Aug 30 2018 kbuild@suse.de
- Automatically updated to 4.19-rc1-next-20180830
- commit 9d88615
* Wed Aug 29 2018 mkubecek@suse.cz
- kernel-binary: check also bzImage on s390/s390x
  Starting with 4.19-rc1, uncompressed image is no longer built on s390x.
  If file "image" is not found in arch/s390/boot after the build, try bzImage
  instead.
  For now, install bzImage under the name image-* until we know grub2 and our
  grub2 scripts can handle correct name.
- commit 92b52c6
* Wed Aug 29 2018 kbuild@suse.de
- Automatically updated to 4.19-rc1-next-20180829
- commit 9d6df36
* Tue Aug 28 2018 kbuild@suse.de
- Automatically updated to 4.19-rc1-next-20180828
- commit 3f7c61d
* Mon Aug 27 2018 kbuild@suse.de
- Automatically updated to 4.19-rc1-next-20180827
- commit e994c42
* Mon Aug 27 2018 mkubecek@suse.cz
- Update to 4.19-rc1
- Eliminated 179 patches (167 stable, 12 other)
- ARM configs need updating
- Config changes:
  - Block:
  - BLK_CGROUP_IOLATENCY=y
  - Networking:
  - XFRM_INTERFACE=m
  - NETFILTER_NETLINK_OSF=m
  - NFT_TUNNEL=m
  - NFT_OSF=m
  - NFT_TPROXY=m
  - NET_SCH_ETF=m
  - NET_SCH_SKBPRIO=m
  - NET_SCH_CAKE=m
  - CAN_UCAN=m
  - BT_HCIUART_RTL=y
  - BT_MTKUART=m
  - BCMGENET=m
  - SYSTEMPORT=m
  - BNXT_HWMON=y
  - NET_VENDOR_CADENCE=y	(rename)
  - BE2NET_BE2=y
  - BE2NET_BE3=y
  - BE2NET_LANCER=y
  - BE2NET_SKYHAWK=y
  - MLX5_EN_ARFS=y
  - MLX5_EN_RXNFC=y
  - NET_VENDOR_NETERION=y
  - NET_VENDOR_PACKET_ENGINES=y
  - MT76x0U=m
  - MT76x2U=m
  - IEEE802154_HWSIM=m
  - File systems:
  - OVERLAY_FS_METACOPY=n
  - UBIFS_FS_XATTR=y
  - PSTORE_ZSTD_COMPRESS=y
  - CIFS_ALLOW_INSECURE_LEGACY=y
  - Security:
  - RANDOM_TRUST_CPU=n
  - IMA_APPRAISE_BUILD_POLICY=n
  - Hacking:
  - CONSOLE_LOGLEVEL_QUIET=4
  - KPROBE_EVENTS_ON_NOTRACE=n
  - TEST_BITFIELD=n
  - TEST_IDA=n
  - Library:
  - CRC64=m
  - Graphics:
  - VIDEO_CROS_EC_CEC=m
  - DRM_DP_CEC=y
  - DRM_VKMS=m
  - TINYDRM_ILI9341=n
  - FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER=y
  - Sound:
  - SND_SOC_INTEL_GLK_RT5682_MAX98357A_MACH=m
  - SND_SOC_ES7241=n
  - SND_SOC_SIMPLE_AMPLIFIER=n
  - Input:
  - TOUCHSCREEN_ADC=m
  - TOUCHSCREEN_BU21029=m
  - HID_COUGAR=m
  - USB:
  - TYPEC_DP_ALTMODE=m
  - Multifunction:
  - MFD_MADERA=m
  - MFD_MADERA_I2C=m
  - MFD_MADERA_SPI=m
  - GPIO_MADERA=m
  - MFD_CS47L35=y
  - MFD_CS47L85=y
  - MFD_CS47L90=y
  - IIO:
  - BME680=m
  - AD5758=n
  - SI1133=n
  - ISL29501=m
  - FPGA:
  - FPGA_DFL=m
  - FPGA_DFL_FME=m
  - FPGA_DFL_FME_MGR=m
  - FPGA_DFL_FME_BRIDGE=m
  - FPGA_DFL_FME_REGION=m
  - FPGA_DFL_AFU=m
  - FPGA_DFL_PCI=m
  - XILINX_PR_DECOUPLER=m
  - Power management:
  - IDLE_INJECT=y
  - CHARGER_ADP5061=m
  - CHARGER_CROS_USBPD=m
  - SENSORS_MLXREG_FAN=m
  - SENSORS_NPCM7XX=m
  - Misc drivers:
  - GNSS=m
  - GNSS_SERIAL=m
  - GNSS_SIRF_SERIAL=m
  - GNSS_UBX_SERIAL=m
  - MTD_SPI_NAND=m
  - NVM_PBLK_DEBUG=n
  - PINCTRL_ICELAKE=m
  - COMMON_CLK_MAX9485=n
  - IOMMU_DEFAULT_PASSTHROUGH=n
  - XEN:
  - XEN_GRANT_DMA_ALLOC=y
  - XEN_GNTDEV_DMABUF=y
  - x86:
  - STAGING_GASKET_FRAMEWORK=m
  - STAGING_APEX_DRIVER=m
  - XIL_AXIS_FIFO=m
  - TOUCHSCREEN_DMI=y
  - I2C_MULTI_INSTANTIATE=m
  - CROS_EC_I2C=m
  - CROS_EC_SPI=m
  - MLXREG_IO=m
  - i386:
  - PCIE_XILINX=y
  - MFD_ROHM_BD718XX=n
  - DRM_PANEL_ILITEK_ILI9881C=n
  - MMC_SDHCI_OF_DWCMSHC=n
  - PAGE_TABLE_ISOLATION=y
  - PowerPC:
  - I2C_MUX_PINCTRL=m
  - I2C_DEMUX_PINCTRL=m
  - I2C_FSI=m
  - DEBUG_PINCTRL=n
  - PINCTRL_AMD=m
  - PINCTRL_MCP23S08=n
  - PINCTRL_SINGLE=n
  - PINCTRL_SX150X=n
  - LEDS_AAT1290=n
  - FSI_NEW_DEV_NODE=n
  - FSI_SBEFIFO=m
  - S/390:
  - KERNEL_GZIP=y
  - S2IO=m
  - VXGE=m
  - VXGE_DEBUG_TRACE_ALL=n
  - HAMACHI=m
  - YELLOWFIN=m
  - MDIO_BCM_UNIMAC=m
  - ISM=m
  - */debug:
  - NVM_PBLK_DEBUG=y
  - IOMMU_DEBUGFS=y
  - PREEMPTIRQ_DELAY_TEST=m
- commit e57803c
* Fri Aug 24 2018 kbuild@suse.de
- Automatically updated to 4.18-next-20180824
- commit 6bc01a5
* Fri Aug 24 2018 jslaby@suse.cz
- Update config files.
- Delete
  patches.suse/revert-mm-relax-deferred-struct-page-requirements.patch.
  We actually do not this non-upstream revert. We only need the config
  change. That is: leave DEFERRED_STRUCT_PAGE_INIT=n for i386 as it was
  before 4.16.
- commit c57c75a
* Thu Aug 23 2018 kbuild@suse.de
- Automatically updated to 4.18-next-20180823
- commit 59d7f54
* Wed Aug 22 2018 kbuild@suse.de
- Automatically updated to 4.18-next-20180822
- commit 7cf7e65
* Tue Aug 21 2018 kbuild@suse.de
- Automatically updated to 4.18-next-20180821
- commit 976db8f
* Mon Aug 20 2018 kbuild@suse.de
- Automatically updated to 4.18-next-20180820
- commit 9e83667
* Fri Aug 17 2018 kbuild@suse.de
- Automatically updated to 4.18-next-20180817
- commit 0fa6157
* Fri Aug 17 2018 mkubecek@suse.cz
- rpm/constraints.in: raise memory constraints
  Build statistics show that most architectures already need more than 2 GB.
  Require 4 GB except s390x where the memory usage is much lower and we might
  have trouble finding any compliant worker.
- commit 71aefb3
* Thu Aug 16 2018 msuchanek@suse.de
- Refresh patches.rpmify/Add-ksym-provides-tool.patch.
- commit f9a55c8
* Thu Aug 16 2018 msuchanek@suse.de
- Update config files.
- commit a356055
* Thu Aug 16 2018 kbuild@suse.de
- Automatically updated to 4.18-next-20180816
- commit 6becbac
* Wed Aug 15 2018 mkubecek@suse.cz
- Update config files.
- commit cd74c39
* Wed Aug 15 2018 jslaby@suse.cz
- Linux 4.18.1-rc1
  It contains the L1TF fixes, so push the rc1 for now.
- x86/paravirt: Fix spectre-v2 mitigations for paravirt guests
  (bnc#1012628).
- x86/speculation: Protect against userspace-userspace spectreRSB
  (bnc#1012628).
- kprobes/x86: Fix %%p uses in error messages (bnc#1012628).
- x86/irqflags: Provide a declaration for native_save_fl
  (bnc#1012628).
- x86/speculation/l1tf: Increase 32bit PAE __PHYSICAL_PAGE_SHIFT
  (bnc#1012628).
- x86/speculation/l1tf: Change order of offset/type in swap entry
  (bnc#1012628).
- x86/speculation/l1tf: Protect swap entries against L1TF
  (bnc#1012628).
- x86/speculation/l1tf: Protect PROT_NONE PTEs against speculation
  (bnc#1012628).
- x86/speculation/l1tf: Make sure the first page is always
  reserved (bnc#1012628).
- x86/speculation/l1tf: Add sysfs reporting for l1tf
  (bnc#1012628).
- x86/speculation/l1tf: Disallow non privileged high MMIO
  PROT_NONE mappings (bnc#1012628).
- x86/speculation/l1tf: Limit swap file size to MAX_PA/2
  (bnc#1012628).
- x86/bugs: Move the l1tf function and define pr_fmt properly
  (bnc#1012628).
- sched/smt: Update sched_smt_present at runtime (bnc#1012628).
- x86/smp: Provide topology_is_primary_thread() (bnc#1012628).
- x86/topology: Provide topology_smt_supported() (bnc#1012628).
- cpu/hotplug: Make bringup/teardown of smp threads symmetric
  (bnc#1012628).
- cpu/hotplug: Split do_cpu_down() (bnc#1012628).
- cpu/hotplug: Provide knobs to control SMT (bnc#1012628).
- x86/cpu: Remove the pointless CPU printout (bnc#1012628).
- x86/cpu/AMD: Remove the pointless detect_ht() call
  (bnc#1012628).
- x86/cpu/common: Provide detect_ht_early() (bnc#1012628).
- x86/cpu/topology: Provide detect_extended_topology_early()
  (bnc#1012628).
- x86/cpu/intel: Evaluate smp_num_siblings early (bnc#1012628).
- x86/CPU/AMD: Do not check CPUID max ext level before parsing
  SMP info (bnc#1012628).
- x86/cpu/AMD: Evaluate smp_num_siblings early (bnc#1012628).
- x86/apic: Ignore secondary threads if nosmt=force (bnc#1012628).
- x86/speculation/l1tf: Extend 64bit swap file size limit
  (bnc#1012628).
- x86/cpufeatures: Add detection of L1D cache flush support
  (bnc#1012628).
- x86/CPU/AMD: Move TOPOEXT reenablement before reading
  smp_num_siblings (bnc#1012628).
- x86/speculation/l1tf: Protect PAE swap entries against L1TF
  (bnc#1012628).
- x86/speculation/l1tf: Fix up pte->pfn conversion for PAE
  (bnc#1012628).
- Revert "x86/apic: Ignore secondary threads if nosmt=force"
  (bnc#1012628).
- cpu/hotplug: Boot HT siblings at least once (bnc#1012628).
- x86/KVM: Warn user if KVM is loaded SMT and L1TF CPU bug being
  present (bnc#1012628).
- x86/KVM/VMX: Add module argument for L1TF mitigation
  (bnc#1012628).
- x86/KVM/VMX: Add L1D flush algorithm (bnc#1012628).
- x86/KVM/VMX: Add L1D MSR based flush (bnc#1012628).
- x86/KVM/VMX: Add L1D flush logic (bnc#1012628).
- x86/KVM/VMX: Split the VMX MSR LOAD structures to have an
  host/guest numbers (bnc#1012628).
- x86/KVM/VMX: Add find_msr() helper function (bnc#1012628).
- x86/KVM/VMX: Separate the VMX AUTOLOAD guest/host number
  accounting (bnc#1012628).
- x86/KVM/VMX: Extend add_atomic_switch_msr() to allow VMENTER
  only MSRs (bnc#1012628).
- x86/KVM/VMX: Use MSR save list for IA32_FLUSH_CMD if required
  (bnc#1012628).
- cpu/hotplug: Online siblings when SMT control is turned on
  (bnc#1012628).
- x86/litf: Introduce vmx status variable (bnc#1012628).
- x86/kvm: Drop L1TF MSR list approach (bnc#1012628).
- x86/l1tf: Handle EPT disabled state proper (bnc#1012628).
- x86/kvm: Move l1tf setup function (bnc#1012628).
- x86/kvm: Add static key for flush always (bnc#1012628).
- x86/kvm: Serialize L1D flush parameter setter (bnc#1012628).
- x86/kvm: Allow runtime control of L1D flush (bnc#1012628).
- cpu/hotplug: Expose SMT control init function (bnc#1012628).
- cpu/hotplug: Set CPU_SMT_NOT_SUPPORTED early (bnc#1012628).
- x86/bugs, kvm: Introduce boot-time control of L1TF mitigations
  (bnc#1012628).
- Documentation: Add section about CPU vulnerabilities
  (bnc#1012628).
- x86/speculation/l1tf: Unbreak !__HAVE_ARCH_PFN_MODIFY_ALLOWED
  architectures (bnc#1012628).
- x86/KVM/VMX: Initialize the vmx_l1d_flush_pages' content
  (bnc#1012628).
- Documentation/l1tf: Fix typos (bnc#1012628).
- cpu/hotplug: detect SMT disabled by BIOS (bnc#1012628).
- x86/KVM/VMX: Don't set l1tf_flush_l1d to true from
  vmx_l1d_flush() (bnc#1012628).
- x86/KVM/VMX: Replace 'vmx_l1d_flush_always' with
  'vmx_l1d_flush_cond' (bnc#1012628).
- x86/KVM/VMX: Move the l1tf_flush_l1d test to vmx_l1d_flush()
  (bnc#1012628).
- x86/irq: Demote irq_cpustat_t::__softirq_pending to u16
  (bnc#1012628).
- x86/KVM/VMX: Introduce per-host-cpu analogue of l1tf_flush_l1d
  (bnc#1012628).
- x86: Don't include linux/irq.h from asm/hardirq.h (bnc#1012628).
- x86/irq: Let interrupt handlers set kvm_cpu_l1tf_flush_l1d
  (bnc#1012628).
- x86/KVM/VMX: Don't set l1tf_flush_l1d from
  vmx_handle_external_intr() (bnc#1012628).
- Documentation/l1tf: Remove Yonah processors from not vulnerable
  list (bnc#1012628).
- x86/speculation: Simplify sysfs report of VMX L1TF vulnerability
  (bnc#1012628).
- x86/speculation: Use ARCH_CAPABILITIES to skip L1D flush on
  vmentry (bnc#1012628).
- KVM: VMX: Tell the nested hypervisor to skip L1D flush on
  vmentry (bnc#1012628).
- cpu/hotplug: Fix SMT supported evaluation (bnc#1012628).
- x86/speculation/l1tf: Invert all not present mappings
  (bnc#1012628).
- x86/speculation/l1tf: Make pmd/pud_mknotpresent() invert
  (bnc#1012628).
- x86/mm/pat: Make set_memory_np() L1TF safe (bnc#1012628).
- x86/mm/kmmio: Make the tracer robust against L1TF (bnc#1012628).
- tools headers: Synchronise x86 cpufeatures.h for L1TF additions
  (bnc#1012628).
- x86/microcode: Allow late microcode loading with SMT disabled
  (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Update config files.
- commit 40b4d05
* Tue Aug 14 2018 kbuild@suse.de
- Automatically updated to 4.18-next-20180814
- commit 8c2407d
* Mon Aug 13 2018 kbuild@suse.de
- Automatically updated to 4.18-next-20180813
- commit e8af89c
* Mon Aug 13 2018 mkubecek@suse.cz
- Update to 4.18-final.
- Refresh configs
- commit 17f1838
* Fri Aug 10 2018 kbuild@suse.de
- Automatically updated to 4.18-rc8-next-20180810
- commit c2d4365
* Thu Aug  9 2018 kbuild@suse.de
- Automatically updated to 4.18-rc8-next-20180809
- commit f1f9e4b
* Wed Aug  8 2018 kbuild@suse.de
- Automatically updated to 4.18-rc8-next-20180808
- commit 1a0d64a
* Tue Aug  7 2018 mkubecek@suse.cz
- config: refresh s390x/vanilla
  Add new option CONFIG_SYSTEM_DATA_VERIFICATION=n
- commit fa79b7c
* Tue Aug  7 2018 kbuild@suse.de
- Automatically updated to 4.18-rc8-next-20180806
- commit 987b924
* Mon Aug  6 2018 mkubecek@suse.cz
- Update to 4.18-rc8
- commit a9297d2
* Fri Aug  3 2018 kbuild@suse.de
- Automatically updated to 4.18-rc7-next-20180803
- commit 1d03345
* Thu Aug  2 2018 kbuild@suse.de
- Automatically updated to 4.18-rc7-next-20180802
- commit 2d1ac76
* Wed Aug  1 2018 kbuild@suse.de
- Automatically updated to 4.18-rc7-next-20180801
- commit 7513d20
* Tue Jul 31 2018 kbuild@suse.de
- Automatically updated to 4.18-rc7-next-20180731
- commit 196689f
* Sat Jul 28 2018 kbuild@suse.de
- Automatically updated to 4.18-rc6-next-20180727
- commit afbafd0
* Thu Jul 26 2018 kbuild@suse.de
- Automatically updated to 4.18-rc6-next-20180726
- commit a010d81
* Wed Jul 25 2018 kbuild@suse.de
- Automatically updated to 4.18-rc6-next-20180725
- commit 8900bd8
* Tue Jul 24 2018 kbuild@suse.de
- Automatically updated to 4.18-rc6-next-20180724
- commit 0280f85
* Tue Jul 24 2018 dmueller@suse.com
- Reenable v8.1/v8.2 aarch64 extensions
  These were enabled already in SLE15 and we want to default to the
  upstream defaults, which enable these features.
  Config changes:
  - aarch64:
    HW_AFDBM=y
    PAN=y
    LSE_ATOMICS=y
    VHE=y
    UAO=y
    SVE=y
- commit adf768e
* Mon Jul 23 2018 msuchanek@suse.de
- Update config files.
- commit 2c7c66c
* Mon Jul 23 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: Add more stuff to Recommends
  ... and move bc to Recommends as well.  All these packages are needed for
  building a kernel manually from scratch with kernel-source files.
- commit 6fcec9a
* Mon Jul 23 2018 kbuild@suse.de
- Automatically updated to 4.18-rc6-next-20180723
- commit 7eed136
* Mon Jul 23 2018 mkubecek@suse.cz
- Update to 4.18-rc6
- Config changes:
  - NF_TABLES_SET=m (replaces NFT_SET_{RBTREE,HASH,BITMAP})
- commit 5e9f220
* Sun Jul 22 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: require bc for kernel-source
  This is needed for building include/generated/timeconst.h from
  kernel/time/timeconst.bc.
- commit d725e3b
* Fri Jul 20 2018 kbuild@suse.de
- Automatically updated to 4.18-rc5-next-20180720
- commit 0f69bc0
* Thu Jul 19 2018 kbuild@suse.de
- Automatically updated to 4.18-rc5-next-20180719
- commit 9d7c49b
* Wed Jul 18 2018 kbuild@suse.de
- Automatically updated to 4.18-rc5-next-20180718
- commit c3a8cd3
* Tue Jul 17 2018 tiwai@suse.de
- Update config files: enable CONFIG_I2C_PXA for arm64 (bsc#1101465)
- commit d407d39
* Tue Jul 17 2018 kbuild@suse.de
- Automatically updated to 4.18-rc5-next-20180717
- commit fa32fa1
* Mon Jul 16 2018 msuchanek@suse.de
- Pass x86 as architecture on x86_64 and i386 (bsc#1093118).
- commit 5f24fb0
* Mon Jul 16 2018 msuchanek@suse.de
- Revert "kconfig: only write '# CONFIG_FOO is not set' for
  visible symbols" (bsc#1093118).
- commit f9aba3d
* Mon Jul 16 2018 kbuild@suse.de
- Automatically updated to 4.18-rc5-next-20180716
- commit d76c0e6
* Fri Jul 13 2018 kbuild@suse.de
- Automatically updated to 4.18-rc4-next-20180713
- commit d22d344
* Thu Jul 12 2018 kbuild@suse.de
- Automatically updated to 4.18-rc4-next-20180712
- commit 452b007
* Wed Jul 11 2018 kbuild@suse.de
- Automatically updated to 4.18-rc4-next-20180711
- commit e69d731
* Tue Jul 10 2018 kbuild@suse.de
- Automatically updated to 4.18-rc4-next-20180710
- commit b2a0b92
* Mon Jul  9 2018 kbuild@suse.de
- Automatically updated to 4.18-rc3-next-20180709
- commit 4af0141
* Mon Jul  9 2018 mkubecek@suse.cz
- Update to 4.18-rc4
- Eliminated 1 patch
- Config changes:
  - s390x:
  - RSEQ=y
  - DEBUG_REQ=n
- commit 90f284f
* Fri Jul  6 2018 kbuild@suse.de
- Automatically updated to 4.18-rc3-next-20180706
- commit 04dd05e
* Thu Jul  5 2018 kbuild@suse.de
- Automatically updated to 4.18-rc3-next-20180705
- commit ddb0da9
* Wed Jul  4 2018 kbuild@suse.de
- Automatically updated to 4.18-rc3-next-20180704
- commit 6000587
* Tue Jul  3 2018 kbuild@suse.de
- Automatically updated to 4.18-rc3-next-20180703
- commit 68adf6a
* Mon Jul  2 2018 kbuild@suse.de
- Automatically updated to 4.18-rc2-next-20180702
- commit 31d4b79
* Mon Jul  2 2018 mkubecek@suse.cz
- Update to 4.18-rc3
- Eliminated 6 patches
- Config changes:
  - Input:
  - INPUT_SC27XX_VIBRA=m (aarch64 only)
- commit 7683d18
* Fri Jun 29 2018 kbuild@suse.de
- Automatically updated to 4.18-rc2-next-20180629
- commit f7f1caf
* Thu Jun 28 2018 kbuild@suse.de
- Automatically updated to 4.18-rc2-next-20180628
- commit e7074d6
* Wed Jun 27 2018 kbuild@suse.de
- Automatically updated to 4.18-rc2-next-20180627
- commit 445f239
* Tue Jun 26 2018 kbuild@suse.de
- Automatically updated to 4.18-rc2-next-20180626
- commit 36f9aba
* Mon Jun 25 2018 kbuild@suse.de
- Automatically updated to 4.18-rc2-next-20180625
- commit 16d2f54
* Sun Jun 24 2018 mkubecek@suse.cz
- Update to 4.18-rc2
- Eliminated 1 patch
- Config changes:
  - aarch64: reenable DWMAC_SOCFPGA (=m)
- commit dedde09
* Sun Jun 24 2018 afaerber@suse.de
- config: arm64: Update to 4.18-rc1
- commit 53f46f4
* Fri Jun 22 2018 kbuild@suse.de
- Automatically updated to 4.18-rc1-next-20180622
- commit 40b1499
* Thu Jun 21 2018 kbuild@suse.de
- Automatically updated to 4.18-rc1-next-20180621
- commit f307d6f
* Wed Jun 20 2018 kbuild@suse.de
- Automatically updated to 4.18-rc1-next-20180620
- commit f0469f9
* Tue Jun 19 2018 kbuild@suse.de
- Automatically updated to 4.18-rc1-next-20180619
- commit 21d0128
* Tue Jun 19 2018 msuchanek@suse.de
- Update config to gcc8 features.
- commit 74767bb
* Mon Jun 18 2018 msuchanek@suse.de
- macros.kernel-source: define linux_arch for KMPs (boo#1098050).
  CONFIG_64BIT is no longer defined so KMP spec files need to include
  %%{?linux_make_arch} in any make call to build modules or descent into
  the kernel directory for any reason.
- commit 5dc40af
* Mon Jun 18 2018 kbuild@suse.de
- Automatically updated to 4.18-rc1-next-20180618
- commit c4ec0d1
* Mon Jun 18 2018 mkubecek@suse.cz
- config: update ppc64le configs
- commit d33e313
* Mon Jun 18 2018 mkubecek@suse.cz
- config: enable NETDEVSIM (as module)
- commit 2f8d475
* Mon Jun 18 2018 mkubecek@suse.cz
- Update to 4.18-rc1.
- Eliminated 66 patches (62 stable, 4 other).
- ARM configs need updating.
- Config changes:
  - General:
  - RSEQ=y
  - i386:
  - BPF_JIT=y
  - BPF_JIT_ALWAYS_ON=y
  - powerpc:
  - LD_DEAD_CODE_DATA_ELIMINATION=n (experimental)
  - s390:
  - FW_LOADER_USER_HELPER=y
  - PCI:
  - PCI_HOST_GENERIC=y
  - Network:
  - TLS_DEVICE=y
  - XDP_SOCKETS=y
  - NFT_CONNLIMIT=m
  - NFT_SOCKET=m
  - IP_VS_MH=m
  - IP_VS_MH_TAB_INDEX=12 (default)
  - NF_TPROXY_IPV4=m
  - NF_TPROXY_IPV6=m
  - BPFILTER=y
  - BPFILTER_UMH=m
  - FAILOVER=m
  - MLX5_EN_TLS=y
  - NET_VENDOR_MICROSEMI=y
  - MSCC_OCELOT_SWITCH=m
  - MSCC_OCELOT_SWITCH_OCELOT=m
  - NFP_APP_ABM_NIC=y
  - MDIO_MSCC_MIIM=m
  - ASIX_PHY=m
  - DP83TC811_PHY=m
  - MICROCHIP_T1_PHY=m
  - NET_FAILOVER=m
  - Block:
  - DM_WRITECACHE=m
  - Input:
  - MOUSE_PS2_ELANTECH_SMBUS=y
  - TOUCHSCREEN_CHIPONE_ICN8505=m
  - HID_STEAM=m
  - Misc:
  - SPI_MEM=y
  - GPIOLIB_FASTPATH_LIMIT=512 (default)
  - VIDEO_CADENCE=y
  - LCD_OTM3225A=n
  - CHROMEOS_TBMC=m
  - FPGA_MGR_MACHXO2_SPI=m
  - Graphics:
  - DRM_I2C_NXP_TDA9950=m
  - DRM_I915_DEBUG_GUC=n
  - DRM_CDNS_DSI=n
  - DRM_THINE_THC63LVD1024=n
  - DRM_XEN=y
  - DRM_XEN_FRONTEND=m
  - Sound:
  - SND_SOC_SSM2305=n
  - SND_SOC_TSCS454=n
  - SND_SOC_WM8782=n
  - SND_SOC_MT6351=n
  - SND_XEN_FRONTEND=m
  - LED:
  - LEDS_CR0014114=m
  - LEDS_LM3601X=m
  - USB:
  - TYPEC_RT1711H=m
  - IIO:
  - AD5686_SPI=n
  - AD5696_I2C=n
  - TI_DAC5571=n
  - TSL2772=n
  - IIO_RESCALE=n
  - Filesystems:
  - PROC_VMCORE_DEVICE_DUMP=y
  - EVM_ADD_XATTRS=y
  - Testing:
  - TEST_OVERFLOW=n
  - Crypto:
  - CRYPTO_AEGIS128=m
  - CRYPTO_AEGIS128L=m
  - CRYPTO_AEGIS256=m
  - CRYPTO_AEGIS128_AESNI_SSE2=m
  - CRYPTO_AEGIS128L_AESNI_SSE2=m
  - CRYPTO_AEGIS256_AESNI_SSE2=m
  - CRYPTO_MORUS640=m
  - CRYPTO_MORUS640_SSE2=m
  - CRYPTO_MORUS1280=m
  - CRYPTO_MORUS1280_SSE2=m
  - CRYPTO_MORUS1280_AVX2=m
  - CRYPTO_ZSTD=m
- commit 680f4ab
* Mon Jun 18 2018 mkubecek@suse.cz
- rpm: ignore CONFIG_GCC_VERSION when checking for oldconfig changes
  Since 4.18-rc1, "make oldconfig" writes gcc version and capabilities into
  generated .config. Thus whenever we build the package or run checks with
  different gcc version than used to update config/*/*, check for "outdated
  configs" fails.
  As a quick band-aid, omit the lines with CONFIG_GCC_VERSION from both
  configs before comparing them. This way, the check won't fail unless run
  with newer gcc which would add new capabilities. More robust solution will
  require a wider discussion.
- commit 546ef32
* Sat Jun 16 2018 jslaby@suse.cz
- Revert "mm: relax deferred struct page requirements"
  (bnc#1092466).
- Update config files.
- commit 1dcbbca
* Fri Jun 15 2018 kbuild@suse.de
- Automatically updated to 4.17-next-20180615
- commit 9071996
* Thu Jun 14 2018 kbuild@suse.de
- Automatically updated to 4.17-next-20180614
- commit f44b3cd
* Wed Jun 13 2018 kbuild@suse.de
- Automatically updated to 4.17-next-20180613
- commit 2df7467
* Tue Jun 12 2018 kbuild@suse.de
- Automatically updated to 4.17-next-20180612
- commit d834976
* Fri Jun  8 2018 kbuild@suse.de
- Automatically updated to 4.17-next-20180608
- commit 9987e6b
* Thu Jun  7 2018 kbuild@suse.de
- Automatically updated to 4.17-next-20180607
- commit 380ccc5
* Wed Jun  6 2018 kbuild@suse.de
- Automatically updated to 4.17-next-20180605
- commit c08b530
* Tue Jun  5 2018 kbuild@suse.de
- Automatically updated to 4.17-next-20180604
- commit 3e7207f
* Mon Jun  4 2018 mkubecek@suse.cz
- config: enable preemption in i386/debug
- commit ebb6f79
* Mon Jun  4 2018 mkubecek@suse.cz
- Update to 4.17-final
- commit 7f668df
* Sat Jun  2 2018 kbuild@suse.de
- Automatically updated to 4.17-rc7-next-20180601
- commit e973a79
* Thu May 31 2018 kbuild@suse.de
- Automatically updated to 4.17-rc7-next-20180531
- commit f4c3c65
* Wed May 30 2018 kbuild@suse.de
- Automatically updated to 4.17-rc7-next-20180529
- commit 1767c64
* Tue May 29 2018 kbuild@suse.de
- Automatically updated to 4.17-rc6-next-20180525
- commit 0931442
* Mon May 28 2018 mkubecek@suse.cz
- Update to 4.17-rc7
- Eliminated 1 patch
- Config changes:
  - reenable SSB_DRIVER_PCICORE and dependencies after revert of
    commit 882164a4a928
- commit 8ae83bf
* Wed May 23 2018 msuchanek@suse.de
- mkspec: only build docs for default variant kernel.
- commit 045f5ac
* Thu May 17 2018 msuchanek@suse.de
- kernel-{binary,docs}.spec sort dependencies.
- commit d2ab971
* Thu May 17 2018 mgalbraith@suse.de
- Fix config/x86_64/debug, turn PREEMPT_NONE off, and PREEMPT_DEBUG on.
- commit 01b8dcd
* Thu May 17 2018 kbuild@suse.de
- Automatically updated to 4.17-rc5-next-20180517
- commit a65ca17
* Wed May 16 2018 msuchanek@suse.de
- macros.kernel-source: Fix building non-x86 KMPs
- commit 8631d05
* Wed May 16 2018 kbuild@suse.de
- Automatically updated to 4.17-rc5-next-20180516
- commit 1a3f5d8
* Tue May 15 2018 jeffm@suse.com
- reiserfs: package in separate KMP (FATE#323394).
- commit d14f152
* Tue May 15 2018 kbuild@suse.de
- Automatically updated to 4.17-rc5-next-20180515
- commit 8c5944a
* Mon May 14 2018 msuchanek@suse.de
- macros.kernel-source: ignore errors when using make to print kernel release
  There is no way to handle the errors anyway and including the error into
  package version does not give good results.
- commit 282e9a6
* Mon May 14 2018 kbuild@suse.de
- Automatically updated to 4.17-rc4-next-20180514
- commit fb789fb
* Mon May 14 2018 mkubecek@suse.cz
- Update to 4.17-rc5
- commit 1d366f5
* Fri May 11 2018 msuchanek@suse.de
- Revert "kernel-binary: do not package extract-cert when not signing modules"
  This reverts commit 10a8bc496a553b8069d490a8ae7508bdb19f58d9.
- commit 1f7acca
* Fri May 11 2018 kbuild@suse.de
- Automatically updated to 4.17-rc4-next-20180511
- commit 2abd284
* Thu May 10 2018 kbuild@suse.de
- Automatically updated to 4.17-rc4-next-20180510
- commit 1964eff
* Tue May  8 2018 kbuild@suse.de
- Automatically updated to 4.17-rc4-next-20180508
- commit a59991b
* Mon May  7 2018 kbuild@suse.de
- Automatically updated to 4.17-rc3-next-20180507
- commit cac5bc2
* Fri May  4 2018 kbuild@suse.de
- Automatically updated to 4.17-rc3-next-20180504
- commit f2a4cea
* Thu May  3 2018 kbuild@suse.de
- Automatically updated to 4.17-rc3-next-20180503
- commit 1a0c9b5
* Wed May  2 2018 msuchanek@suse.de
- kernel-binary: also default klp_symbols to 0 here.
- commit e35f14a
* Wed May  2 2018 msuchanek@suse.de
- klp_symbols: make --klp-symbols argument semantic sane
  It selects build of klp symbols and defaults to off
- commit 0e53042
* Wed May  2 2018 kbuild@suse.de
- Automatically updated to 4.17-rc3-next-20180502
- commit 7c60211
* Tue May  1 2018 kbuild@suse.de
- Automatically updated to 4.17-rc3-next-20180501
- commit 76d41ef
* Mon Apr 30 2018 kbuild@suse.de
- Automatically updated to 4.17-rc3-next-20180430
- commit c8cfe63
* Mon Apr 30 2018 mkubecek@suse.cz
- Update to 4.17-rc3
- Eliminated 1 patch
- Config changes:
  - x86_64 and i386
  - SND_SST_ATOM_HIFI2_PLATFORM_ACPI=m
  - armv7hl
  - CONFIG_NFT_REDIR_IPV4=m (sync with other configs)
  - CONFIG_NFT_REDIR_IPV6=m (sync with other configs)
- commit 34975a8
* Sun Apr 29 2018 afaerber@suse.de
- config: armv7hl: Update to 4.17-rc2
- commit 293d056
* Sun Apr 29 2018 afaerber@suse.de
- config: armv6hl: Update to 4.17-rc2
- commit a586fe4
* Sun Apr 29 2018 afaerber@suse.de
- config: arm64: Update to 4.17-rc2
- commit 3b0fcca
* Fri Apr 27 2018 msuchanek@suse.de
- kernel-binary: only install modules.fips on modular kernels.
- commit 2cb2bec
* Thu Apr 26 2018 kbuild@suse.de
- Automatically updated to 4.17-rc2-next-20180426
- commit 7872999
* Tue Apr 24 2018 msuchanek@suse.de
- split-modules: use MAKE_ARGS
- commit d8fe174
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass MAKE_ARGS to install script as well.
- commit ce62ae7
* Tue Apr 24 2018 mkubecek@suse.cz
- Update config files.
- commit 57d6246
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass ARCH= to kernel build
  Recent kernel does not save CONFIG_64BIT so it has to be specified by
  arch.
- commit fb21b73
* Tue Apr 24 2018 kbuild@suse.de
- Automatically updated to 4.17-rc2-next-20180424
- commit b36ec36
* Tue Apr 24 2018 mkubecek@suse.cz
- config: fix i386 configs
  Since mainline commit f467c5640c29 ("kconfig: only write '# CONFIG_FOO is
  not set' for visible symbols"), make silentoldconfig (or make syncconfig as
  it is called now) doesn't add CONFIG_64BIT line into i386 configs if called
  with ARCH=i386.
  During the build, it's called without ARCH=i386 so that it requests this
  option to be entered manually and the build fails. Long term solution would
  probably be passing ARCH=%%{cpu_arch} to all make commands; for now, just
  add CONFIG_64BIT line to i386/pae to fix the build as is.
- commit 7241f73
* Mon Apr 23 2018 mkubecek@suse.cz
- Update to 4.17-rc2
- Eliminated 2 patches
- Config changes:
  - s390x:
  - KEXEC_FILE=y
- commit a0aa4ec
* Mon Apr 23 2018 kbuild@suse.de
- Automatically updated to 4.17-rc1-next-20180423
- commit da3fd9b
* Fri Apr 20 2018 kbuild@suse.de
- Automatically updated to 4.17-rc1-next-20180420
- commit 6bd99cc
* Fri Apr 20 2018 mkubecek@suse.cz
- Update to 4.17-rc1.
- Eliminated 55 patches (51 stable 4.16.x)
- ARM configs need updating.
- Config changes:
  - x86:
  - ACPI_TAD=m
  - s390:
  - EXPOLINE_FULL=y
  - VT=y
  - CONSOLE_TRANSLATIONS=y
  - VT_CONSOLE=y
  - VT_HW_CONSOLE_BINDING=n
  - DUMMY_CONSOLE_COLUMNS=80
  - DUMMY_CONSOLE_ROWS=25
  - SPEAKUP=n
  - Network:
  - NF_TABLES_INET=y
  - NF_TABLES_NETDEV=y
  - NF_TABLES_ARP=y
  - NF_TABLES_BRIDGE=y
  - NET_EMATCH_IPT=m
  - ICE=m
  - RSI_COEX=y
  - IEEE802154_MCR20A=m
  - INFINIBAND_EXP_LEGACY_VERBS_NEW_UAPI=n
  - Filesystems:
  - OVERLAY_FS_XINO_AUTO=n
  - PSTORE_DEFLATE_COMPRESS=m
  - PSTORE_LZ4HC_COMPRESS=m
  - PSTORE_842_COMPRESS=n
  - PSTORE_DEFLATE_COMPRESS_DEFAULT=deflate
  - Crypto:
  - CRYPTO_CFB=m
  - CRYPTO_SM4=m
  - CRYPTO_SPECK=m
  - CRYPTO_DEV_CHELSIO_TLS=m
  - Input:
  - JOYSTICK_PXRC=m
  - HID_ELAN=m
  - HID_GOOGLE_HAMMER=m
  - Sound:
  - SND_SOC_INTEL_CHT_BSW_NAU8824_MACH=m
  - SND_SOC_INTEL_KBL_DA7219_MAX98357A_MACH=m
  - SND_SOC_AK4458=n
  - SND_SOC_AK5558=n
  - SND_SOC_BD28623=n
  - SND_SOC_MAX9867=n
  - SND_SOC_PCM1789_I2C=n
  - SND_SOC_TDA7419=m
  - SND_SOC_MAX9759=n
  - USB:
  - TYPEC_MUX_PI3USB30532=m
  - USB_ROLES_INTEL_XHCI=m
  - GPIO:
  - GPIO_104_DIO_48E=m
  - GPIO_104_IDIO_16=m
  - GPIO_104_IDI_48=m
  - GPIO_GPIO_MM=m
  - GPIO_WINBOND=m
  - GPIO_WS16C48=m
  - Media:
  - CEC_PIN_ERROR_INJ=n
  - CXD2880_SPI_DRV=m
  - MTK_MMC=n
  - IIO:
  - 104_QUAD_8=m
  - CIO_DAC=n
  - AD5272=m
  - MCP4018=m
  - MLX90632=m
  - Other:
  - THERMAL_STATISTICS=y
  - EBC_C384_WDT=m
  - LEDS_MLXREG=m
  - COMMON_CLK_SI544=n
  - STX104=n
  - LV0104CS=n
  - Remote controlers:
  - IR_IMON_DECODER=m
  - IR_IMON_RAW=m
  - INTEL_TH_ACPI=m
  - Debugging:
  - DEBUG_RWSEMS=n
- commit 5fcd3a7
* Fri Apr 20 2018 mkubecek@suse.cz
- config: enable TCP_MD5SIG (bsc#1090162)
- commit b479997
* Fri Apr 20 2018 msuchanek@suse.de
- HID: redragon: Fix modifier keys for Redragon Asura Keyboard
  (https://build.opensuse.org/request/show/597583).
  Update config files.
- commit 6ab92b0
* Thu Apr 19 2018 kbuild@suse.de
- Automatically updated to 4.17-rc1-next-20180419
- commit b142c16
* Wed Apr 18 2018 kbuild@suse.de
- Automatically updated to 4.17-rc1-next-20180418
- commit b6c44d0
* Tue Apr 17 2018 kbuild@suse.de
- Automatically updated to 4.17-rc1-next-20180417
- commit 047aae1
* Mon Apr 16 2018 kbuild@suse.de
- Automatically updated to 4.17-rc1-next-20180416
- commit 1689ccb
* Mon Apr 16 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1089764)
  Increase NR_CPUS to 384
- commit b4f8666
* Fri Apr 13 2018 kbuild@suse.de
- Automatically updated to 4.16-next-20180413
- commit 9ec2d9a
* Thu Apr 12 2018 kbuild@suse.de
- Automatically updated to 4.16-next-20180412
- commit 2b79ff7
* Wed Apr 11 2018 kbuild@suse.de
- Automatically updated to 4.16-next-20180411
- commit 2c23e8f
* Wed Apr 11 2018 jslaby@suse.cz
- Update config files.
  s390x/vanilla fails to build without this.
- commit 326b580
* Tue Apr 10 2018 msuchanek@suse.de
- rpm/package-descriptions: fix typo in kernel-azure
- Add azure kernel description.
- commit af0f13e
* Tue Apr 10 2018 kbuild@suse.de
- Automatically updated to 4.16-next-20180410
- commit d6e704a
* Mon Apr  9 2018 kbuild@suse.de
- Automatically updated to 4.16-next-20180409
- commit 6a29620
* Fri Apr  6 2018 kbuild@suse.de
- Automatically updated to 4.16-next-20180406
- commit 6290786
* Fri Apr  6 2018 agraf@suse.de
- armv6hl: Disable uacces with memcpy (boo#1080435)
- commit 8e78432
* Thu Apr  5 2018 kbuild@suse.de
- Automatically updated to 4.16-next-20180405
- commit 0240a7e
* Wed Apr  4 2018 kbuild@suse.de
- Automatically updated to 4.16-next-20180404
- commit 6f6a23e
* Tue Apr  3 2018 kbuild@suse.de
- Automatically updated to 4.16-next-20180403
- commit 4ae1199
* Mon Apr  2 2018 jeffm@suse.com
- Update to 4.16-final.
- commit 19ebb62
* Thu Mar 29 2018 kbuild@suse.de
- Automatically updated to 4.16-rc7-next-20180329
- commit 8f5f6d4
* Wed Mar 28 2018 kbuild@suse.de
- Automatically updated to 4.16-rc7-next-20180328
- commit 03f15e8
* Tue Mar 27 2018 kbuild@suse.de
- Automatically updated to 4.16-rc7-next-20180327
- commit 4b66791
* Mon Mar 26 2018 jeffm@suse.com
- Update to 4.16-rc7.
- Eliminated 1 patch.
- commit c9eade5
* Fri Mar 23 2018 agraf@suse.de
- armv7hl: Disable uacces with memcpy (boo#1080435)
- commit 632818b
* Fri Mar 23 2018 kbuild@suse.de
- Automatically updated to 4.16-rc6-next-20180323
- commit 1064a17
* Thu Mar 22 2018 kbuild@suse.de
- Automatically updated to 4.16-rc6-next-20180322
- commit 8da5c6d
* Wed Mar 21 2018 kbuild@suse.de
- Automatically updated to 4.16-rc6-next-20180321
- commit 14714d3
* Tue Mar 20 2018 kbuild@suse.de
- Automatically updated to 4.16-rc6-next-20180320
- commit 7e0d9d9
* Mon Mar 19 2018 kbuild@suse.de
- Automatically updated to 4.16-rc5-next-20180319
- commit f6774df
* Mon Mar 19 2018 msuchanek@suse.de
- kernel-*.spec: remove remaining occurences of %%release from dependencies
  There is a mix of %%release and %%source_rel in manually added
  dependencies and the %%release dependencies tend to fail due to rebuild
  sync issues. So get rid of them.
- commit b4ec514
* Fri Mar 16 2018 kbuild@suse.de
- Automatically updated to 4.16-rc5-next-20180316
- commit 84a7b78
* Thu Mar 15 2018 kbuild@suse.de
- Automatically updated to 4.16-rc5-next-20180315
- commit df541d1
* Wed Mar 14 2018 jeffm@suse.com
- config: sync i386/default
  Some options had been removed completely.
- commit 8a98c99
* Wed Mar 14 2018 jeffm@suse.com
- rpm/kernel-source.spec.in: Add check-module-license to Sources
  The package builds in the build service but the script won't make it
  into the SRPM if it's not in the Sources list.
- commit 031ed9e
* Wed Mar 14 2018 kbuild@suse.de
- Automatically updated to 4.16-rc5-next-20180314
- commit 000f2ce
* Tue Mar 13 2018 msuchanek@suse.de
- mkspec: fix perl warning
- commit f15670f
* Tue Mar 13 2018 kbuild@suse.de
- Automatically updated to 4.16-rc5-next-20180313
- commit ec42ab3
* Mon Mar 12 2018 jeffm@suse.com
- Update to 4.16-rc5.
- Eliminated 1 patch.
- commit 03e79ab
* Sun Mar 11 2018 afaerber@suse.de
- config: armv7hl: Update to 4.16-rc4
- commit ba82f1a
* Sun Mar 11 2018 afaerber@suse.de
- config: armv6hl: Update to 4.16-rc4
- commit 76710d3
* Sat Mar 10 2018 jeffm@suse.com
- kernel: add release status to kernel build (bsc#FATE#325281).
- commit 88741f9
* Sat Mar 10 2018 jeffm@suse.com
- rpm: use %%_sourcedir prefix for release-projects
- rpm: set SUSE_KERNEL_RELEASED based on project name
  Set SUSE_KERNEL_RELEASED in the config only if the project name matches
  a list of projects that are part of official release channels.  This
  list of projects is maintained per-branch.
- commit a391a5b
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is an unreleased internal configuration intended for kernel
  developers to use in simple virtual machines.  It contains only the
  device drivers necessary to use a KVM virtual machine *without* device
  passthrough enabled.  Common local and network file systems are enabled.
  All device mapper targets are enabled.  Only the network and graphics
  drivers for devices that qemu emulates are enabled.  Many subsystems
  enabled in the default kernel are entirely disabled.  This kernel is
  meant to be small and to build very quickly.  There will be no kABI
  stability and its configuration may be changed arbitrarily.
- commit 088f1da
* Fri Mar  9 2018 jeffm@suse.com
- config: convert kvmsmall to fragment config
- commit 1a463f9
* Fri Mar  9 2018 jeffm@suse.com
- config: disabled some more options for kvmsmall
  Disable CAN, BT, rare partition types, unused mouse protocols, UIO,
  STM, and others.
- commit 3fd917a
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is intended for kernel developers to use in simple virtual
  machines.  It contains only the device drivers necessary to use a
  KVM virtual machine *without* device passthrough enabled.  Common
  local and network file systems are enabled.  All device mapper targets
  are enabled.  Only the network and graphics drivers for devices that qemu
  emulates are enabled.  Many subsystems enabled in the default kernel
  are entirely disabled.  This kernel is meant to be small and to build
  very quickly.
- commit 73312c7
* Fri Mar  9 2018 kbuild@suse.de
- Automatically updated to 4.16-rc4-next-20180309
- commit a7dd8a2
* Thu Mar  8 2018 msuchanek@suse.de
- mkspec: do not build dtbs for architectures with no kernel.
- commit 8394abf
* Thu Mar  8 2018 jeffm@suse.com
- kconfig: move SUSE options from init/Kconfig to init/Kconfig.suse
- commit c7bf062
* Thu Mar  8 2018 kbuild@suse.de
- Automatically updated to 4.16-rc4-next-20180308
- commit 4c2f9f9
* Wed Mar  7 2018 afaerber@suse.de
- config: arm64: Update to 4.16-rc4
- commit 02afac6
* Wed Mar  7 2018 tiwai@suse.de
- rpm/kernel-binary.spec.in: Check module licenses (bsc#1083215,bsc#1083527)
- commit e41de0c
* Wed Mar  7 2018 kbuild@suse.de
- Automatically updated to 4.16-rc4-next-20180307
- commit 37ab82f
* Tue Mar  6 2018 jslaby@suse.cz
- Update config files.
  Enable module signing (bnc#1082905):
  * CONFIG_MODULE_SIG=y
  * # CONFIG_MODULE_SIG_FORCE is not set
  * # CONFIG_MODULE_SIG_ALL is not set
  * # CONFIG_MODULE_SIG_SHA1 is not set
  * # CONFIG_MODULE_SIG_SHA224 is not set
  * CONFIG_MODULE_SIG_SHA256=y
  * # CONFIG_MODULE_SIG_SHA384 is not set
  * # CONFIG_MODULE_SIG_SHA512 is not set
  * CONFIG_MODULE_SIG_HASH="sha256"
  * CONFIG_MODULE_SIG_KEY="certs/signing_key.pem"
  * CONFIG_SECONDARY_TRUSTED_KEYRING=y
  * CONFIG_SYSTEM_BLACKLIST_KEYRING=y
  * CONFIG_SYSTEM_BLACKLIST_HASH_LIST=""
  This commit synchronizes these options with SLE15.
  We do not add patches for loading keys from the shim layer (as in
  SLE15) for the time being. They were rejected multiple times in
  upstream and we do not want to forward-port them infinitely. This only
  means that loading KMPs with none/invalid signatures generates this:
  <module_name>: loading out-of-tree module taints kernel.
  <module_name>: module verification failed: signature and/or required key missing - tainting kernel
  But the modules load fine after that as we have MODULE_SIG_FORCE set
  to 'n'.
  Tested in qemu+OVMF and bare metal and everything looks fine.
- commit 1fe6b80
* Tue Mar  6 2018 kbuild@suse.de
- Automatically updated to 4.16-rc4-next-20180306
- commit 9d3f96b
* Mon Mar  5 2018 msuchanek@suse.de
- rpm: provide %%name%%-srchash = <kernel-source commit hash> (FATE#325312).
  - Also use for kernel-obs-build dependency.
- commit b6fccdf
* Mon Mar  5 2018 kbuild@suse.de
- Automatically updated to 4.16-rc3-next-20180305
- commit 0274143
* Mon Mar  5 2018 jeffm@suse.com
- Update to 4.16-rc4.
- IBRS patches need review.
- commit 0ea2557
* Sun Mar  4 2018 msuchanek@suse.de
- arch-symbols: use bash as interpreter since the script uses bashism.
- commit 4cdfb23
* Fri Mar  2 2018 msuchanek@suse.de
- kernel-binary: do not BuildIgnore m4.
  It is actually needed for regenerating zconf when it is not up-to-date
  due to merge.
- commit 967b28b
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add build requirement for flex
  In addition to bison, we also need flex for "make oldconfig".
- commit 83d831c
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: remove m4 from BuildIgnore list
  As bison depends on m4, we cannot set !BuildIgnore for it any more.
- commit d7695e1
* Fri Mar  2 2018 kbuild@suse.de
- Automatically updated to 4.16-rc3-next-20180302
- commit 9880014
* Thu Mar  1 2018 kbuild@suse.de
- Automatically updated to 4.16-rc3-next-20180301
- commit cade58e
* Wed Feb 28 2018 msuchanek@suse.de
- bs-upload-kernel: do not set %%opensuse_bs
  Since SLE15 it is not set in the distribution project so do not set it
  for kernel projects either.
- commit d696aa0
* Wed Feb 28 2018 kbuild@suse.de
- Automatically updated to 4.16-rc3-next-20180228
- commit 0b4af3f
* Wed Feb 28 2018 jeffm@suse.com
- kernel: add product-identifying information to kernel build (FATE#325281).
- commit 77f1a25
* Tue Feb 27 2018 msuchanek@suse.de
- Revert "rpm/kernel-binary.spec.in: Also require m4 for build."
  This reverts commit 0d7b4b3f948c2efb67b7d1b95b5e1dcae225991c.
- commit f5686d2
* Tue Feb 27 2018 kbuild@suse.de
- Automatically updated to 4.16-rc3-next-20180227
- commit 4530fce
* Tue Feb 27 2018 tiwai@suse.de
- kernel-binary: do not package extract-cert when not signing modules
  (boo#1080250).
- commit 10a8bc4
* Tue Feb 27 2018 jeffm@suse.com
- Update to 4.16-rc2.
- Eliminated 1 patch.
- Config changes:
  - i386:
  - X86_MINIMUM_CPU_FAMILY (set automatically by oldconfig).
- commit 523831c
* Tue Feb 27 2018 jeffm@suse.com
- Update to 4.16-rc1.
- Eliminated 624 patches (mostly 4.15.x).
- ARM configs need updating.
- Config changes:
  - General:
  - CC_STACKPROTECTOR_REGULAR=y
  - x86:
  - ACPI_SPCR_TABLE=y
  - ACER_WIRELESS=m
  - GPD_POCKET_FAN=m
  - INTEL_CHTDC_TI_PWRBTN=m
  - MELLANOX_PLATFORM=y
  - MLXREG_HOTPLUG=m
  - JAILHOUSE_GUEST=y
  - i386:
  - MLX_PLATFORM=m
  - DEFERRED_STRUCT_PAGE_INIT=y
  - powerpc:
  - PPC_MEM_KEYS=y
  - OCXL=m
  - PPC_IRQ_SOFT_MASK_DEBUG=n
  - s390:
  - KERNEL_NOBP=y
  - EXPOLINE=y
  - EXPOLINE_FULL=y
  - PCI:
  - PCIE_CADENCE_HOST=y
  - PCIE_CADENCE_EP=y
  - Network:
  - NF_FLOW_TABLE=m
  - NF_FLOW_TABLE_IPV4=m
  - NF_FLOW_TABLE_IPV6=m
  - IP6_NF_MATCH_SRH=m
  - BT_HCIBTUSB_AUTOSUSPEND=y
  - NET_VENDOR_CORTINA=y
  - GEMINI_ETHERNET=m
  - NET_VENDOR_SOCIONEXT=y
  - NETDEVSIM=n
  - NFT_FLOW_OFFLOAD=m
  - NF_FLOW_TABLE_INET=m
  - Block:
  - BLK_DEV_NULL_BLK_FAULT_INJECTION=n
  - SATA_MOBILE_LPM_POLICY=0
  - DM_UNSTRIPED=m
  - MMC_SDHCI_F_SDH30=n
  - Misc:
  - MISC_RTSX_PCI=m
  - MISC_RTSX_USB=m
  - HW_RANDOM_TPM=y (from m)
  - I2C_GPIO_FAULT_INJECTOR=n
  - PINCTRL_AXP209=m
  - GPIO_WINBOND=m
  - GPIO_PCIE_IDIO_24=m
  - SENSORS_W83773G=m
  - MFD_CROS_EC_CHARDEV=n
  - RAVE_SP_CORE=n
  CAVIUM_PTP=m
  - Graphics:
  - DRM_PANEL_ILITEK_IL9322=n
  - TINYDRM_ILI9225=n
  - TINYDRM_ST7735R=n
  - Sound:
  - SND_SOC_INTEL_SST_TOPLEVEL=y
  - SND_SST_ATOM_HIFI2_PLATFORM_PCI=m
  - SND_SOC_INTEL_BYT_MAX98090_MACH=m
  - SND_SOC_INTEL_BYT_RT5640_MACH=m
  - SND_SOC_MAX98373=n
  - SND_SOC_PCM186X_I2C=n
  - SND_SOC_PCM186X_SPI=n
  - SND_SOC_TAS6424=n
  - SND_SOC_TLV320AIC32X4_I2C=n
  - SND_SOC_TLV320AIC32X4_SPI=n
  - SND_SOC_TSCS42XX=n
  - SOUNDWIRE=y
  - SOUNDWIRE_INTEL=m
  - Input:
  - HID_JABRA=n
  - USB:
  - USB_XHCI_DBGCAP=n
  - LEDS:
  - LEDS_LM3692X=n
  - LEDS_TRIGGER_NETDEV=m
  - LEDS_LP8860=n
  - RTC:
  - RTC_DRV_CROS_EC=n
  - VIRT:
  - VBOXGUEST=m
  - VIRTIO_MENU=y
  - KVM_AMD_SEV=y
  - Filesystems:
  - CIFS_SMB_DIRECT=n (still experimental)
  - Other:
  - UNISYSSPAR=n
  - XILINX_VCU=n
  - IIO_BUFFER_HW_CONSUMER=n
  - SD_ADC_MODULATOR=n
  - OF_FPGA_REGION=n
  - SIOX=n
  - SLIMBUS=n
  - BPF_KPROBE_OVERRIDE=n
  - FPGA_BRIDGE=n
  - Sensors:
  - ST_UVIS25=n
  - ZOPT2201=n
  - Media:
  - MT76x2E=m
  - LIRC=y
  - DVB_MMAP=n (still experimental)
  - DVB_ULE_DEBUG=n
  - Testing:
  - FAIL_FUNCTION=n
  - RUNTIME_TESTING_MENU=y
  - FIND_BIT_BENCHMARK=n
  - Crypto:
  - CHELSIO_IPSEC_INLINE=n
  - CRYPTO_DEV_SP_PSP=y
- commit 91eace5
* Mon Feb 26 2018 kbuild@suse.de
- Automatically updated to 4.16-rc2-next-20180226
- commit fc3e7d4
* Fri Feb 23 2018 kbuild@suse.de
- Automatically updated to 4.16-rc2-next-20180223
- commit 7bf4379
* Thu Feb 22 2018 lpechacek@suse.com
- rpm/kernel-spec-macros: Try harder to detect Build Service environment (bsc#1078788)
- commit a5f1a4a
* Thu Feb 22 2018 kbuild@suse.de
- Automatically updated to 4.16-rc2-next-20180222
- commit 3eebe45
* Wed Feb 21 2018 msuchanek@suse.de
- kernel-binary undefine unique_debug_names
  Some tools do not understand names like
  usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
- commit 2b90c1e
* Wed Feb 21 2018 kbuild@suse.de
- Automatically updated to 4.16-rc2-next-20180221
- commit a828de4
* Tue Feb 20 2018 kbuild@suse.de
- Automatically updated to 4.16-rc2-next-20180220
- commit d207517
* Tue Feb 20 2018 jeffm@suse.com
- config: enable IMA and EVM
- commit ff57721
* Mon Feb 19 2018 kbuild@suse.de
- Automatically updated to 4.16-rc1-next-20180219
- commit 45d9b14
* Sun Feb 18 2018 afaerber@suse.de
- config: arm64: Enable MAX77620 for Nvidia Jetson TX1 (boo#1081473)
- commit 34555b7
* Sat Feb 17 2018 jslaby@suse.cz
- Linux 4.15.4 (bnc#1012628).
- watchdog: indydog: Add dependency on SGI_HAS_INDYDOG
  (bnc#1012628).
- cifs: Fix missing put_xid in cifs_file_strict_mmap
  (bnc#1012628).
- cifs: Fix autonegotiate security settings mismatch
  (bnc#1012628).
- CIFS: zero sensitive data when freeing (bnc#1012628).
- cpufreq: mediatek: add mediatek related projects into blacklist
  (bnc#1012628).
- dmaengine: dmatest: fix container_of member in dmatest_callback
  (bnc#1012628).
- ssb: Do not disable PCI host on non-Mips (bnc#1012628).
- watchdog: gpio_wdt: set WDOG_HW_RUNNING in gpio_wdt_stop
  (bnc#1012628).
- Revert "drm/i915: mark all device info struct with __initconst"
  (bnc#1012628).
- sched/rt: Use container_of() to get root domain in
  rto_push_irq_work_func() (bnc#1012628).
- sched/rt: Up the root domain ref count when passing it around
  via IPIs (bnc#1012628).
- media: dvb-usb-v2: lmedm04: Improve logic checking of warm start
  (bnc#1012628).
- media: dvb-usb-v2: lmedm04: move ts2020 attach to
  dm04_lme2510_tuner (bnc#1012628).
- media: hdpvr: Fix an error handling path in hdpvr_probe()
  (bnc#1012628).
- arm64: cpu_errata: Add Kryo to Falkor 1003 errata (bnc#1012628).
- arm64: kpti: Make use of nG dependent on
  arm64_kernel_unmapped_at_el0() (bnc#1012628).
- arm64: mm: Permit transitioning from Global to Non-Global
  without BBM (bnc#1012628).
- arm64: kpti: Add ->enable callback to remap swapper using nG
  mappings (bnc#1012628).
- arm64: Force KPTI to be disabled on Cavium ThunderX
  (bnc#1012628).
- arm64: entry: Reword comment about post_ttbr_update_workaround
  (bnc#1012628).
- arm64: idmap: Use "awx" flags for .idmap.text .pushsection
  directives (bnc#1012628).
- arm64: barrier: Add CSDB macros to control data-value prediction
  (bnc#1012628).
- arm64: Implement array_index_mask_nospec() (bnc#1012628).
- arm64: Make USER_DS an inclusive limit (bnc#1012628).
- arm64: Use pointer masking to limit uaccess speculation
  (bnc#1012628).
- arm64: entry: Ensure branch through syscall table is bounded
  under speculation (bnc#1012628).
- arm64: uaccess: Prevent speculative use of the current
  addr_limit (bnc#1012628).
- arm64: uaccess: Don't bother eliding access_ok checks in __{get,
  put}_user (bnc#1012628).
- arm64: uaccess: Mask __user pointers for __arch_{clear,
  copy_*}_user (bnc#1012628).
- arm64: futex: Mask __user pointers prior to dereference
  (bnc#1012628).
- arm64: cpufeature: __this_cpu_has_cap() shouldn't stop early
  (bnc#1012628).
- arm64: entry: Apply BP hardening for high-priority synchronous
  exceptions (bnc#1012628).
- arm64: entry: Apply BP hardening for suspicious interrupts
  from EL0 (bnc#1012628).
- arm64: KVM: Increment PC after handling an SMC trap
  (bnc#1012628).
- arm/arm64: KVM: Consolidate the PSCI include files
  (bnc#1012628).
- arm/arm64: KVM: Add PSCI_VERSION helper (bnc#1012628).
- arm/arm64: KVM: Add smccc accessors to PSCI code (bnc#1012628).
- arm/arm64: KVM: Implement PSCI 1.0 support (bnc#1012628).
- arm/arm64: KVM: Advertise SMCCC v1.1 (bnc#1012628).
- arm/arm64: KVM: Turn kvm_psci_version into a static inline
  (bnc#1012628).
- arm64: KVM: Report SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: KVM: Add SMCCC_ARCH_WORKAROUND_1 fast handling
  (bnc#1012628).
- firmware/psci: Expose PSCI conduit (bnc#1012628).
- firmware/psci: Expose SMCCC version through psci_ops
  (bnc#1012628).
- arm/arm64: smccc: Make function identifiers an unsigned quantity
  (bnc#1012628).
- arm/arm64: smccc: Implement SMCCC v1.1 inline primitive
  (bnc#1012628).
- arm64: Add ARM_SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: Kill PSCI_GET_VERSION as a variant-2 workaround
  (bnc#1012628).
- mtd: cfi: convert inline functions to macros (bnc#1012628).
- mtd: nand: brcmnand: Disable prefetch by default (bnc#1012628).
- mtd: nand: Fix nand_do_read_oob() return value (bnc#1012628).
- mtd: nand: sunxi: Fix ECC strength choice (bnc#1012628).
- ubi: Fix race condition between ubi volume creation and udev
  (bnc#1012628).
- ubi: fastmap: Erase outdated anchor PEBs during attach
  (bnc#1012628).
- ubi: block: Fix locking for idr_alloc/idr_remove (bnc#1012628).
- ubifs: free the encrypted symlink target (bnc#1012628).
- nfs/pnfs: fix nfs_direct_req ref leak when i/o falls back to
  the mds (bnc#1012628).
- nfs41: do not return ENOMEM on LAYOUTUNAVAILABLE (bnc#1012628).
- NFS: Add a cond_resched() to nfs_commit_release_pages()
  (bnc#1012628).
- NFS: Fix nfsstat breakage due to LOOKUPP (bnc#1012628).
- NFS: commit direct writes even if they fail partially
  (bnc#1012628).
- NFS: reject request for id_legacy key without auxdata
  (bnc#1012628).
- NFS: Fix a race between mmap() and O_DIRECT (bnc#1012628).
- nfsd: Detect unhashed stids in nfsd4_verify_open_stid()
  (bnc#1012628).
- kernfs: fix regression in kernfs_fop_write caused by wrong type
  (bnc#1012628).
- ahci: Annotate PCI ids for mobile Intel chipsets as such
  (bnc#1012628).
- ahci: Add PCI ids for Intel Bay Trail, Cherry Trail and Apollo
  Lake AHCI (bnc#1012628).
- ahci: Add Intel Cannon Lake PCH-H PCI ID (bnc#1012628).
- crypto: hash - introduce crypto_hash_alg_has_setkey()
  (bnc#1012628).
- crypto: cryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: mcryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: poly1305 - remove ->setkey() method (bnc#1012628).
- crypto: hash - annotate algorithms taking optional key
  (bnc#1012628).
- crypto: hash - prevent using keyed hashes without setting key
  (bnc#1012628).
- media: v4l2-ioctl.c: use check_fmt for enum/g/s/try_fmt
  (bnc#1012628).
- media: v4l2-ioctl.c: don't copy back the result for -ENOTTY
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: add missing VIDIOC_PREPARE_BUF
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix the indentation (bnc#1012628).
- media: v4l2-compat-ioctl32.c: move 'helper' functions to
  __get/put_v4l2_format32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: avoid sizeof(type) (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy m.userptr in put_v4l2_plane32
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix ctrl_is_pointer (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy clip list in
  put_v4l2_window32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: drop pr_info for unknown buffer
  type (bnc#1012628).
- media: v4l2-compat-ioctl32.c: don't copy back the result for
  certain errors (bnc#1012628).
- media: v4l2-compat-ioctl32.c: refactor compat ioctl32 logic
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: make ctrl_is_pointer work for
  subdevs (bnc#1012628).
- crypto: caam - fix endless loop when DECO acquire fails
  (bnc#1012628).
- crypto: sha512-mb - initialize pending lengths correctly
  (bnc#1012628).
- crypto: talitos - fix Kernel Oops on hashing an empty file
  (bnc#1012628).
- arm: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bnc#1012628).
- KVM: nVMX: Fix races when sending nested PI while dest
  enters/leaves L2 (bnc#1012628).
- KVM: nVMX: Fix bug of injecting L2 exception into L1
  (bnc#1012628).
- KVM: PPC: Book3S HV: Make sure we don't re-enter guest without
  XIVE loaded (bnc#1012628).
- KVM: PPC: Book3S HV: Drop locks before reading guest memory
  (bnc#1012628).
- KVM: arm/arm64: Handle CPU_PM_ENTER_FAILED (bnc#1012628).
- KVM: PPC: Book3S PR: Fix broken select due to misspelling
  (bnc#1012628).
- ASoC: acpi: fix machine driver selection based on quirk
  (bnc#1012628).
- ASoC: rockchip: i2s: fix playback after runtime resume
  (bnc#1012628).
- ASoC: skl: Fix kernel warning due to zero NHTL entry
  (bnc#1012628).
- ASoC: compress: Correct handling of copy callback (bnc#1012628).
- watchdog: imx2_wdt: restore previous timeout after
  suspend+resume (bnc#1012628).
- afs: Add missing afs_put_cell() (bnc#1012628).
- afs: Need to clear responded flag in addr cursor (bnc#1012628).
- afs: Fix missing cursor clearance (bnc#1012628).
- afs: Fix server list handling (bnc#1012628).
- btrfs: Handle btrfs_set_extent_delalloc failure in fixup worker
  (bnc#1012628).
- Btrfs: raid56: iterate raid56 internal bio with
  bio_for_each_segment_all (bnc#1012628).
- kasan: don't emit builtin calls when sanitization is off
  (bnc#1012628).
- kasan: rework Kconfig settings (bnc#1012628).
- media: dvb_frontend: be sure to init dvb_frontend_handle_ioctl()
  return code (bnc#1012628).
- media: dvb-frontends: fix i2c access helpers for KASAN
  (bnc#1012628).
- media: dt-bindings/media/cec-gpio.txt: mention the CEC/HPD
  max voltages (bnc#1012628).
- media: ts2020: avoid integer overflows on 32 bit machines
  (bnc#1012628).
- media: vivid: fix module load error when enabling fb and
  no_error_inj=1 (bnc#1012628).
- media: cxusb, dib0700: ignore XC2028_I2C_FLUSH (bnc#1012628).
- fs/proc/kcore.c: use probe_kernel_read() instead of memcpy()
  (bnc#1012628).
- kernel/async.c: revert "async: simplify lowest_in_progress()"
  (bnc#1012628).
- kernel/relay.c: revert "kernel/relay.c: fix potential memory
  leak" (bnc#1012628).
- pipe: actually allow root to exceed the pipe buffer limits
  (bnc#1012628).
- pipe: fix off-by-one error when checking buffer limits
  (bnc#1012628).
- HID: quirks: Fix keyboard + touchpad on Toshiba Click Mini
  not working (bnc#1012628).
- Bluetooth: btsdio: Do not bind to non-removable BCM43341
  (bnc#1012628).
- Revert "Bluetooth: btusb: fix QCA Rome suspend/resume"
  (bnc#1012628).
- Bluetooth: btusb: Restore QCA Rome suspend/resume fix with a
  "rewritten" version (bnc#1012628).
- ipmi: use dynamic memory for DMI driver override (bnc#1012628).
- signal/openrisc: Fix do_unaligned_access to send the proper
  signal (bnc#1012628).
- signal/sh: Ensure si_signo is initialized in do_divide_error
  (bnc#1012628).
- alpha: fix crash if pthread_create races with signal delivery
  (bnc#1012628).
- alpha: osf_sys.c: fix put_tv32 regression (bnc#1012628).
- alpha: Fix mixed up args in EXC macro in futex operations
  (bnc#1012628).
- alpha: fix reboot on Avanti platform (bnc#1012628).
- alpha: fix formating of stack content (bnc#1012628).
- xtensa: fix futex_atomic_cmpxchg_inatomic (bnc#1012628).
- EDAC, octeon: Fix an uninitialized variable warning
  (bnc#1012628).
- genirq: Make legacy autoprobing work again (bnc#1012628).
- pinctrl: intel: Initialize GPIO properly when used through
  irqchip (bnc#1012628).
- pinctrl: mcp23s08: fix irq setup order (bnc#1012628).
- pinctrl: sx150x: Unregister the pinctrl on release
  (bnc#1012628).
- pinctrl: sx150x: Register pinctrl before adding the gpiochip
  (bnc#1012628).
- pinctrl: sx150x: Add a static gpio/pinctrl pin range mapping
  (bnc#1012628).
- pktcdvd: Fix pkt_setup_dev() error path (bnc#1012628).
- pktcdvd: Fix a recently introduced NULL pointer dereference
  (bnc#1012628).
- blk-mq: quiesce queue before freeing queue (bnc#1012628).
- clocksource/drivers/stm32: Fix kernel panic with multiple timers
  (bnc#1012628).
- lib/ubsan.c: s/missaligned/misaligned/ (bnc#1012628).
- lib/ubsan: add type mismatch handler for new GCC/Clang
  (bnc#1012628).
- objtool: Fix switch-table detection (bnc#1012628).
- arm64: dts: marvell: add Ethernet aliases (bnc#1012628).
- drm/i915: Avoid PPS HW/SW state mismatch due to rounding
  (bnc#1012628).
- ACPI: sbshc: remove raw pointer from printk() message
  (bnc#1012628).
- acpi, nfit: fix register dimm error handling (bnc#1012628).
- ovl: force r/o mount when index dir creation fails
  (bnc#1012628).
- ovl: fix failure to fsync lower dir (bnc#1012628).
- ovl: take mnt_want_write() for work/index dir setup
  (bnc#1012628).
- ovl: take mnt_want_write() for removing impure xattr
  (bnc#1012628).
- ovl: hash directory inodes for fsnotify (bnc#1012628).
- mn10300/misalignment: Use SIGSEGV SEGV_MAPERR to report a
  failed user copy (bnc#1012628).
- devpts: fix error handling in devpts_mntget() (bnc#1012628).
- ftrace: Remove incorrect setting of glob search field
  (bnc#1012628).
- scsi: core: Ensure that the SCSI error handler gets woken up
  (bnc#1012628).
- scsi: lpfc: Fix crash after bad bar setup on driver attachment
  (bnc#1012628).
- scsi: cxlflash: Reset command ioasc (bnc#1012628).
- rcu: Export init_rcu_head() and destroy_rcu_head() to GPL
  modules (bnc#1012628).
- media: dvb_frontend: fix return error code (git-fixes).
- mtd: ubi: wl: Fix error return code in ubi_wl_init()
  (git-fixes).
- Update config files.
- commit 67968b5
* Fri Feb 16 2018 kbuild@suse.de
- Automatically updated to 4.16-rc1-next-20180216
- commit 5d48f7f
* Thu Feb 15 2018 jmoreira@suse.de
- Add kernel livepatch-devel package
  Resolving non-exported static symbols in kernel livepatches cannot
  be done implicitly. For such, the relocations of these symbols must
  follow a specially crafted format in the respective elf file. Willing
  to make the task of converting the elf into the right format, a tool
  named klp-convert was proposed. Through a file that maps all kernel
  symbols into their respective kernel object, this tool infers which
  non-exported symbol is relative to a livepatch relocation and
  automatically formats the final elf file.
  Add support to the generation of a map file right after the kernel
  compilation.
  Add the package kernel-<flavour>-livepatch-devel that brings
  the map file.
- commit 0b1b4d3
* Thu Feb 15 2018 kbuild@suse.de
- Automatically updated to 4.16-rc1-next-20180215
- commit e694e87
* Wed Feb 14 2018 kbuild@suse.de
- Automatically updated to 4.16-rc1-next-20180214
- commit a21142d
* Tue Feb 13 2018 kbuild@suse.de
- Automatically updated to 4.16-rc1-next-20180213
- commit 44e6b74
* Mon Feb 12 2018 kbuild@suse.de
- Automatically updated to 4.16-rc1-next-20180212
- commit d0ab2ff
* Sun Feb 11 2018 afaerber@suse.de
- config: arm64: Enable Hi6421 PMU (bsc#1080449)
- commit c3d5ec3
* Fri Feb  9 2018 jslaby@suse.cz
- Update i386 config files.
  Switch from almost unusable UNWINDER_GUESS to UNWINDER_FRAME_POINTER
  (which enables FRAME_POINTERs). It will slow down the kernel a bit,
  but improves the stack traces by the order of magnitude. Sad is that
  we have no ORCs on i386...
- commit e0a39f0
* Fri Feb  9 2018 jslaby@suse.cz
- Update config files.
  Sync vanilla configs to 4.15.
- commit 2583453
* Fri Feb  9 2018 kbuild@suse.de
- Automatically updated to 4.15-next-20180209
- commit c2e7cef
* Thu Feb  8 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also require m4 for build.
- commit 0d7b4b3
* Thu Feb  8 2018 kbuild@suse.de
- Automatically updated to 4.15-next-20180208
- commit 70a3c0c
* Wed Feb  7 2018 msuchanek@suse.de
- Fix whitespace in series.conf
- commit 60f1256
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: install ksym-provides tool (bsc#1077692).
- commit 679f5c5
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: require bison for build.
  linux-next tends to have outdated generated files so it needs bison to
  regenerate them.
- commit 4ad1ede
* Wed Feb  7 2018 msuchanek@suse.de
- Add ksym-provides tool (bsc#1077692).
- commit 1463336
* Wed Feb  7 2018 kbuild@suse.de
- Automatically updated to 4.15-next-20180207
- commit d0a6c49
* Tue Feb  6 2018 kbuild@suse.de
- Automatically updated to 4.15-next-20180206
- commit 11dd31b
* Mon Feb  5 2018 msuchanek@suse.de
- Automatically updated to 4.15-next-20180205
- commit 6ddf93f
* Mon Feb  5 2018 msuchanek@suse.de
- Automatically updated to 4.15-10668-g35277995e179
- commit e0e79e0
* Mon Feb  5 2018 kbuild@suse.de
- Automatically updated to 4.15-next-20180205
- commit 9982876
* Fri Feb  2 2018 kbuild@suse.de
- Automatically updated to 4.15-next-20180202
- commit a3a14ff
* Thu Feb  1 2018 matwey.kornilov@gmail.com
- config: arm64: Enable RockChip 8xx
  We need RockChip RK-808 support to run openSUSE on Rock64 board (RK3328).
  Currently, even voltage regulator is missed.
- commit 3d4ddde
* Thu Feb  1 2018 kbuild@suse.de
- Automatically updated to 4.15-next-20180201
- commit 9c644fd
* Wed Jan 31 2018 kbuild@suse.de
- Automatically updated to 4.15-next-20180131
- commit be12852
* Tue Jan 30 2018 kbuild@suse.de
- Automatically updated to 4.15-next-20180130
- commit 3ec6f34
* Mon Jan 29 2018 jeffm@suse.com
- Update to 4.15-final.
- Eliminated 5 patches.
- commit 5e4691f
* Mon Jan 29 2018 kbuild@suse.de
- Automatically updated to 4.15-rc9-next-20180129
- commit 9f88d28
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable UNMAP_KERNEL_AT_EL0 and HARDEN_BRANCH_PREDICTOR
- commit 3fc66bb
* Fri Jan 26 2018 kbuild@suse.de
- Automatically updated to 4.15-rc9-next-20180126
- commit d972ba3
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable rk3399 missing drivers
  These drivers are required for Rockchip RK3399 Sapphire board
- commit e5fb37e
* Mon Jan 22 2018 msuchanek@suse.de
- rpm/mkspec-dtb: Remove COPYING file (bsc#1076905).
  It conflicts between different versions of dtb package.
- commit 0e5fcf9
* Fri Jan 19 2018 kbuild@suse.de
- Automatically updated to 4.15-rc8-next-20180119
- commit 53bebac
* Thu Jan 18 2018 kbuild@suse.de
- Automatically updated to 4.15-rc8-next-20180118
- commit 58110e1
* Thu Jan 18 2018 jslaby@suse.cz
- Update config files (bsc#1068032 CVE-2017-5715).
  Enable RETPOLINE -- the compiler is capable of them already.
- commit d3d5e6d
* Wed Jan 17 2018 rjschwei@suse.com
- kernel-obs-build.spec.in: enable xfs module
  This allows the public cloud team to build images with XFS
  as root filesystem
- commit 95a2d6f
* Wed Jan 17 2018 msuchanek@suse.de
- macros.kernel-source: pass -f properly in module subpackage (boo#1076393).
- commit 66bd9b8
* Wed Jan 17 2018 kbuild@suse.de
- Automatically updated to 4.15-rc8-next-20180117
- commit 62cb70b
* Tue Jan 16 2018 kbuild@suse.de
- Automatically updated to 4.15-rc8-next-20180116
- commit 5299ede
* Mon Jan 15 2018 jeffm@suse.com
- Update to 4.15-rc8.
- Eliminated 3 patches.
- Config changes:
  - Security:
  - BPF_JIT_ALWAYS_ON=y
  - RETPOLINE=n (depends on gcc with -mindirect-branch=thunk-extern)
- commit 106a1c6
* Mon Jan 15 2018 kbuild@suse.de
- Automatically updated to 4.15-rc7-next-20180115
- commit 4cc624e
* Fri Jan 12 2018 kbuild@suse.de
- Automatically updated to 4.15-rc7-next-20180112
- commit c9e21ff
* Thu Jan 11 2018 matwey.kornilov@gmail.com
- config: arm64: Enable Aardvark PCIe controller
  Aardvark PCIe controller is a part of Marvel Armada 3700 SoC.
  This option is required to support PCIe for JeOS-espressobin.
- commit a1edfb8
* Thu Jan 11 2018 kbuild@suse.de
- Automatically updated to 4.15-rc7-next-20180111
- commit a758f2f
* Thu Jan 11 2018 lpechacek@suse.com
- rpm/kernel-binary.spec.in: more specific kGraft Provides: (fate#323682)
  Follow openSUSE packaging practices described at
  https://en.opensuse.org/openSUSE:Package_dependencies#Renaming_a_package.
- commit 050081b
* Wed Jan 10 2018 kbuild@suse.de
- Automatically updated to 4.15-rc7-next-20180110
- commit 3226cd7
* Tue Jan  9 2018 kbuild@suse.de
- Automatically updated to 4.15-rc7-next-20180109
- commit a659a38
* Mon Jan  8 2018 kbuild@suse.de
- Automatically updated to 4.15-rc6-next-20180108
- commit 69857ab
* Mon Jan  8 2018 msuchanek@suse.de
- kernel-obs-build.spec.in: add --no-hostonly-cmdline to dracut invocation (boo#1062303).
  call dracut with --no-hostonly-cmdline to avoid the random rootfs UUID
  being added into the initrd's /etc/cmdline.d/95root-dev.conf
- commit da5186f
* Mon Jan  8 2018 jeffm@suse.com
- Update to 4.15-rc7.
- Eliminated 1 patch.
- commit aa37aa1
* Sat Jan  6 2018 jslaby@suse.cz
- rpm/constraints.in: lower kernel-syzkaller's mem requirements
  OBS now reports that it needs only around 2G, so lower the limit to
  8G, so that more compliant workers can be used.
- commit a73399a
* Fri Jan  5 2018 kbuild@suse.de
- Automatically updated to 4.15-rc6-next-20180105
- commit 7be9f06
* Thu Jan  4 2018 kbuild@suse.de
- Automatically updated to 4.15-rc6-next-20180104
- commit c8b7160
* Wed Jan  3 2018 jeffm@suse.com
- config: x86, PAGE_TABLE_ISOLATION=y (bsc#1068032).
- commit 30359cd
* Wed Jan  3 2018 kbuild@suse.de
- Automatically updated to 4.15-rc6-next-20180103
- commit 6e3d45f
* Tue Jan  2 2018 kbuild@suse.de
- Automatically updated to 4.15-rc6-next-20180102
- commit 56449fe
* Tue Jan  2 2018 jeffm@suse.com
- Update to 4.15-rc6.
- Config changes:
  - x86: PAGE_TABLE_ISOLATION=n (default, performance)
- commit 07d3845
* Mon Dec 25 2017 jeffm@suse.com
- config: disable BUG_ON_DATA_CORRUPTION
  On its face this option makes sense but it brings along with it
  DEBUG_LIST, which is very expensive and obvious on benchmarks.
- commit 6e7fd4d
* Mon Dec 25 2017 jeffm@suse.com
- config: refresh i386/default
  Commit 4735d41aeeb added a disabled CONFIG_SPI_INTEL_SPI_PLATFORM option
  that doesn't exist on i386/default (at least in 4.15-rc5).
- commit 7f27344
* Sun Dec 24 2017 jeffm@suse.com
- Update to 4.15-rc5.
- Config changes:
  - i386: NR_CPUS 128->64
  - 7bbcbd3d1cd (x86/Kconfig: Limit NR_CPUS on 32-bit to a sane amount)
- commit b761e0f
* Fri Dec 22 2017 kbuild@suse.de
- Automatically updated to 4.15-rc4-next-20171222
- commit eaf9f59
* Thu Dec 21 2017 msuchanek@suse.de
- kernel-obs-build: use pae and lpae kernels where available
  (bsc#1073579).
- commit 1ac1946
* Thu Dec 21 2017 kbuild@suse.de
- Automatically updated to 4.15-rc4-next-20171221
- commit e20ab81
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PCI as well (bsc#1073836)
- commit cdb39a0
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PLATFORM for BIOS breakge on Lenovo laptops
  (bsc#1073836)
- commit c1a8fe3
* Wed Dec 20 2017 kbuild@suse.de
- Automatically updated to 4.15-rc4-next-20171220
- commit 883c8c1
* Tue Dec 19 2017 kbuild@suse.de
- Automatically updated to 4.15-rc4-next-20171219
- commit 3ecca68
* Tue Dec 19 2017 jeffm@suse.com
- Update to 4.15-rc4.
- Eliminated 1 patch.
- Config changes:
  - ARM:
  - QCOM_FALKOR_ERRATUM_E1041=y
  - Overlayfs:
  - OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW=y (preserves existing behavior)
- commit 858f298
* Mon Dec 18 2017 kbuild@suse.de
- Automatically updated to 4.15-rc3-next-20171218
- commit a8082e8
* Sat Dec 16 2017 kbuild@suse.de
- Automatically updated to 4.15-rc3-next-20171215
- commit 0478af3
* Thu Dec 14 2017 kbuild@suse.de
- Automatically updated to 4.15-rc3-next-20171214
- commit e92477b
* Wed Dec 13 2017 kbuild@suse.de
- Automatically updated to 4.15-rc3-next-20171213
- commit ae6032e
* Tue Dec 12 2017 kbuild@suse.de
- Automatically updated to 4.15-rc3-next-20171212
- commit 81bcc68
* Mon Dec 11 2017 kbuild@suse.de
- Automatically updated to 4.15-rc2-next-20171211
- commit c1f030b
* Mon Dec 11 2017 jeffm@suse.com
- Update to 4.15-rc3.
- Eliminated 1 patch.
- commit 89ba6c8
* Sat Dec  9 2017 afaerber@suse.de
- config: armv7hl: Enable SUN4I_A10_CCU for Allwinner A20 (boo#1072032)
- commit a1e3086
* Fri Dec  8 2017 msuchanek@suse.de
- Add undefine _unique_build_ids (bsc#964063)
- commit 47e91a1
* Fri Dec  8 2017 kbuild@suse.de
- Automatically updated to 4.15-rc2-next-20171208
- commit 1a99255
* Thu Dec  7 2017 kbuild@suse.de
- Automatically updated to 4.15-rc2-next-20171207
- commit f6aa474
* Wed Dec  6 2017 kbuild@suse.de
- Automatically updated to 4.15-rc2-next-20171206
- commit 88b9d62
* Tue Dec  5 2017 kbuild@suse.de
- Automatically updated to 4.15-rc2-next-20171205
- commit 396b341
* Mon Dec  4 2017 jeffm@suse.com
- Update to 4.15-rc2.
- Eliminated 2 patches.
- commit e268cab
* Mon Dec  4 2017 kbuild@suse.de
- Automatically updated to 4.15-rc2-next-20171204
- commit 1e7ba66
* Fri Dec  1 2017 kbuild@suse.de
- Automatically updated to 4.15-rc1-next-20171201
- commit 331822f
* Thu Nov 30 2017 kbuild@suse.de
- Automatically updated to 4.15-rc1-next-20171130
- commit d4c416f
* Wed Nov 29 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: fix incorrectly moved comment
  While moving # END COMMON DEPS moved following comment with it.
- commit 858b7e7
* Wed Nov 29 2017 kbuild@suse.de
- Automatically updated to 4.15-rc1-next-20171129
- commit 74bd22b
* Tue Nov 28 2017 kbuild@suse.de
- Automatically updated to 4.15-rc1-next-20171128
- commit 1f518ac
* Tue Nov 28 2017 afaerber@suse.de
- config: armv7hl: Update to 4.15-rc1
- commit c62ce70
* Tue Nov 28 2017 afaerber@suse.de
- config: armv6hl: Update to 4.15-rc1
- commit f0b24ea
* Tue Nov 28 2017 afaerber@suse.de
- config: arm64: Update to 4.15-rc1
- commit f97438c
* Mon Nov 27 2017 jeffm@suse.com
- Update to 4.15-rc1.
- Eliminated 74 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - CPU_ISOLATION=y
  - GUP_BENCHMARK=n
  - x86:
  - X86_INTEL_UMIP=y
  - PINCTRL_CEDARFORK=m
  - INTEL_SOC_PMIC_CHTDC_TI=m
  - INTEL_WMI_THUNDERBOLT=m
  - DELL_SMBIOS_WMI=m
  - DELL_SMBIOS_SMM=m
  - CHT_DC_TI_PMIC_OPREGION=y
  - RPMSG_CHAR=m
  - i386:
  - IR_SPI=m
  - IR_GPIO_CIR=m
  - IR_GPIO_TX=m
  - IR_PWM_TX=m
  - powerpc:
  - PPC_RADIX_MMU_DEFAULT=y (default)
  - MEM_SOFT_DIRTY=n (needs arch expert review)
  - PINCTRL=n
  - PPC_FAST_ENDIAN_SWITCH=n (default)
  - s390:
  - GCC_PLUGINS=n
  - MEM_SOFT_DIRTY=(needs arch expert review)
  - PINCTRL=n
  - FORTIFY_SOURCE=y
  - s390/zfcpdump:
  - BPF_STREAM_PARSER=n
  - MTD=n
  - Network:
  - NET_SCH_CBS=m
  - VSOCKETS_DIAG=m
  - DP83822_PHY=m
  - RENESAS_PHY=m
  - THUNDERBOLT_NET=m
  - Input:
  - TOUCHSCREEN_EXC3000=m
  - TOUCHSCREEN_HIDEEP=m
  - TOUCHSCREEN_S6SY761=m
  - DRM_I2C_ADV7511_CEC=y
  - Misc:
  - IPMI_PROC_INTERFACE=y
  - GPIO_MAX3191X=m
  - MANAGER_SBS=m
  - W1_SLAVE_DS28E17=m
  - SENSORS_MAX6621=m
  - SENSORS_MAX31785=m
  - CEC_GPIO=m
  - TYPEC_TPS6598X=m
  - RPMSG_VIRTIO=m
  - IIO_CROS_EC_ACCEL_LEGACY=m
  - RFD77402=m
  - NTB_SWITCHTEC=m
  - MMC_SDHCI_OMAP=m
  - Filesystems:
  - XFS_ONLINE_SCRUB=n (still experimental)
  - BTRFS_FS_REF_VERIFY=n
  - CRAMFS_BLOCKDEV=y
  - CRAMFS_MTD=y
  - INTEGRITY_TRUSTED_KEYRING=y
  - Crypto:
  - CRYPTO_SM3=m
  - SIGNED_PE_FILE_VERIFICATION=y
  - SYSTEM_TRUSTED_KEYS (empty)
  - SYSTEM_EXTRA_CERTIFICATE=n
  - SECONDARY_TRUSTED_KEYRING=n
  - LEDS:
  - LEDS_APU=m
  - LEDS_TRIGGER_ACTIVITY=m
  - RTC:
  - RTC_DRV_PCF85363=m
  - Xen:
  - XEN_PVCALLS_FRONTEND=n
  - Graphics:
  - DRM_AMD_DC=y
  - DRM_AMD_DC_PRE_VEGA=y
  - DRM_AMD_DC_FBC=y ?
  - DRM_AMD_DC_DCN1_0=y
  - DEBUG_KERNEL_DC=n
  - NOUVEAU_DEBUG_MMU=n
  - Storage:
  - NVME_MULTIPATH=y
  - IB:
  - MLX4_CORE_GEN2=y
  - Sound:
  - SND_SOC_INTEL_SST_TOPLEVEL=m
  - SND_SOC_INTEL_BAYTRAIL=m
  - Testing:
  - KCOV_ENABLE_COMPARISONS=y (syzkaller)
  - BOOTPARAM_LOCKDEP_CROSSRELEASE_FULLSTACK=n
  - PREEMPTIRQ_EVENTS=y
  - TEST_FIND_BIT=n
  - PKCS7_TEST_KEY=n
  - CHASH_SELFTEST=n
  - CHASH_STATS=n
- commit c5cce47
* Mon Nov 27 2017 kbuild@suse.de
- Automatically updated to 4.14-next-20171127
- commit 829e422
* Sun Nov 26 2017 afaerber@suse.de
- config: armv6hl: Enable 8250 irq sharing for RPi Zero W (boo#1069828)
- commit f4d0c3c
* Sat Nov 25 2017 afaerber@suse.de
- config: armv6hl: Enable brcmfmac for RPi Zero W (boo#1069830)
- commit 6efa56f
* Sat Nov 25 2017 afaerber@suse.de
- config: armv6hl: Enable 8250 serial console for RPi Zero W (boo#1069828)
- commit 5bb4686
* Fri Nov 24 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Correct supplements for recent SLE products (bsc#1067494)
- commit 8f05b9f
* Fri Nov 24 2017 kbuild@suse.de
- Automatically updated to 4.14-next-20171124
- commit cd1a2ef
* Thu Nov 23 2017 kbuild@suse.de
- Automatically updated to 4.14-next-20171123
- commit aed7f7a
* Wed Nov 22 2017 kbuild@suse.de
- Automatically updated to 4.14-next-20171122
- commit 1f3df95
* Tue Nov 21 2017 jslaby@suse.cz
- Update config files.
  After renaming the UNWINDER config options, vanilla has the old names
  and they need to be in configs. For example, x86_64 default config
  has CONFIG_UNWINDER_ORC=y, vanilla has CONFIG_ORC_UNWINDER=y.
- commit 538b36b
* Tue Nov 21 2017 jslaby@suse.cz
- x86/unwind: Make CONFIG_UNWINDER_ORC=y the default in kconfig
  for 64-bit (bnc#1058115).
- Update config files.
- x86/unwind: Rename unwinder config options to
  'CONFIG_UNWINDER_*' (bnc#1058115).
- Refresh patches.suse/0001-orc-mark-it-as-reliable.patch.
- Update config files.
- commit 17abe2f
* Tue Nov 21 2017 kbuild@suse.de
- Automatically updated to 4.14-next-20171121
- commit c82964e
* Mon Nov 20 2017 kbuild@suse.de
- Automatically updated to 4.14-next-20171120
- commit e4d630e
* Fri Nov 17 2017 kbuild@suse.de
- Automatically updated to 4.14-next-20171117
- commit bb362a1
* Thu Nov 16 2017 kbuild@suse.de
- Automatically updated to 4.14-next-20171116
- commit 195923c
* Wed Nov 15 2017 kbuild@suse.de
- Automatically updated to 4.14-next-20171115
- commit 80c9e14
* Tue Nov 14 2017 kbuild@suse.de
- Automatically updated to 4.14-next-20171114
- commit 6659d96
* Mon Nov 13 2017 jeffm@suse.com
- Update to 4.14-final.
- commit 4788586
* Mon Nov 13 2017 kbuild@suse.de
- Automatically updated to 4.14-next-20171113
- commit 1eb027e
* Fri Nov 10 2017 kbuild@suse.de
- Automatically updated to 4.14-rc8-next-20171110
- commit 7d0f1c3
* Thu Nov  9 2017 lpechacek@suse.com
- rpm/kernel-binary.spec.in: rename kGraft to KLP (fate#323682)
- commit 0ed191d
* Thu Nov  9 2017 kbuild@suse.de
- Automatically updated to 4.14-rc8-next-20171109
- commit 6ca78bf
* Wed Nov  8 2017 kbuild@suse.de
- Automatically updated to 4.14-rc8-next-20171108
- commit 28f969e
* Tue Nov  7 2017 kbuild@suse.de
- Automatically updated to 4.14-rc8-next-20171107
- commit ab35ad5
* Mon Nov  6 2017 jeffm@suse.com
- Update to 4.14-rc8.
- commit 8ddb72e
* Mon Nov  6 2017 kbuild@suse.de
- Automatically updated to 4.14-rc7-next-20171106
- commit 0f72218
* Mon Nov  6 2017 jkosina@suse.cz
- rpm/kernel-binary.spec.in: add explicit dependency of kernel-*-devel on
  libelf-devel. Otherwise warning that got turned into error by e683952999
  ("objtool: Upgrade libelf-devel warning to error...") would trigger and
  cause any packages being built against kernel-*-devel (such as KMPs,
  crash) not to have the libelf dependency included, and fail to build.
- commit cad1ef9
* Fri Nov  3 2017 kbuild@suse.de
- Automatically updated to 4.14-rc7-next-20171103
- commit 4112aab
* Thu Nov  2 2017 kbuild@suse.de
- Automatically updated to 4.14-rc7-next-20171102
- commit 8384ffa
* Mon Oct 30 2017 jeffm@suse.com
- Update to 4.14-rc7.
- commit a432932
* Mon Oct 23 2017 jeffm@suse.com
- Update to 4.14-rc6.
- Eliminated 2 patches.
- commit 0ac1d5a
* Thu Oct 19 2017 kbuild@suse.de
- Automatically updated to 4.14-rc5-next-20171018
- commit 3429891
* Wed Oct 18 2017 kbuild@suse.de
- Automatically updated to 4.14-rc5-next-20171017
- commit 0d19ebe
* Tue Oct 17 2017 kbuild@suse.de
- Automatically updated to 4.14-rc4-next-20171016
- commit c503fbb
* Mon Oct 16 2017 jeffm@suse.com
- Update to 4.14-rc5.
- commit 1ff59ff
* Sun Oct 15 2017 kbuild@suse.de
- Automatically updated to 4.14-rc4-next-20171013
- commit c1226ac
* Fri Oct 13 2017 msuchanek@suse.de
- Revert "rpm/constraints.in: Lower default disk space requirement from 25G to 24G"
  This reverts commit 406abda1467c038842febffe264faae1fa2e3c1d.
  ok, did not wait long enough to see the failure.
- commit ada4b33
* Fri Oct 13 2017 msuchanek@suse.de
- rpm/constraints.in: Lower default disk space requirement from 25G to 24G
  25G is rejected by the build service on ARM.
- commit 406abda
* Fri Oct 13 2017 kbuild@suse.de
- Automatically updated to 4.14-rc4-next-20171012
- commit c570449
* Tue Oct 10 2017 kbuild@suse.de
- Automatically updated to 4.14-rc4-next-20171009
- commit 3db6c62
* Mon Oct  9 2017 jeffm@suse.com
- Update to 4.14-rc4.
- commit bcbbfc5
* Fri Oct  6 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: add the kernel-binary dependencies to
  kernel-binary-base (bsc#1060333).
- commit 955681c
* Wed Oct  4 2017 jslaby@suse.cz
- orc: mark it as reliable (bnc#1058115).
- Update config files.
- commit ec98c19
* Mon Oct  2 2017 jeffm@suse.com
- Moved powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch to patches.rpmify.
  It's a compiler blacklist addition and should be applied to vanilla too.
- commit 770aa88
* Mon Oct  2 2017 jeffm@suse.com
- Update to 4.14-rc3.
- Eliminated 2 patches.
- Config changes:
  - Crypto:
  - Crypto changes brought by Kconfig changes:
  - CONFIG_CRYPTO_GHASH=y (Kconfig dependency change)
  - CONFIG_CRYPTO_GCM=y (Kconfig dependency change)
  - armv7hl:
  - DRM_SUN4I_HDMI_CEC=y
  - CONFIG_CEC_PIN=y (dependency)
  - s390x/zfcpdump:
  - Crypto changes brought by Kconfig changes, consistent with other configs:
  - CRYPTO_MANAGER_DISABLE_TESTS=n
  - CRYPTO_DRBG_HASH=y
  - CRYPTO_DRBG_CTR=y
  - Lots of dependencies
- commit d15531d
* Fri Sep 29 2017 kbuild@suse.de
- Automatically updated to 4.14-rc2-next-20170929
- commit 26111a2
* Thu Sep 28 2017 kbuild@suse.de
- Automatically updated to 4.14-rc2-next-20170928
- commit 7fc1dce
* Thu Sep 28 2017 jeffm@suse.com
- Update to 4.14-rc2.
- Eliminated 21 patches.
- commit 8cc8ff7
* Wed Sep 27 2017 kbuild@suse.de
- Automatically updated to 4.14-rc2-next-20170927
- commit d623e24
* Tue Sep 26 2017 kbuild@suse.de
- Automatically updated to 4.14-rc2-next-20170926
- commit 0cfee96
* Sun Sep 24 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: only rewrite modules.dep if non-zero in size
  (bsc#1056979).
- commit 75691fd
* Fri Sep 22 2017 kbuild@suse.de
- Automatically updated to 4.14-rc1-next-20170922
- commit 0ec14e5
* Thu Sep 21 2017 kbuild@suse.de
- Automatically updated to 4.14-rc1-next-20170921
- commit 83453fe
* Wed Sep 20 2017 afaerber@suse.de
- config: armv7hl: Update to 4.14-rc1
- commit 4fc5b41
* Wed Sep 20 2017 afaerber@suse.de
- config: armv6hl: Update to 4.14-rc1
- commit 8d42e2b
* Wed Sep 20 2017 afaerber@suse.de
- config: arm64: Update to 4.14-rc1
- commit 1cde1de
* Wed Sep 20 2017 kbuild@suse.de
- Automatically updated to 4.14-rc1-next-20170920
- commit 9b98f7f
* Tue Sep 19 2017 kbuild@suse.de
- Automatically updated to 4.14-rc1-next-20170919
- commit 3749a46
* Tue Sep 19 2017 jeffm@suse.com
- Update to 4.14-rc1.
- Eliminated 17 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - HMM_MIRROR=n
  - DEVICE_PRIVATE=n
  - DEVICE_PUBLIC=n
  - SQUASHFS_ZSTD=y
  - ZRAM_WRITEBACK=y
  - x86:
  - INTEL_RDT=y (renamed option)
  - XEN_PVCALLS_BACKEND=y
  - X86_5LEVEL=n (will only boot on systems that support it)
  - AMD_MEM_ENCRYPT=y
  - AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT=n
  - ppc:
  - PPC_MEMTRACE=y
  - PPC_VAS=y
  - s390:
  - CMA_DEBUG=n
  - CMA_DEBUGFS=n
  - CMA_AREAS=7 (default)
  - DMA_CMA=n
  - VMCP_CMA_SIZE=4 (default)
  - Netfilter:
  - NFT_FIB_NETDEV
  - Hyperv:
  - HYPERV_VSOCKETS
  - Network:
  - NET_NSH
  - BPF_STREAM_PARSER=y (build fix)
  - BNXT_FLOWER_OFFLOAD=y
  - HINIC
  - MLX5_MPFS=y
  - MLX5_ESWITCH=y
  - RMNET=n
  - ROCKCHIP_PHY
  - WIL6210_DEBUGFS=n
  - ATH10K_USB
  - Bluetooth:
  - BT_LEGACY_IOCTL=y (default)
  - SPI:
  - SPI_INTEL_SPI_PCI
  - Misc:
  - INPUT_PWM_VIBRA=m
  - SERIO_GPIO_PS2=m
  - PINCTRL_DENVERTON
  - PINCTRL_LEWISBURG
  - W1_SLAVE_DS2805
  - BATTERY_BQ27XXX_HDQ=m
  - BATTERY_MAX1721X
  - SENSORS_IBM_CFFPS
  - SENSORS_TPS53679
  - CLOCK_THERMAL=y
  - DEVFREQ_THERMAL=y
  - MFD_BD9571MWV=n
  - INTEL_SOC_PMIC_CHTWC=y
  - MFD_TPS68470=n
  - IR_GPIO_TX=n
  - IR_PWM_TX=n
  - DVB_DDBRIDGE
  - DVB_DDBRIDGE_MSIENABLE=n
  - TINYDRM_REPAPER=n
  - TINYDRM_ST7586=n
  - SND_SOC_CS43130=n
  - SND_SOC_WM8524=n
  - MMC_SPI
  - LEDS_AS3645A=n
  - LEDS_PCA955X_GPIO=y
  - INFINIBAND_EXP_USER_ACCESS=y [?]
  - CONFIG_ALTERA_MSGDMA
  - R8822BE
  - PI433=n
  - CLK_HSDK=n
  - EXTCON_USBC_CROS_EC
  - DLN2_ADC=m
  - LTC2471=n
  - CCS811=n
  - RESET_HSDK_V1=n
  - FPGA_MGR_ALTERA_CVP=m
  - FPGA_MGR_ALTERA_PS_SPI=m
  - CRYPTO_DEV_SP_CCP=y
  - I2C_CHT_WC=m
  - RESET_ATTACK_MITIGATION=y
- commit 2858315
* Mon Sep 18 2017 kbuild@suse.de
- Automatically updated to 4.14-rc1-next-20170918
- commit fbde903
* Fri Sep 15 2017 kbuild@suse.de
- Automatically updated to 4.13-next-20170915
- commit c83df53
* Thu Sep 14 2017 kbuild@suse.de
- Automatically updated to 4.13-next-20170914
- commit 0efb20d
* Wed Sep 13 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix a thinko for xmlto buildreq condition
- commit 0ef59d3
* Wed Sep 13 2017 kbuild@suse.de
- Automatically updated to 4.13-next-20170913
- commit 7a3dc5d
* Tue Sep 12 2017 msuchanek@suse.de
- rpm/kernel-docs.spec.in: make unpack scripts executable
- commit 1ba3766
* Tue Sep 12 2017 kbuild@suse.de
- Automatically updated to 4.13-next-20170912
- commit 0070705
* Mon Sep 11 2017 kbuild@suse.de
- Automatically updated to 4.13-next-20170911
- commit 7886ce7
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: build ARM on at least 2 cpus
- commit b7edeaf
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: increase memory for kernel-syzkaller
  And see if it helps. If so, push it to packaging...
- commit 7193e65
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable legacy instruction emulation (boo#1029158)
  Needed for execution of older e.g. ARMv6 code.
- commit 69483cb
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable ACPI_DOCK for consistency
- commit 755d6b5
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable some network options
- Marvell Armada 7K/8K Ethernet driver
- Microchip ENC28J60 and related SPI Ethernet drivers
- Micrel KS8851 SPI Ethernet driver
- MMIO MDIO mux driver
- commit a26dfab
* Fri Sep  8 2017 mmarek@suse.com
- README.BRANCH: Michal Suchánek is the maintainer
- commit 80d9c24
* Fri Sep  8 2017 jslaby@suse.cz
- rpm/kernel-binary.spec.in: package ftrace-mod.o on arm64
  It is needed for building modules since 4.13:
  CC [M]  /suse/jslaby/a/aaa.o
  Building modules, stage 2.
  MODPOST 1 modules
  CC      /suse/jslaby/a/aaa.mod.o
  LD [M]  /suse/jslaby/a/aaa.ko
  ld: cannot find ./arch/arm64/kernel/ftrace-mod.o: No such file or directory
  ...
- commit 07da115
* Fri Sep  8 2017 kbuild@suse.de
- Automatically updated to 4.13-next-20170908
- commit 6b3ac16
* Thu Sep  7 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Expand kernel tree directly from sources (bsc#1057199)
- commit a61b4d9
* Thu Sep  7 2017 kbuild@suse.de
- Automatically updated to 4.13-next-20170907
- commit 01a2f7a
* Wed Sep  6 2017 mcgrof@suse.com
- supported.conf: add test_syctl to new kselftests-kmp package FATE#323821
  As per FATE#323821 we will require new FATE requests per each
  new selftest driver. We don't want to support these module on
  production runs but we do want to support them for QA / testing
  uses. The compromise is to package them into its own package,
  this will be the kselftests-kmp package.
  Selftests can also be used as proof of concept vehicle for issues
  by customers or ourselves.
  Vanilla kernels do not get test_sysctl given that driver was
  using built-in defaults, this also means we cannot run sefltests
  on config/s390x/zfcpdump which does not enable modules.
  Likeweise, since we had to *change* the kernel for test_syctl, it
  it also means we can't test test_syctl with vanilla kernels. It
  should be possible with other selftests drivers if they are
  present in vanilla kernels though.
- commit ae8069f
* Wed Sep  6 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Re-add xmlto buildreq conditionally for SLE15 & co
- commit 259b49e
* Wed Sep  6 2017 mchandras@suse.de
- rpm/group-source-files.pl: Add arch/*/tools/* files to the devel package
  Commit b71c9ffb1405 ("powerpc: Add arch/powerpc/tools directory")
  introduced in v4.12-rc1 release, moved the scripts into the tools
  directory. However, this location is not considered for the kernel devel
  package and the following error occurs when building a kmp for powerpc
  make[2]: /usr/src/linux-4.12.9-1/arch/powerpc/tools/gcc-check-mprofile-kernel.sh: Command not found
- commit 5f1ff53
* Wed Sep  6 2017 kbuild@suse.de
- Automatically updated to 4.13-next-20170906
- commit 577722c
* Tue Sep  5 2017 jeffm@suse.com
- Update to 4.13-final.
- commit c5af5ab
* Tue Sep  5 2017 kbuild@suse.de
- Automatically updated to 4.13-next-20170905
- commit 908289e
* Mon Sep  4 2017 kbuild@suse.de
- Automatically updated to 4.13-next-20170904
- commit b0cd0c0
* Fri Sep  1 2017 kbuild@suse.de
- Automatically updated to 4.13-rc7-next-20170901
- commit f9433d2
* Thu Aug 31 2017 jeffm@suse.com
- Update to 4.13-rc7.
- Eliminate 2 patches.
- commit 8e72bcc
* Thu Aug 31 2017 kbuild@suse.de
- Automatically updated to 4.13-rc7-next-20170831
- commit 6f7288f
* Tue Aug 29 2017 kbuild@suse.de
- Automatically updated to 4.13-rc7-next-20170829
- commit 3c777c4
* Tue Aug 29 2017 tiwai@suse.de
- Update config files: enable CONFIG_SPI_PXA2XX for MacBook (bsc#1055817)
- commit 775cfdc
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Update drm-kmp obsolete for SLE12-SP3/Leap-42.3
- commit 77ccbd0
* Mon Aug 28 2017 kbuild@suse.de
- Automatically updated to 4.13-rc6-next-20170828
- commit ea9d844
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Disable PDF build again
  ... due to the breakage with the recent TeXLive 2017.
  Also add the missing dependency on texlive-varwidth.
- commit 9f682b5
* Fri Aug 25 2017 kbuild@suse.de
- Automatically updated to 4.13-rc6-next-20170825
- commit 0315e67
* Thu Aug 24 2017 kbuild@suse.de
- Automatically updated to 4.13-rc6-next-20170824
- commit 5eb9c10
* Wed Aug 23 2017 kbuild@suse.de
- Automatically updated to 4.13-rc6-next-20170823
- commit 528bfa8
* Tue Aug 22 2017 kbuild@suse.de
- Automatically updated to 4.13-rc6-next-20170822
- commit f44130c
* Mon Aug 21 2017 jeffm@suse.com
- Update to 4.13-rc6.
- commit 6d92a12
* Fri Aug 18 2017 msuchanek@suse.de
- Do not ship firmware (bsc#1054239).
  Pull firmware from kernel-firmware instead.
- commit 0b0b5c9
* Thu Aug 17 2017 jeffm@suse.com
- Update to 4.13-rc5.
- commit d618535
* Thu Aug 17 2017 kbuild@suse.de
- Automatically updated to 4.13-rc5-next-20170817
- commit 5d8d0ce
* Wed Aug 16 2017 kbuild@suse.de
- Automatically updated to 4.13-rc5-next-20170816
- commit 346719f
* Tue Aug 15 2017 kbuild@suse.de
- Automatically updated to 4.13-rc5-next-20170815
- commit a4cf047
* Fri Aug 11 2017 kbuild@suse.de
- Automatically updated to 4.13-rc4-next-20170811
- commit 7eb8a48
* Thu Aug 10 2017 msuchanek@suse.de
- Refresh vanilla config.
- commit 2e39bf2
* Thu Aug 10 2017 msuchanek@suse.de
- rpm/modules.fips include module list from dracut
- commit f70bab5
* Thu Aug 10 2017 kbuild@suse.de
- Automatically updated to 4.13-rc4-next-20170810
- commit 66cc6d4
* Wed Aug  9 2017 kbuild@suse.de
- Automatically updated to 4.13-rc4-next-20170809
- commit fa04d8a
* Tue Aug  8 2017 kbuild@suse.de
- Automatically updated to 4.13-rc4-next-20170808
- commit 8059f9e
* Tue Aug  8 2017 jeffm@suse.com
- Update to 4.13-rc4.
- commit 98221b4
* Mon Aug  7 2017 kbuild@suse.de
- Automatically updated to 4.13-rc3-next-20170807
- commit ea39be0
* Fri Aug  4 2017 kbuild@suse.de
- Automatically updated to 4.13-rc3-next-20170804
- commit e698374
* Thu Aug  3 2017 kbuild@suse.de
- Automatically updated to 4.13-rc3-next-20170803
- commit 5a1f327
* Wed Aug  2 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix package list and enable building PDFs
  Finally it works!  Added some missing pieces (ImageMagick, some texlive
  subpkgs) in addition to use explicitly python3-Sphinx stuff.
- commit c117a0c
* Wed Aug  2 2017 kbuild@suse.de
- Automatically updated to 4.13-rc3-next-20170802
- commit a613c94
* Tue Aug  1 2017 kbuild@suse.de
- Automatically updated to 4.13-rc3-next-20170801
- commit 4272eb8
* Mon Jul 31 2017 jeffm@suse.com
- Update to 4.13-rc3.
- commit 328b00d
* Mon Jul 31 2017 kbuild@suse.de
- Automatically updated to 4.13-rc3-next-20170731
- commit c88557b
* Fri Jul 28 2017 kbuild@suse.de
- Automatically updated to 4.13-rc2-next-20170728
- commit 2cee606
* Thu Jul 27 2017 kbuild@suse.de
- Automatically updated to 4.13-rc2-next-20170727
- commit f13b9d9
* Thu Jul 27 2017 jslaby@suse.cz
- x86/kconfig: Make it easier to switch to the new ORC unwinder
  (bnc#1018348).
- x86/kconfig: Consolidate unwinders into multiple choice
  selection (bnc#1018348).
- Update config files.
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
  Update to version from -tip. ORC is in -tip completely. So make sure
  we use the upstream version.
- commit 0387cca
* Wed Jul 26 2017 jeffm@suse.com
- Update to 4.13-rc2.
- Eliminated 1 patch.
- Config changes:
  - DRM_VBOXVIDEO=m
- commit 2d688da
* Wed Jul 26 2017 kbuild@suse.de
- Automatically updated to 4.13-rc2-next-20170726
- commit 87053eb
* Tue Jul 25 2017 kbuild@suse.de
- Automatically updated to 4.13-rc2-next-20170725
- commit 6e22a63
* Mon Jul 24 2017 kbuild@suse.de
- Automatically updated to 4.13-rc2-next-20170724
- commit 01c33ef
* Sun Jul 23 2017 stefan.bruens@rwth-aachen.de
- config: arm64: Enable RTC and SPI on Allwinner A64/H5
  A64 and H5 share the RTC and SPI functional blocks with older SoCs,
  enable the corresponding drivers.
- commit 2a51004
* Fri Jul 21 2017 kbuild@suse.de
- Automatically updated to 4.13-rc1-next-20170721
- commit 135d16a
* Thu Jul 20 2017 kbuild@suse.de
- Automatically updated to 4.13-rc1-next-20170720
- commit 18a57e3
* Wed Jul 19 2017 mmarek@suse.cz
- rpm/kernel-binary.spec.in: find-debuginfo.sh should not touch build-id
  This needs rpm-4.14+ (bsc#964063).
- commit f622d60
* Wed Jul 19 2017 kbuild@suse.de
- Automatically updated to 4.13-rc1-next-20170719
- commit ff1627f
* Tue Jul 18 2017 afaerber@suse.de
- config: armv7hl: Update to v4.13-rc1
- commit c11fd07
* Tue Jul 18 2017 afaerber@suse.de
- config: armv6hl: Update to v4.13-rc1
- commit 247e298
* Tue Jul 18 2017 afaerber@suse.de
- config: arm64: Update to v4.13-rc1
- commit c838e12
* Tue Jul 18 2017 kbuild@suse.de
- Automatically updated to 4.13-rc1-next-20170718
- commit cd30139
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Drop unnecessary xmlto for 4.13+
- commit e47dc84
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Correct kernel-docs package summary/description
- commit 697b763
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: refresh dependencies for PDF build (bsc#1048129)
  But it still doesn't work with Tex Live 2017, thus disabled yet.
  Also add texlive-anyfontsize for HTML math handling.
- commit ead44a1
* Mon Jul 17 2017 jeffm@suse.com
- Updated to 4.13-rc1.
- Eliminated 13 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - SLAB_MERGE_DEFAULT=y (current behavior)
  - REFCOUNT_FULL=n (current behavior)
  - PERCPU_STATS=n (default)
  - FORTIFY_SOURCE=n (needs performance analysis)
  - WARN_ALL_UNSEEDED_RANDOM=n
  - TRACE_EVAL_MAP_FILE=n
  - TEST_SYSCTL=n
  - TEST_KMOD=n
  - Storage:
  - DM_ZONED=m
  - IB:
  - Options for MLX5:
  - MLX5_FPGA
  - MLX5_EN_IPSEC=y
  - MLXFW=m
  - SECURITY_INFINIBAND=y
  - Network:
  - Options for NFP:
  - NFP_APP_FLOWER=y
  - CORTINA_PHY=n (intended for embedded apps)
  - ATH10K_SDIO=m
  - QTNFMAC_PEARL_PCIE=m
  - DRM:
  - DRM_I915_SW_FENCE_CHECK_DAG=n
  - Sound:
  - SND_SOC_INTEL_BYT_CHT_ES8316_MACH=m
  - SND_SOC_INTEL_KBL_RT5663_MAX98927_MACH=m
  - SND_SOC_INTEL_KBL_RT5663_RT5514_MAX98927_MACH=m
  - SND_SOC_ZX_AUD96P22=n
  - HID:
  - HID_ITE=n
  - HID_RETRODE=m
  - USB:
  - TYPEC_UCSI=m
  - UCSI_ACPI=m
  - Misc:
  - RTC_NVMEM=y
  - RTC_DRV_DS3232_HWMON=y
  - WMI_BMOF=m
  - PEAQ_WMI=m
  - INTEL_INT0002_VGPIO=m
  - CROS_EC_LPC_MEC=y
  - EXTCON_INTEL_CHT_WC=m
  - NTB_IDT=m
  - MULTIPLEXER=m
  - KEYBOARD_DLINK_DIR685=n
  - TOUCHSCREEN_STMFTS=n
  - I2C_DESIGNWARE_SLAVE=n
  - SPI_SLAVE=n
  - PINCTRL_MCP23S08=n
  - PINCTRL_CANNONLAKE=m
  - GPIO_XRA1403=n
  - BATTERY_BQ27XXX_DT_UPDATES_NVM=n
  - CHARGER_LTC3651=n
  - SENSORS_IR35221=n
  - WATCHDOG_HANDLE_BOOT_ENABLED=y (default)
  - File Systems:
  - OVERLAY_FS_INDEX=n (mounting on an older kernel read-write will cause unexpected results)
  - CIFS_DEBUG_DUMP_KEYS=n
  - Crypto:
  - CRC4=m
  - X86:
  - INTEL_SOC_PMIC_CHTWC=m
  - CHT_WC_PMIC_OPREGION=y
  - ppc64/ppc64le:
  - CONFIG_IRQ_TIME_ACCOUNTING=n
  - CONFIG_LD_HEAD_STUB_CATCH=n
  - ZONE_DEVICE=y
  - ppc64le:
  - STRICT_KERNEL_RWX=y
  - s390x:
  - CRYPTO_PAES_S390=m
- commit ed7a465
* Mon Jul 17 2017 kbuild@suse.de
- Automatically updated to 4.13-rc1-next-20170717
- commit 9867770
* Mon Jul 17 2017 mmarek@suse.cz
- Drop multiversion(kernel) from the KMP template (fate#323189)
- commit 71504d8
* Fri Jul 14 2017 kbuild@suse.de
- Automatically updated to 4.12-next-20170714
- commit fef9ec1
* Thu Jul 13 2017 kbuild@suse.de
- Automatically updated to 4.12-next-20170713
- commit a60a99d
* Wed Jul 12 2017 kbuild@suse.de
- Automatically updated to 4.12-next-20170712
- commit 0a983ae
* Tue Jul 11 2017 kbuild@suse.de
- Automatically updated to 4.12-next-20170711
- commit 2b231b7
* Tue Jul 11 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix and cleanup for 4.13 doc build (bsc#1048129)
  The whole DocBook stuff has been deleted.  The PDF build still non-working
  thus the sub-packaging disabled so far.
- commit 8e7de10
* Mon Jul 10 2017 mmarek@suse.com
- Automatically updated to 4.12-next-20170710
- commit 9fe348e
* Fri Jul  7 2017 kbuild@suse.de
- Automatically updated to 4.12-next-20170707
- commit 5cb2ea0
* Thu Jul  6 2017 kbuild@suse.de
- Automatically updated to 4.12-next-20170706
- commit 0516f1c
* Wed Jul  5 2017 kbuild@suse.de
- Automatically updated to 4.12-next-20170705
- commit 69f4562
* Tue Jul  4 2017 kbuild@suse.de
- Automatically updated to 4.12-next-20170704
- commit 2395188
* Tue Jul  4 2017 jslaby@suse.cz
- Update to 4.12-final.
- commit be83a00
* Mon Jul  3 2017 kbuild@suse.de
- Automatically updated to 4.12-rc7-next-20170703
- commit 3349535
* Mon Jul  3 2017 jslaby@suse.cz
- objtool: Silence warnings for functions which use IRET
  (bnc#1018348).
- Update config files.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
  Push the new version of unDWARF unwinder which is now called Orc. The
  first 4 patches were accepted to the -tip tree, so they are marked
  appropriatelly.
- commit 4d8dd16
* Fri Jun 30 2017 kbuild@suse.de
- Automatically updated to 4.12-rc7-next-20170630
- commit a322fb5
* Thu Jun 29 2017 kbuild@suse.de
- Automatically updated to 4.12-rc7-next-20170629
- commit d82684c
* Wed Jun 28 2017 kbuild@suse.de
- Automatically updated to 4.12-rc7-next-20170628
- commit e8ff188
* Tue Jun 27 2017 kbuild@suse.de
- Automatically updated to 4.12-rc7-next-20170627
- commit 11b2ed1
* Tue Jun 27 2017 tiwai@suse.de
- config/x86_64: Align 8250 serial configs for many ports (bsc#1024449)
- commit 2ed15f3
* Mon Jun 26 2017 jeffm@suse.com
- Update to 4.12-rc7.
- commit 8102802
* Mon Jun 26 2017 kbuild@suse.de
- Automatically updated to 4.12-rc6-next-20170626
- commit 10ca9dc
* Sun Jun 25 2017 afaerber@suse.de
- config: ARM: Consistently enable SPI_GPIO
  Bit-banging is needed when a SoC doesn't support native SPI or when such
  drivers are missing. SPI_GPIO was enabled for armv6hl and armv7hl default,
  but missing for armv7hl lpae and arm64. Set CONFIG_SPI_GPIO=m consistently.
- commit cf05312
* Fri Jun 23 2017 kbuild@suse.de
- Automatically updated to 4.12-rc6-next-20170623
- commit b0f8d95
* Thu Jun 22 2017 jeffm@suse.com
- config: VGACON_SOFT_SCROLLBACK_SIZE=128 (FATE#307471).
  This doubles the scrollback buffer on VGA consoles with only a little
  bit of memory cost.
- commit 0942b92
* Thu Jun 22 2017 kbuild@suse.de
- Automatically updated to 4.12-rc6-next-20170622
- commit 2ff1a44
* Wed Jun 21 2017 kbuild@suse.de
- Automatically updated to 4.12-rc6-next-20170621
- commit 4fc059e
* Tue Jun 20 2017 jjolly@suse.de
- Update config files.
- config.conf: Added s390x zfcpdump kernel
- commit 90b8f98
* Tue Jun 20 2017 jeffm@suse.com
- Update to 4.12-rc6.
- commit 73c8a51
* Tue Jun 20 2017 mmarek@suse.com
- Only set CONFIG_GCC_PLUGINS=y in kernel-syzkaller (boo#1043591)
- commit 439fa0e
* Tue Jun 20 2017 kbuild@suse.de
- Automatically updated to 4.12-rc6-next-20170620
- commit b3861eb
* Tue Jun 20 2017 mmarek@suse.com
- rpm/kernel-binary.spec.in: Only kernel-syzkaller needs gcc-devel
  (boo#1043591).
- commit d7ff041
* Mon Jun 19 2017 kbuild@suse.de
- Automatically updated to 4.12-rc5-next-20170619
- commit bfb4b58
* Fri Jun 16 2017 kbuild@suse.de
- Automatically updated to 4.12-rc5-next-20170616
- commit a22f002
* Thu Jun 15 2017 mmarek@suse.com
- kabi.pl: Consider GPL vs. non-GPL exports (fate#322999)
- commit 8bde754
* Thu Jun 15 2017 kbuild@suse.de
- Automatically updated to 4.12-rc5-next-20170615
- commit 80dda4d
* Wed Jun 14 2017 kbuild@suse.de
- Automatically updated to 4.12-rc5-next-20170614
- commit 7e29b9a
* Tue Jun 13 2017 mmarek@suse.com
- rpm/kernel-module-subpackage: Generate proper supplements in the template
  ... instead of relying on find-provides.ksyms to do it (bsc#981083).
- commit b1fe840
* Tue Jun 13 2017 kbuild@suse.de
- Automatically updated to 4.12-rc5-next-20170613
- commit d28b26e
* Mon Jun 12 2017 jeffm@suse.com
- Update to 4.12-rc5.
- Eliminated 1 patch.
- commit fd5275a
* Mon Jun 12 2017 mmarek@suse.com
- rpm/kernel-source.spec.in: Do not list deleted depdendency helpers
  (bsc#981083).
- commit 9306efe
* Fri Jun  9 2017 mmarek@suse.com
- Define dependencies of in-kernel KMPs statically
  This allows us to use rpm's internal dependency generator (bsc#981083).
- commit 88d6128
* Fri Jun  9 2017 mmarek@suse.com
- rpm/find-provides: Delete, as /boot/vmlinux-* is no longer in -devel
- commit 4df55cc
* Fri Jun  9 2017 mmarek@suse.com
- rpm/package-descriptions: Import SLE12-SP3 KMP descriptions
- commit ff51a7c
* Fri Jun  9 2017 kbuild@suse.de
- Automatically updated to 4.12-rc4-next-20170609
- commit af0c94f
* Thu Jun  8 2017 kbuild@suse.de
- Automatically updated to 4.12-rc4-next-20170608
- commit 5722354
* Wed Jun  7 2017 kbuild@suse.de
- Automatically updated to 4.12-rc4-next-20170607
- commit 8fc6fc8
* Tue Jun  6 2017 kbuild@suse.de
- Automatically updated to 4.12-rc4-next-20170606
- commit 387e867
* Tue Jun  6 2017 jslaby@suse.cz
- Update config files.
  Disable CONFIG_DRM_I915_WERROR, i.e. -Werror in i915. It causes build
  failures in -syzkaller flavor due to a bit oversized frames:
  drivers/gpu/drm/i915/intel_dpll_mgr.c:1548:1: error: the frame size of 2240 bytes is larger than 2048 bytes
- commit 662ef8a
* Mon Jun  5 2017 msuchanek@suse.de
- rpm/kernel-binary.spec: remove superfluous flags
  This should make build logs more readable and people adding more flags
  should have easier time finding a place to add them in the spec file.
- commit 13e40fa
* Mon Jun  5 2017 kbuild@suse.de
- Automatically updated to 4.12-rc3-next-20170605
- commit 9bb05f7
* Mon Jun  5 2017 msuchanek@suse.de
- kernel-binary.spec: Propagate MAKE_ARGS to %%build (bsc#1012422)
- commit 6171b7a
* Mon Jun  5 2017 jeffm@suse.com
- Update to 4.12-rc4.
- Eliminated 1 patch.
- commit d11b4ab
* Fri Jun  2 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Fix new include path
  Commit 89de3db69113d58cdab14d2c777de6080eac49dc ("rpm/dtb.spec.in.in:
  Update include path for dt-bindings") introduced an additional include
  path for 4.12. The commit message had it correct, but the spec file
  template lacked a path component, breaking the aarch64 build while
  succeeding on armv7hl. Fix that.
- commit c8d853a
* Fri Jun  2 2017 kbuild@suse.de
- Automatically updated to 4.12-rc3-next-20170602
- commit eab5a79
* Fri Jun  2 2017 mmarek@suse.com
- rpm/kernel-source.spec.in: Drop patches.{trace,xen}.tar.bz2
  These are empty in current branches.
- commit 742f1d0
* Thu Jun  1 2017 kbuild@suse.de
- Automatically updated to 4.12-rc3-next-20170601
- commit 74bc243
* Wed May 31 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Update include path for dt-bindings
  Kernels before 4.12 had arch/{arm,arm64}/boot/dts/include/ directories
  with a symlink to include/dt-bindings/.
  In 4.12 those include/ directories were dropped.
  Therefore use include/ directly.
  Additionally some cross-architecture .dtsi reuse was introduced, which
  requires scripts/dtc/include-prefixes/ that didn't exist on older kernels.
- rpm/dtb.spec.in.in: Update include path for dt-bindings
  Kernels before 4.12 had arch/{arm,arm64}/boot/dts/include/ directories
  with a symlink to include/dt-bindings/.
  In 4.12 those include/ directories were dropped.
  Therefore use include/ directly.
  Additionally some cross-architecture .dtsi reuse was introduced, which
  requires scripts/dtc/include-prefixes/ that didn't exist on older kernels.
  (cherry picked from commit ef40691e46873ca29986013e31b6fca9e27e2ac0)
- commit 466f108
* Wed May 31 2017 kbuild@suse.de
- Automatically updated to 4.12-rc3-next-20170531
- commit 435005a
* Wed May 31 2017 jslaby@suse.cz
- objtool: move checking code to check.c (bnc#1018348).
- objtool, x86: add several functions and files to the objtool
  whitelist (bnc#1018348).
- objtool: stack validation 2.0 (bnc#1018348).
- objtool: add undwarf debuginfo generation (bnc#1018348).
- objtool, x86: add facility for asm code to provide CFI hints
  (bnc#1018348).
- x86/entry: add CFI hint undwarf annotations (bnc#1018348).
- x86/asm: add CFI hint annotations to sync_core() (bnc#1018348).
- extable: rename 'sortextable' script to 'sorttable'
  (bnc#1018348).
- extable: add undwarf table sorting ability to sorttable script
  (bnc#1018348).
- x86/unwind: add undwarf unwinder (bnc#1018348).
- Delete patches.arch/x86_64-unwind-annotations.
- Update config files.
  Switch from DWARF to unDWARF. This is the way upstream wants us to go.
  We can drop patches.arch/x86_64-unwind-annotations now as it is
  superseded by the patchset:
  1) Objtool generates info for assembly now.
  2) Manual annotations are put to places where objtool gets lost.
  This version is RFC submitted upstream.
  DWARF unwinder is not dropped on the floor yet, just commented out.
  Let's see how this works out and drop it then. So far both
  task-context and the interrupt-context traces look good (TM).
  unDWARF is supported only on x86_64 so far.
- commit 86d4a13
* Tue May 30 2017 afaerber@suse.de
- config: armv7hl: Update to v4.12-rc3
- commit 802e56e
* Tue May 30 2017 afaerber@suse.de
- config: armv6hl: Update to v4.12-rc3
- commit 373746a
* Tue May 30 2017 afaerber@suse.de
- config: arm64: Update to v4.12-rc3
  Harmonize the display drivers while at it.
- commit 11528c2
* Tue May 30 2017 kbuild@suse.de
- Automatically updated to 4.12-rc3-next-20170530
- commit 62527e2
* Mon May 29 2017 mkubecek@suse.cz
- Update to 4.12-rc3.
- Eliminated 1 patch.
- commit abc9925
* Mon May 29 2017 kbuild@suse.de
- Automatically updated to 4.12-rc2-next-20170529
- commit b036277
* Fri May 26 2017 kbuild@suse.de
- Automatically updated to 4.12-rc2-next-20170526
- commit e151622
* Fri May 26 2017 afaerber@suse.de
- config: arm64: Make PINCTRL_SINGLE built-in
  This fixes serial console on the HiKey board (bsc#1040492).
- commit 6ee2e84
* Fri May 26 2017 mkubecek@suse.cz
- Update to 4.12-rc2
- Eliminated 32 patches.
- ARM configs need updating.
- OSS (sound) support marked broken
- Config changes:
  - Kernel hacking:
  - EARLY_PRINTK_USB_XDBC=y
  - Block:
  - BFQ_GROUP_IOSCHED=y
  - BLK_DEV_THROTTLING_LOW=n (experimental)
  - DM_INTEGRITY=m
  - IOSCHED_BFQ=y
  - MQ_IOSCHED_KYBER=y
  - Filesystems:
  - UBIFS_FS_SECURITY=y
  - Networking:
  - NET_9P_XEN=m
  - NET_SCH_DEFAULT=n (for custom builds)
  - Network drivers:
  - BT_HCIUART_NOKIA=m
  - CAN_HI311X=m
  - CAN_MCBA_USB=m
  - CAN_PEAK_PCIEFD=m
  - CAN_VXCAN=m
  - DWC_XLGMAC=m
  - DWC_XLGMAC_PCI=m
  - IEEE802154_CA8210=m
  - IEEE802154_CA8210_DEBUGFS=n
  - MDIO_DEVICE=m
  - MLX5_CORE_IPOIB=y
  - NET_VENDOR_SYNOPSYS=y
  - RTL8723BS=m
  - TIGON3_HWMON=y
  - VSOCKMON=m
  - DRM:
  - BACKLIGHT_ARCXCNN=m
  - DM_INTEGRITY=m
  - DRM_FBDEV_OVERALLOC=100 (default)
  - DRM_I915_DEBUG_VBLANK_EVADE=n (driver debugging)
  - DRM_I915_LOW_LEVEL_TRACEPOINTS=n (driver debugging)
  - DRM_I915_SELFTEST=n (driver debugging)
  - Sound:
  - SND_FIREFACE=m
  - SND_FIREWIRE_MOTU=m
  - SND_I2S_HI6210_I2S=m
  - SND_SOC_ADAU1761_I2C=n
  - SND_SOC_ADAU1761_SPI=n
  - SND_SOC_CS35L35=m
  - SND_SOC_DA7213=m
  - SND_SOC_DIO2125=n
  - SND_SOC_ES7134=n
  - SND_SOC_INTEL_BYT_CHT_DA7213_MACH=m
  - SND_SOC_INTEL_BYT_CHT_NOCODEC_MACH=m
  - SND_SOC_MAX98927=n
  - SND_SOC_NAU8824=m
  - PCI:
  - PCI_ENDPOINT=y
  - PCI_ENDPOINT_CONFIGFS=n
  - PCI_ENDPOINT_TEST=m
  - PCI_EPF_TEST=m
  - PCI_SW_SWITCHTEC=m
  - USB:
  - TYPEC_FUSB302=m
  - TYPEC_TCPCI=m
  - TYPEC_TCPM=m
  - TYPEC_WCOVE=m
  - USB_PCI=y
  - NVM:
  - NVM_PBLK=m
  - Power supply:
  - BATTERY_AXP20X=m
  - CHARGER_AXP20X=m
  - Multimedia:
  - CEC_PLATFORM_DRIVERS=y
  - IR_SIR=m (renamed LIRC_SIR)
  - MEDIA_CEC_RC=y
  - USB_RAINSHADOW_CEC=m
  - VIDEO_OV2640=m (renamed SOC_CAMERA_OV2640)
  - Input:
  - JOYSTICK_PSXPAD_SPI=m
  - JOYSTICK_PSXPAD_SPI_FF=y
  - MOUSE_PS2_SYNAPTICS_SMBUS=y
  - TOUCHSCREEN_TSC2007_IIO=y
  - Hardware monitoring:
  - SENSORS_ASPEED=m
  - DAX:
  - DAX=y
  - EDAC:
  - EDAC_GHES=n (causes problems, ask bpetkov)
  - Crypto:
  - SYSTEM_BLACKLIST_KEYRING=n
  - HID:
  - HID_ACCUTOUCH=m
  - HID_NTI=m
  - HID_SENSOR_HUMIDITY=m
  - HID_SENSOR_TEMP=m
  - Industrial I/O
  - AXP20X_ADC=m
  - LTC2497=n
  - LTC2632=n
  - MAX1118=n
  - MAX30102=m
  - MAX9611=n
  - SRF04=m
  - VL6180=m
  - Thermal:
  - THERMAL_EMERGENCY_POWEROFF_DELAY_MS=0
  - I2C:
  - I2C_MUX_LTC4306=m
  - IB:
  - INFINIBAND_OPA_VNIC=m
  - Staging:
  - LNET_XPRT_IB=m
  - Xen:
  - XEN_PV=y
  - x86:
  - DELL_WMI_LED=m (renamed LEDS_DELL_NETBOOKS)
  - INTEL_CHT_INT33FE=m
  - X86_MCELOG_LEGACY=y
  - Misc:
  - ALTERA_PR_IP_CORE=m
  - CHARLCD=m
  - FPGA_MGR_XILINX_SPI=m
  - HD44780=m
  - INTEL_SOC_PMIC_BXTWC=m
  - MFD_TI_LMU=m
  - MMC_SDHCI_XENON=m
  - RAS_CEC=y
  - RESET_IMX7=n
  - W1_SLAVE_DS2438=m
  - XPOWER_PMIC_OPREGION=y
  - ppc64le:
  - ARCH_MMAP_RND_BITS=14
  - ARCH_MMAP_RND_COMPAT_BITS=7
  - CRYPTO_CRCT10DIF_VPMSUM=n
  - CRYPTO_DEV_CCREE=n
  - DA9062_THERMAL=n
  - DRM_LVDS_ENCODER=n
  - DRM_MEGACHIPS_STDPXXXX_GE_B850V3_FW=n
  - DRM_RCAR_DW_HDMI=n
  - FA_DUMP=n
  - FPGA_MGR_ICE40_SPI=n
  - GPIO_FTGPIO010=n
  - KPROBES_ON_FTRACE=y
  - LEDS_LP3952=n
  - PPC_DT_CPU_FTRS=n
  - PPC_XIVE_NATIVE=y
  - THREAD_SHIFT=14
  - XILINX_PR_DECOUPLER=n
  - s390x:
  - ARCH_RANDOM=y
  - ATA=n
  - DEFERRED_STRUCT_PAGE_INIT=n
  - MAX_PHYSMEM_BITS=46
  - S390_CCW_IOMMU=n
- commit df8bd3d
* Thu May 25 2017 kbuild@suse.de
- Automatically updated to 4.12-rc2-next-20170525
- commit c1e80f7
* Wed May 24 2017 kbuild@suse.de
- Automatically updated to 4.12-rc2-next-20170524
- commit b2d5157
* Tue May 23 2017 kbuild@suse.de
- Automatically updated to 4.12-rc2-next-20170523
- commit cd88c7a
* Mon May 22 2017 kbuild@suse.de
- Automatically updated to 4.12-rc1-next-20170522
- commit f695020
* Fri May 19 2017 tiwai@suse.de
- Update config files: set HD-audio power save as default (boo#1039995).
- commit a2f965e
* Fri May 19 2017 kbuild@suse.de
- Automatically updated to 4.12-rc1-next-20170519
- commit 910f14b
* Thu May 18 2017 kbuild@suse.de
- Automatically updated to 4.12-rc1-next-20170518
- commit 5b4a768
* Wed May 17 2017 kbuild@suse.de
- Automatically updated to 4.12-rc1-next-20170517
- commit 6dbf0e4
* Tue May 16 2017 kbuild@suse.de
- Automatically updated to 4.12-rc1-next-20170516
- commit 175f451
* Mon May 15 2017 kbuild@suse.de
- Automatically updated to 4.12-rc1-next-20170515
- commit 3e567c4
* Fri May 12 2017 kbuild@suse.de
- Automatically updated to 4.11-next-20170512
- commit 9f4ea83
* Thu May 11 2017 kbuild@suse.de
- Automatically updated to 4.11-next-20170511
- commit e271071
* Wed May 10 2017 jeffm@suse.com
- config: disable XFS_RT
- commit 4422f8b
* Wed May 10 2017 kbuild@suse.de
- Automatically updated to 4.11-next-20170510
- commit 0342d9a
* Tue May  9 2017 kbuild@suse.de
- Automatically updated to 4.11-next-20170509
- commit 36bca4f
* Mon May  8 2017 kbuild@suse.de
- Automatically updated to 4.11-next-20170508
- commit 5a6c134
* Mon May  8 2017 jdelvare@suse.de
- config: armv6hl: Disable KEYBOARD_TM2_TOUCHKEY
  The Samsung TM2 board is based on an Exynos SoC, which the armv6
  kernel does not support.
- commit 6b1a68e
* Sat May  6 2017 stefan.bruens@rwth-aachen.de
- config: arm64: Enable MEDIA_CONTROLLER API
  Option is already set on armv7hl/armv6hl.
- commit 14ea4f7
* Sat May  6 2017 stefan.bruens@rwth-aachen.de
- config: arm64: Enable SND_SOC and codecs
  Config mimics armv7hl, save any differences due to less SoCs supported
  by arm64.
  [AF: Rebased onto v4.12-rc3]
- commit 807fbcc
* Fri May  5 2017 kbuild@suse.de
- Automatically updated to 4.11-next-20170505
- commit d6d8d6d
* Thu May  4 2017 mmarek@suse.com
- Revert "powerpc: Blacklist GCC 5.4 6.1 and 6.2 (boo#1028895)."
  The patch is misplaced and breaks the build of dtb-*.spec. We will get
  it from upstream eventually (bsc#1037391).
  This reverts commit 966dfc6d971b7e8880689852c0457ab02f6b9b6e.
- commit 3746ed9
* Thu May  4 2017 kbuild@suse.de
- Automatically updated to 4.11-next-20170504
- commit 9b59aa5
* Wed May  3 2017 kbuild@suse.de
- Automatically updated to 4.11-next-20170503
- commit d1f2472
* Wed May  3 2017 msuchanek@suse.de
- kernel-binary.spec Remove superfluous [].
- commit 0bf8e9f
* Tue May  2 2017 msuchanek@suse.de
- Use make --output-sync feature when available (bsc#1012422).
  The mesages in make output can interleave making it impossible to
  extract warnings reliably. Since version 4 GNU Make supports
  - -output-sync flag that prints output of each sub-command atomically
  preventing this issue. Detect the flag and use it if available.
  SLE11 has make 3.81 so it is required to include make 4 in the kernel
  OBS projects to take advantege of this.
- commit 8c2f46d
* Tue May  2 2017 kbuild@suse.de
- Automatically updated to 4.11-next-20170502
- commit 4153765
* Tue May  2 2017 tiwai@suse.de
- Set CONFIG_CRYPTO_MD5=y for a better diagnoise at S4 resume (bsc#1031893).
- commit ff2e9c7
* Mon May  1 2017 jeffm@suse.com
- Update to 4.11-final.
- commit 2a34db6
* Mon May  1 2017 kbuild@suse.de
- Automatically updated to 4.11-rc8-next-20170501
- commit 81c7a97
* Fri Apr 28 2017 kbuild@suse.de
- Automatically updated to 4.11-rc8-next-20170428
- commit 93e07aa
* Fri Apr 28 2017 jdelvare@suse.de
- Update x86 config files: disable SILEAD_DMI
  The silead_dmi "driver" is in an horrible shape. The design is pretty
  bad and the implementation is poor, to stay polite. I wish such code
  would not make it into the upstream kernel in the first place. I
  don't want it to run on any openSUSE system until it is fixed.
- commit 958157c
* Thu Apr 27 2017 kbuild@suse.de
- Automatically updated to 4.11-rc8-next-20170427
- commit f76522f
* Wed Apr 26 2017 kbuild@suse.de
- Automatically updated to 4.11-rc8-next-20170426
- commit 2cf9194
* Tue Apr 25 2017 mmarek@suse.com
- rpm/kernel-binary.spec.in: Do not split KMPs for openSUSE (fate#319339)
- commit a259f75
* Tue Apr 25 2017 mmarek@suse.com
- rpm/dtb.spec.in.in: Do not depend on kernel-source (bsc#1034066)
  Apply the patches during build, just like kernel-binary.spec.in does.
- commit 4e37db7
* Mon Apr 24 2017 jeffm@suse.com
- Update to 4.11-rc8.
- commit 739c1be
* Mon Apr 24 2017 tiwai@suse.de
- Disable CONFIG_POWER_SUPPLY_DEBUG in debug kernels (bsc#1031500).
- commit 4778f61
* Mon Apr 24 2017 mmarek@suse.com
- Disable CONFIG_DRM_RCAR_DW_HDMI on ppc64{,le}
- commit 6d0dd14
* Mon Apr 24 2017 mmarek@suse.com
- Automatically updated to 4.11-rc7-next-20170424
- commit 767ab1a
* Fri Apr 21 2017 kbuild@suse.de
- Automatically updated to 4.11-rc7-next-20170421
- commit d54f2e2
* Thu Apr 20 2017 kbuild@suse.de
- Automatically updated to 4.11-rc7-next-20170420
- commit 854a2ec
* Thu Apr 20 2017 tiwai@suse.de
- Enable CONFIG_INTEL_SOC_PMIC and CONFIG_PMIC_OPREGION (boo#1035040).
  Some of these configs are built-in only, unfortunately, and consequently
  it requires CONFIG_MFD_CORE=y, too.
- commit 1153a92
* Thu Apr 20 2017 tiwai@suse.de
- Enable configs for AXP I2C stuff on Cherrytail devices (boo#1035040).
- commit 1db572a
* Thu Apr 20 2017 tiwai@suse.de
- Enable CONFIG_INPUT_SOC_BUTTON_ARRAY for x86 (boo#1034642).
- commit 22afdb2
* Wed Apr 19 2017 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not sign modules if CONFIG_MODULE_SIG=n (bsc#1035053)
- commit 50db9ef
* Wed Apr 19 2017 kbuild@suse.de
- Automatically updated to 4.11-rc7-next-20170419
- commit 5e5f498
* Wed Apr 19 2017 jeffm@suse.com
- Update to 4.11-rc7.
- commit cbbf792
* Wed Apr 19 2017 afaerber@suse.de
- config: arm64: Enable SUN8I_H3_CCU for Allwinner H5
- commit b2d2ddb
* Tue Apr 18 2017 tiwai@suse.de
- Enable CONFIG_KXCJK1013 for Cherrytrail devices (boo#1034809).
- commit 15b7a7a
* Tue Apr 18 2017 kbuild@suse.de
- Automatically updated to 4.11-rc7-next-20170418
- commit 82d0e5c
* Thu Apr 13 2017 kbuild@suse.de
- Automatically updated to 4.11-rc6-next-20170413
- commit 9eb24ad
* Thu Apr 13 2017 afaerber@suse.de
- config: ARM: Make SERIAL_DEV_BUS built-in
- Makes available SERIAL_DEV_CTRL_TTYPORT
- commit bdd0894
* Thu Apr 13 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Enable overlay support for Tumbleweed and Leap 42.3
- Generate __symbols__ node to allow resolution of labels in overlays
- commit c94e646
* Wed Apr 12 2017 kbuild@suse.de
- Automatically updated to 4.11-rc6-next-20170412
- commit b2d5a79
* Tue Apr 11 2017 kbuild@suse.de
- Automatically updated to 4.11-rc6-next-20170411
- commit ea8aca0
* Mon Apr 10 2017 jeffm@suse.com
- Update to 4.11-rc6.
- Eliminated 2 patches.
- commit 6b6eb5a
* Mon Apr 10 2017 kbuild@suse.de
- Automatically updated to 4.11-rc6-next-20170410
- commit 12cb38f
* Sun Apr  9 2017 afaerber@suse.de
- config: armv7hl: Enable i.MX 7 ADC
- commit 1f8be53
* Sat Apr  8 2017 afaerber@suse.de
- config: armv7hl: Update for 4.11-rc5
- commit 71055d3
* Sat Apr  8 2017 afaerber@suse.de
- config: armv6hl: Update to 4.11-rc5
- commit 7e98096
* Fri Apr  7 2017 kbuild@suse.de
- Automatically updated to 4.11-rc5-next-20170407
- commit 1b36db4
* Fri Apr  7 2017 mmarek@suse.com
- Sync i386/debug with i386/pae
  CONFIG_HWMON=y
  CONFIG_LGUEST_GUEST=y
  CONFIG_PATA_LEGACY=n
  CONFIG_USB_OHCI_HCD_SSB=y
- commit 4252ab8
* Fri Apr  7 2017 mmarek@suse.com
- Disable CONFIG_ISA in i386/debug to sync with pae.
- commit 4ba4255
* Fri Apr  7 2017 mmarek@suse.com
- Use fragment configs for debug and i386/default.
- commit e1ba64b
* Fri Apr  7 2017 stefan.bruens@rwth-aachen.de
- config: ARM: Enable TI INA2xx current/voltage sensors
  [AF: Disable hwmon driver; enable for armv6hl and armv7hl lpae, too]
- commit f104f3b
* Thu Apr  6 2017 kbuild@suse.de
- Automatically updated to 4.11-rc5-next-20170406
- commit 4b9516b
* Wed Apr  5 2017 kbuild@suse.de
- Automatically updated to 4.11-rc5-next-20170405
- commit 818b825
* Tue Apr  4 2017 kbuild@suse.de
- Automatically updated to 4.11-rc5-next-20170404
- commit a0881dd
* Mon Apr  3 2017 jeffm@suse.com
- Update to 4.11-rc5.
- Eliminated 1 patch.
- commit 5f80f06
* Mon Apr  3 2017 kbuild@suse.de
- Automatically updated to 4.11-rc5-next-20170403
- commit a4b2568
* Fri Mar 31 2017 mmarek@suse.com
- Automatically updated to 4.11-rc4-next-20170331
- commit c4ce0d3
* Fri Mar 31 2017 mmarek@suse.com
- Update config files: Enable SND_SOC and reenable DRM_VC4
- commit 6583eda
* Fri Mar 31 2017 lpechacek@suse.com
- doc/README.SUSE: update links to KMP manual
- commit 9ab365a
* Mon Mar 27 2017 jeffm@suse.com
- Update to 4.11-rc4.
- commit 7d631e2
* Mon Mar 27 2017 kbuild@suse.de
- Automatically updated to 4.11-rc4-next-20170327
- commit c7017db
* Fri Mar 24 2017 kbuild@suse.de
- Automatically updated to 4.11-rc3-next-20170324
- commit 8f3728d
* Thu Mar 23 2017 kbuild@suse.de
- Automatically updated to 4.11-rc3-next-20170323
- commit 6ea13bd
* Wed Mar 22 2017 kbuild@suse.de
- Automatically updated to 4.11-rc3-next-20170322
- commit c5e40b7
* Tue Mar 21 2017 kbuild@suse.de
- Automatically updated to 4.11-rc3-next-20170321
- commit 0afc98d
* Mon Mar 20 2017 afaerber@suse.de
- config: arm64: Update to 4.11-rc3
- commit 11bc564
* Mon Mar 20 2017 jeffm@suse.com
- Update to 4.11-rc3.
- Config changes:
  - LPFC_NVME_INITIATOR=y
  - LPFC_NVME_TARGET=y
- commit 1f69553
* Mon Mar 20 2017 mmarek@suse.com
- Automatically updated to 4.11-rc2-next-20170320
- commit 39c3140
* Tue Mar 14 2017 mmarek@suse.com
- rpm/apply-patches: Fix failure if there are no vanilla patches
  The grep command returns 1 if there are no patches and we are using
  pipefail.
- commit 6dc70de
* Tue Mar 14 2017 mmarek@suse.com
- Restore patches.rpmify/firmware-path after update error
- commit 62ac2d3
* Tue Mar 14 2017 mmarek@suse.com
- rpm/config.sh: Repair the SRCVERSION variable
  The update script did not handle a missing next-20170307 tag properly.
- commit da31bed
* Mon Mar 13 2017 mkubecek@suse.cz
- config: enable IPv6 multicast routing (bsc#1010755)
  While the reasoning in bugzilla is rather weak (basically just failing
  automated test checking for the feature, without any real user actually
  asking for it), I see little reason to have multicast routing enabled
  for IPv4 and disabled for IPv6.
- commit af4a82b
* Mon Mar 13 2017 jeffm@suse.com
- Update to 4.11-rc2.
- Eliminated 2 patches.
- Config changes:
  - UPROBE_EVENT=y -> UPROBE_EVENTS=y
  - KPROBE_EVENT=y -> KPROBE_EVENTS=y
- commit 30a3089
* Fri Mar 10 2017 msuchanek@suse.de
- powerpc: Blacklist GCC 5.4 6.1 and 6.2 (boo#1028895).
- commit 0a190f0
* Tue Mar  7 2017 kbuild@suse.de
- Automatically updated to
- commit 7ca6c86
* Mon Mar  6 2017 jeffm@suse.com
- Update to 4.11-rc1.
- Eliminated 3 patches.
- ARM configs need updating.
- Important for developers, DEBUG_RODATA was renamed to STRICT_KERNEL_RWX
- Config changes:
  - Generic:
  - PRINTK_SAFE_LOG_BUF_SHIFT=13
  - renamed from NMI_LOG_BUF_SHIFT, uses the same value
  - CGROUP_RDMA=y
  - MAGIC_SYSRQ_SERIAL=y
  - WW_MUTEX_SELFTEST=n
  - TEST_SORT=n
  - TEST_PARMAN=n
  - STATIC_USERMODEHELPER=n (needs distro support first)
  - SECURITY_APPARMOR_DEBUG=n
  - CRYPTO_AES_TIm
  - SERIAL_DEV_BUS=m
  - GCC:
  - GCC_PLUGIN_STRUCTLEAK=n
  - Block/Storage:
  - BLK_DEBUG_FS=y
  - BLK_SED_OPAL=y
  - MQ_IOSCHED_DEADLINE=y
  - VIRTIO_BLK_SCSI=n (default, use virtio-scsi)
  - Network:
  - SMC=m
  - INET_ESP_OFFLOAD=m
  - INET6_ESP_OFFLOAD=m
  - NFT_SET_BITMAP=m
  - NET_ACT_SAMPLE=m
  - PSAMPLE=m
  - NET_IFE=m
  - QEDF=m
  - IPVTAP=m
  - NFP=m
  - NFP_DEBUG=n (performance)
  - i386/x86_64:
  - SPI_INTEL_SPI_PLATFORM=m
  - XEN_PVH=y
  - PC104=y
  - x86_64:
  - AQTION=m
  - INTEL_TURBO_MAX_3=y
  - DVB:
  - DVB_USB_ZD1301=m
  - VIDEO_IVTV_DEPRECATED_IOCTLS=n (default)
  - DRM:
  - DRM_DEBUG_MM_SELFTEST=n (default)
  - DRM_I915_SW_FENCE_DEBUG_OBJECTS=n
  - DRM_TINYDRM=m
  - TINYDRM_MI0283QT=n
  - Console:
  - VGACON_SOFT_SCROLLBACK_PERSISTENT_ENABLE_BY_DEFAULT=y (old behavior)
  - USB:
  - USB_SERIAL_UPD78F0730=m
  - USB_HUB_USB251XB=m
  - IB:
  - INFINIBAND_BNXT_RE=m (except on s390x)
  - x86:
  - SILEAD_DMI=y
  - SND_X86=m
  - HDMI_LPE_AUDIO=m
  - EXTCON_INTEL_INT3496=m
  - ppc64/ppc64le:
  - FSI=m
  - IIO ADC/DAC/Sensors:
  - HX711=n
  - MAX11100=n
  - TI_ADS7950=n
  - TI_TLC4541=n
  - MPU3050_I2C=n
  - IIO_ST_LSM6DSX=n
  - M3605=n
  - MAX5481=n
  - SRF08=n
  - TMP007=n
  - PHY:
  - PHY_QCOM_USB_HS=m (ARM-only?)
  - PHY_QCOM_USB_HSIC=m (ARM-only?)
  - Misc:
  - LEDS_BRIGHTNESS_HW_CHANGED=y
  - TOUCHSCREEN_ZET6223=m
  - SERIAL_8250_EXAR=y
  - PTP_1588_CLOCK_KVM=m
  - PWRSEQ_SD8787=m
  - PINCTRL_GEMINILAKE=m
  - GPIO_EXAR=m
  - GPIO_PCI_IDIO_16=m
  - W1_SLAVE_DS2405=m
  - CHARGER_SBS=m
  - SENSORS_STTS751=m
  - SOFT_WATCHDOG_PRETIMEOUT=y
  - NIC7018=m
  - IR_SPI=m
  - EEPROM_IDT_89HPESX=m
  - ARM:
  - KEYBOARD_TM2_TOUCHKEY=n (exynos)
  - PINCTRL_TI_IODELAY=n
  - CHARGER_DETECTOR_MAX14656=n
  - COMMON_CLK_VC5=n
  - MFD_CPCAP=n
  - SND_SOC_ES8328_I2C=n
  - SND_SOC_ES8328_SPI=n
  - SND_SOC_NAU8540=n
  - COMMON_CLK_VC5=n
  - SOC_ZTE=n
- commit 84d80cb
* Mon Mar  6 2017 kbuild@suse.de
- Automatically updated to 4.11-rc1-next-20170306
- commit e56253c
* Fri Mar  3 2017 kbuild@suse.de
- Automatically updated to 4.10-next-20170303
- commit f243fd6
* Thu Mar  2 2017 kbuild@suse.de
- Automatically updated to 4.10-next-20170302
- commit af8612f
* Wed Mar  1 2017 kbuild@suse.de
- Automatically updated to 4.10-next-20170301
- commit 06947a7
* Tue Feb 28 2017 kbuild@suse.de
- Automatically updated to 4.10-next-20170228
- commit c03bf14
* Mon Feb 27 2017 kbuild@suse.de
- Automatically updated to 4.10-next-20170227
- commit 4613245
* Fri Feb 24 2017 kbuild@suse.de
- Automatically updated to 4.10-next-20170224
- commit 310de16
* Thu Feb 23 2017 kbuild@suse.de
- Automatically updated to 4.10-next-20170223
- commit af9806c
* Wed Feb 22 2017 kbuild@suse.de
- Automatically updated to 4.10-next-20170222
- commit d2baffd
* Tue Feb 21 2017 kbuild@suse.de
- Automatically updated to 4.10-next-20170221
- commit 09445e3
* Mon Feb 20 2017 jeffm@suse.com
- Update to 4.10-final.
- commit 8d9922a
* Mon Feb 20 2017 kbuild@suse.de
- Automatically updated to 4.10-rc8-next-20170220
- commit 39a550e
* Fri Feb 17 2017 mmarek@suse.com
- Automatically updated to 4.10-rc8-next-20170217
- commit a315db2
* Mon Feb 13 2017 jeffm@suse.com
- Update to 4.10-rc8.
- Eliminated 1 patch.
- commit 3d838dc
* Tue Feb  7 2017 afaerber@suse.de
- config: armv6hl: Enable RASPBERRYPI_POWER
- commit 44158a4
* Tue Feb  7 2017 afaerber@suse.de
- config: Make VIRTIO_CONSOLE built-in
- commit 488219c
* Mon Feb  6 2017 jeffm@suse.com
- Update to 4.10-rc7.
- Eliminated 1 patch.
- commit 35d92a6
* Thu Feb  2 2017 jslaby@suse.cz
- Update config files.
- Refresh patches.suse/DWARF-EH-frame-based-stack-unwinding.patch.
- fix for save_stack_trace (lockdep et al.)
- depends on !KASAN (too slow)
- commit c19f140
* Wed Feb  1 2017 kbuild@suse.de
- Automatically updated to 4.10-rc6-next-20170201
- commit 274bde8
* Tue Jan 31 2017 kbuild@suse.de
- Automatically updated to 4.10-rc6-next-20170131
- commit 7f84807
* Tue Jan 31 2017 jslaby@suse.cz
- Update config files.
- Refresh patches.suse/DWARF-EH-frame-based-stack-unwinding.patch.
- Refresh patches.suse/stack-unwind-disable-kasan.patch.
  Update dwarf unwinder. It fixes a build failure when disabled and
  moves files around.
- commit 4c2f0d8
* Tue Jan 31 2017 jslaby@suse.cz
- Update config files.
  Re-disable CONFIG_STACK_UNWIND in syzkaller. It was disabled until
  4.9-rc1 because the stack unwinder and KASAN do not play well
  together. In 4.9-rc1 we disabled DWARF stack unwinder completely due
  to upstream stack unwindining rewrite. I ported the unwinder recently,
  but forgot to disable it in the syzkaller flavor. Do it now.
- commit 659ae3d
* Mon Jan 30 2017 jeffm@suse.com
- Update to 4.10-rc6.
- Eliminated 1 patch.
- commit 66afaf9
* Mon Jan 30 2017 kbuild@suse.de
- Automatically updated to 4.10-rc6-next-20170130
- commit fc7e492
* Wed Jan 25 2017 kbuild@suse.de
- Automatically updated to 4.10-rc5-next-20170125
- commit bbe0e64
* Tue Jan 24 2017 kbuild@suse.de
- Automatically updated to 4.10-rc5-next-20170124
- commit 26b1992
* Mon Jan 23 2017 jeffm@suse.com
- Update to 4.10-rc5.
- commit a8e5ac9
* Mon Jan 23 2017 kbuild@suse.de
- Automatically updated to 4.10-rc5-next-20170123
- commit 6e3feff
* Mon Jan 23 2017 dsterba@suse.com
- rpm/kernel-binary.spec.in: gcc plugins needs gcc-devel
  The build fails with missing bversion.h header.
- commit 95b4403
* Fri Jan 20 2017 mmarek@suse.com
- rpm/kernel-binary.spec.in: scripts/gcc-plugin.sh needs gcc-c++
- commit d577958
* Fri Jan 20 2017 kbuild@suse.de
- Automatically updated to 4.10-rc4-next-20170120
- commit 62f9db2
* Thu Jan 19 2017 kbuild@suse.de
- Automatically updated to 4.10-rc4-next-20170119
- commit bded315
* Wed Jan 18 2017 jslaby@suse.cz
- Update config files (bnc#1011884).
  Kill FRAME_POINTER. Thanks to the stack traces generation rewrite in
  4.9 & DWARF unwinding port, frame pointers are no longer needed for
  stack traces. We can shoot them down now. I am going to implement
  generation of DWARF info for assembly rather soon.
  If issues occur, please revert this and let me know.
- commit cffa23c
* Wed Jan 18 2017 kbuild@suse.de
- Automatically updated to 4.10-rc4-next-20170118
- commit c1b13c2
* Tue Jan 17 2017 kbuild@suse.de
- Automatically updated to 4.10-rc4-next-20170117
- commit 9738e8f
* Tue Jan 17 2017 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix installation of /etc/uefi/certs (bsc#1019594)
- commit c6c6a91
* Mon Jan 16 2017 kbuild@suse.de
- Automatically updated to 4.10-rc3-next-20170116
- commit 93f9a97
* Mon Jan 16 2017 jeffm@suse.com
- Update to 3.10-rc4.
- commit 3df05a3
* Sun Jan 15 2017 agraf@suse.de
- Enable CMA DMA on AArch64 (boo#1020021)
- commit 00f2a52
* Fri Jan 13 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix building docs
- Fix html and pdf creation in Documetation/media/*
- Add graphviz to buildreq for image conversion
- Fix file list to remove REPORTING-BUGS
- commit a6d2693
* Fri Jan 13 2017 jeffm@suse.com
- config: RING_BUFFER_BENCHMARK=m on s390x (bsc#1019860).
  Commit 0b422208 should have done this but set it =y instead.
- commit 3fa1566
* Fri Jan 13 2017 kbuild@suse.de
- Automatically updated to 4.10-rc3-next-20170113
- commit a6eced4
* Thu Jan 12 2017 kbuild@suse.de
- Automatically updated to 4.10-rc3-next-20170112
- commit 65ca818
* Thu Jan 12 2017 mmarek@suse.com
- Automatically updated to 4.10-rc3-next-20170111
- commit 54204d8
* Mon Jan  9 2017 jeffm@suse.com
- config/vanilla: re-add CONFIG_SCHED_OMIT_FRAME_POINTER=y
  Re-enabling the stack unwind patches means that we need this defined
  on vanilla flavors on i386 and x86_64.
- commit 6998f24
* Mon Jan  9 2017 jeffm@suse.com
- Update to 4.10-rc3.
- Config changes:
  - armv7hl/default:
  - HZ_FIXED=0, HZ_200=y (restriction removed upstream)
- commit 8e11370
* Mon Jan  9 2017 kbuild@suse.de
- Automatically updated to 4.10-rc2-next-20170109
- commit 08ba324
* Fri Jan  6 2017 jslaby@suse.cz
- Refresh patches.suse/stack-unwind-disable-kasan.patch.
- Delete
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops.
- Update config files.
  Port the DWARF unwinder to 4.9+.
- commit 68726ae
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-zte subpackage
  4.9 added arch/arm64/boot/dts/zte/.
- rpm: Add arm64 dtb-zte subpackage
  4.9 added arch/arm64/boot/dts/zte/.
  (cherry picked from commit 23a79e358a8644d6a51c72c54d9d55698868105a)
- commit 073d831
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-allwinner subpackage
  4.10 added arch/arm64/boot/dts/allwinner/.
- rpm: Add arm64 dtb-allwinner subpackage
  4.10 added arch/arm64/boot/dts/allwinner/.
  (cherry picked from commit 81535fa841c80541350e4aa1047d2ddbbd6e9ebc)
- commit dfeb94a
* Fri Jan  6 2017 kbuild@suse.de
- Automatically updated to 4.10-rc2-next-20170106
- commit 8722b68
* Thu Jan  5 2017 mmarek@suse.cz
- rpm/kernel-obs-build.spec.in: Fix typo
- commit 45e1765
* Thu Jan  5 2017 mmarek@suse.com
- Delete scripts/config.sh, obsoleted by rpm/config.sh long ago
- commit 6fd3ed4
* Thu Jan  5 2017 mmarek@suse.com
- Enable kernel-obs-{build,qa} also in the vanilla branches
- commit 022e5fb
* Thu Jan  5 2017 mmarek@suse.com
- rpm/dtb.spec.in.in: Fix for kernel-source-vanilla (bsc#1011920)
- commit 4de517c
* Thu Jan  5 2017 kbuild@suse.de
- Automatically updated to 4.10-rc2-next-20170105
- commit f45a2ba
* Thu Jan  5 2017 mmarek@suse.com
- rpm/mkspec: Do not build dtbs for kernel-source-rt (bsc#1011920)
- commit f3a9899
* Thu Jan  5 2017 mmarek@suse.com
- rpm/dtb.spec.in.in: Use kernel-source-vanilla in vanilla branches (bsc#1011920)
- commit 44cf2d6
* Wed Jan  4 2017 kbuild@suse.de
- Automatically updated to 4.10-rc2-next-20170104
- commit 174934d
* Tue Jan  3 2017 mmarek@suse.com
- Automatically updated to 4.10-rc2-next-20170103
- commit 9258641
* Mon Jan  2 2017 jeffm@suse.com
- Update to 4.10-rc2.
- Eliminated 1 patch.
- commit c49c7eb
* Mon Jan  2 2017 afaerber@suse.de
- config: armv7hl: Update to v4.10-rc1
- commit c3f482f
* Mon Jan  2 2017 afaerber@suse.de
- config: armv6hl: Update to v4.10-rc1
- commit 9675f65
* Mon Jan  2 2017 afaerber@suse.de
- config: arm64: Update to 4.10-rc1
- commit 849b265
* Thu Dec 29 2016 jeffm@suse.com
- Update to 4.10-rc1.
- Eliminated 6 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - CONSOLE_LOGLEVEL_DEFAULT=7 (default)
  - BUG_ON_DATA_CORRUPTION=y
  - REMOTEPROC=m
  - CGROUP_BPF=y
  - STM_SOURCE_FTRACE=m
  - Block:
  - BLK_DEV_ZONED=y
  - BLK_WBT=y
  - BLK_WBT_SQ=n (default)
  - BLK_WBT_MQ=y (default)
  - x86:
  - INTEL_RDT_A=y
  - SCHED_MC_PRIO=y
  - Net:
  - INET_RAW_DIAG=m
  - IPV6_SEG6_LWTUNNEL=y
  - IPV6_SEG6_INLINE=n
  - IPV6_SEG6_HMAC=y
  - NF_LOG_NETDEV=m
  - NF_CT_PROTO_DCCP=y
  - NF_CT_PROTO_SCTP=y
  - NF_CT_PROTO_UDPLITE=y
  - NFT_RT=m
  - NFT_OBJREF=m
  - IP_SET_HASH_IPMAC=m
  - NF_SOCKET_IPV4=m
  - NFT_FIB_IPV4=m
  - NF_SOCKET_IPV6=m
  - NFT_FIB_IPV6=m
  - NFT_FIB_INET=m
  - LWTUNNEL_BPF=y
  - AMD_XGBE=m
  - AMD_XGBE_DCB=y
  - BNXT_DCB=y
  - MLXSW_CORE_THERMAL=y
  - MLXSW_I2C=m
  - MLXSW_SWITCHIB=m
  - MLXSW_MINIMAL=m
  - SFC_FALCON=m
  - SFC_FALCON_MTD=y
  - LED_TRIGGER_PHY=y
  - Debugging:
  - TEST_ASYNC_DRIVER_PROBE=n
  - DMA_FENCE_TRACE=n
  - DVB_DEMUX_SECTION_LOSS_LOG=n
  - SW_SYNC=n
  - MTD:
  - MTD_NAND_OXNAS=n
  - NVME:
  - NVME_FC=m
  - NVME_TARGET_FC=m
  - NVME_TARGET_FCLOOP=m
  - DM_DEBUG_BLOCK_MANAGER_LOCKING=n
  - iSCSI:
  - QEDI=m
  - ARM:
  - MESON_GXL_PHY
  - PINCTRL_SX150X
  - DRM_SIL_SII8620
  - DRM_TI_TFP410
  - DRM_HISI_HIBMC
  - DRM_MXSFB
  - SND_SOC_MSM8916_WCD_ANALOG
  - SND_SOC_MSM8916_WCD_DIGITAL
  - LEDS_NIC78BX
  - RTC_DRV_R7301
  - COMMON_CLK_MT2701
  - COMMON_CLK_MT2701_MMSYS
  - COMMON_CLK_MT2701_IMGSYS
  - COMMON_CLK_MT2701_VDECSYS
  - COMMON_CLK_MT2701_HIFSYS
  - COMMON_CLK_MT2701_ETHSYS
  - COMMON_CLK_MT2701_BDPSYS
  - LIQUIDIO_VF
  - SENSORS_XGENE
  - ALTERA_MBOX
  - ARM_SCPI_PROTOCOL
  - IIO_CROS_EC_SENSORS_CORE
  - Sound:
  - SND_SOC_CS35L34=m
  - SND_SOC_CS42L42=m
  - Wifi:
  - WIRELESS_WDS=n (deprecated)
  - Misc drivers:
  - RMI4_SMB=m
  - RMI4_F03=y
  - RMI4_F34=y
  - SCR24X=m
  - I2C_MUX_MLXCPLD=m
  - SENSORS_TC654=m
  - SENSORS_TMP108=m
  - MEDIA_CEC_SUPPORT=y
  - IR_SERIAL=m
  - IR_SERIAL_TRANSMITTER=y
  - DRM_I915_ALPHA_SUPPORT=n
  - DRM_I915_CAPTURE_ERROR=y
  - DRM_I915_COMPRESS_ERROR=y
  - DRM_I2C_ADV7511_AUDIO=y
  - HID_MAYFLASH=m
  - HID_UDRAW_PS3=m
  - USB_SERIAL_F8153X=m
  - MMC_SDHCI_CADENCE=m
  - LEDS_USER=m
  - INFINIBAND_VMWARE_PVRDMA=m
  - HT16K33=m
  - UIO_HV_GENERIC=m
  - VFIO_MDEV=m
  - VFIO_MDEV_DEVICE=m
  - SURFACE3_WMI=m
  - SURFACE_3_BUTTON=m
  - MLX_CPLD_PLATFORM=m
  - CRYPTO_DEV_VIRTIO=m
  - I2C_MLXCPLD=m
  - Misc chip drivers:
  - DA280=n
  - DA311=n
  - DMARD10=n
  - AD7766=n
  - ENVELOPE_DETECTOR=n
  - 104_QUAD_8=n
  - DPOT_DAC=n
  - HTS221=n
  - LMP91000=n
  - ABP060MG=n
  - FPGA_BRIDGE=m
  - FPGA_REGION=m
  - GPU:
  - DRM_I915_GVT_KVMGT=m
  - File systems:
  - OVERLAY_FS_REDIRECT_DIR=n (not backward compatible)
  - UBIFS_FS_ENCRYPTION=y
  - ppc64:
  - CC_STACKPROTECTOR_REGULAR=y
  - USE_THIN_ARCHIVES=n
  - KEXEC_FILE=y
  - RELOCATABLE_TEST=n
  - MOVABLE_NODE=y
  - TCG_TIS=m
  - PPC_PTDUMP=n
  - CRYPTO_CRC32C_VPMSUM=m
  - s390x:
  - IRQ_DOMAIN_DEBUG=n
  - BATMAN_ADV_BATMAN_V=y (consistent with other flavors)
  - I2C options, mostly =n -- enable as needed
- commit f18c55a
* Wed Dec 28 2016 tiwai@suse.de
- rpm/kernel-binary.spec.in: Obsolete ftsteutates KMP (boo#997172)
- commit 34c1867
* Sat Dec 24 2016 kbuild@suse.de
- Automatically updated to 4.9-next-20161224
- commit 81616fb
* Fri Dec 23 2016 kbuild@suse.de
- Automatically updated to 4.9-next-20161223
- commit b423ec6
* Thu Dec 22 2016 kbuild@suse.de
- Automatically updated to 4.9-next-20161222
- commit e110c84
* Wed Dec 21 2016 kbuild@suse.de
- Automatically updated to 4.9-next-20161221
- commit d59b864
* Tue Dec 20 2016 xxxxxmichl@googlemail.com
- added De0-Nanos-SoC board support (and others based on Altera SOC).
- commit 9278339
* Tue Dec 20 2016 kbuild@suse.de
- Automatically updated to 4.9-next-20161220
- commit 789e92c
* Mon Dec 19 2016 kbuild@suse.de
- Automatically updated to 4.9-next-20161219
- commit f44e452
* Mon Dec 19 2016 jdelvare@suse.de
- config: Disable GPIO_TS4900 in most kernels
  The gpio-ts4900 driver is only useful on i.MX6 boards, and only one
  of our kernels supports them.
- commit eca4732
* Fri Dec 16 2016 kbuild@suse.de
- Automatically updated to 4.9-next-20161216
- commit 98ce322
* Thu Dec 15 2016 kbuild@suse.de
- Automatically updated to 4.9-next-20161215
- commit 1cdd31f
* Wed Dec 14 2016 kbuild@suse.de
- Automatically updated to 4.9-next-20161214
- commit da7734e
* Tue Dec 13 2016 kbuild@suse.de
- Automatically updated to 4.9-next-20161213
- commit 6ce9844
* Mon Dec 12 2016 jeffm@suse.com
- Update to 4.9-final.
- Eliminated 1 patch.
- commit b6ba2f6
* Mon Dec 12 2016 kbuild@suse.de
- Automatically updated to 4.9-next-20161212
- commit ca1b7f3
* Fri Dec  9 2016 kbuild@suse.de
- Automatically updated to 4.9-rc8-next-20161209
- commit 0903ca7
* Thu Dec  8 2016 kbuild@suse.de
- Automatically updated to 4.9-rc8-next-20161208
- commit 511df6f
* Wed Dec  7 2016 kbuild@suse.de
- Automatically updated to 4.9-rc8-next-20161207
- commit f44ba95
* Tue Dec  6 2016 kbuild@suse.de
- Automatically updated to 4.9-rc8-next-20161206
- commit 5508710
* Mon Dec  5 2016 jeffm@suse.com
- Update to 4.9-rc8.
- Eliminated 1 patch.
- MODVERSIONS is enabled again.
- commit 9188ffe
* Mon Dec  5 2016 kbuild@suse.de
- Automatically updated to 4.9-rc8-next-20161205
- commit 66c1e37
* Fri Dec  2 2016 kbuild@suse.de
- Automatically updated to 4.9-rc7-next-20161202
- commit eb19959
* Thu Dec  1 2016 kbuild@suse.de
- Automatically updated to 4.9-rc7-next-20161201
- commit d78ae24
* Wed Nov 30 2016 jeffm@suse.com
- Update to 4.9-rc7.
- Eliminated 3 patches.
- MODVERSIONS (temporarily) depends on BROKEN (because it is).  This will
  need to be re-enabled when it is fixed or KMPs won't work.
- commit baf0b69
* Wed Nov 30 2016 afaerber@suse.de
- config: arm64: Enable TCG_INFINEON
- commit 2b901bd
* Wed Nov 30 2016 kbuild@suse.de
- Automatically updated to 4.9-rc7-next-20161130
- commit b613b72
* Tue Nov 29 2016 msuchanek@suse.de
- Add power key support for PMIcs which are already included in the configs
  (boo#1012477).
  Arm64 already has these so no need to patch it.
- commit aaff1c2
* Tue Nov 29 2016 kbuild@suse.de
- Automatically updated to 4.9-rc7-next-20161129
- commit c3e5ce2
* Tue Nov 29 2016 mmarek@suse.cz
- rpm/kernel-spec-macros: Fix the check if there is no rebuild counter (bsc#1012060)
- commit 6f16f5f
* Mon Nov 28 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Export a make-stderr.log file (bsc#1012422)
- commit f738229
* Mon Nov 28 2016 kbuild@suse.de
- Automatically updated to 4.9-rc7-next-20161128
- commit 1df96bf
* Fri Nov 25 2016 mmarek@suse.com
- rpm/dtb.spec.in.in: Adjust the formatting to osc's liking (bsc#1011920)
- commit cdcab93
* Fri Nov 25 2016 kbuild@suse.de
- Automatically updated to 4.9-rc6-next-20161125
- commit 690ca74
* Thu Nov 24 2016 msuchanek@suse.de
- Enable Intel i810 audio driver used in OpenQA VMs (boo#1012575).
- commit be3acc5
* Thu Nov 24 2016 kbuild@suse.de
- Automatically updated to 4.9-rc6-next-20161124
- commit d5499de
* Thu Nov 24 2016 mmarek@suse.com
- rpm/kernel-spec-macros: Ignore too high rebuild counter (bsc#1012060)
- commit 4ba30ba
* Wed Nov 23 2016 mmarek@suse.com
- rpm/mkspec-dtb: Print progress like mkspec does (bsc#1011920)
- commit 327c01e
* Wed Nov 23 2016 mmarek@suse.com
- Drop dtb-source.spec and move the sources to kernel-source (bsc#1011920)
- commit 3a67f58
* Wed Nov 23 2016 mmarek@suse.com
- Preprocess the dtb spec template with the kernel mkspec script
  This sets up the kernel version and release macros (bsc#1011920).
- commit 814c4ec
* Wed Nov 23 2016 mmarek@suse.com
- rpm/mkspec-dtb: Do not run the osc specfile formatter (bsc#1011920)
  It may produce varying output depending on the installed osc version.
- commit 2673925
* Wed Nov 23 2016 mmarek@suse.com
- rpm/mkspec-dtb: Stop copying the dtb .changes files (bsc#1011920)
  We are using the kernel changelog now.
- commit c7605f2
* Wed Nov 23 2016 mmarek@suse.com
- rename dtb's pre_checkin.pl to mkspec-dtb (bsc#1011920)
- commit 9e33f22
* Wed Nov 23 2016 mmarek@suse.com
- Import dtb-source specfiles into kernel-source (bsc#1011920)
- commit 7975919
* Wed Nov 23 2016 kbuild@suse.de
- Automatically updated to 4.9-rc6-next-20161123
- commit 56bfdb3
* Tue Nov 22 2016 kbuild@suse.de
- Automatically updated to 4.9-rc6-next-20161122
- commit 8e4408b
* Mon Nov 21 2016 mmarek@suse.cz
- Drop kernel-obs-qa-xen unconditionally (bsc#1010040)
  The IBS cannot build it, even if there is a xen-capable
  kernel-obs-build.
- commit f4797cb
* Mon Nov 21 2016 jeffm@suse.com
- Update to 4.9-rc6.
- commit 14ded04
* Thu Nov 17 2016 kbuild@suse.de
- Automatically updated to 4.9-rc5-next-20161117
- commit 9a15727
* Wed Nov 16 2016 kbuild@suse.de
- Automatically updated to 4.9-rc5-next-20161116
- commit 575ff3a
* Tue Nov 15 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Only build -base and -extra with CONFIG_MODULES (bsc#1000118)
- commit 4bd9ec7
* Tue Nov 15 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Do not create KMPs with CONFIG_MODULES=n
- commit 1cf9838
* Tue Nov 15 2016 mmarek@suse.com
- Reformat spec files according to the format_spec_file osc helper
- commit a3cd251
* Tue Nov 15 2016 mmarek@suse.com
- Update the copyright header in spec files
- commit 50b5bef
* Tue Nov 15 2016 kbuild@suse.de
- Automatically updated to 4.9-rc5-next-20161115
- commit e1ce6f6
* Mon Nov 14 2016 jeffm@suse.com
- Update to 4.9-rc5.
- commit 2e67bf1
* Mon Nov 14 2016 jslaby@suse.cz
- rpm/constraints.in: increase disk for kernel-syzkaller
  The kernel-syzkaller build now consumes around 30G. This causes
  headache in factory where the package rebuilds over and over. Require
  35G disk size to successfully build the flavor.
- commit 970a25c
* Mon Nov 14 2016 kbuild@suse.de
- Automatically updated to 4.9-rc5-next-20161114
- commit 89a37ce
* Sat Nov 12 2016 tiwai@suse.de
- Update config files: disable ASoC Intel BXT drivers
  They are still premature, and it enables snd-soc-skl automatically
  that interferes with the legacy HD-audio driver.  Keep them disabled
  until the issues are solved in upstream.
- commit de337ce
* Fri Nov 11 2016 kbuild@suse.de
- Automatically updated to 4.9-rc4-next-20161111
- commit c780acb
* Thu Nov 10 2016 kbuild@suse.de
- Automatically updated to 4.9-rc4-next-20161110
- commit 4a16f85
* Wed Nov  9 2016 kbuild@suse.de
- Automatically updated to 4.9-rc4-next-20161109
- commit 6a8c8e5
* Tue Nov  8 2016 kbuild@suse.de
- Automatically updated to 4.9-rc4-next-20161108
- commit 3faad36
* Sun Nov  6 2016 jeffm@suse.com
- Update to 4.9-rc4.
- Eliminated 2 patches.
- commit a0e8675
* Wed Nov  2 2016 afaerber@suse.de
- config: arm64/armv7hl: Disable QCOM_WCNSS_PIL for now
  Avoids a depmod error/abort:
  depmod: ERROR: Cycle detected: qcom_wcnss_iris -> qcom_wcnss -> qcom_wcnss_iris
- commit 874aa18
* Sun Oct 30 2016 jeffm@suse.com
- Update to 4.9-rc3.
- Eliminated 2 patches.
- commit d145950
* Fri Oct 28 2016 kbuild@suse.de
- Automatically updated to 4.9-rc2-next-20161028
- commit 18875ae
* Thu Oct 27 2016 kbuild@suse.de
- Automatically updated to 4.9-rc2-next-20161027
- commit 09ce144
* Wed Oct 26 2016 kbuild@suse.de
- Automatically updated to 4.9-rc2-next-20161026
- commit 4beccb4
* Tue Oct 25 2016 kbuild@suse.de
- Automatically updated to 4.9-rc2-next-20161025
- commit 2dd6da6
* Mon Oct 24 2016 mmarek@suse.com
- Automatically updated to 4.9-rc1-next-20161024
- commit c4e0961
* Mon Oct 24 2016 jeffm@suse.com
- Update to 4.9-rc2.
- commit 45d9748
* Fri Oct 21 2016 afaerber@suse.de
- config: armv7hl: Update to v4.9-rc1
- commit 485cab2
* Thu Oct 20 2016 afaerber@suse.de
- config: arm64: Update to v4.9-rc1
- commit 0aea73f
* Wed Oct 19 2016 afaerber@suse.de
- config: armv6hl: Update to v4.9-rc1
- commit b65955f
* Mon Oct 17 2016 jeffm@suse.com
- config: restore vanilla configs
  I accidentally appended the new config options to the vanilla configs.
  This patch restores them.
- commit 8ee5cb9
* Mon Oct 17 2016 jeffm@suse.com
- Update to 4.9-rc1.
- Eliminated 14 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - VMAP_STACK=y (where supported)
  - GCC plugins:
  - GCC_PLUGIN_LATENT_ENTROPY=n (fork/irq overhead)
  - CPUFREQ:
  - CPU_FREQ_GOV_SCHEDUTIL=y
  - x86:
  - MLX_PLATFORM=m
  - INTEL_ISH_HID=m
  - SND_SOC_INTEL_BDW_RT5677_MACH=m
  - SERIAL_8250_LPSS=y (i386)
  - PCI:
  - PCIE_PTM=y
  - Networking:
  - TCP_CONG_BBR=m
  - NFT_NUMGEN=m
  - NFT_SET_RBTREE=m
  - NFT_SET_HASH=m
  - NFT_QUOTA=m
  - NET_ACT_SKBMOD=m
  - NET_ACT_TUNNEL_KEY=m
  - NET_IFE_SKBTCINDEX=m
  - BATMAN_ADV_DEBUGFS=y
  - BT_HCIUART_MRVL=y
  - AF_RXRPC_IPV6=y
  - AF_RXRPC_INJECT_LOSS=n
  - ENA_ETHERNET=m
  - MICROSEMI_PHY=m
  - CRYPTO_DEV_CHELSIO=m
  - INFINIBAND_QEDR=m
  - GPIO:
  - INPUT_GPIO_DECODER=m
  - GPIO_MOCKUP=m
  - GPIO_GPIO_MM=m
  - GPIO_TS4900=m
  - DRM:
  - DRM_AMDGPU_SI=y
  - DRM_PANEL_JDI_LT070ME05000=n
  - DRM_DUMB_VGA_DAC=m
  - DRM_LEGACY (this may impact users with older hardware)
  - Sound:
  - SND_SOC_NAU88C10=m
  - SND_SIMPLE_SCU_CARD=m
  - USB:
  - USB_LEDS_TRIGGER_USBPORT=m
  - USBIP_VHCI_HC_PORTS=8 (default)
  - USBIP_VHCI_NR_HCS=1 (default)
  - USB_HSIC_USB4604=m
  - Other:
  - LEDS_IS31FL319X=m
  - RTC_DRV_DS1307_CENTURY=y
  - WDAT_WDT=m
  - WATCHDOG_PRETIMEOUT_GOV_PANIC=m
  - WATCHDOG_PRETIMEOUT_GOV_NOOP=y
  - VIDEO_TW5864=m
  - CONFIG_LEDS_MLXCPLD=m
  - SCSI_SMARTPQI=m
  - TOUCHSCREEN_EKTF2127=m
  - syzkaller config:
  - UBSAN_NULL=y
- commit ab8f77b
* Mon Oct 17 2016 jeffm@suse.com
- config: disable NET_DSA on non-ARM
- commit a29d99c
* Mon Oct 17 2016 kbuild@suse.de
- Automatically updated to 4.9-rc1-next-20161017
- commit ae83488
* Sun Oct 16 2016 kbuild@suse.de
- Automatically updated to 4.9-rc1-next-20161016
- commit 536410d
* Sun Oct 16 2016 afaerber@suse.de
- config: armv7hl: Enable MMC_SDHCI_IPROC for lpae (boo#1005019)
  Needed for Raspberry Pi 2, and default flavor already has it.
- commit 4d12943
* Fri Oct 14 2016 kbuild@suse.de
- Automatically updated to 4.8-next-20161014
- commit 80ba2d1
* Thu Oct 13 2016 kbuild@suse.de
- Automatically updated to 4.8-next-20161013
- commit 7e2adb7
* Wed Oct 12 2016 kbuild@suse.de
- Automatically updated to 4.8-next-20161012
- commit b6da1e0
* Tue Oct 11 2016 kbuild@suse.de
- Automatically updated to 4.8-next-20161011
- commit ff098b8
* Mon Oct 10 2016 kbuild@suse.de
- Automatically updated to 4.8-next-20161010
- commit c5b3956
* Thu Oct  6 2016 kbuild@suse.de
- Automatically updated to 4.8-next-20161006
- commit 0723278
* Wed Oct  5 2016 kbuild@suse.de
- Automatically updated to 4.8-next-20161005
- commit 9667f14
* Tue Oct  4 2016 kbuild@suse.de
- Automatically updated to 4.8-next-20161004
- commit 1abc899
* Mon Oct  3 2016 jeffm@suse.com
- Update to 4.8-final.
- commit 9eb03d0
* Mon Oct  3 2016 kbuild@suse.de
- Automatically updated to 4.8-rc8-next-20161003
- commit e10aae4
* Mon Oct  3 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Simplify debug info switch
  Any CONFIG_DEBUG_INFO sub-options are answered in the configs nowadays.
- commit d404ac5
* Fri Sep 30 2016 jslaby@suse.cz
- rpm/package-descriptions: the flavor is 64kb, not 64k
- commit 2e05d02
* Fri Sep 30 2016 kbuild@suse.de
- Automatically updated to 4.8-rc8-next-20160930
- commit cbfb2b9
* Thu Sep 29 2016 kbuild@suse.de
- Automatically updated to 4.8-rc8-next-20160929
- commit 62d4b30
* Wed Sep 28 2016 kbuild@suse.de
- Automatically updated to 4.8-rc8-next-20160928
- commit 7f923e2
* Tue Sep 27 2016 kbuild@suse.de
- Automatically updated to 4.8-rc8-next-20160927
- commit db78683
* Mon Sep 26 2016 jeffm@suse.com
- Update to 4.8-rc8.
- Eliminated 2 patches.
- commit da297e0
* Mon Sep 26 2016 schwab@suse.de
- kernel-module-subpackage: Properly quote flavor in expressions
  That fixes a parse error if the flavor starts with a digit or contains
  other non-alphabetic characters.
- commit 19ba528
* Mon Sep 26 2016 agraf@suse.de
- rpm/package-descriptions: Add 64kb kernel flavor description
- commit 7d9e0ef
* Fri Sep 23 2016 afaerber@suse.de
- config: arm64: Enable RASPBERRYPI_POWER
- commit 8acc1b7
* Fri Sep 23 2016 afaerber@suse.de
- config: armv7hl: Enable RASPBERRYPI_POWER
- commit c7ed0a6
* Fri Sep 23 2016 afaerber@suse.de
- config: armv7hl: Enable virtio-pci
  Needed for armv7l-on-aarch64 OBS workers.
- commit 74174bf
* Fri Sep 23 2016 afaerber@suse.de
- config: armv6hl: Enable USB OTG
  The Raspberry Pi Zero has an OTG port accessible.
- commit 7d2c5ce
* Fri Sep 23 2016 jslaby@suse.cz
- Update config files.
- Delete patches.suse/syzkaller-no-gcc-plugin.patch.
  The patch is actually not needed as we have sanitizer support in gcc
  directly (no need for plugins).
- commit cf5af61
* Fri Sep 23 2016 kbuild@suse.de
- Automatically updated to 4.8-rc7-next-20160923
- commit ff9644b
* Fri Sep 23 2016 jslaby@suse.cz
- Update config files.
  Enable UBSAN for syzkaller. It still boots, even though we are down
  at 250 s boot time from 130 s. Might be reconsidered later.
- commit 52f74a2
* Thu Sep 22 2016 mmarek@suse.com
- Automatically updated to 4.8-rc7-next-20160922
- commit 4b4d92d
* Wed Sep 21 2016 agraf@suse.de
- arm64: disable hvc_dcc
- commit b16a827
* Wed Sep 21 2016 agraf@suse.de
- arm64: Refuse to install 4k kernel on 64k system
- commit 478142f
* Wed Sep 21 2016 mmarek@suse.com
- Delete now unneeded patches.suse/split-package (bsc#1000118)
- Update config files.
- Refresh patches.suse/supported-flag,
- commit 315e5df
* Wed Sep 21 2016 mmarek@suse.com
- rpm/package-descriptions: pv has been merged into -default (fate#315712)
- commit 711ab33
* Wed Sep 21 2016 jslaby@suse.cz
- rpm/package-descriptions: add kernel-syzkaller
- commit 620032b
* Wed Sep 21 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Build the -base package unconditionally (bsc#1000118)
- commit 1d8c576
* Wed Sep 21 2016 jslaby@suse.cz
- Add syzkaller flavor (bnc#1000094).
- Update config files.
- syzkaller: no need for gcc plugins (bnc#1000094).
- commit 4331f54
* Tue Sep 20 2016 agraf@suse.de
- arm64: Add 64kb flavor for 64kb page size
- commit 4253ecb
* Tue Sep 20 2016 agraf@suse.de
- Switch arm64 default config to 4k
- commit bd1d0fb
* Tue Sep 20 2016 tiwai@suse.de
- rpm/kernel-docs.spec.in: Add support of sphinx with recent kernels
- commit b503754
* Mon Sep 19 2016 jeffm@suse.com
- Update to 4.8-rc7.
- Eliminated 1 patch.
- commit bdebea1
* Mon Sep 19 2016 kbuild@suse.de
- Automatically updated to 4.8-rc6-next-20160919
- commit 709eab9
* Fri Sep 16 2016 kbuild@suse.de
- Automatically updated to 4.8-rc6-next-20160916
- commit aea3b2b
* Thu Sep 15 2016 kbuild@suse.de
- Automatically updated to 4.8-rc6-next-20160915
- commit a36bd74
* Wed Sep 14 2016 jeffm@suse.com
- config: enable RANDOMIZE_BASE and friends (bsc#998554).
- commit 6bc2dde
* Wed Sep 14 2016 jeffm@suse.com
- Update to 4.8-rc6.
- commit f9425a6
* Wed Sep 14 2016 kbuild@suse.de
- Automatically updated to 4.8-rc6-next-20160914
- commit 28c1ca2
* Tue Sep 13 2016 kbuild@suse.de
- Automatically updated to 4.8-rc6-next-20160913
- commit 7bc0b94
* Mon Sep 12 2016 mmarek@suse.com
- Automatically updated to 4.8-rc5-next-20160912
- commit ca08988
* Wed Sep  7 2016 jeffm@suse.com
- config: enable FAIL_MAKE_REQUEST for testing purposes
- commit b432273
* Tue Sep  6 2016 jeffm@suse.com
- Update to 4.8-rc5.
- Config changes:
  - ARMV6: HW_RANDOM_MXC_RNGA=m
- commit 32e0b20
* Sun Sep  4 2016 afaerber@suse.de
- config: arm64: Enable brcmfmac
  The Raspberry Pi 3 has a BCM43438, with a firmware package being prepared.
- commit 660727d
* Fri Sep  2 2016 mmarek@suse.com
- rpm/mkspec: Read a default release string from rpm/config.sh (bsc997059)
- commit cf65a8d
* Thu Sep  1 2016 afaerber@suse.de
- config: arm64: Update to 4.8-rc4
- commit b86a2a5
* Thu Sep  1 2016 afaerber@suse.de
- config: armv6hl: Update to 4.8-rc4
- commit 4146d65
* Thu Sep  1 2016 afaerber@suse.de
- config: armv7hl: Update to 4.8-rc4
- commit cd5b1cd
* Mon Aug 29 2016 jeffm@suse.com
- Update to 4.8-rc4.
- commit 09ea9bf
* Thu Aug 25 2016 kbuild@suse.de
- Automatically updated to 4.8-rc3-next-20160825
- commit 1450e95
* Wed Aug 24 2016 kbuild@suse.de
- Automatically updated to 4.8-rc3-next-20160824
- commit 52e106f
* Tue Aug 23 2016 kbuild@suse.de
- Automatically updated to 4.8-rc3-next-20160823
- commit 087e953
* Mon Aug 22 2016 jeffm@suse.com
- Update to 4.8-rc3.
- Eliminated 1 patch.
- commit 1f5cb00
* Mon Aug 22 2016 kbuild@suse.de
- Automatically updated to 4.8-rc3-next-20160822
- commit b959b54
* Sat Aug 20 2016 mmarek@suse.cz
- rpm/old-flavors: Obsolte kernel-compute by kernel-rt (fate#320686)
- commit 964f3e2
* Sat Aug 20 2016 jason.derose@experient-inc.com
- Enable Sea Island GPUs in AMDGPU
- commit 575be0a
* Fri Aug 19 2016 kbuild@suse.de
- Automatically updated to 4.8-rc2-next-20160819
- commit a633358
* Thu Aug 18 2016 kbuild@suse.de
- Automatically updated to 4.8-rc2-next-20160818
- commit 5a1c7db
* Thu Aug 18 2016 mmarek@suse.com
- Disable CONFIG_GCC_PLUGINS for now
  Lets enable it and fix the build once we have a use case for it.
- commit 97a990b
* Wed Aug 17 2016 kbuild@suse.de
- Automatically updated to 4.8-rc2-next-20160817
- commit ac802dc
* Tue Aug 16 2016 mmarek@suse.com
- Automatically updated to 4.8-rc2-next-20160816
- commit cbe3de8
* Tue Aug 16 2016 mmarek@suse.com
- rpm/kernel-source.spec.in: Unroll a loop with only a single iteration
- commit 601c09e
* Mon Aug 15 2016 jeffm@suse.com
- Re-enable s390 message catalog patches.
  The printk changes that went into v4.8-rc1 were reverted (temporarily)
  for -rc2, so the old patches merge simply again.
- commit 4ec7bea
* Mon Aug 15 2016 jeffm@suse.com
- Update to 4.8-rc2.
- Config changes:
  - Global:
  - HARDENED_USERCOPY=n (we need to examine how it affects performance)
  - s390:
  - S390_GUEST_OLD_TRANSPORT=n (deprecated)
- commit 295dafe
* Mon Aug 15 2016 mmarek@suse.com
- Automatically updated to 4.8-rc1-next-20160815
- commit 976eb18
* Mon Aug 15 2016 jeffm@suse.com
- Update to 4.8-rc1.
- Eliminated 7 patches.
- ARM configs need updating.
- Several patches need to be merged by their owners.
- Config changes:
  - Global:
  - GCC_PLUGINS=y (menu option)
  - GCC_PLUGIN_CYC_COMPLEXITY=n
  - TPM:
  - TCG_TIS_SPI
  - TCG_VTPM_PROXY
  - TCG_TIS_ST33ZP24_I2C
  - TCG_TIS_ST33ZP24_SPI
  - Sensors:
  - SENSORS_FTSTEUTATES
  - SENSORS_SHT3x
  - SENSORS_INA3221
  - BMA220=n
  - MMA7660=n
  - MAX5487=n
  - Graphics:
  - DRM_I915_GVT=y
  - ACPI:
  - DPTF_POWER
  - ACPI_CONFIGFS
  - CPUFreq:
  - CPU_FREQ_STAT=n (overhead)
  - PCI:
  - PCIE_DPC=y (should be m but it's a bool)
  - RapidIO:
  - RAPIDIO_CHMAN
  - RAPIDIO_RXS_GEN3
  - IP:
  - TCP_CONG_NV
  - Netfilter:
  - NET_CLS_MATCHALL
  - Virtualization:
  - VIRTIO_VSOCKETS
  - VHOST_VSOCK
  - Networking hardware:
  - INTEL_XWAY_PHY
  - B53=n
  - NVME:
  - NVME_RDMA
  - NVME_TARGET
  - NVME_TARGET_LOOP
  - NVME_TARGET_RDMA
  - Infiniband:
  - RDMA_RXE
  - RTC:
  - RTC_DRV_MAX6916=n
  - Storage:
  - SCSI_UFS_DWC_TC_PCI=n (test hardware)
  - SCSI_UFS_DWC_TC_PLATFORM=n
  - Input:
  - TABLET_USB_PEGASUS
  - INPUT_ATMEL_CAPTOUCH
  - HID:
  - HID_LED
  - HID_ALPS
  - LEDs:
  - LEDS_LP3952
  - LEDS_TRIGGER_DISK
  - Touchscreen I2C/SPI:
  - TOUCHSCREEN_RM_TS
  - TOUCHSCREEN_SILEAD
  - TOUCHSCREEN_SIS_I2C
  - TOUCHSCREEN_SURFACE3_SPI
  - File Systems:
  - EXT4_ENCRYPTION=y
  - PSTORE_LZO_COMPRESS=y
  - NFSD_FLEXFILELAYOUT=y
  - SECURITY_APPARMOR_HASH_DEFAULT=y
  - Crypto:
  - CRYPTO_DH
  - CRYPTO_ECDH
  - CRYPTO_SHA3
  - Video:
  - DRM_I2C_ADV7533
  - Staging:
  - MEDIA_CEC=y (will be part of another module when out of staging)
  - KS7010
  - Audio:
  - SND_SOC_INTEL_BXT_DA7219_MAX98357A_MACH
  - SND_SOC_BT_SCO
  - Misc:
  - IIO_SW_DEVICE
  - IIO_TIGHTLOOP_TRIGGER=n
  - MTD_NAND_MTK
  - x86:
  - INTEL_VBTN
  - PWM_CROS_EC
  - x86_64:
  - CRYPTO_SHA256_MB
  - CRYPTO_SHA512_MB
  - powerpc:
  - GEN_RTC=n
  - HOTPLUG_PCI_POWERNV
  - CXL_BIMODAL=y
  - SCSI_IBMVSCSIS
  - ADB_PMU_LED_DISK=y
  - POWERNV_OP_PANEL
  - JUMP_LABEL_FEATURE_CHECKS=y
  - JUMP_LABEL_FEATURE_CHECK_DEBUG=n
  - CRYPT_CRC32C_VPMSUM
  - BPF_JIT=y
  - s390:
  - KCOV=n
  - CRYPTO_CRC32_S390=y
  - ARM (disabled):
  - MDIO_HISI_FEMAC
  - DRM_SII902X
  - DRM_TOSHIBA_TC358767
  - SND_SUN4I_I2S
  - SND_SOC_ADAU7002
  - SND_SOC_CS35L33
  - SND_SOC_CS53L30
  - SND_SOC_MAX98504
  - SND_SOC_MAX9860
  - SND_SOC_WM8985
  - SUNXI_CCU
  - TI_SYSCON_RESET
  - NET_NCSI (only used by Faraday, which is ARM hardware)
- commit 00b8fd4
* Fri Aug 12 2016 kbuild@suse.de
- Automatically updated to 4.8-rc1-next-20160812
- commit 524839e
* Thu Aug 11 2016 kbuild@suse.de
- Automatically updated to 4.8-rc1-next-20160811
- commit 9a6aac8
* Tue Aug  9 2016 kbuild@suse.de
- Automatically updated to 4.8-rc1-next-20160809
- commit 032e3f7
* Mon Aug  8 2016 kbuild@suse.de
- Automatically updated to 4.7-next-20160808
- commit 48c6828
* Fri Aug  5 2016 mmarek@suse.com
- Automatically updated to 4.7-next-20160805
- commit f76e37c
* Fri Aug  5 2016 jslaby@suse.cz
- rpm/constraints.in: set memory minimum for binaries
  Binary packages are sometimes built on machines with 1G. For example
  one arm build ran in a VM with -smp 1 -m 1024. And it caused OOMs.
  So set the minimal memory to 2G for all archs.
- commit b3acaa2
* Wed Aug  3 2016 kbuild@suse.de
- Automatically updated to 4.7-next-20160803
- commit 81e9cd4
* Tue Aug  2 2016 kbuild@suse.de
- Automatically updated to 4.7-next-20160802
- commit da485ea
* Tue Aug  2 2016 jdelvare@suse.de
- Make pinctrl-amd driver modular
  The pinctrl-amd driver can now be built as a module.
- commit 8fecf37
* Tue Aug  2 2016 jdelvare@suse.de
- config: Enable missing BayTrail and LynxPoint drivers
  We support the Intel BayTrail and LynxPoint systems so I believe we
  should enable all related drivers.
- commit adadb56
* Mon Aug  1 2016 kbuild@suse.de
- Automatically updated to 4.7-next-20160801
- commit 92d5fe1
* Mon Aug  1 2016 jslaby@suse.cz
- rpm/constraints.in: inscrease binary size req to 25G
  Currently, the build of master's -default kernel consumes exactly 20G.
  So increase the limit from 20G to 25G to stop build failures in the
  BS.
- commit c8360d6
* Fri Jul 29 2016 kbuild@suse.de
- Automatically updated to 4.7-next-20160729
- commit efdfc54
* Thu Jul 28 2016 kbuild@suse.de
- Automatically updated to 4.7-next-20160728
- commit c83c3c1
* Wed Jul 27 2016 kbuild@suse.de
- Automatically updated to 4.7-next-20160727
- commit 56e72f3
* Wed Jul 27 2016 schwab@suse.de
- group-source-files.pl: mark arch/*/scripts as devel
  make[2]: /usr/src/linux-4.6.4-2/arch/powerpc/scripts/gcc-check-mprofile-kernel.sh: Command not found
- commit aa32770
* Tue Jul 26 2016 kbuild@suse.de
- Automatically updated to 4.7-next-20160726
- commit bb13198
* Mon Jul 25 2016 kbuild@suse.de
- Automatically updated to 4.7-next-20160725
- commit b5d23cc
* Mon Jul 25 2016 jeffm@suse.com
- Update to 4.7-final.
- commit 1706eb4
* Sun Jul 24 2016 kbuild@suse.de
- Automatically updated to 4.7-rc7-next-20160724
- commit 6a9d2bd
* Fri Jul 22 2016 kbuild@suse.de
- Automatically updated to 4.7-rc7-next-20160722
- commit e5b004f
* Thu Jul 21 2016 agraf@suse.de
- Disable all ARMv8.1 and 8.2 features (bsc#981051)
- commit c106e70
* Thu Jul 21 2016 kbuild@suse.de
- Automatically updated to 4.7-rc7-next-20160721
- commit 52f1cef
* Wed Jul 20 2016 kbuild@suse.de
- Automatically updated to 4.7-rc7-next-20160720
- commit 5b14cbf
* Tue Jul 19 2016 kbuild@suse.de
- Automatically updated to 4.7-rc7-next-20160719
- commit 64b980a
* Mon Jul 18 2016 jeffm@suse.com
- Update to 4.7-rc7.
- Eliminated 2 patches.
- commit ebb3380
* Mon Jul 18 2016 kbuild@suse.de
- Automatically updated to 4.7-rc7-next-20160718
- commit ae21e6a
* Mon Jul 18 2016 mmarek@suse.com
- rpm/kernel-spec-macros: Add kver_cmp macro
  This allows to use %%if statements based on the version of the kernel to
  be built.
- commit ea700be
* Fri Jul 15 2016 afaerber@suse.de
- config: armv7hl: Enable POWER_RESET_AS3722 for lpae
  It's needed for the Jetson TK1.
- commit 836836a
* Fri Jul 15 2016 tiwai@suse.de
- rpm/kernel-source.spec.in: recommends openssl-devel (bsc#987384)
- commit 2c51311
* Fri Jul 15 2016 kbuild@suse.de
- Automatically updated to 4.7-rc7-next-20160715
- commit 49b06be
* Thu Jul 14 2016 mmarek@suse.com
- Automatically updated to 4.7-rc7-next-20160714
- commit 6a676ce
* Wed Jul 13 2016 tiwai@suse.de
- rpm/constraints.in: Increase to 8GB for kernel-source
  4GB seems still too tight for some archs like ppc64le...
- commit d82b2bf
* Wed Jul 13 2016 kbuild@suse.de
- Automatically updated to 4.7-rc7-next-20160713
- commit 676b526
* Tue Jul 12 2016 mmarek@suse.com
- Automatically updated to 4.7-rc7-next-20160712
- commit 883e2f5
* Fri Jul  8 2016 tiwai@suse.de
- Update config files: enable DW_DMAC and ASoC Intel BDW/HSW drivers (boo#988117)
- commit c331523
* Fri Jul  8 2016 kbuild@suse.de
- Automatically updated to 4.7-rc6-next-20160708
- commit 6d93b1b
* Fri Jul  8 2016 jdelvare@suse.de
- config: Disable RTC_DRV_DS1302
  All other SPI RTC device drivers are disabled, no reason why this
  one would be an exception.
- commit 07af450
* Fri Jul  8 2016 afaerber@suse.de
- config: arm64: Enable TEGRA210_ADMA
- commit 2e59fd1
* Fri Jul  8 2016 afaerber@suse.de
- config: arm64: Enable DRM_ANALOGIX_ANX78XX
- commit 57dc19d
* Fri Jul  8 2016 afaerber@suse.de
- config: armv7hl: Enable HDCP support for Snapdragon
  arm64 already had it enabled.
- commit 39a1ad8
* Fri Jul  8 2016 afaerber@suse.de
- config: arm64: Align USB gadget options
  Enable serial gadget console support, enable a missing configfs option
  and disable legacy UAC1.
- commit 37e9506
* Fri Jul  8 2016 afaerber@suse.de
- config: armv7hl: Enable USB gadget options
  This allows to build solutions like a Ceph USB storage gateway,
  presented at openSUSE Conference:
  https://events.opensuse.org/conference/oSC16/program/proposal/934
- commit 6529e81
* Fri Jul  8 2016 afaerber@suse.de
- config: armv6hl: Enable remaining LED triggers
  Also enable flash LED class while at it.
- commit 016ec4d
* Fri Jul  8 2016 afaerber@suse.de
- config: armv6hl: Update to 4.7
- commit ab5f9ed
* Thu Jul  7 2016 jeffm@suse.com
- config: restore default cpufreq governor
  The update to 4.7-rc1 mistakenly used CPU_FREQ_DEFAULT_GOV_PERFORMANCE=y.
  This patch reverts to the longtime default of ONDEMAND.
- commit a215e1e
* Thu Jul  7 2016 kbuild@suse.de
- Automatically updated to 4.7-rc6-next-20160707
- commit b65de49
* Thu Jul  7 2016 mbrugger@suse.com
- Update config files.
  Disable GCC_PLUGIN_* for arm64, as the ABI/API is not stable and
  therefore plugins are not supported in gcc (bsc#988009)
- commit a841672
* Wed Jul  6 2016 kbuild@suse.de
- Automatically updated to 4.7-rc6-next-20160706
- commit e043b13
* Tue Jul  5 2016 afaerber@suse.de
- config: armv7hl: Enable ipq4019
  It's a Cortex-A7.
- commit f646b17
* Tue Jul  5 2016 afaerber@suse.de
- config: armv7hl: Enable BCM2836 support for lpae
  The Raspberry Pi 2 has a Cortex-A7, so let's enable it in lpae flavor.
  Consistently make HW_RANDOM_BCM2835 a module.
- commit e01b0d5
* Tue Jul  5 2016 afaerber@suse.de
- config: armv7hl: Enable all LED triggers
  Let's be consistent about offering them. arm64 has them already.
- commit 147dbb0
* Tue Jul  5 2016 kbuild@suse.de
- Automatically updated to 4.7-rc6-next-20160705
- commit 9519ce4
* Mon Jul  4 2016 jeffm@suse.com
- Update to 4.7-rc6.
- commit c7b901d
* Mon Jul  4 2016 kbuild@suse.de
- Automatically updated to 4.7-rc5-next-20160704
- commit 9ab9718
* Fri Jul  1 2016 jthumshirn@suse.de
- Update config files to allow building of libnvdimm as module.
- commit be602da
* Fri Jul  1 2016 kbuild@suse.de
- Automatically updated to 4.7-rc5-next-20160701
- commit 01ead3e
* Thu Jun 30 2016 kbuild@suse.de
- Automatically updated to 4.7-rc5-next-20160630
- commit 803bf0b
* Wed Jun 29 2016 kbuild@suse.de
- Automatically updated to 4.7-rc5-next-20160629
- commit 9e8bdf0
* Tue Jun 28 2016 kbuild@suse.de
- Automatically updated to 4.7-rc5-next-20160628
- commit 5b6af8c
* Mon Jun 27 2016 jeffm@suse.com
- Update to 4.7-rc5.
- Eliminated 1 patch.
- commit 31b643d
* Mon Jun 27 2016 kbuild@suse.de
- Automatically updated to 4.7-rc4-next-20160627
- commit 4d74869
* Fri Jun 24 2016 kbuild@suse.de
- Automatically updated to 4.7-rc4-next-20160624
- commit 7963538
* Thu Jun 23 2016 kbuild@suse.de
- Automatically updated to 4.7-rc4-next-20160623
- commit 3f3cc79
* Wed Jun 22 2016 matwey.kornilov@gmail.com
- config: armv7hl: Update configs for 4.7
  [AF: Updated to -rc6: OMAP5 erratum]
  [AF: Revert CPU_FREQ_DEFAULT_GOV_PERFORMANCE (follows x86)]
  [AF: Keep CONFIG_ARM_EXYNOS[5]_BUS_DEVFREQ enabled]
  [AF: Enable DRM_ANALOGIX_ANX78XX, SND_SOC_WM8960]
- commit 5f0d12e
* Wed Jun 22 2016 mmarek@suse.com
- Automatically updated to 4.7-rc4-next-20160622
- commit 7ea3053
* Mon Jun 20 2016 jeffm@suse.com
- Update to 4.7-rc4.
- commit 93905de
* Mon Jun 20 2016 kbuild@suse.de
- Automatically updated to 4.7-rc3-next-20160620
- commit 810cd37
* Fri Jun 17 2016 mmarek@suse.com
- Update config files: CONFIG_GCC_PLUGINS=n
- commit 2f602cb
* Fri Jun 17 2016 mmarek@suse.com
- Automatically updated to 4.7-rc3-next-20160617
- commit 020791e
* Wed Jun 15 2016 mmarek@suse.cz
- rpm/constraints.in: Really require 4GB for kernel-source, add -rt (bsc#984845)
- commit a0dec36
* Wed Jun 15 2016 mmarek@suse.cz
- rpm/constraints.in: Require 4GB of disk space for kernel-source (bsc#984845)
- commit 1b20111
* Tue Jun 14 2016 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Use the default value for CONFIG_MODULE_SIG_KEY (bsc#983634)
- commit 6eb6cd2
* Mon Jun 13 2016 jeffm@suse.com
- Update to 4.7-rc3.
- 2 patches eliminated.
- commit 73460a2
* Fri Jun 10 2016 jslaby@suse.cz
- Update config files.
  Disable SECURITY_LOADPIN as it prevents every module from loading.
- commit eeec0de
* Fri Jun 10 2016 agraf@suse.de
- enable arm64 config again
- commit 623606d
* Mon Jun  6 2016 jeffm@suse.com
- Update to 4.7-rc2.
- commit 384e1cd
* Mon Jun  6 2016 jeffm@suse.com
- config: update ppc64 configs
  Config changes:
- ppc64:
  - PPC_RADIX_MMU=m
  - FSL_LBC=y
  - UIO_FSL_ELBC_GPCM=m
  - UIO_FSL_ELBC_GPCM_NETX5152=y
  - LIVEPATCH=y
- commit 01942a0
* Mon Jun  6 2016 kbuild@suse.de
- Automatically updated to 4.7-rc2-next-20160606
- commit dd931ab
* Fri Jun  3 2016 kbuild@suse.de
- Automatically updated to 4.7-rc1-next-20160603
- commit 1fcb092
* Thu Jun  2 2016 kbuild@suse.de
- Automatically updated to 4.7-rc1-next-20160602
- commit f083181
* Wed Jun  1 2016 jeffm@suse.com
- Update to 4.7-rc1.
- Eliminated 14 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - NMI_LOG_BUF_SHIFT=13 (default 8k, old value ~4k)
  - CC_OPTIMIZE_FOR_PERFORMANCE=y (no change)
  - MEMORY_HOTPLUG_DEFAULT_ONLINE=n (no change)
  - CPU_FREQ_DEFAULT_GOV_PERFORMANCE=y (no change)
  - SLAB_FREELIST_RANDOM=y (security feature, minimal performance impact)
  - DEVFREQ_GOV_PASSIVE=m
  - CPU_FREQ_GOV_SCHEDUTIL=m
  - Security:
  - KEY_DH_OPERATIONS=y
  - SECURITY_LOADPIN=n
  - DAX:
  - NVDIMM_DAX=y
  - DEV_DAX=m
  - DEV_DAX_PMEM=m
  - EFI:
  - EFI_BOOTLOADER_CONTROL=m
  - EFI_CAPSULE_LOADER=m
  - Misc:
  - RCU_PERF_TEST=m
  - HIST_TRIGGERS=y
  - TEST_HASH=n
  - Z3FOLD=m
  - ACPI_TABLE_UPGRADE=y
  - Options for existing drivers:
  - F2FS
  - F2FS_FAULT_INJECTION=y
  - QED
  - QED_SRIOV=y
  - QEDE
  - QEDE_GENEVE=y
  - QEDE_VXLAN=y
  - MLXSW_SPECTRUM
  - MLXSW_SPECTRUM_DCB=y
  - SERIAL_8250
  - SERIAL_8250_FINTEK=y
  - DRM_I915
  - DRM_I915_WERROR=y
  - DRM_I915_DEBUG=n
  - DRM_I915_DEBUG_GEM=n
  - NFC_PN533
  - NFC_PN533_USB=m
  - NFC_PN533_I2C=m
  - TCM_QLA2XXX
  - TCM_QLA2XXX_DEBUG=n
  - DRM_AMDGPU
  - DRM_AMDGPU_GART_DEBUGFS=n
  - WIZNET_W5100
  - WIZNET_W5100_SPI=m
  - Storage:
  - ISCSI_TARGET_CXGB4=m
  - SATA_DWC=n -- ppc32 only
  - Networking:
  - RXKAD=y
  - GTP=m
  - Sound:
  - SND_SOC_TAS5720=m
  - USB:
  - UCSI=m
  - Video:
  - VIDEO_TW686X=m
  - Misc drivers:
  - MFD_MAX77620=n
  - DRM_ARCPGU=n
  - PWRSEQ_EMMC=m
  - PWRSEQ_SIMPLE=m
  - PCIE_DPC=m
  - SENSORS_MAX31722=m
  - INT3406_THERMAL=m
  - GENERIC_ADC_THERMAL=m
  - LEDS_TRIGGER_MTD=n (bool)
  - LEDS_TRIGGER_PANIC=n (bool)
  - RTC_DRV_DS1302=m
  - SYNC_FILE=n
  - AD5592R=n
  - AD5593R=n
  - AM2315=m
  - BMI160_I2C=m
  - BMI160_SPI=m
  - BH1780=m
  - MAX44000=m
  - VEML6070=m
  - BMC150_MAGN_I2C=m
  - BMC150_MAGN_SPI=m
  - DS1803=m
  - MCP4131=m
  - HP03=m
  - HP206C=m
  - x86:
  - PERF_EVENTS_INTEL_RAPL=y
  - PERF_EVENTS_INTEL_CSTATE=y
  - SND_SOC_INTEL_BXT_RT298_MACH=m
  - INTEL_PMC_CORE=y
  - CROS_KBD_LED_BACKLIGHT=m
  - MCE_AMD_INJ=m
  - HID_ASUS=m
  - s390:
  - GPIOLIB=n
  - ARM:
  - SPI_ROCKCHIP=n
  - DRM_ANALOGIX_ANX78XX=n
  - SND_SOC_WM8960=n
  - COMMON_CLK_OXNAS=n
- commit 74200ea
* Wed Jun  1 2016 mbrugger@suse.com
- [v1,6/6] drivers: net: xgene: Fix module load/unload crash
  (bsc#981652 bsc#979043).
- Update config files.
- commit bd806d6
* Wed Jun  1 2016 kbuild@suse.de
- Automatically updated to 4.7-rc1-next-20160601
- commit f4ca1a6
* Tue May 31 2016 kbuild@suse.de
- Automatically updated to 4.7-rc1-next-20160531
- commit eaa1a93
* Mon May 30 2016 kbuild@suse.de
- Automatically updated to 4.7-rc1-next-20160530
- commit 7ad887d
* Fri May 27 2016 kbuild@suse.de
- Automatically updated to 4.6-next-20160527
- commit 8f9b99c
* Thu May 26 2016 kbuild@suse.de
- Automatically updated to 4.6-next-20160526
- commit d24d8ab
* Thu May 26 2016 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete SLE12-SP1 compat-wireless-kmp (bsc#975894)
- commit 127728b
* Wed May 25 2016 dmueller@suse.com
- Set CONFIG_NET_XGENE=y as a workaround for (bsc#973756)
- commit 6d654a6
* Wed May 25 2016 kbuild@suse.de
- Automatically updated to 4.6-next-20160525
- commit 9eb8e47
* Wed May 25 2016 tiwai@suse.de
- Fix build breakage due to missing buildroot in rpm/kernel-binary.spec.in
- commit c03eb71
* Tue May 24 2016 jeffm@suse.com
- drm/amd: add Kconfig dependency for ACP on DRM_AMDGPU.
- Update config files.
- commit b5d9cb4
* Tue May 24 2016 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix build error when no firmware is installed
- commit a09ef60
* Tue May 24 2016 kbuild@suse.de
- Automatically updated to 4.6-next-20160524
- commit 795891a
* Tue May 24 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Do not package helper files in -devel (bsc#981204)
- commit 4c334f0
* Mon May 23 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Install only needed firmware for -base (bsc#966447)
- commit f685839
* Mon May 23 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix placement of the reproducible build hack
- commit 26e4b73
* Mon May 23 2016 mmarek@suse.com
- rpm/config.sh: Build against Factory
  This should fix build issues on ppc64le and armv7l caused by too old
  toolchains.
- commit eaa23c6
* Mon May 23 2016 kbuild@suse.de
- Automatically updated to 4.6-next-20160523
- commit 19b898e
* Fri May 20 2016 kbuild@suse.de
- Automatically updated to 4.6-next-20160520
- commit dfedc79
* Thu May 19 2016 kbuild@suse.de
- Automatically updated to 4.6-next-20160519
- commit b78115e
* Wed May 18 2016 kbuild@suse.de
- Automatically updated to 4.6-next-20160518
- commit 32e19ff
* Tue May 17 2016 kbuild@suse.de
- Automatically updated to 4.6-next-20160517
- commit ad146f1
* Mon May 16 2016 jeffm@suse.com
- Update to 4.6-final.
- Eliminated 1 patch.
- Config changes:
  - MLX5_CORE_EN_VXLAN=y
- commit bb0b266
* Mon May 16 2016 mmarek@suse.com
- Automatically updated to 4.6-rc7-next-20160516
- commit bf9cc31
* Fri May 13 2016 mmarek@suse.com
- Automatically updated to 4.6-rc7-next-20160513
- commit 69829ea
* Wed May 11 2016 jeffm@suse.com
- config: FRAME_POINTER is required on i386/x86_64 vanilla configs
- commit 7701676
* Wed May 11 2016 jeffm@suse.com
- config: re-disable FRAME_POINTER on i386/x86_64
  It was enabled during the brief time that STACK_UNWIND was disabled and
  should have been disabled once that patchset was updated.
- commit c2c70be
* Mon May  9 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Make KMPs provide "$name-kmp" (bsc#976634)
- commit c1a48cb
* Mon May  9 2016 jeffm@suse.com
- Update to 4.6-rc7
- Eliminated 1 patch.
- Config changes:
  - ARM64:
  - SATA_AHCI_SEATTLE=m
- commit 08222b3
* Mon May  2 2016 jeffm@suse.com
- Update to 4.6-rc6.
- Config changes:
  - ARM64:
  - I2C_XLP9XX=m
- commit ffd49cf
* Mon May  2 2016 jeffm@suse.com
- config: use fragment configs for vanilla
  scripts/run_oldconfig.sh now preserves the options needed by the spec file.
- commit 35139d2
* Mon May  2 2016 mmarek@suse.com
- Automatically updated to 4.6-rc6-next-20160502
- commit b5aa22a
* Fri Apr 29 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: CONFIG_MODULE_SIG_KEY is not needed as a macro
- commit f445774
* Thu Apr 28 2016 jeffm@suse.com
- Revert "config: use fragment configs for vanilla"
  This reverts commit aa69781bd1b338ca6d45d2e2f3f88296c3d5f3f5.
  The macros in the spec file don't work with the fragments yet.
- commit a275308
* Thu Apr 28 2016 jeffm@suse.com
- config: use fragment configs for vanilla
- commit f952485
* Wed Apr 27 2016 jeffm@suse.com
- rpm/kernel-binary.spec.in: only merge configs when vanilla is a fragment
  We can skip the (slow) merging when we know that the config isn't a
  fragment by keying off of an always-defined option like CONFIG_MMU.
- commit 66c90c3
* Tue Apr 26 2016 mmarek@suse.cz
- Drop sysctl files for dropped archs, add ppc64le and arm (bsc#1178838).
- commit fe276fa
* Tue Apr 26 2016 jeffm@suse.com
- config: resync vanilla configs with default
  This is the result of copying default (or pae) to vanilla and running
  run_oldconfig.sh --vanilla.
  Differences from default:
- General:
  - LOCALVERSION="-vanilla" -- obvious
- x86_64/i386:
  - SCHED_OMIT_FRAME_POINTER=y -- option is removed with STACK_UNWIND=y
- commit 71fb34e
* Mon Apr 25 2016 jeffm@suse.com
- Update to 4.6-rc5.
- Config changes:
  - SERIAL_8250_RT288X=n (mips32 only)
- commit ebb1aae
* Mon Apr 25 2016 jeffm@suse.com
- rpm/kernel-binary.in: reassemble vanilla config from arch default and fragment
  This patch reassembles the vanilla config using the default config
  for the arch ("default" for everything but i386 which uses "pae") and
  the vanilla config fragment.
  This will do the right thing even if the vanilla config is still a
  standalone config, but scripts/kconfig/merge_config.sh will be slow.  Care
  should be taken to convert the vanilla configs on any branch that pulls
  this commit.
- commit a9a75a0
* Fri Apr 22 2016 kbuild@suse.de
- Automatically updated to 4.6-rc4-next-20160422
- commit d59d6b6
* Thu Apr 21 2016 kbuild@suse.de
- Automatically updated to 4.6-rc4-next-20160421
- commit 086d363
* Wed Apr 20 2016 eich@suse.com
- rpm/kernel-binary.spec.in:
  Add
  Recommends: perl make gcc
  to kernel-devel. This will install the tools requires to build
  kernels or kernel modules.
- commit 9c9087c
* Wed Apr 20 2016 kbuild@suse.de
- Automatically updated to 4.6-rc4-next-20160420
- commit 2905dfa
* Tue Apr 19 2016 kbuild@suse.de
- Automatically updated to 4.6-rc4-next-20160419
- commit f3e6ab2
* Mon Apr 18 2016 mmarek@suse.com
- Automatically updated to 4.6-rc3-next-20160418
- commit 030e995
* Mon Apr 18 2016 jeffm@suse.com
- Update to 4.6-rc4.
- Eliminated 1 patch.
- commit f4296f0
* Thu Apr 14 2016 jeffm@suse.com
- Update to 4.6-rc3.
- Eliminated 3 patches.
- Config changes:
  - i386/default: FB_OLPC_DCON=m
- commit 1113036
* Thu Apr 14 2016 afaerber@suse.de
- arm64: Drop broken non-mainline Synopsys USB driver
  For 13.2 a downstream USB driver was added (USB_EHCI_HCD_SYNOPSYS)
  for the Juno board (boo#902632). With 4.6 that driver no longer builds.
  A check of arch/arm64/boot/dts/arm/juno-base.dtsi indicates that it
  is using the "generic-ehci" compatible string, i.e. not this driver.
  Therefore drop these patches:
  patches.arch/arm64-0001-usb-Add-support-for-Synopsis-H20AHB-EHCI-host-contro.patch
  patches.arch/arm64-0002-usb-fix-hcd-h20ahb-driver-depends.patch
  Cc: Andreas Schwab <schwab@suse.de>
- commit e04657f
* Thu Apr 14 2016 afaerber@suse.de
- config: armv7hl: Disable USB_EHCI_HCD_SYNOPSYS
  patches.arch/arm64-0001-usb-Add-support-for-Synopsis-H20AHB-EHCI-host-contro.patch
  was added for the arm64 Juno board (bsc#902632).
  Is no longer building okay in 4.6, so disable it where not needed, as a
  first step.
- commit 610e022
* Thu Apr 14 2016 afaerber@suse.de
- config: arm64: Enable drivers for ZynqMP
  Enable options reported missing for Xilinx Zynq UltraScale+ MPSoC.
- commit 74e72bb
* Thu Apr 14 2016 agraf@suse.de
- Update config files: Enable Xlilinx ZynqMP
- commit b768297
* Wed Apr 13 2016 mmarek@suse.cz
- rpm/kernel-binary.spec.in: No -kgraft subpackage for openSUSE (fate#320268)
- commit 269d6bf
* Sun Apr 10 2016 afaerber@suse.de
- config: armv7hl: Disable SND_SOC_MT8173_*
  MediaTek MT8173 is arm64.
- commit b721a84
* Sun Apr 10 2016 afaerber@suse.de
- config: armv7hl: Update for 4.6-rc2
- commit a1182bd
* Sun Apr 10 2016 afaerber@suse.de
- config: armv6hl: Update for 4.6-rc2
- commit c883b70
* Sun Apr 10 2016 afaerber@suse.de
- config: arm64: Update for 4.6-rc2
  Update configs and align vanilla with default again.
- commit 15208c0
* Sat Apr  9 2016 afaerber@suse.de
- config: armv7hl: Enable R8169
  Enable RTL8169 PCI NIC, found on Jetson TK1 board.
- commit 0880d75
* Mon Apr  4 2016 jeffm@suse.com
- Update to 4.6-rc2.
- commit 7270a23
* Mon Apr  4 2016 mmarek@suse.com
- rpm/find-requires: Generate dependencies for KMPs defined in supported.conf (fate#319339)
- commit 007a83c
* Mon Apr  4 2016 jeffm@suse.com
- Update to 4.6-rc1.
- Eliminated 12 patches.
- ARM configs need updating.
- Config changes:
  - i386/x86_64
  - PERF_EVENTS_AMD_POWER=m
  - DELL_SMBIOS=m
  - x86_64:
  - ZONE_DEVICE=y (required by DAX)
  - X86_INTEL_MEMORY_PROTECTION_KEYS=y
  - PCI_HYPERV=m
  - CONFIG_VOP_BUS=m
  - VOP=m
  - ppc64:
  - DEFERRED_STRUCT_PAGE_INIT=y
  - DISABLE_MPROFILE_KERNEL=n
  - s390:
  - IRQ_DOMAIN_DEBUG=y
  - Networking:
  - NET_ACT_IFE=m
  - NET_IFE_SKBMARK=m
  - NET_IFE_SKBPRIO=m
  - AF_KCM=m
  - NET_DEVLINK=m
  - MACSEC=m
  - NET_DSA_MV88E6123=m
  - BNX2X_GENEVE=y
  - CHELSIO_T4_UWIRE=y
  - E1000E_HWTS=y
  - MLX5_CORE_EN_DCB=y
  - IWLWIFI_PCIE_RTPM=y
  - BATMAN_ADV_BATMAN_V=y
  - CAN_IFI_CANFD=m
  - INFINIBAND_I40IW=m
  - INFINIBAND_RDMAVT=m
  - MM:
  - NVDIMM_PFN=y
  - FS:
  - FS_ENCRYPTION=m
  - FAT_DEFAULT_UTF8=n (change in default)
  - ORANGEFS_FS=m
  - NFSD_BLOCKLAYOUT=y
  - NFSD_SCSILAYOUT=y
  - Debug:
  - PAGE_POISONING=n
  - DEBUG_PAGE_REF=n
  - CPU_HOTPLUG_STATE_CONTROL=n
  - OF_RECONFIG_NOTIFIER_ERROR_INJECT=n
  - TEST_BITMAP=n
  - STACK_VALIDATION=y (compile time)
  - KASAN=n (runtime)
  - KCOV=n (runtime)
  - Input:
  - MOUSE_PS2_BYD=y
  - TOUCHSCREEN_MELFAS_MIP4=m
  - RMI4_CORE=m
  - RMI4_I2C=m
  - RMI4_SPI=m
  - RMI4_F11=y
  - RMI4_F12=y
  - RMI4_F30=y
  - SERIAL_8250_MOXA=m
  - SERIAL_MVEBU_UART=n (no module option)
  - HID:
  - HID_CMEDIA=m
  - Bluetooth:
  - BT_LEDS=y
  - BT_HCIUART_AG6XX=y
  - DRM:
  - DRM_DP_AUX_CHARDEV=y
  - DRM_AMD_ACP=y
  - DRM_I915_USERPTR=y
  - Misc:
  - LEDS_IS31FL32XX=m
  - I2C_DEMUX_PINCTRL=m
  - GPIO_104_DIO_48E=m
  - GPIO_WS16C48=m
  - GPIO_TPIC2810=m
  - GPIO_PISOSR=m
  - SENSORS_LTC2990=m
  - RTC_DRV_DS1307_HWMON=y
  - ATLAS_PH_SENSOR=m
  - INV_MPU6050_I2C=m
  - TPL0102=m
  - STM_SOURCE_HEARTBEAT=m
  - FW_CFG_SYSFS=m
  - FW_CFG_SYSFS_CMDLINE=y
  - RAPIDIO_MPORT_CDEV
  - Watchdog:
  - EBC_C384_WDT=m
  - INTEL_MEI_WDT=m
  - NI903X_WDT=m
  - MFD:
  - MFD_ACT8945A=n
  - MFD_AXP20X_I2C=n
  - MFD_TPS65086=n
  - Sensors and DACs for specialty applications:
  - TI_ADC0832=n
  - TI_ADS1015=n
  - AD5761 (go fix)
  - STX104=n
  - VF610_DAC=n
  - AFE4403=n
  - AFE4404=n
  - INV_MPU6050_SPI=n
  - MPL115_I2C=n
  - MPL115_SPI=n
  - ARM:
  - PCIE_DW_PLAT=n
  - ATH10K_AHB=n
  - SPI_AXI_SPI_ENGINE=n
  - SND_SUN4I_SPDIF=n
  - SND_SOC_PCM179X_I2C=n
  - SND_SOC_PCM179X_SPI=n
  - SND_SOC_RT5616=n
  - RTC_DRV_RX6110=n
  - QCOM_HIDMA_MGMT=n
  - QCOM_HIDMA=n
  - GOLDFISH=n
  - MDIO_THUNDER=n
- commit 50c62ad
* Mon Apr  4 2016 kbuild@suse.de
- Automatically updated to 4.6-rc2-next-20160404
- commit 21b3a38
* Mon Apr  4 2016 mmarek@suse.com
- rpm/kernel-source.rpmlintrc: Disable rpmlint check for KMP subpackages
  The check is there to ensure that KMPs are built using the
  %%kernel_module_package macro, but we are deliberately not doing this for
  KMPs built from the kernel specfile (fate#319339).
- commit 7c48b60
* Sun Apr  3 2016 jslaby@suse.cz
- Update config files.
  Set SERIAL_8250_SHARE_IRQ (bnc#973748).
- commit 2598e42
* Fri Apr  1 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Only build the -kgraft package for modular kernels (fate#320268)
- commit 9bab96f
* Fri Apr  1 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Only build KMPs if CONFIG_SPLIT_PACKAGE=y (fate#319339)
- commit def905b
* Fri Apr  1 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Tag KMPs so that weak-modules2 ignores them
  Also require a suse-module-tools version that can handle this (fate#319339).
- commit 58d21f9
* Fri Apr  1 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Add rpm scriptlets for KMPs (fate#319339)
  Use the --{add,remove}-kernel-modules options of weak-modules2 instead
  of --{add,remove}-kmp, because we do not want any symlinks to be created
  for these KMPs.
- commit 95f8b94
* Fri Apr  1 2016 kbuild@suse.de
- Automatically updated to 4.6-rc1-next-20160401
- commit cd08f99
* Thu Mar 31 2016 mmarek@suse.com
- rpm/split-modules: Split modules into KMPs defined in supported.conf (fate#319339)
- commit 39da39b
* Thu Mar 31 2016 mmarek@suse.com
- rpm/mkspec: Generate KMP subpackage sections from a template (fate#319339)
  The KMPs are defined in the supported.conf file using a +<name>-kmp
  guard.
- commit 09cb6b1
* Thu Mar 31 2016 kbuild@suse.de
- Automatically updated to 4.6-rc1-next-20160331
- commit 786bfc3
* Thu Mar 31 2016 dvaleev@suse.com
- rpm/kernel-obs-build.spec.in:add e1000 and ibmveth
  Those modules are required in order to have --vm-telnet option
  working
- commit 1e87b6d
* Wed Mar 30 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Simplify parsing of supported.conf (fate#319339)
- commit 006b146
* Wed Mar 30 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Introduce a kernel-default-kgraft metapackage (fate#320268)
- commit 0439a47
* Wed Mar 30 2016 kbuild@suse.de
- Automatically updated to 4.6-rc1-next-20160330
- commit 315b199
* Tue Mar 29 2016 kbuild@suse.de
- Automatically updated to 4.6-rc1-next-20160329
- commit 57de241
* Mon Mar 28 2016 kbuild@suse.de
- Automatically updated to 4.6-rc1-next-20160327
- commit 436af61
* Thu Mar 24 2016 kbuild@suse.de
- Automatically updated to 4.5-next-20160324
- commit 8aa8db8
* Wed Mar 23 2016 kbuild@suse.de
- Automatically updated to 4.5-next-20160323
- commit e32f6b1
* Tue Mar 22 2016 kbuild@suse.de
- Automatically updated to 4.5-next-20160322
- commit d4df913
* Mon Mar 21 2016 kbuild@suse.de
- Automatically updated to 4.5-next-20160321
- commit 0561aae
* Fri Mar 18 2016 hare@suse.de
- Update config files: Enable CONFIG_BLK_DEV_NVME_SCSI (bsc#965497)
- commit 1d18ae5
* Fri Mar 18 2016 kbuild@suse.de
- Automatically updated to 4.5-next-20160318
- commit 00d03c2
* Thu Mar 17 2016 kbuild@suse.de
- Automatically updated to 4.5-next-20160317
- commit df84e68
* Wed Mar 16 2016 kbuild@suse.de
- Automatically updated to 4.5-next-20160316
- commit d4adf07
* Tue Mar 15 2016 kbuild@suse.de
- Automatically updated to 4.5-next-20160315
- commit 57625f2
* Mon Mar 14 2016 kbuild@suse.de
- Automatically updated to 4.5-rc7-next-20160314
- commit c6a73a6
* Mon Mar 14 2016 jeffm@suse.com
- Update to 4.5-final.
- commit d438600
* Fri Mar 11 2016 kbuild@suse.de
- Automatically updated to 4.5-rc7-next-20160311
- commit eaf84c9
* Thu Mar 10 2016 kbuild@suse.de
- Automatically updated to 4.5-rc7-next-20160310
- commit 3f59c28
* Wed Mar  9 2016 jdelvare@suse.de
- Update s390x config files: Bump NR_CPUS to 256
  It was set to 256 in the SLES kernel 2 years ago already.
- commit 403c3bc
* Wed Mar  9 2016 kbuild@suse.de
- Automatically updated to 4.5-rc7-next-20160309
- commit 12d94e3
* Tue Mar  8 2016 afaerber@suse.de
- config: armv7hl: Enable DRM_ROCKCHIP
  Firefly-RK3288 is among the boards that this will benefit.
- commit ff168c0
* Tue Mar  8 2016 kbuild@suse.de
- Automatically updated to 4.5-rc7-next-20160308
- commit 480ccbf
* Mon Mar  7 2016 jeffm@suse.com
- Update to 4.5-rc7.
- commit b161887
* Mon Mar  7 2016 jdelvare@suse.de
- Update config files: Modularize NF_REJECT_IPV4/V6
  There is no reason why these helper modules should be built-in when
  the rest of netfilter is built as modules.
- commit d8ad327
* Mon Mar  7 2016 kbuild@suse.de
- Automatically updated to 4.5-rc6-next-20160307
- commit d7551bf
* Fri Mar  4 2016 kbuild@suse.de
- Automatically updated to 4.5-rc6-next-20160304
- commit ac96f36
* Thu Mar  3 2016 dsterba@suse.com
- Add build dependency for objtool
  objtool requires libelf development headers.
- commit 16f65f2
* Thu Mar  3 2016 kbuild@suse.de
- Automatically updated to 4.5-rc6-next-20160303
- commit a077228
* Wed Mar  2 2016 kbuild@suse.de
- Automatically updated to 4.5-rc6-next-20160302
- commit dec10bc
* Tue Mar  1 2016 dmueller@suse.com
- config: ARM64: Remove hardcoded console setting
  Proper way would be to derive it from the ACPI or
  Device tree chosen output.
- commit 17bf680
* Tue Mar  1 2016 kbuild@suse.de
- Automatically updated to 4.5-rc6-next-20160301
- commit ebf6443
* Tue Mar  1 2016 mmarek@suse.com
- rpm/kernel-module-subpackage: Fix obsoleting dropped flavors (bsc#968253)
- commit 5295c19
* Mon Feb 29 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Obsolete xen-kmp (fate#315712, bsc#968253)
- commit 0e7c4d5
* Mon Feb 29 2016 mmarek@suse.com
- Copy packaging changes from master to the packaging branch
- commit 0a2490d
* Mon Feb 29 2016 kbuild@suse.de
- Automatically updated to 4.5-rc6-next-20160229
- commit 0e0db26
* Mon Feb 29 2016 jeffm@suse.com
- Update to 4.5-rc6.
- commit bd506a7
* Fri Feb 26 2016 mmarek@suse.com
- Automatically updated to 4.5-rc5-next-20160226
- commit 09167df
* Tue Feb 23 2016 guillaume.gardet@free.fr
- config: armv7hl: Enable CONFIG_DRM_ETNAVIV
  Enable CONFIG_DRM_ETNAVIV for armv7 (default and vanilla) to get graphics
  acceleration on top of the Vivante GPU IP cores used in different SoCs,
  such as the Freescale i.MX6.
- commit fc4db56
* Tue Feb 23 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Sync the main and -base package dependencies
  (bsc#965830#c51).
- commit bf655ed
* Tue Feb 23 2016 jeffm@suse.com
- Update to v4.5-rc5.
- commit da69853
* Tue Feb 23 2016 jeffm@suse.com
- config: complete disabling THERMAL from s390
  Commit fd5ffd694f9 (Update s390x config files: Disable THERMAL)
  left some stray config options around.  Clean them up.
- commit 71a8242
* Mon Feb 22 2016 jdelvare@suse.de
- Update config files: Set CRYPTO_CHACHA20POLY1305=m
  We support every other crypto algorithm so why not this one.
- commit f85871a
* Mon Feb 22 2016 kbuild@suse.de
- Automatically updated to 4.5-rc5-next-20160222
- commit 1925a8b
* Mon Feb 22 2016 jdelvare@suse.de
- Update config files: Disable SERIAL_8250_RT288X
  This option is only useful on MIPS.
- commit e78925d
* Sun Feb 21 2016 dmueller@suse.com
- config: armv6hl: Disable CMA and DEBUGFS settings
  CMA allocates 16MB of reserved memory on boot, which takes
  away a very scarce resource for unpacking the kiwi initrd
  and provides little value (is also disabled on other x86*)
- commit 106824a
* Sat Feb 20 2016 jdelvare@suse.de
- Update s390x config files: Disable THERMAL
  The THERMAL subsystem serves no purpose on S/390, disable it. It was
  already disabled in the SLES kernel long ago.
- commit 7295905
* Fri Feb 19 2016 kbuild@suse.de
- Automatically updated to 4.5-rc4-next-20160219
- commit 1170211
* Thu Feb 18 2016 dsterba@suse.com
- Fix lint warnings: E: summary-ended-with-dot
  kernel-source-vanilla.noarch: E: summary-ended-with-dot (Badness: 89) C
  Vanilla Linux kernel sources with minor build fixes.
  Summary ends with a dot.
- commit 9050a39
* Thu Feb 18 2016 kbuild@suse.de
- Automatically updated to 4.5-rc4-next-20160218
- commit e9e266b
* Wed Feb 17 2016 mmarek@suse.com
- Automatically updated to 4.5-rc4-next-20160217
- commit 1337a4b
* Wed Feb 17 2016 mbrugger@suse.com
- Update config files for arm64.
  Enable ACPI.
- commit 630ab79
* Tue Feb 16 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Set CONFIG_MODULE_SIG_KEY only if a cert is present
  This allows using the unmodified .config from the kernel-source tree in
  the expanded tree.
- commit 5fa6ddd
* Mon Feb 15 2016 jdelvare@suse.de
- Update x86 config files: Enable Intel RAPL
  This driver is useful when power caping is needed. It was enabled in
  the SLE kernel 2 years ago.
- commit b57e2e0
* Mon Feb 15 2016 jdelvare@suse.de
- Update config files: Disable MFD_TPS65218
  The TPS65218 is a power management IC for 32-bit ARM systems. Its
  driver serves no purpose on other architectures. All sub-drivers were
  already disabled anyway.
- commit 6e1f874
* Mon Feb 15 2016 jeffm@suse.com
- Update to 4.5-rc4.
- commit 28e5cb3
* Fri Feb 12 2016 mmarek@suse.com
- Automatically updated to 4.5-rc3-next-20160212
- commit 38290f0
* Thu Feb 11 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Use correct variable to point to the keyring
- commit f026a54
* Thu Feb 11 2016 jdelvare@suse.de
- Update config/armv7hl: Clean up TS-4800 support
  The Technologic Systems TS-4800 is an i.MX515 board. The lpae flavor
  doesn't support this platform so it shouldn't include any TS-4800
  driver. The default and vanilla flavors do support it. If we want
  them to support the board properly then all its drivers should be
  enabled.
- commit 0158f88
* Thu Feb 11 2016 jslaby@suse.cz
- rpm/kernel-obs-build.spec.in: do not limit TasksMax
  We run with build as PID 1 (boo#965564).
- commit 39b708b
* Wed Feb 10 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Adapt certificate handling for changes in v4.3
- commit 589be33
* Tue Feb  9 2016 jdelvare@suse.de
- Update config files: disable MFD_SYSCON on non-arm
  Disable MFD_SYSCON, GPIO_SYSCON and LEDS_SYSCON in non-arm
  configurations. SYSCON is an arm thing, it was enabled accidentally
  in other configurations because STMMAC_PLATFORM and
  TOUCHSCREEN_TS4800, which were once enabled by accident, select it.
  As REGMAP_MMIO was also only selected by MFD_SYSCON, we can disable
  it too.
- commit 28a4e6b
* Tue Feb  9 2016 jdelvare@suse.de
- Update config files: disable TS-4800 drivers on non-arm
  The TS-4800 is an arm board, so its drivers are useless on i386 and
  ppc64. Disable TOUCHSCREEN_TS4800 on these architectures.
- commit 93db9dd
* Tue Feb  9 2016 dmueller@suse.com
- config: reenable Exynos4 support for default kernel
  needed for odroid
- commit 124a779
* Tue Feb  9 2016 dmueller@suse.com
- Config: ARMv7: Disable Exynos 4 related drivers
  We don't have Exynos 4 support enabled, so there
  is no point in building the drivers for it.
- commit 1d73965
* Mon Feb  8 2016 jeffm@suse.com
- Update to 4.5-rc3.
- commit cd8a1fe
* Mon Feb  8 2016 jdelvare@suse.de
- Update s390x config files: CONFIG_ENCLOSURE_SERVICES
  Per bsc#884701, CONFIG_ENCLOSURE_SERVICES isn't needed on S/390. It
  was already disabled in SLE, so disable it in openSUSE too.
- commit 19ae0ad
* Mon Feb  8 2016 jeffm@suse.com
- Update to 4.5-rc2.
- Eliminated 2 patches.
- commit f44dec1
* Mon Feb  8 2016 dvaleev@suse.com
- Delete config/ppc/default.
- Delete config/ppc/vanilla.
  Drop building for ppc architecture. We use 64bit kernel nowadays.
- commit 14a3b26
* Fri Feb  5 2016 dmueller@suse.com
- config: ARM64: disable CONFIG_DDR again
  Was accidentally reeanbled in the 4.5-rc1 bump
- commit 81c5296
* Thu Feb  4 2016 afaerber@suse.de
- config: arm64: Enable Tegra 210 and SMMU
  The new Tegra210 option did not get enabled during the 4.5-rc1 update.
  Also enable the Tegra IOMMU for 132 and 210.
- commit 9424350
* Thu Feb  4 2016 kbuild@suse.de
- Automatically updated to 4.5-rc2-next-20160204
- commit 521ef5f
* Wed Feb  3 2016 kbuild@suse.de
- Automatically updated to 4.5-rc2-next-20160203
- commit 18d6bd3
* Tue Feb  2 2016 kbuild@suse.de
- Automatically updated to 4.5-rc2-next-20160202
- commit 3ce7d3a
* Tue Feb  2 2016 jdelvare@suse.de
- Update config files: Disable CONFIG_DDR
  CONFIG_DDR is selected automatically by drivers which need it. This
  piece of helper code is useless in the absence of any such driver.
- commit bd54e21
* Tue Feb  2 2016 dmueller@suse.com
- Disable CMOS RTC
  This Motorola compatible RTC doesn't exist on ARMv7, and triggers
  an non-root triggerable immediate panic  on the system when being
  accessed, so we better don't include it.
- commit d7ecd00
* Mon Feb  1 2016 kbuild@suse.de
- Automatically updated to 4.5-rc1-next-20160201
- commit edd87bc
* Sun Jan 31 2016 dmueller@suse.com
- config: Update armv6hl config for 4.5-rc1
- Enable BCM2835 related options
- Rest disabled if arch specific
- Generic follows x86_64
- commit 6da850b
* Sun Jan 31 2016 dmueller@suse.com
- config: armv7hl: Enable VDSO
  VDSO provides, starting with glibc 2.22, a lower latency implementation
  for time related syscalls.
- commit 23c0ff1
* Sun Jan 31 2016 dmueller@suse.com
- config: Update armv7hl config to 4.5-rc1
- Disable Mobile ARCH
- Enable BCM2835/BCM2836 options (RPI 1 B/2 B)
- set voltage regulators to =m
- Rest follows x86_64 update, see there for details
- commit 413a849
* Sun Jan 31 2016 dmueller@suse.com
- config: Update ARM64 config to 4.5-rc1
- Enabled support for Qualcom SoC
- Rest follows update for x86_64
- commit 5ef6b8e
* Fri Jan 29 2016 mmarek@suse.com
- Automatically updated to 4.5-rc1-next-20160129
- commit 6c517b1
* Wed Jan 27 2016 jeffm@suse.com
- Revert "Merge remote-tracking branch 'origin/users/tiwai/master/for-next'"
  This reverts commit b27160caadedcda2dc864615e51461c7db19bba1, reversing
  changes made to e1ac7b484beda5dfd27b84365f83a308de7c7a9c.
- commit dc8c416
* Wed Jan 27 2016 bp@suse.de
- Update config files.
  Disable CONFIG_DEBUG_WX as stuff needs to be sorted out upstream first.
- commit 2b5deaf
* Tue Jan 26 2016 jeffm@suse.com
- Update to 4.5-rc1
- Eliminated 15 patches.
- ARM configs need updating.
- Config changes:
  - Generic changes:
  - ARCH_MMAP_RND_BITS=<default>
  - MANDATORY_FILE_LOCKING=n (removes "dead" code, can re-enable if needed)
  - WQ_WATCHDOG=y
  - NETDEV_NOTIFIER_ERROR_INJECT=m
  - UBSAN=n (performance penalty)
  - IO_STRICT_DEVMEM=y
  - VFIO_NOIOMMU=n
  - NTB_PERF=m
  - x86:
  - VMD=m
  - DRM_AMD_POWERPLAY=y
  - CRYPTO_DEV_QAT_C3XXX=m
  - CRYPTO_DEV_QAT_C62X=m
  - CRYPTO_DEV_QAT_C3XXXVF=m
  - CRYPTO_DEV_QAT_C62XVF=m
  - QUEUED_LOCK_STAT=n
  - INTEL_TELEMETRY=m
  - INTEL_HID_EVENT=m
  - INTEL_PUNIT_IPC=m
  - NTB_AMD=m
  - ASUS_WIRELESS=m
  - s390x:
  - SCLP_OFB=y
  - ppc64:
  - IBMVNIC=m
  - Networking:
  - INET_DIAG_DESTROY=y (built as part of inet_diag.ko)
  - NF_DUP_NETDEV=m
  - NFT_FWD_NETDEV=m
  - 6LOWPAN_DEBUGFS=n
  - 6LOWPAN_GHC_EXT_HDR_HOP=m
  - 6LOWPAN_GHC_UDP=m
  - 6LOWPAN_GHC_ICMPV6=m
  - 6LOWPAN_GHC_EXT_HDR_DEST=m
  - 6LOWPAN_GHC_EXT_HDR_FRAG=m
  - 6LOWPAN_GHC_EXT_HDR_ROUTE=m
  - ATH9K_HWRNG=y
  - GENEVE=y
  - NFP_NETVF=m
  - IEEE802154_ADF7242=m
  - Storage:
  - BLK_DEV_NVME_SCSI=n (dangerous)
  - SCSI_HISI_SAS=m
  - DM_VERITY_FEC=y
  - Misc platform-independent drivers:
  - NFC_ST21NFCA_I2C=m
  - NFC_ST95HF=m
  - MTD_MT81xx_NOR=m
  - MLXSW_CORE_HWMON=y
  - TOUCHSCREEN_EGALAX_SERIAL=m
  - SPI_LOOPBACK_TEST=m
  - GPIO_SYSCON=m
  - GPIO_104_IDI_48=m
  - SENSORS_LTC3815=m
  - WATCHDOG_SYSFS=y
  - ZIIRAVE_WATCHDOG=m
  - COMMON_CLK_CS2000_CP=m
  - EXTCON_MAX3355=m
  - IIO_CONFIGFS=m
  - IIO_SW_TRIGGER=m
  - MMA7455_I2C=m
  - MMA7455_SPI=m
  - MXC6255=m
  - INA2XX_ADC=n (use hwmon)
  - USB_SERIAL_MXUPORT11=m
  - LEDS_SYSCON=y
  - RTC_DRV_RX8010=m
  - IAQCORE=m
  - MAX30100=m
  - IIO_HRTIMER_TRIGGER=m
  - ARM (disabled):
  - IMX_THERMAL=n
  - TS4800_WATCHDOG=n
  - TS4800_IRQ=n
  - DRM_PANEL_PANASONIC_VVX10F034N00=n
  - DRM_PANEL_SHARP_LS043T1LE01=n
  - TI_ADS8688=n
  - PHY_HI6220_USB=n
  - WILC1000_SDIO=n
  - WILC1000_SPI=n
- commit bb77251
* Tue Jan 26 2016 jeffm@suse.com
- config: disable POWER_RESET on non-ARM platforms.
- commit 2da98b7
* Tue Jan 26 2016 mmarek@suse.com
- rpm/kernel-spec-macros: Do not modify the release string in PTFs (bsc#963449)
- commit dc2b096
* Tue Jan 26 2016 tiwai@suse.de
- Enable kconfigs for a few intel ASoC drivers (bsc#963456)
- commit 0d24004
* Mon Jan 25 2016 kbuild@suse.de
- Automatically updated to 4.4-next-20160125
- commit e535df4
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-source.spec.in: Install kernel-macros for kernel-source-vanilla
  (bsc#959090)
- commit cd33617
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix paths in kernel-vanilla-devel (bsc#959090).
- commit 2d2ec7f
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix kernel-vanilla-devel dependency (bsc#959090)
- commit fbbc989
* Fri Jan 22 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Use bzip compression to speed up build (bsc#962356)
- commit e8f8f54
* Fri Jan 22 2016 kbuild@suse.de
- Automatically updated to 4.4-next-20160122
- commit 3aba5e2
* Thu Jan 21 2016 dvaleev@suse.com
- Add sd_mod to initrd modules
  For some reason PowerVM backend can't work without sd_mod
- commit 7c2bd21
* Thu Jan 21 2016 kbuild@suse.de
- Automatically updated to 4.4-next-20160121
- commit 7fac435
* Thu Jan 21 2016 mmarek@suse.com
- rpm/package-descriptions: Add kernel-zfcpdump and drop -desktop
- commit 54e8f7c
* Wed Jan 20 2016 kbuild@suse.de
- Automatically updated to 4.4-next-20160120
- commit b42d68c
* Wed Jan 20 2016 tiwai@suse.de
- Enable CONFIG_PINCTRL_CHERRYVIEW and _BROXTON (boo#954532)
  Needed for recent tablets/laptops.
  CONFIG_PINCTRL_BAYTRAIL is still disabled as it can't be built as a
  module.
- commit 1825309
* Tue Jan 19 2016 kbuild@suse.de
- Automatically updated to 4.4-next-20160119
- commit cd9a750
* Mon Jan 18 2016 kbuild@suse.de
- Automatically updated to 4.4-next-20160118
- commit 76e76d2
* Fri Jan 15 2016 kbuild@suse.de
- Automatically updated to 4.4-next-20160115
- commit a4858b4
* Thu Jan 14 2016 kbuild@suse.de
- Automatically updated to 4.4-next-20160114
- commit eba59ab
* Wed Jan 13 2016 kbuild@suse.de
- Automatically updated to 4.4-next-20160113
- commit edfd2ab
* Tue Jan 12 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Fix build if no UEFI certs are installed
- commit ef1b7d3
* Tue Jan 12 2016 mmarek@suse.com
- rpm/kernel-binary.spec.in: Install libopenssl-devel for newer sign-file
- commit fbdf0b8
* Tue Jan 12 2016 kbuild@suse.de
- Automatically updated to 4.4-next-20160112
- commit 609a205
* Mon Jan 11 2016 mmarek@suse.cz
- rpm/constraints.in: Bump disk space requirements up a bit
  Require 10GB on s390x, 20GB elsewhere.
- commit 558b7b3
* Mon Jan 11 2016 jeffm@suse.com
- Update to 4.4-final.
- commit 0f3cf03
* Mon Jan 11 2016 kbuild@suse.de
- Automatically updated to 4.4-rc8-next-20160111
- commit a56088d
* Fri Jan  8 2016 kbuild@suse.de
- Automatically updated to 4.4-rc8-next-20160108
- commit 822ac97
* Thu Jan  7 2016 kbuild@suse.de
- Automatically updated to 4.4-rc8-next-20160107
- commit 09b46de
* Wed Jan  6 2016 mmarek@suse.com
- Automatically updated to 4.4-rc8-next-20160106
- commit f5d5c0b
* Mon Jan  4 2016 jeffm@suse.com
- Update to 4.4-rc8.
- commit 75dbec4
* Mon Jan  4 2016 dvaleev@suse.com
- Driver for IBM System i/p VNIC protocol.
- Update config files CONFIG_VNIC=m
- commit d33e3d0
* Mon Jan  4 2016 kbuild@suse.de
- Automatically updated to 4.4-rc7-next-20160104
- commit fe19f06
* Fri Jan  1 2016 kbuild@suse.de
- Automatically updated to 4.4-rc7-next-20151231
- commit fff13db
* Fri Jan  1 2016 afaerber@suse.de
- config: armv7hl: Enable more RK3288 options for lpae
  Namely MMC and IO domains, already enabled for default/vanilla.
- commit d3477c7
* Wed Dec 23 2015 kbuild@suse.de
- Automatically updated to 4.4-rc6-next-20151223
- commit 4d2544d
* Tue Dec 22 2015 jeffm@suse.com
- Update to 4.4-rc6.
- commit e15e92b
* Tue Dec 22 2015 kbuild@suse.de
- Automatically updated to 4.4-rc6-next-20151222
- commit b4cd839
* Mon Dec 21 2015 kbuild@suse.de
- Automatically updated to 4.4-rc5-next-20151221
- commit 992eb4d
* Fri Dec 18 2015 kbuild@suse.de
- Automatically updated to 4.4-rc5-next-20151218
- commit 468943d
* Thu Dec 17 2015 mmarek@suse.com
- Delete unused rpm/config-subst.
- commit e0ec62c
* Thu Dec 17 2015 kbuild@suse.de
- Automatically updated to 4.4-rc5-next-20151217
- commit 8fe3e40
* Wed Dec 16 2015 kbuild@suse.de
- Automatically updated to 4.4-rc5-next-20151216
- commit fc6f2b8
* Tue Dec 15 2015 kbuild@suse.de
- Automatically updated to 4.4-rc5-next-20151215
- commit ffed6f5
* Tue Dec 15 2015 mmarek@suse.com
- rpm/compute-PATCHVERSION.sh: Skip stale directories in the package dir
- commit 014bd26
* Tue Dec 15 2015 jeffm@suse.com
- Update to 4.4-rc5.
- commit c0e4f67
* Mon Dec 14 2015 kbuild@suse.de
- Automatically updated to 4.4-rc4-next-20151214
- commit 60bec47
* Sun Dec 13 2015 afaerber@suse.de
- config: armv7hl: Enable ACT8865 for lpae, too
  It is needed for the Firefly-RK3288 board.
- commit 071a132
* Fri Dec 11 2015 kbuild@suse.de
- Automatically updated to 4.4-rc4-next-20151211
- commit 34634ae
* Thu Dec 10 2015 kbuild@suse.de
- Automatically updated to 4.4-rc4-next-20151210
- commit 153c1ae
* Wed Dec  9 2015 kbuild@suse.de
- Automatically updated to 4.4-rc4-next-20151209
- commit 21df71d
* Tue Dec  8 2015 mmarek@suse.com
- Automatically updated to 4.4-rc4-next-20151208
- commit 3c0658f
* Mon Dec  7 2015 jeffm@suse.com
- Update to 4.4-rc4.
- Eliminated 5 patches.
- commit aa95ae6
* Mon Dec  7 2015 kbuild@suse.de
- Automatically updated to 4.4-rc3-next-20151207
- commit 391d41e
* Fri Dec  4 2015 kbuild@suse.de
- Automatically updated to 4.4-rc3-next-20151203
- commit 42e93ca
* Thu Dec  3 2015 mmarek@suse.com
- Automatically updated to 4.4-rc3-next-20151202
- commit fb0dd17
* Mon Nov 30 2015 jeffm@suse.com
- config: sync SWIOTLB config change to ppc/vanilla
- commit 7ceae84
* Mon Nov 30 2015 duwe@suse.de
- On ppc, SWIOTLB is just an alias for DMA bounce buffers
  (see Kconfig help:
  "Support for IO bounce buffering for systems without an IOMMU..." )
  The systems we support all have proper IOMMUs and thus don't need
  it.
- commit b675200
* Mon Nov 30 2015 jeffm@suse.com
- Update to 4.4-rc3.
- Eliminated 2 patches.
- commit f06b082
* Mon Nov 30 2015 dvaleev@suse.com
- Add RHEL to kernel-obs-build
- commit a010d5e
* Mon Nov 30 2015 mmarek@suse.com
- Enable Xen in x86 vanilla configs
  Align the vanilla configs with i386/pae and x86_64/default,
  respectively.
- commit 1a185ab
* Mon Nov 30 2015 mmarek@suse.com
- Enable pae in i386/vanilla
  We use kernel-pae in majority of 32bit installs, so it makes sense to
  sync i386/vanilla with this flavor.
- commit 9185cf4
* Mon Nov 30 2015 mmarek@suse.com
- Drop SUSE_KERNEL and SPLIT_PACKAGE patches from vanilla (bsc#957159)
- commit 354953f
* Fri Nov 27 2015 kbuild@suse.de
- Automatically updated to 4.4-rc2-next-20151127
- commit 6f1ef7c
* Thu Nov 26 2015 mmarek@suse.com
- Automatically updated to 4.4-rc2-next-20151126
- commit 2a738c5
* Mon Nov 23 2015 jeffm@suse.com
- config: refresh ARM configs for 4.4-rc2.
- commit 4bae3d6
* Mon Nov 23 2015 jeffm@suse.com
- Update to 4.4-rc2.
- Eliminated 1 patch.
- commit 73ea2e7
* Mon Nov 23 2015 mmarek@suse.com
- Automatically updated to 4.4-rc1-next-20151123
- commit ec4f856
* Sun Nov 22 2015 afaerber@suse.de
- config: arm64: Update configs for 4.4-rc1
  Align vanilla and default while at it.
- commit d0142a5
* Sun Nov 22 2015 afaerber@suse.de
- config: armv6hl: Update configs for 4.4-rc1
  Align vanilla and default while at it.
- commit ecabf39
* Sun Nov 22 2015 afaerber@suse.de
- config: armv7hl: Update configs for 4.4-rc1
  Disable FW_LOADER_USER_HELPER_FALLBACK for vanilla (boo#944661, boo#951260).
- commit f4e9f0a
* Thu Nov 19 2015 mmarek@suse.cz
- staging: lustre: remove IOC_LIBCFS_PING_TEST ioctl.
- commit 9066561
* Wed Nov 18 2015 mmarek@suse.cz
- XEN: Use the PVOPS kernel (fate#315712)
  Merge the -pv configs into -default (-pae on i386) and -debug and drop
  the -xen flavor and the associated patches.xen series. For a
  transitional period, the -xen flavor will be maintained in a separate
  branch as a reference.
- commit dbc0d5b
* Wed Nov 18 2015 mmarek@suse.cz
- Refresh config files.
- commit f574cd6
* Mon Nov 16 2015 jeffm@suse.com
- Update to 4.4-rc1.
- Xen is disabled.
- ARM configs need updating.
- 7 patches eliminated.
- Config changes:
  - Networking:
  - NETFILTER_NETLINK_GLUE_CT=y
  - renamed from NETFILTER_NETLINK_QUEUE_CT
  - IEEE802154_NL802154_EXPERIMENTAL=n
  - still in development, assumed the option
    will be renamed when it's finalized
  - NET_L3_MASTER_DEV=y (library, no code execution by itself)
  - NFC_FDP=m
  - NFC_FDP_I2C=m
  - NFC_MRVL_I2C=m
  - BNXT=m
  - BNXT_SRIOV=y
  - MLXSW_SPECTRUM=m
  - QED=m
  - QEDE=m
  - RTL8XXXU=m
  - RTL8XXXU_UNTESTED=y
  - WILC1000_DRIVER=n (no module option)
  - Storage:
  - NVM=y
  - NVM_DEBUG=n
  - NVM_GENNVM=m
  - NVM_RRPC=m
  - Input/Serial:
  - TOUCHSCREEN_FT6236=m
  - TOUCHSCREEN_TSC2004=m
  - TOUCHSCREEN_ROHM_BU21023=m
  - INPUT_DA9063_ONKEY=m
  - USERIO=m
  - SERIAL_8250_RT288X=y
  - SERIAL_8250_MID=m
  - HID_CORSAIR=m
  - HID_GFRM=m
  - Misc:
  - PINCTRL_BROXTON=n
  - GPIO_AMDPT=m
  - GPIO_104_IDIO_16=m
  - GPIO_IT87=m
  - BATTERY_BQ27XXX=m
  - BATTERY_BQ27XXX_I2C=y
  - BATTERY_BQ27XXX_PLATFORM=y
  - Video:
  - VIDEO_VIVID_MAX_DEVS=64 (default)
  - FB_IBM_GXT4500=m
  - Audio:
  - SND_PCM_TIMER=y
  - SND_FIREWIRE_DIGI00X=m
  - SND_FIREWIRE_TASCAM=m
  - Sensors:
  - MXC4005=m
  - HI8435=m
  - VZ89X=m
  - HDC100X=m
  - HTU21=m
  - APDS9960=m
  - US5182D=m
  - MCP4531=m
  - MS5637=m
  - LIDAR_LITE_V2=m
  - TSYS01=m
  - TSYS02D=m
  - SENSORS_MAX31790=m
  - Misc:
  - FPGA=m
  - FPGA_MGR_ZYNQ_FPGA=n
  - UBIFS_ATIME_SUPPORT=y
  - VFIO_NOIOMMU=n
  - COMMON_CLK_SI514=m
  - RTC_DRV_RV8803=m
  - Tracing:
  - STM=m
  - STM_DUMMY=m
  - STM_SOURCE_CONSOLE=m
  - TRACING_EVENTS_GPIO=y
  - Debugging:
  - TEST_PRINTF=n
  - SECTION_MISMATCH_WARN_ONLY=y (current behavior)
  - ACPI_DEBUGGER=n
  - EFI:
  - EFI_FAKE_MEMMAP=n
  - EFI_PGT_DUMP=n
  - DEBUG_WX=y
  - Crypto:
  - CRYPTO_KEYWRAP=m
  - PWM_PCA9685=m
  - x86:
  - MIC_COSM=m
  - UNISYS_VISORINPUT=m
  - UNISYS_VISORHBA=m
  - LEGACY_VSYSCALL_EMULATE=emulate
  - INTEL_TH=m
  - INTEL_TH_PCI=m
  - INTEL_TH_GTH=m
  - INTEL_TH_STH=m
  - INTEL_TH_MSU=m
  - INTEL_TH_PTI=m
  - INTEL_TH_DEBUG=n
  - INTEL_IOMMU_SVM=y
  - INTEL_IDMA64=m
  - TOSHIBA_WMI=m
  - ARM:
  - AHCI_QORIQ=n
  - BCM7038_WDT=n
  - SSB_HOST_SOC=n
  - MFD_ATMEL_FLEXCOM=n
- commit bb1502f
* Mon Nov 16 2015 kbuild@suse.de
- Automatically updated to 4.3-next-20151116
- commit e3579dd
* Sun Nov 15 2015 kbuild@suse.de
- Automatically updated to 4.3-next-20151115
- commit d8ee587
* Sun Nov 15 2015 jslaby@suse.cz
- Update config files.
  Enable CRASHER on s390x to be the same as in all other configs.
- commit 36b091a
* Sat Nov 14 2015 kbuild@suse.de
- Automatically updated to 4.3-next-20151113
- commit d2bb13d
* Thu Nov 12 2015 tiwai@suse.de
- Clear CONFIG_FW_LOADER_USER_HELPER_FALLBACK in vanilla configs (boo#944661)
  armv7hl/vanilla still contains it because of boo#951260
- commit 2a788b3
* Thu Nov 12 2015 kbuild@suse.de
- Automatically updated to 4.3-next-20151112
- commit dd3cf28
* Wed Nov 11 2015 dvaleev@suse.com
- Update config files (bsc#951533).
  Set CONFIG_SPARSEMEM_VMEMMAP=y for Power
- commit 4962ac6
* Wed Nov 11 2015 kbuild@suse.de
- Automatically updated to 4.3-next-20151111
- commit de94933
* Tue Nov 10 2015 kbuild@suse.de
- Automatically updated to 4.3-next-20151110
- commit 922f8af
* Mon Nov  9 2015 kbuild@suse.de
- Automatically updated to 4.3-next-20151109
- commit 12f31c7
* Fri Nov  6 2015 mmarek@suse.com
- Update config files: Disable CONFIG_NFC_MRVL_SPI to fix build
  http://lkml.kernel.org/r/1446564627-27939-1-git-send-email-mmarek@suse.com
- commit 9dcf8db
* Fri Nov  6 2015 kbuild@suse.de
- Automatically updated to 4.3-next-20151106
- commit 910033a
* Thu Nov  5 2015 kbuild@suse.de
- Automatically updated to 4.3-next-20151105
- commit b838971
* Wed Nov  4 2015 kbuild@suse.de
- Automatically updated to 4.3-next-20151104
- commit eba7488
* Tue Nov  3 2015 jbeulich@suse.com
- Update Xen patches to 4.3-final and c/s 1298.
- Update Xen config files.
- commit 0fc9c4a
* Tue Nov  3 2015 schwab@suse.de
- group-source-files: mark module.lds as devel file
  ld: cannot open linker script file /usr/src/linux-4.2.5-1/arch/arm/kernel/module.lds: No such file or directory
- commit ec6d351
* Tue Nov  3 2015 mmarek@suse.com
- Automatically updated to 4.3-next-20151103
- commit f3cf4f8
* Tue Nov  3 2015 mmarek@suse.com
- Update config files: Disable some new debug options
- commit 3f17a44
* Mon Nov  2 2015 jeffm@suse.com
- Update to 4.3-final.
  - 1 patch eliminated.
- commit 79838f6
* Mon Nov  2 2015 kbuild@suse.de
- Automatically updated to 4.3-rc7-next-20151102
- commit 6cd0086
* Wed Oct 28 2015 jslaby@suse.cz
- rpm/kernel-binary.spec.in: really pass down %%{?_smp_mflags}
- commit 273a7fb
* Mon Oct 26 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Use parallel make in all invocations
  Also, remove the lengthy comment, since we are using a standard rpm
  macro now.
- commit 4d6ba88
* Mon Oct 26 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Delete one more DEBUG_SECTION_MISMATCH assignment
- commit fce45dc
* Mon Oct 26 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Do not explicitly set DEBUG_SECTION_MISMATCH
  CONFIG_DEBUG_SECTION_MISMATCH is a selectable Kconfig option since
  2.6.39 and is enabled in our configs.
- commit 15aa4f8
* Sat Oct 24 2015 stefan.bruens@rwth-aachen.de
- config: arm: Enable ADS7846 touchscreen driver
  This SPI connected chip is common on RPi TFT displays.
- commit 9ede684
* Thu Oct 22 2015 kbuild@suse.de
- Automatically updated to 4.3-rc6-next-20151022
- commit 575faa8
* Wed Oct 21 2015 guillaume.gardet@free.fr
- config: arm: Enable CONFIG_PPS_CLIENT_GPIO
  Set CONFIG_PPS_CLIENT_GPIO=m for all ARM configs to be able to use GPS
  with PPS line connected to a GPIO, as a high-precision time reference.
- commit e47ea7a
* Wed Oct 21 2015 mmarek@suse.com
- Automatically updated to 4.3-rc6-next-20151021
- commit 48e2b5d
* Tue Oct 20 2015 tiwai@suse.de
- Disable leftover CONFIG_FW_LOADER_USER_HELPER_FALLBACK in armv7hl/* (boo#951260)
- commit 8cfd2f6
* Tue Oct 20 2015 tiwai@suse.de
- Disable CONFIG_RT_GROUP_SCHED (boo#950955)
  Even people originally demanded suggest to drop it now...
- commit ebebcd7
* Mon Oct 19 2015 jeffm@suse.com
- config: Re-enable DEBUG_INFO on ec2 flavors.
  It was disabled in commit a104accda85, but is enabled explicitly in the
  spec file.  The options that depend on it must be in the config file for
  the build to succeed.
- commit 5e46ef6
* Mon Oct 19 2015 kbuild@suse.de
- Automatically updated to 4.3-rc5-next-20151019
- commit 756dbb4
* Fri Oct 16 2015 mmarek@suse.com
- rpm/kernel-source.rpmlintrc: Update the filters
- commit e26b4cc
* Fri Oct 16 2015 kbuild@suse.de
- Automatically updated to 4.3-rc5-next-20151016
- commit a09a97a
* Fri Oct 16 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Use upstream script to support config.addon
- commit e8739f8
* Fri Oct 16 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Drop the %%build_src_dir macro
  It is the parent directory of the O= directory.
- commit 2ed0dbe
* Thu Oct 15 2015 jbeulich@suse.com
- Update Xen patches to 4.3-rc5 and c/s 1293.
- netback: coalesce (guest) RX SKBs as needed (bsc#919154).
- config.conf: Re-enable Xen and PV configs.
- Update config files.
- commit b3702e5
* Thu Oct 15 2015 kbuild@suse.de
- Automatically updated to 4.3-rc5-next-20151015
- commit b055053
* Wed Oct 14 2015 matwey.kornilov@gmail.com
- config: armv7hl: Enable new OMAP serial driver
- commit 932085e
* Tue Oct 13 2015 kbuild@suse.de
- Automatically updated to 4.3-rc5-next-20151013
- commit 2b41b58
* Mon Oct 12 2015 jeffm@suse.com
- Update to 4.3-rc5.
- commit cc76695
* Mon Oct 12 2015 kbuild@suse.de
- Automatically updated to 4.3-rc5-next-20151012
- commit 90a1fcd
* Mon Oct 12 2015 mmarek@suse.com
- rpm/kernel-obs-build.spec.in: Add virtio_rng to the initrd
  This allows to feed some randomness to the OBS workers.
- commit fbb0589
* Fri Oct  9 2015 kbuild@suse.de
- Automatically updated to 4.3-rc4-next-20151009
- commit 88264bf
* Thu Oct  8 2015 kbuild@suse.de
- Automatically updated to 4.3-rc4-next-20151008
- commit b525cac
* Wed Oct  7 2015 mmarek@suse.com
- Automatically updated to 4.3-rc4-next-20151007
- commit 43643ef
* Tue Oct  6 2015 mmarek@suse.com
- Add ARM and POWER configs
- commit 3502ec5
* Tue Oct  6 2015 kbuild@suse.de
- Automatically updated to 4.3-rc4-next-20151006
- commit 310e173
* Mon Oct  5 2015 mmarek@suse.com
- rpm/config.sh: Build against 13.2
- commit 286af80
* Mon Oct  5 2015 dmueller@suse.com
- Update config files.
  Disable CONFIG_LEDS_BCM6328 and CONFIG_LEDS_BCM6358, as those
  are MIPS and unlikely to exist on an ARM board.
- commit 332db9e
* Sun Oct  4 2015 matwey.kornilov@gmail.com
- config: armv7hl: Sync vanilla with default
  Let vanilla follow changes made in default.
- commit 3e35c0a
* Sun Oct  4 2015 afaerber@suse.de
- config: armv7hl: Disable all msm8916/apq8016 options
  They are arm64 SoCs, so not needed for armv7hl.
- commit 2fed843
* Sun Oct  4 2015 matwey.kornilov@gmail.com
- config: armv7hl: Enable preemption
  This patch is to follow 1fcdac3f3d277ffea3462af635a3dea6b854a09a.
  [AF/MK: Enable preemption for vanilla config as well]
- commit 6048d12
* Sat Oct  3 2015 afaerber@suse.de
- config: armv7hl: Enable missing STMMAC Ethernet options
  This attempts to fix regressions from 4.1 like built-in Ethernet on
  Cubietruck not working.
- commit a99ec0f
* Fri Oct  2 2015 kbuild@suse.de
- Automatically updated to 4.3-rc3-next-20151002
- commit d9f6174
* Thu Oct  1 2015 kbuild@suse.de
- Automatically updated to 4.3-rc3-next-20151001
- commit f9eea7d
* Wed Sep 30 2015 kbuild@suse.de
- Automatically updated to 4.3-rc3-next-20150930
- commit f74d9b9
* Wed Sep 30 2015 jlee@suse.com
- Update config files. (bsc#947816)
  Put # CONFIG_KEXEC_VERIFY_SIG is not set (bsc#947816)
- commit 241080f
* Wed Sep 30 2015 jeffm@suse.com
- Update to 4.3-rc3.
- Eliminated 1 patch.
- commit 0e6e2cf
* Tue Sep 29 2015 kbuild@suse.de
- Automatically updated to 4.3-rc3-next-20150929
- commit 260931d
* Fri Sep 25 2015 mmarek@suse.cz
- Merge kernel-desktop back into kernel-default/kernel-pae (fate#319416)
- commit 8b30fee
* Fri Sep 25 2015 kbuild@suse.de
- Automatically updated to 4.3-rc2-next-20150925
- commit f7ff0ee
* Thu Sep 24 2015 kbuild@suse.de
- Automatically updated to 4.3-rc2-next-20150924
- commit e2f3f97
* Wed Sep 23 2015 dmueller@suse.com
- Backport of https://lkml.org/lkml/2015/9/11/507
  Fixes a build issue with aarch64, see
  http://www.spinics.net/lists/arm-kernel/msg446809.html.
- Update config files.
- commit 6eb7a1b
* Wed Sep 23 2015 jdelvare@suse.de
- Update x86 config files: CONFIG_SURFACE_PRO3_BUTTON=m
  This is an x86 driver, no reason to not enable it.
- commit 840018d
* Wed Sep 23 2015 jeffm@suse.com
- config: re-enabled EXT4_USE_FOR_EXT2
- commit 9e47c71
* Wed Sep 23 2015 kbuild@suse.de
- Automatically updated to 4.3-rc2-next-20150923
- commit 6454675
* Tue Sep 22 2015 jslaby@suse.cz
- Update config files.
- Refresh patches.suse/stack-unwind.
  Reenable dwarf stack unwinder for C. Assembler is not dwarf-friendly
  annotated (removed in upstream and neither
  patches.arch/x86_64-unwind-annotations is enabled (yet)), so dwarf
  unwinder does not work there (yet).
  This should be fixed by Josh Poimbeouf's stacktool later. But until
  then, dwarf-unwind at least C and use frame pointers for asm.
  I.e. no more question marks for most cases:
  [<ffffffff81008415>] try_stack_unwind+0x175/0x190
  [<ffffffff81007293>] dump_trace+0x93/0x3a0
  [<ffffffff8100847b>] show_trace_log_lvl+0x4b/0x60
  [<ffffffff810076ac>] show_stack_log_lvl+0x10c/0x180
  [<ffffffff81008515>] show_stack+0x25/0x50
  [<ffffffff81364619>] dump_stack+0x4b/0x72
  [<ffffffffa01a302e>] init1+0xe/0x20 [aaa]
  [<ffffffff810002f3>] do_one_initcall+0xb3/0x200
  [<ffffffff8116e4da>] do_init_module+0x5f/0x1f6
  [<ffffffff810ee87e>] load_module+0x15fe/0x1b60
  [<ffffffff810eefe8>] SYSC_finit_module+0x98/0xc0
  [<ffffffff810ef02e>] SyS_finit_module+0xe/0x10
  [<ffffffff816b07b6>] entry_SYSCALL_64_fastpath+0x16/0x75
  DWARF2 unwinder stuck at entry_SYSCALL_64_fastpath+0x16/0x75
  Leftover inexact backtrace:
  <nothing>
  Instead of the funny:
  [<ffffffff81364619>] ? dump_stack+0x4b/0x72
  [<ffffffffa022a02e>] ? init1+0xe/0x20 [aaa]
  [<ffffffff810002f3>] ? do_one_initcall+0xb3/0x200
  [<ffffffff8116e4a2>] ? do_init_module+0x27/0x1f6
  [<ffffffff8116e4da>] ? do_init_module+0x5f/0x1f6
  [<ffffffff810ee87e>] ? load_module+0x15fe/0x1b60
  [<ffffffff810eaa40>] ? __symbol_put+0x50/0x50
  [<ffffffff811e9501>] ? kernel_read+0x41/0x60
  [<ffffffff810eefe8>] ? SYSC_finit_module+0x98/0xc0
  [<ffffffff810ef02e>] ? SyS_finit_module+0xe/0x10
  [<ffffffff816b07b6>] ? entry_SYSCALL_64_fastpath+0x16/0x75
  where __symbol_put and do_init_module+0x27 should not be there at all.
- commit e40e27c
* Tue Sep 22 2015 kbuild@suse.de
- Automatically updated to 4.3-rc2-next-20150922
- commit a4424b6
* Mon Sep 21 2015 jeffm@suse.com
- Update to 4.3-rc2.
- Eliminated 1 patch.
- Config changes:
  - ARM (32/64-bit)
  - STUB_CLK_HI6220=n
  - ARM64
  - ARM64_ERRATUM_843419=y
- commit 29797d1
* Mon Sep 21 2015 mmarek@suse.com
- Automatically updated to 4.3-rc2-next-20150921
- commit 0ea0208
* Sun Sep 20 2015 afaerber@suse.de
- config: armv6hl: Update for 4.3-rc1
- commit 66ac375
* Sun Sep 20 2015 afaerber@suse.de
- config: arm64: Update for 4.3-rc1
- commit a18aed9
* Thu Sep 17 2015 jeffm@suse.com
- config: disable MTD_NAND_DENALI_PCI
- commit f8a6e2e
* Wed Sep 16 2015 matwey.kornilov@gmail.com
- config: armv7hl: Reenable for 4.3
  [AF: Keep STM32 serial disabled, sanitize STi, enable more Qualcomm,
    MediaTek and Renesas options, disable i.MX6 for lpae, switch
    MUSB to Dual Mode while at it, keep SUSE options out of vanilla]
- commit 980db78
* Wed Sep 16 2015 jeffm@suse.com
- config: resync vanilla configs
- commit e14e658
* Wed Sep 16 2015 jeffm@suse.com
- Update to 4.3-rc1.
- Eliminated 8 patches.
- Xen needs updating.
- ARM configs need updating.
- Config changes:
  - General options:
  - CGROUP_PIDS=y
  - USERFAULTFD=y
  - MEMBARRIER=y
  - EXT4_USE_FOR_EXT2=n
  - TEST_STATIC_KEYS=n
  - NVMEM=m
  - SCSI_DH=y
  - [debug] FAIL_FUTEX=y
  - IDLE_PAGE_TRACKING=n
  - SUSPEND_SKIP_SYNC=n
  - x86 options:
  - X86_LEGACY_VM86=n (dosemu vm86 support eliminaed, use a vm or emulation)
  - MODIFY_LDT_SYSCALL=y
  - CRYPTO_POLY1305_X86_64=m
  - CRYPTO_CHACHA20_X86_64=m
  - IDMA64=m
  - AMD_MCE_INJ=m
  - Networking:
  - IPV6_ILA=m
  - IP_VS_OVF=m
  - NFT_DUP_IPV4=m (go back and check)
  - NF_DUP_IPV4=m
  - NFT_DUP_IPV6=m
  - NF_DUP_IPV6=m
  - MPLS_IPTUNNEL=m
  - BT_HS=y
  - BT_HCIUART_QCA=y
  - NFC_ST_NCI_SPI=m
  - NFC_S3FWRN5_I2C=m
  - NET_VRF=m
  - BNX2X_VXLAN=y
  - MLXSW_CORE=m
  - MLXSW_PCI=m
  - MLXSW_SWITCHX2=m
  - NET_VENDOR_SYNOPSYS=y
  - SYNOPSYS_DWC_ETH_QOS=m
  - AQUANTIA_PHY=m
  - TERANETICS_PHY=m
  - MICROCHIP_PHY=m
  - USB_LAN78XX=m
  - FUJITSU_ES=m
  - INFINIBAND_HFI1=m
  - HFI1_DEBUG_SDMA_ORDER=n
  - HFI1_VERBS_31BIT_PSN=y
  - ESCAN_RXQ=n
  - Other:
  - MTD_NAND_DENALI_PCI=m (do we support moorestown?)
  - MTD_NAND_DENALI_DT=n
  - TOUCHSCREEN_IMX6UL_TSC=m
  - I2C_MUX_REG=m
  - SENSORS_MAX20751=m
  - INTEL_PCH_THERMAL=m
  - MFD_DA9062=m
  - MFD_INTEL_LPSS_ACPI=m
  - DVB_NETUP_UNIDVB=m
  - DVB_PLATFORM_DRIVERS=y
  - DRM_FBDEV_EMULATION=y
  - BACKLIGHT_PM8941_WLED=m
  - HID_GEMBIRD=m
  - STAGING_RDMA=y
  - RPR0521=m
  - CRYPTO_DEV_QAT_DH895xCCVF=m
  - DA9062_WATCHDOG=m
  - ARM:
  - MDIO_OCTEON=n
  - MOST=n
  - SURFACE_PRO3_BUTTON=n
  - USB_XHCI_PLATFORM=n
  - MMC_SDHCI_OF_AT91=n
  - RTC_DRV_DA9063=n
  - RTC_DRV_ZYNQMP=n
  - OPT3001=n
  - PA12203001=n
  - DRM_PANEL_SAMSUNG_LD9040=n
  - DRM_PANEL_LG_LG4573=n
  - DRM_PANEL_SAMSUNG_S6E8AA0=n
  - DRM_NXP_PTN3460=n
  - DRM_PARADE_PS8622=n
  - FB_SM712=n
  - SERIAL_UARTLITE=n
  - I2C_EMEV2=n
  - GPIO_ZX=n
  - ppc64:
  - CXLFLASH=m
  - LEDS_POWERNV=m
- commit 7f842a4
* Tue Sep 15 2015 kbuild@suse.de
- Automatically updated to 4.3-rc1-next-20150915
- commit 483142e
* Mon Sep 14 2015 kbuild@suse.de
- Automatically updated to 4.3-rc1-next-20150914
- commit c310228
* Sun Sep 13 2015 dmueller@suse.com
- Update config files: ARM64: Raise CPUs to 128
  There are machines with more than 64 CPUs, allow them
  to be used. Update vanilla config from default.
- commit b9e4415
* Sat Sep 12 2015 kbuild@suse.de
- Automatically updated to 4.2-next-20150912
- commit cbc9134
* Fri Sep 11 2015 jslaby@suse.cz
- Update config files.
  Fix FW fixes fallout (bnc#944661).
- commit 82d2c61
* Fri Sep 11 2015 kbuild@suse.de
- Automatically updated to 4.2-next-20150911
- commit 5655c24
* Thu Sep 10 2015 mmarek@suse.com
- rpm/kernel-spec-macros: Include the version string in the Obsoletes line
- commit 083cdb4
* Thu Sep 10 2015 mmarek@suse.com
- rpm/kernel-binary.spec.in: Obsolete previous builds of the same package (boo#867595)
- commit ffb73eb
* Thu Sep 10 2015 kbuild@suse.de
- Automatically updated to 4.2-next-20150910
- commit 34a33a8
* Wed Sep  9 2015 jdelvare@suse.de
- config/x86_64/ec2: Align CONFIG_STRICT_DEVMEM
  CONFIG_STRICT_DEVMEM is enabled in every other kernel flavor, so
  enable it for x86_64/ec2 as well.
- commit 3d3e945
* Wed Sep  9 2015 kbuild@suse.de
- Automatically updated to 4.2-next-20150909
- commit f7c999c
* Tue Sep  8 2015 kbuild@suse.de
- Automatically updated to 4.2-next-20150908
- commit e8e1735
* Mon Sep  7 2015 tiwai@suse.de
- Disable CONFIG_FW_LOADER_USER_HELPER_FALLBACK that was reenabled unexpectedly (boo#944661)
- commit cb20b4b
* Mon Sep  7 2015 tiwai@suse.de
- Update config files: enable leftover CONFIG_FB_TFT_HX8357D=m for arm
- commit ae13bf9
* Thu Sep  3 2015 kbuild@suse.de
- Automatically updated to 4.2-next-20150903
- commit 680ef94
* Wed Sep  2 2015 kbuild@suse.de
- Automatically updated to 4.2-next-20150902
- commit 7630183
* Tue Sep  1 2015 kbuild@suse.de
- Automatically updated to 4.2-next-20150901
- commit dd6ad2f
* Mon Aug 31 2015 kbuild@suse.de
- Automatically updated to 4.2-next-20150831
- commit daf8e56
* Mon Aug 31 2015 jeffm@suse.com
- Update to 4.2-final.
- commit 303d037
* Fri Aug 28 2015 kbuild@suse.de
- Automatically updated to 4.2-rc8-next-20150828
- commit fbb8b97
* Thu Aug 27 2015 kbuild@suse.de
- Automatically updated to 4.2-rc8-next-20150827
- commit df4f7aa
* Wed Aug 26 2015 mmarek@suse.com
- rpm/constraints.in: Require 14GB worth of disk space on POWER
  The builds started to fail randomly due to ENOSPC errors.
- commit 9012f40
* Wed Aug 26 2015 kbuild@suse.de
- Automatically updated to 4.2-rc8-next-20150826
- commit 7d8afee
* Tue Aug 25 2015 kbuild@suse.de
- Automatically updated to 4.2-rc8-next-20150825
- commit 1fd9eca
* Mon Aug 24 2015 jbeulich@suse.com
- Update EC2 config files: Re-enable DEBUG_INFO.
- commit 516b056
* Mon Aug 24 2015 jeffm@suse.com
- Update to 4.2-rc8.
- commit de5c17f
* Fri Aug 21 2015 jbeulich@suse.com
- Update Xen patches to 4.2-rc7.
- config.conf: Re-enable Xen and PV configs.
- Update config files.
- commit 2615767
* Fri Aug 21 2015 kbuild@suse.de
- Automatically updated to 4.2-rc7-next-20150821
- commit fc35760
* Wed Aug 19 2015 dvaleev@suse.com
- Update config files.
  Enable KSM on Power
- commit 05e453f
* Wed Aug 19 2015 kbuild@suse.de
- Automatically updated to 4.2-rc7-next-20150819
- commit ba3240c
* Tue Aug 18 2015 kbuild@suse.de
- Automatically updated to 4.2-rc6-next-20150817
- commit 5fdc859
* Mon Aug 17 2015 zombah@gmail.com
- config: armv7hl: Disable Exynos IOMMU
  Enabling DRM Exynos IOMMU is currently broken, source
  commit: 6562f3bd396a ("ARM: exynos_defconfig: Disable IOMMU support").
- commit aa7b3f3
* Mon Aug 17 2015 jeffm@suse.com
- Update to 4.2-rc7.
- commit 07a9ace
* Fri Aug 14 2015 kbuild@suse.de
- Automatically updated to 4.2-rc6-next-20150814
- commit e0939a9
* Thu Aug 13 2015 kbuild@suse.de
- Automatically updated to 4.2-rc6-next-20150813
- commit 2767aa2
* Wed Aug 12 2015 jeffm@suse.com
- config: enable IPV6_SIT_6RD on all flavors
  The option was initially disabled because it was labeled experimental.
- commit 51b1435
* Tue Aug 11 2015 stefan.bruens@rwth-aachen.de
- config: arm*: Enable FB_TFT
  Set CONFIG_FB_TFT*=m for arm64/armv6hl/armv7hl.
  There are several TFT capes/hats/... for all kinds of SBCs, enable these.
  Tested on RPi B with 3.2" TFT connected over SPI.
- commit 6f46b66
* Mon Aug 10 2015 mmarek@suse.cz
- Automatically updated to 4.2-rc6-next-20150810
- commit 5294f69
* Mon Aug 10 2015 jeffm@suse.com
- Update to 4.2-rc6.
- commit df50d08
* Fri Aug  7 2015 kbuild@suse.de
- Automatically updated to 4.2-rc5-next-20150807
- commit 4920cbb
* Thu Aug  6 2015 kbuild@suse.de
- Automatically updated to 4.2-rc5-next-20150806
- commit b11aa82
* Wed Aug  5 2015 kbuild@suse.de
- Automatically updated to 4.2-rc5-next-20150805
- commit 987f0ca
* Tue Aug  4 2015 kbuild@suse.de
- Automatically updated to 4.2-rc5-next-20150804
- commit 499fa9d
* Mon Aug  3 2015 afaerber@suse.de
- config: arm64: Clean up serial options
  [this commit was somehow overwritten with the update to -rc6]
  Change SERIAL_8250_DW from =m to =y.
  Change SERIAL_SAMSUNG from =m to =y and enable SERIAL_SAMSUNG_CONSOLE=y.
  Enable Qualcomm serial: SERIAL_MSM=y and SERIAL_MSM_CONSOLE=y
  Enable Spreadtrum serial: SERIAL_SPRD=y and SERIAL_SPRD_CONSOLE=y
  Disable Altera serial: SERIAL_ALTERA_JTAGUART and SERIAL_ALTERA_UART
  We can revisit this when they have arm64 support out.
  Disable Conexant serial: SERIAL_CONEXANT_DIGICOLOR (not arm64)
- config: arm64: Clean up serial options
  Change SERIAL_8250_DW from =m to =y.
  Change SERIAL_SAMSUNG from =m to =y and enable SERIAL_SAMSUNG_CONSOLE=y.
  Enable Qualcomm serial: SERIAL_MSM=y and SERIAL_MSM_CONSOLE=y
  Enable Spreadtrum serial: SERIAL_SPRD=y and SERIAL_SPRD_CONSOLE=y
  Disable Altera serial: SERIAL_ALTERA_JTAGUART and SERIAL_ALTERA_UART
  We can revisit this when they have arm64 support out.
  Disable Conexant serial: SERIAL_CONEXANT_DIGICOLOR (not arm64)
- commit eabe95f
* Mon Aug  3 2015 afaerber@suse.de
- config: armv7hl: Clean up serial options
  Fix SERIAL_OF_PLATFORM to be =y. This unbreaks AC100 serial.
  SERIAL_STM32 is for armv7ml and thus irrelevant for armv7hl, disable it.
  SERIAL_8250_INGENIC is for MIPS SoCs, so disable it for armv7hl.
  Fix CONFIG_SERIAL_CONEXANT_DIGICOLOR from =m to =y and
  enable CONFIG_SERIAL_CONEXANT_DIGICOLOR_CONSOLE=y,
  but only for default and vanilla, as it is a Cortex-A8.
  Fix SERIAL_AMBA_PL010 from =m to =y for lpae, matching default, and
  enable CONFIG_SERIAL_AMBA_PL010_CONSOLE=y for lpae, too.
  Disable SERIAL_ST_ASC for lpae, as STi are Cortex-A9 only.
  (cherry picked from commit 5f5dbd3a9cd58bfb803b83459a564d06eb1e1a37)
  [AF: Accidentally reverted in 4a2cf4a409b54e75f8ac4cd7a19fa8e8bc516aca]
- config: armv7hl: Clean up serial options
  Fix SERIAL_OF_PLATFORM to be =y. This unbreaks AC100 serial and
  hopefully Cubietruck as well.
  SERIAL_STM32 is for armv7ml and thus irrelevant for armv7hl, disable it.
  SERIAL_8250_INGENIC is for MIPS SoCs, so disable it for armv7hl.
  Fix CONFIG_SERIAL_CONEXANT_DIGICOLOR from =m to =y and
  enable CONFIG_SERIAL_CONEXANT_DIGICOLOR_CONSOLE=y,
  but only for default and vanilla, as it is a Cortex-A8.
  Fix SERIAL_AMBA_PL010 from =m to =y for lpae, matching default, and
  enable CONFIG_SERIAL_AMBA_PL010_CONSOLE=y for lpae, too.
  Disable SERIAL_ST_ASC for lpae, as STi are Cortex-A9 only.
- commit f88046c
* Mon Aug  3 2015 kbuild@suse.de
- Automatically updated to 4.2-rc4-next-20150803
- commit ea802de
* Fri Jul 31 2015 kbuild@suse.de
- Automatically updated to 4.2-rc4-next-20150731
- commit f182f90
* Thu Jul 30 2015 kbuild@suse.de
- Automatically updated to 4.2-rc4-next-20150730
- commit 5144b86
* Wed Jul 29 2015 kbuild@suse.de
- Automatically updated to 4.2-rc4-next-20150729
- commit e122983
* Tue Jul 28 2015 kbuild@suse.de
- Automatically updated to 4.2-rc4-next-20150728
- commit 246cf13
* Mon Jul 27 2015 dmueller@suse.com
- Update config files.
  Disable Exynos 3/4 related options.
- commit cdbbeec
* Mon Jul 27 2015 dmueller@suse.com
- Update config files.
  Disable Exynos 5 related config options.
- commit 841c202
* Mon Jul 27 2015 jeffm@suse.com
- config: disable HIBERNATION on ppc64* vanilla configs
- commit 5a64aac
* Mon Jul 27 2015 mkubecek@suse.cz
- config: x86_64: enable EFI_MIXED in nonvirtual configs
  An x86_64 kernel needs CONFIG_EFI_MIXED to be able to access EFI
  variables and services if booted under 32-bit UEFI. Some bootloaders
  also need it to be able to boot 64-bit kernel under 32-bit UEFI.
  (boo#935027 fate#318252)
- commit 0b271f0
* Mon Jul 27 2015 mkubecek@suse.cz
- config: enable NET_DROP_MONITOR=m
  The drop_monitor module is useful for debugging networking issues. It
  collects information where in the kernel code are packets dropped;
  dropwatch utility can be used to process the data.
- commit f2ffd9c
* Mon Jul 27 2015 kbuild@suse.de
- Automatically updated to 4.2-rc4-next-20150727
- commit 1d78866
* Fri Jul 24 2015 mmarek@suse.cz
- Automatically updated to 4.2-rc3-next-20150724
- commit 3b05372
* Thu Jul 23 2015 mbrugger@suse.com
- Enable PCI host controller dirver for arm64
  PCI host controller is not yet supported on mainline.
  We need this patch to get lspci working.
- commit bce6796
* Thu Jul 23 2015 dvaleev@suse.com
- Update config files.
  Disable HIBERNATION on power due to invalid code generation (bsc#938934)
- commit 0d8d92e
* Wed Jul 22 2015 jeffm@suse.com
- Update to 4.2-rc3.
- commit 5bec57a
* Wed Jul 22 2015 kbuild@suse.de
- Automatically updated to 4.2-rc3-next-20150722
- commit 2500534
* Tue Jul 21 2015 dmueller@suse.com
- Disable PCI host support for ARM64
  This needs to be rebased on top of 4.2-rcX before they can be enabled
  as they break the build right now, and for now we don't really need it.
  Update config files.
- commit 1e470c7
* Tue Jul 21 2015 kbuild@suse.de
- Automatically updated to 4.2-rc3-next-20150721
- commit dfe52dc
* Mon Jul 20 2015 dmueller@suse.com
- Update config files:
  ARM64/default,vanilla: Disable CONFIG_XEN as that should
  only be enabled in the pv flavor
- commit 5b11c20
* Mon Jul 20 2015 kbuild@suse.de
- Automatically updated to 4.2-rc3-next-20150720
- commit 8365487
* Fri Jul 17 2015 kbuild@suse.de
- Automatically updated to 4.2-rc2-next-20150717
- commit 14840c1
* Thu Jul 16 2015 kbuild@suse.de
- Automatically updated to 4.2-rc2-next-20150716
- commit e024641
* Wed Jul 15 2015 jeffm@suse.com
- Update to 4.2-rc2.
- commit 109f613
* Wed Jul 15 2015 kbuild@suse.de
- Automatically updated to 4.2-rc2-next-20150715
- commit 4a6d500
* Tue Jul 14 2015 kbuild@suse.de
- Automatically updated to 4.2-rc2-next-20150714
- commit dc71973
* Mon Jul 13 2015 mmarek@suse.cz
- Automatically updated to 4.2-rc2-next-20150713
- commit 437ef27
* Wed Jul  8 2015 dmueller@suse.com
- AArch64: config: Update to 4.2-rc1
- config.conf:
- Enabling Hisilicon, Cavium and XGene related options
- rest is synced with x86_64
- commit 44bf23d
* Tue Jul  7 2015 matwey.kornilov@gmail.com
- config: Update armv7hl config for 4.2-rc1
- commit 22b9e1f
* Tue Jul  7 2015 jeffm@suse.com
- config: sync CIFS_SMB2=y across all configs
  Note that since Xen and ARM are disabled, these need to updated
  independently.
- commit e518894
* Mon Jul  6 2015 jeffm@suse.com
- Update to 4.2-rc1.
- Xen needs updating.
- ARM configs need updating.
- DWARF2 / stack unwinding need updating.
- 5 patches eliminated.
- Config changes:
  - Generic:
  - RCU_EXPERT=n (default)
  - SCHED_OMIT_FRAME_POINTER=y (temporary)
  - ACPI_REV_OVERRIDE_POSSIBLE=y (default)
  - OF_UNITTEST=n (default)
  - THERMAL_WRITABLE_TRIPS=n
  - THERMAL_DEFAULT_GOV_STEP_WISE=y
  - THERMAL_GOV_POWER_ALLOCATOR=n
  - SND_PROC_FS=y
  - DEFERRED_STRUCT_PAGE_INIT=y
  - PROC_CHILDREN=y
  - RCU_EQS_DEBUG=n
  - Networking:
  - GENEVE_CORE=m
  - TCP_CONG_CDG=m
  - NETFILTER_INGRESS=y
  - NF_TABLES_NETDEV=m
  - NET_CLS_FLOWER=m
  - SUNRPC_XPRT_RDMA=m
  - Network drivers:
  - BE2NET_HWMON=y (option to existing driver)
  - EZCHIP_NPS_MANAGEMENT_ENET=m
  - MLX5_CORE_EN=y (option to existing driver)
  - SFC_MCDI_LOGGING=y (option to existing driver)
  - DP83867_PHY=m
  - MT7601U=m
  - IEEE802154_ATUSB=n
  - PHY_PXA_28NM_HSIC=n
  - PHY_PXA_28NM_USB2=n
  - PHY_TUSB1210=n
  - DELL_RBTN=m
  - Input:
  - INPUT_LEDS=y
  - LEDS_AAT1290=n
  - LEDS_BCM6328=n
  - LEDS_BCM6358=n
  - LEDS_TLC591XX=n
  - LEDS_KTD2692=n
  - TOUCHSCREEN_WDT87XX_I2C=m
  - INPUT_DRV2665_HAPTICS=m
  - SERIAL_SC16IS7XX_I2C=y
  - SERIAL_SC16IS7XX_SPI=n
  - Chargers:
  - CHARGER_BQ24257=m
  - CHARGER_BQ25890=m
  - CHARGER_RT9455=m
  - Sensors:
  - SENSORS_TC74=m
  - MAX63XX_WATCHDOG=n
  - GPU:
  - DRM_AMDGPU=m
  - DRM_AMDGPU_CIK=n (experimental)
  - DRM_AMDGPU_USERPTR=y
  - DRM_VIRTIO_GPU=m
  - USB_ULPI_BUS=m
  - Android:
  - STAGING_BOARD=n
  - Accelerometers:
  - STK8312=m
  - STK8BA50=m
  - Light sensors:
  - ACPI_ALS=m
  - BH1750=n
  - STK3310=n
  - MMC35240=n
  - BMC150_MAGN=n
  - Non-Transparent Bridging:
  - NTB_PINGPONG=n
  - NTB_TOOL=n
  - NTB_TRANSPORT=m
  - NTB=n (ppc)
  - Other:
  - F2FS_FS_ENCRYPTION=y
  - Crypto:
  - CRYPTO_RSA=m
  - CRYPTO_CHACHA20POLY1305=m
  - CRYPTO_ECHAINIV=m
  - CRYPTO_POLY1305=m
  - CRYPTO_CHACHA20=m
  - CRYPTO_842=m
  - CRYPTO_JITTERENTROPY=m
  - CRYPTO_USER_API_AEAD=m
  - NV-DIMM:
  - ACPI_NFIT=m
  - ACPI_NFIT_DEBUG=n
  - ND_BLK=m
  - BTT=y
  - Bluetooth:
  - BT_HCIBTUSB_RTL=y (default)
  - NFC:
  - NFC_NCI_UART=m
  - NFC_MRVL_UART=m
  - NFC_ST_NCI=m
  - NFC_ST_NCI_I2C=m
  - Storage:
  - SCSI_SNIC=m
  - SCSI_SNIC_DEBUG_FS=n
  - DM_CACHE_SMQ=m (EXPERIMENTAL)
  - MMC_MTK=m
  - x86:
  - X86_DEBUG_FPU=n
  - PUNIT_ATOM_DEBUG=n
  - UNISYS_VISORBUS=m
  - UNISYS_VISORNIC=m
  - NTB_INTEL=m
  - SCIF_BUS=m
  - SCIF=m
  - INTEL_QUARK_DTS_THERMAL=m
  - INTEL_PMC_IPC=m
  - ppc:
  - GIANFAR=n
  - SERIAL_8250_INGENIC=n
  - ppc64:
  - OPAL_PRD=m
  - MTD_POWERNV_FLASH=m
  - CRYPTO_DEV_NX_COMPRESS_PSERIES=m
  - CRYPTO_DEV_NX_COMPRESS_POWERNV=m
  - CRYPTO_DEV_NX_COMPRESS_CRYPTO=m
  - Cross-endian virtio:
  - TUN_VNET_CROSS_LE=n
  - VHOST_CROSS_ENDIAN_LEGACY=n
  - ARM:
  - SPI_ZYNQMP_GQSPI=n
  - AHCI_CEVA=n (Xilinx Zynq UltraScale+ MPSoC.)
  - QCOM_SPMI_TEMP_ALARM=n
  - THUNDER_NIC_PF=n
  - THUNDER_NIC_VF=n
  - THUNDER_NIC_BGX=n
  - LIQUIDIO=n
  - COMMON_CLK_CDCE925=n
  - UIO_PRUSS=n
- commit 7e3dcf5
* Mon Jul  6 2015 jeffm@suse.com
- config: disable CONFIG_GPIO_MCP23S08 on non-ARM platforms
- commit 915234d
* Mon Jul  6 2015 jeffm@suse.com
- config: disable MFD_SYSCON on non-ARM platforms
- commit e896277
* Mon Jul  6 2015 jeffm@suse.com
- config: BLK_DEV_SKD=m on ppc64 vanilla configs
  BLK_DEV_SKD was disabled on ppc64 vanilla configs but enabled for
  default.
- commit 1a0b697
* Mon Jul  6 2015 jeffm@suse.com
- config: disable BCMGENET on non-ARM platforms
  The Broadcom GENET ethernet chip is part of their BCM7xxx Set Top Box
  chipset and doesn't need to be built on non-ARM architectures.
- commit a801f2a
* Mon Jul  6 2015 kbuild@suse.de
- Automatically updated to 4.2-rc1-next-20150706
- commit e99cd82
* Fri Jul  3 2015 kbuild@suse.de
- Automatically updated to 4.1-next-20150703
- commit a7e3b5a
* Thu Jul  2 2015 kbuild@suse.de
- Automatically updated to 4.1-next-20150702
- commit 5701b79
* Wed Jul  1 2015 jeffm@suse.com
- sysctl/defaults: remove semaphore sysctl override (bsc#936290).
  The sysctl values were lower than the new defaults.
- commit cbe4ad2
* Wed Jul  1 2015 kbuild@suse.de
- Automatically updated to 4.1-next-20150701
- commit 9f04df4
* Tue Jun 30 2015 kbuild@suse.de
- Automatically updated to 4.1-next-20150630
- commit d26c37c
* Mon Jun 29 2015 kbuild@suse.de
- Automatically updated to 4.1-next-20150629
- commit d205eba
* Fri Jun 26 2015 kbuild@suse.de
- Automatically updated to 4.1-next-20150626
- commit 6cd59cd
* Thu Jun 25 2015 dmueller@suse.com
- ARM64: config: UNWIND_INFO=y
- commit baf83bc
* Thu Jun 25 2015 kbuild@suse.de
- Automatically updated to 4.1-next-20150625
- commit 24f6c8b
* Wed Jun 24 2015 kbuild@suse.de
- Automatically updated to 4.1-next-20150624
- commit c081d21
* Tue Jun 23 2015 mmarek@suse.cz
- Automatically updated to 4.1-next-20150623
- commit e887e42
* Tue Jun 23 2015 jeffm@suse.com
- Update to 4.1-final.
- commit 47e580e
* Mon Jun 22 2015 kbuild@suse.de
- Automatically updated to 4.1-rc8-next-20150621
- commit 602196d
* Mon Jun 22 2015 schwab@suse.de
- kernel-obs-build: add btrfs to initrd
  This is needed for kiwi builds.
- commit 1ebf037
* Sun Jun 21 2015 kbuild@suse.de
- Automatically updated to 4.1-rc8-next-20150620
- commit c9e244a
* Fri Jun 19 2015 kbuild@suse.de
- Automatically updated to 4.1-rc8-next-20150619
- commit c752946
* Thu Jun 18 2015 kbuild@suse.de
- Automatically updated to 4.1-rc8-next-20150618
- commit 5a4f854
* Wed Jun 17 2015 kbuild@suse.de
- Automatically updated to 4.1-rc8-next-20150617
- commit 03b20d6
* Tue Jun 16 2015 tiwai@suse.de
- Enable brcmfmac driver for x86-64 and i586 (boo#934932)
- commit db880b2
* Tue Jun 16 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Change BuildRequires to match OBS's taste
- commit 15501f0
* Mon Jun 15 2015 kbuild@suse.de
- Automatically updated to 4.1-rc7-next-20150615
- commit d7e52bd
* Sat Jun 13 2015 kbuild@suse.de
- Automatically updated to 4.1-rc7-next-20150612
- commit 59b4151
* Fri Jun 12 2015 tiwai@suse.de
- Update config files: extend CONFIG_DPM_WATCHDOG_TIMEOUT to 60 (bnc#934397)
- commit a2a63f7
* Fri Jun 12 2015 kbuild@suse.de
- Automatically updated to 4.1-rc7-next-20150611
- commit 0e3da93
* Thu Jun 11 2015 kbuild@suse.de
- Automatically updated to 4.1-rc7-next-20150610
- commit 3a4f8c1
* Wed Jun 10 2015 kbuild@suse.de
- Automatically updated to 4.1-rc7-next-20150609
- commit d556f9b
* Tue Jun  9 2015 jeffm@suse.com
- Update to 4.1-rc7.
- Config changes:
  - arm64/armv7hl:
  - PHY_QCOM_UFS=m
- commit 21b908b
* Mon Jun  8 2015 kbuild@suse.de
- Automatically updated to 4.1-rc6-next-20150605
- commit a82932b
* Sat Jun  6 2015 dirk@dmllr.de
- ARM: config: Sync more settings with x86_64
  Compile in modules that are =y on x86_64, remove modules
  that are not compiled on x86_64
- commit 0aa422f
* Sat Jun  6 2015 dirk@dmllr.de
- config: armv7hl: Disable CONFIG_FW_LOADER_USER_HELPER_FALLBACK
  Only needed by DRM_STI, which we don't need, so disable
  it alltogether (it isn't configured in userspace anyway
  and deprecated)
- commit c312041
* Sat Jun  6 2015 dirk@dmllr.de
- config: armv7hl: Disable DECNET
  DECNET is not enabled on any other arch either
  and we don't need it
- commit 97c6ad2
* Sat Jun  6 2015 dirk@dmllr.de
- armv6hl: config: Reenable for 4.1
  Generic options follow x86_64 ones.
- commit f0dc848
* Sat Jun  6 2015 dmueller@suse.com
- config: armv7hl: Enable ARM optimized crypto
  Enable the CONFIG_ARM_CRYPTO related options for up to
  45%% speed improvement on some of the algorithms.
- commit 7070913
* Fri Jun  5 2015 kbuild@suse.de
- Automatically updated to 4.1-rc6-next-20150604
- commit 4a74c68
* Wed Jun  3 2015 mmarek@suse.cz
- Automatically updated to 4.1-rc6-next-20150603
- commit e1d76fe
* Tue Jun  2 2015 jbeulich@suse.com
- Update Xen patches to 4.1-rc6.
- config.conf: Re-enabled Xen and PV configs.
- Update config files.
- commit 72ee122
* Mon Jun  1 2015 jeffm@suse.com
- config: restore FRAME_POINTER configs to pre-4.1-rc1 values
  The disabling of the stack unwind patches due to required merging
  ended up enabling FRAME_POINTER on some configs. Now that stack
  unwinding is re-enabled, we can disable it again.
- commit 64581e0
* Mon Jun  1 2015 jeffm@suse.com
- config: revert options initially selected by EXT4_ENCRYPTION
  EXT4_ENCRYPTION was initially a bool, which caused anything
  selected by it to be selected as =y even if EXT4 was =m.
  We can restore the following options back to being modular:
- CRYPTO_CTS
- CRYPTO_ECB
- CRYPTO_GF128MUL
- CRYPTO_XTS
  Other crypto-related options enabled in the v4.1-rc1 update are
  a result of INTEGRITY=y and can't be returned to modular options
  without also disabling INTEGRITY.
- commit 677dc74
* Mon Jun  1 2015 jeffm@suse.com
- Update to 4.1-rc6.
- commit 9a1837a
* Sat May 30 2015 kbuild@suse.de
- Automatically updated to 4.1-rc5-next-20150529
- commit a148824
* Fri May 29 2015 kbuild@suse.de
- Automatically updated to 4.1-rc5-next-20150528
- commit 803d541
* Thu May 28 2015 jbeulich@suse.com
- Refresh patches.arch/x86_64-unwind-annotations.
- Refresh
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops.
- Refresh patches.suse/stack-unwind.
- Delete
  patches.arch/stack-unwind-cfi_ignore-takes-more-arguments,
  patches.suse/no-frame-pointer-select,
  patches.suse/unwind-remove-check-for-vdso32-compat-range:
  All folded into base patch.
- Update config files.
- commit 26987d9
* Wed May 27 2015 kbuild@suse.de
- Automatically updated to 4.1-rc5-next-20150527
- commit 6bee6cc
* Tue May 26 2015 kbuild@suse.de
- Automatically updated to 4.1-rc5-next-20150526
- commit cec2dca
* Fri May 22 2015 kbuild@suse.de
- Automatically updated to 4.1-rc4-next-20150522
- commit 6145d0c
* Thu May 21 2015 kbuild@suse.de
- Automatically updated to 4.1-rc4-next-20150521
- commit a6f460c
* Wed May 20 2015 kbuild@suse.de
- Automatically updated to 4.1-rc4-next-20150520
- commit 415ad0a
* Tue May 19 2015 jeffm@suse.com
- Update to 4.1-rc4.
- Config changes:
  - armv7hl: SPI_FSL_DSPI=m
- commit 7167e36
* Tue May 19 2015 jslaby@suse.cz
- Update config files.
  Unset PKCS7_TEST_KEY, so that SYSTEM_TRUSTED_KEYRING can stay
  disabled. I.e. make it the same as on other configs/arches.
- commit 008a976
* Tue May 19 2015 kbuild@suse.de
- Automatically updated to 4.1-rc4-next-20150519
- commit f42e9d3
* Mon May 18 2015 kbuild@suse.de
- Automatically updated to 4.1-rc3-next-20150518
- commit 61191dc
* Fri May 15 2015 kbuild@suse.de
- Automatically updated to 4.1-rc3-next-20150515
- commit c9f3de0
* Thu May 14 2015 kbuild@suse.de
- Automatically updated to 4.1-rc3-next-20150514
- commit 0625753
* Wed May 13 2015 kbuild@suse.de
- Automatically updated to 4.1-rc3-next-20150513
- commit f91f2ba
* Tue May 12 2015 kbuild@suse.de
- Automatically updated to 4.1-rc3-next-20150512
- commit 0761342
* Mon May 11 2015 jeffm@suse.com
- Update to 4.1-rc3.
- Config changes:
  - RTC_DRV_ABX80X=m
- commit f558dcc
* Mon May 11 2015 kbuild@suse.de
- Automatically updated to 4.1-rc3-next-20150511
- commit 89b43b4
* Fri May  8 2015 kbuild@suse.de
- Automatically updated to 4.1-rc2-next-20150508
- commit a7e581f
* Thu May  7 2015 kbuild@suse.de
- Automatically updated to 4.1-rc2-next-20150507
- commit d4b68ed
* Thu May  7 2015 jdelvare@suse.de
- config/armv7hl: Disable AMD_XGBE_PHY
  The AMD XGBE ethernet chip is only used on ARM64 systems.
- commit 95ef3be
* Wed May  6 2015 kbuild@suse.de
- Automatically updated to 4.1-rc2-next-20150506
- commit 5c41ef0
* Wed May  6 2015 dmueller@suse.com
- config: arm64: Reenable for 4.1
  ACPI left disabled for now, Qualcom/Xen enabled,
  rest synced with x86_64
- commit f90fb57
* Tue May  5 2015 kbuild@suse.de
- Automatically updated to 4.1-rc2-next-20150505
- commit 811cdd8
* Mon May  4 2015 jeffm@suse.com
- config: disable XGBE on non-ARM hardware
  It's documented as being present only on AMD SoCs.
- commit 64f15fd
* Mon May  4 2015 jeffm@suse.com
- Update to 4.1-rc2.
- Config changes:
  - CONFIG_EXT4_ENCRYPTION y->m (changed to tristate)
- commit 28ae130
* Mon May  4 2015 mmarek@suse.cz
- Automatically updated to 4.1-rc1-next-20150504
- commit 6c90159
* Sat May  2 2015 matwey.kornilov@gmail.com
- config: Reenable armv7hl for 4.1
  Update armv7hl configs for 4.1
  Generic options follow x86_64 ones.
  CONFIG_DRM_I2C_NXP_TDA998X set to y as it is single known way to make video work on BBB
- commit d74f57e
* Fri May  1 2015 jeffm@suse.com
- Update to 4.1-rc1.
- Xen needs updating.
- ARM configs need updating.
- Stack unwinding needs updating.
- 11 patches eliminated.
- Config changes:
  - Generic:
  - MULTIUSER=y (default)
  - Networking
  - 6LOWPAN_NHC=m
  - 6LOWPAN_NHC_DEST=m
  - 6LOWPAN_NHC_FRAGMENT=m
  - 6LOWPAN_NHC_HOP=m
  - 6LOWPAN_NHC_IPV6=m
  - 6LOWPAN_NHC_MOBILITY=m
  - 6LOWPAN_NHC_ROUTING=m
  - 6LOWPAN_NHC_UDP=m
  - MPLS_ROUTING=m
  - BT_DEBUGFS=n
  - Driver options:
  - BT_HCIBTUSB
  - BT_HCIBTUSB_BCM=y
  - BT_HCIUART
  - BT_HCIUART_INTEL=y
  - BT_HCIUART_BCM=y
  - TARGET_CORE
  - TCM_USER2=m
  - CHELSIO_T4
  - CHELSIO_T4_FCOE=y
  - MOUSE_PS2
  - MOUSE_PS2_VMMOUSE=y
  - New modules:
  - TOUCHSCREEN_CHIPONE_ICN8318=m
  - TOUCHSCREEN_SX8654=m
  - NFC_NXP_NCI=m
  - NFC_NXP_NCI_I2C=m
  - Storage:
  - BLK_DEV_PMEM=m
  - MD_CLUSTER=m
  - DM_MQ_DEFAULT=n (needs performance testing)
  - DM_LOG_WRITES=m
  - MTD_PARTITIONED_MASTER=y
  - x86/x86_64:
  - SCHED_OMIT_FRAME_POINTER=y (only because unwinding needs updating)
  - X86_PMEM_LEGACY=y (compatibility)
  - MFD_INTEL_QUARK_I2C_GPIO=m
  - PINCTRL_AMD=y
  - ARM (disabled):
  - MACB=n
  - KEYBOARD_BCM=n
  - TCG_TIS_ST33ZP24=n
  - SPI_CADENCE=n
  - GPIO_ALTERA=n
  - GPIO_DWAPB=n
  - POWER_RESET_SYSCON_POWEROFF=n
  - CADENCE_WATCHDOG=n
  - MFD_MAX77843=n
  - MFD_MT6397=n
- commit 1f8d072
* Fri May  1 2015 kbuild@suse.de
- Automatically updated to 4.1-rc1-next-20150501
- commit 7c33782
* Thu Apr 30 2015 kbuild@suse.de
- Automatically updated to 4.1-rc1-next-20150430
- commit 97af8b2
* Wed Apr 29 2015 kbuild@suse.de
- Automatically updated to 4.1-rc1-next-20150429
- commit 7d3eff6
* Wed Apr 29 2015 jdelvare@suse.de
- rpm/guards: Clarify user message
  When --config=series is used and a listed file is not found on the
  disk, guards prints the following message:
  Not found in series: file
  This message is confusing, as the file was found in series, it is
  missing on the disk. Change the message to make this more obvious.
- commit 3fbe9e5
* Tue Apr 28 2015 kbuild@suse.de
- Automatically updated to 4.1-rc1-next-20150428
- commit cc3fdde
* Mon Apr 27 2015 kbuild@suse.de
- Automatically updated to 4.0-next-20150427
- commit a997489
* Fri Apr 24 2015 jdelvare@suse.de
- rpm/guards: Documentation update
  * Fix synopsis format.
  * Document the new --path=@<file> option.
- commit 7fd4136
* Fri Apr 24 2015 jdelvare@suse.de
- rpm/guards: White space cleanups
- commit d8089eb
* Fri Apr 24 2015 kbuild@suse.de
- Automatically updated to 4.0-next-20150424
- commit 00cd323
* Thu Apr 23 2015 kbuild@suse.de
- Automatically updated to 4.0-next-20150423
- commit 75e1ab4
* Wed Apr 22 2015 kbuild@suse.de
- Automatically updated to 4.0-next-20150422
- commit dba13bb
* Wed Apr 22 2015 mmarek@suse.cz
- rpm/kernel-obs-build.spec.in: Add .build.hostarch.kvm to the filelist
- commit c65f3ca
* Tue Apr 21 2015 mmarek@suse.cz
- rpm/mkspec: Do not build kernel-obs-* on 32bit ppc
  The buildservice uses the ppc64 kernel-obs-build package for 32bit
  workers.
- commit d1e0beb
* Tue Apr 21 2015 dvaleev@suse.com
- create .build.hostarch.kvm for kernel-obs-build
  OBS needs to know hostarch, with ppc64/ppc64le this is not that easy.
  Lets create a marker file to help with it.
  See obs-build commit: e47399d738e51
- commit e5d9da9
* Tue Apr 21 2015 kbuild@suse.de
- Automatically updated to 4.0-next-20150421
- commit 86bfec4
* Mon Apr 20 2015 kbuild@suse.de
- Automatically updated to 4.0-next-20150420
- commit 8100299
* Wed Apr 15 2015 kbuild@suse.de
- Automatically updated to 4.0-next-20150415
- commit 5ab37b8
* Tue Apr 14 2015 mmarek@suse.cz
- rpm/kernel-obs-qa.spec.in: Do not fail if the kernel versions do not match
- commit 28e9e74
* Tue Apr 14 2015 kbuild@suse.de
- Automatically updated to 4.0-next-20150414
- commit eb072b2
* Tue Apr 14 2015 jlee@suse.com
- Update config files. (boo#925479)
  Do not set CONFIG_SYSTEM_TRUSTED_KEYRING until we need it in future
  openSUSE version:
  e.g. MODULE_SIG, IMA, PKCS7(new), KEXEC_BZIMAGE_VERIFY_SIG(new)
- commit 8c585aa
* Mon Apr 13 2015 jeffm@suse.com
- Update to 4.0-final.
- commit eb85681
* Mon Apr 13 2015 kbuild@suse.de
- Automatically updated to 4.0-rc7-next-20150410
- commit 5bcd1b9
* Fri Apr 10 2015 jeffm@suse.com
- Update to 4.0-rc7.
- Config changes:
  - x86_64/pv:
  - CONFIG_XEN_BALLOON_MEMORY_HOTPLUG_LIMIT=512 (default)
- commit 158a4d8
* Thu Apr  9 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc7-next-20150409
- commit cbae639
* Wed Apr  8 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc7-next-20150407
- commit 5603314
* Mon Apr  6 2015 dmueller@suse.com
- ARMv7: config: Enable more features
  Sync over config settings that have been enabled on x86_64 in the
  last few years also to ARMv7
- commit c798306
* Sun Apr  5 2015 dmueller@suse.com
- ARMv8: config: Enable more modules / feature flags
- commit 8ac09cb
* Sun Apr  5 2015 dmueller@suse.com
- ARM64: config: Disable CONFIG_INPUT_E3X0_BUTTON
- commit 7e60d56
* Sun Apr  5 2015 dmueller@suse.com
- ARMv6/v7/v8: config: Disable ISA bus related drivers
  There is no ISA bus here
- commit 3e2a02b
* Sun Apr  5 2015 dmueller@suse.com
- ARMv7/v8: config: Disable IIO dummy drivers
  Not enabled on any other arch either.
- commit 50f6012
* Sun Apr  5 2015 dmueller@suse.com
- ARMv7: config: Disable accessibility
  Its not enabled on any other architecture, and enablement was
  an accident.
- commit 0e2ef1c
* Sun Apr  5 2015 dmueller@suse.com
- ARMv6/v7/v8: config: Disable debug/compat/self test options
  Disable those options that shouldn't be enabled on a production
  kernel and are not either enabled on x86_64
- commit 76b3af1
* Sun Apr  5 2015 dmueller@suse.com
- ARMv8/v7: config: Sync more features from x86_64
  Enable various feature flags on ARM if they're also set on x86_64
  to ensure that the feature sets available is roughly compareable
- commit 7c5b337
* Sat Apr  4 2015 dmueller@suse.com
- ARMv6/v7: config: build uncommon HID drivers as modules
  92db3f1ad forgot to update ARM configs accordingly.
- commit b6f7140
* Sat Apr  4 2015 dmueller@suse.com
- ARM64: config: Sync vanilla with default config
- commit 2f3f1e0
* Sat Apr  4 2015 dmueller@suse.com
- ARM64/ARMv6/ARMv7: config: Sync tunables with x86_64
  Set numeric tunables to the same values as on x86_64 if they're
  available for both platforms.
- commit 78f3f29
* Fri Apr  3 2015 mmarek@suse.cz
- Automatically Provide/Obsolete all subpackages of old flavors (bnc#925567)
- commit e3547a5
* Thu Apr  2 2015 dmueller@suse.com
- ARMv6: config: Update and reenable for 4.0-rc6
- commit 8bc8fbd
* Thu Apr  2 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc6-next-20150402
- commit 198c2c1
* Wed Apr  1 2015 dmueller@suse.com
- ARMv6: config: Reenable DWC2 host support
  We need the USB host controller support in order to have
  network on the Raspberry Pi, as the network is connected
  via USB.
- commit c34ba66
* Wed Apr  1 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc6-next-20150401
- commit e01e7ee
* Tue Mar 31 2015 dmueller@suse.com
- ARM: config: Enable Stack Protector
- commit 112b24b
* Tue Mar 31 2015 dmueller@suse.com
- ARMv6: config: Cleanup default config
  Previous updates enabled config options that do not make sense
  on ARMv6. ARMv6 default flavor is actually just a RPi1 kernel,
  so enabling platform support for hardware that is unavailable there
  and that conflicts with the Rpi drivers should not be done.
  This causes the kernel to boot again on a Rpi1.
- commit c71417e
* Tue Mar 31 2015 jeffm@suse.com
- Update to 4.0-rc6.
- commit df3470e
* Mon Mar 30 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc6-next-20150330
- commit 1aa849d
* Fri Mar 27 2015 mmarek@suse.cz
- guards: Include the file name also in the "Not found" error
- commit 9b71e7b
* Fri Mar 27 2015 mmarek@suse.cz
- guards: Add support for an external filelist in --check mode
  This will allow us to run --check without a kernel-source.git work tree.
- commit 61c3df5
* Fri Mar 27 2015 mmarek@suse.cz
- guards: Simplify help text
- commit f0c085a
* Fri Mar 27 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc5-next-20150327
- commit 64b6865
* Thu Mar 26 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc5-next-20150326
- commit b8814af
* Wed Mar 25 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc5-next-20150325
- commit 6679563
* Tue Mar 24 2015 dsterba@suse.cz
- config: disable SCSI_MQ_DEFAULT on all architectures and configs
  The scsi-mq feature lacks support for io schedulers right now.  This
  exhibits as performance drop for random RW workloads due to excessive
  seeking. The real benefit of scsi-mq comes with high-end and fast
  devices, the estimated impact on our users is low.
- commit 2d2d685
* Tue Mar 24 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc5-next-20150324
- commit a907fa1
* Tue Mar 24 2015 agraf@suse.de
- pci: Enable pci-host-generic support for ARM64 (bnc#911732).
- commit 51c5f90
* Mon Mar 23 2015 jeffm@suse.com
- config: disable CONFIG_ACPI_PROCFS_POWER (i386/x86_64) (boo#917728)
  CONFIG_ACPI_PROCFS_POWER is deprecated and should be disabled.
- commit c22f30d
* Mon Mar 23 2015 jeffm@suse.com
- Update to 4.0-rc5.
- Eliminated 1 patch.
- Config changes:
  - ARM64:
  - CAN_XILINXCAN=m
- commit 4702d69
* Mon Mar 23 2015 mmarek@suse.cz
- fs: btrfs: Add missing include file.
- commit 8001230
* Mon Mar 23 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc4-next-20150323
- commit 779ea24
* Sat Mar 21 2015 dmueller@suse.com
- ARM64: config: Raise NR cpus to 64
  There is hardware that has more than 32 cores, so we would
  like to support them out of the box.
- commit 17ebb7b
* Fri Mar 20 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc4-next-20150320
- commit 9b75089
* Thu Mar 19 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc4-next-20150319
- commit 112256c
* Wed Mar 18 2015 jbeulich@suse.com
- Update Xen patches to 4.0-rc4 and c/s 1283.
- config.conf: Re-enable Xen and PV configs.
- Update config files.
- commit 4e76575
* Wed Mar 18 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc4-next-20150318
- commit 5fcd13d
* Tue Mar 17 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc4-next-20150317
- commit 5493d2b
* Mon Mar 16 2015 jeffm@suse.com
- Update to 4.0-rc4.
- Config changes:
  - ppc/ppc64/ppc64le/armv7hl/arm64:
  - OF_OVERLAY=y (no functional change, the option was introduced to
    allow disabling of previously builtin behavior)
  - CONFIG_OF_RECONFIG_NOTIFIER_ERROR_INJECT=m
  - i386:
  - OF_OVERLAY=n
- commit 87444cd
* Mon Mar 16 2015 jeffm@suse.com
- config: refresh armv7hl-vanilla config
  The armv7hl-vanilla config contained options not offered by the vanilla
  kernel, showing it hadn't been resynced.
- commit d4db309
* Mon Mar 16 2015 jeffm@suse.com
- config: update arm64-vanilla config
  The ARM64 update for 4.0-rc3 updated default, but not vanilla. This commit
  just syncs the changes.
- commit f51a0c1
* Mon Mar 16 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc3-next-20150316
- commit a8100e0
* Fri Mar 13 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc3-next-20150313
- commit aa4b26b
* Thu Mar 12 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc3-next-20150312
- commit dfc5d03
* Wed Mar 11 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc3-next-20150311
- commit 4fcd9c4
* Tue Mar 10 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc3-next-20150310
- commit c54583f
* Mon Mar  9 2015 dmueller@suse.com
- config: ARM64: Reenable configs for 4.0-rc3
  This mainly adds support for Exynos 7, Mediatek and
  Freescale's SoCs.
- commit c96a0e0
* Mon Mar  9 2015 dmueller@suse.com
- ARM64: Use 64k zero page protection like on other arches
  For cross-architecture compatibility, use the 64k MMAP min
  addr. The old value was nonsensical anyway since we switched to 64k
  page size, which means this change is effectively a NOOP in the 64k
  Pagesize flavor.
- commit 7c6b48b
* Mon Mar  9 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc2-next-20150306
- commit f8f528e
* Mon Mar  9 2015 jeffm@suse.com
- config: disable FEC_MPC52xx on ppc
  List discussion indicates that the openSUSE kernel doesn't properly
  support Efika and that there aren't users of the hardware.
  These devices can only be enumerated using open firmware.
- commit ecdb85c
* Mon Mar  9 2015 jeffm@suse.com
- Update to 4.0-rc3.
- commit 72c19fa
* Sat Mar  7 2015 jeffm@suse.com
- config: disable SERIAL_XILINX_PS_UART on i386
  These devices can only be enumerated using open firmware.
- commit 65319be
* Sat Mar  7 2015 jeffm@suse.com
- config: disable W1_MASTER_GPIO on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit bf6dbfe
* Sat Mar  7 2015 jeffm@suse.com
- config: disable VIRTIO_MMIO on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit 3466d73
* Sat Mar  7 2015 jeffm@suse.com
- config: disable MFD_TI_AM335X_TSCADC on non-ARM platforms
  These devices can only be enumerated using open firmware.
- commit 61156cb
* Sat Mar  7 2015 jeffm@suse.com
- config: disable STMMAC_PLATFORM on non-ARM platforms
  These devices can only be enumerated using open firmware.
- commit dae570d
* Sat Mar  7 2015 jeffm@suse.com
- config: disable TI_ST and RADIO_WL128X on i386, x86_64
  Can probably also be disabled on ppc*
  These devices can only be enumerated using open firmware.
- commit cc841a1
* Sat Mar  7 2015 jeffm@suse.com
- config: disable MMC_SDHCI_OF_ARASAN on i386
  Can probably also be disabled on ARM64
  These devices can only be enumerated using open firmware.
- commit 252183f
* Sat Mar  7 2015 jeffm@suse.com
- config: disable PPS_CLIENT_GPIO on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit 809b510
* Sat Mar  7 2015 jeffm@suse.com
- config: disable MDIO_BUS_MUX_GPIO on i386
  These devices can only be enumerated using open firmware.
- commit 46a5e6d
* Sat Mar  7 2015 jeffm@suse.com
- config: disable KS8851_MLL on i386, x86_64
  Can probably also be disabled on ppc, ppc64, ppc64le but I couldn't
  find a definitive list of platforms this hardware is used with.
  These devices can only be enumerated using open firmware.
- commit f09408f
* Sat Mar  7 2015 jeffm@suse.com
- config: disable I2C_MPC on ppc64, ppc64le
  These devices can only be enumerated using open firmware.
- commit 3ed04f3
* Sat Mar  7 2015 jeffm@suse.com
- config: disable GPIO_WATCHDOG on i386
  These devices can only be enumerated using open firmware.
- commit eba8a77
* Sat Mar  7 2015 jeffm@suse.com
- config: disable GPIO_SYSCON on i386
  These devices can only be enumerated using open firmware.
- commit 88cb7d4
* Sat Mar  7 2015 jeffm@suse.com
- config: disable IR_GPIO_CIR on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit 811d0f6
* Sat Mar  7 2015 jeffm@suse.com
- config: disable GPIO_GRGPIO on i386, ppc, ppc64, ppc64le
  The hardware enabled by this driver is typically only found on LEON
  SPARC systems. Since it enables an IP library that could potentially
  be found on any embedded board, I've left it enabled for ARM and PPC.
- commit 8be0c24
* Sat Mar  7 2015 jeffm@suse.com
- config: disable INPUT_GPIO_BEEPER on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit 665fc88
* Sat Mar  7 2015 jeffm@suse.com
- config: disable GPIO_74XX_MMIO on i386
  These devices can only be enumerated using open firmware.
- commit 967f362
* Sat Mar  7 2015 jeffm@suse.com
- config: disable SERIAL_FSL_LPUART on non-ARM platforms.
  This hardware is only found on Freescale ARM platforms.
- commit aa35800
* Sat Mar  7 2015 jeffm@suse.com
- config: disable ETHOC on i386, x86_64
  These devices can only be enumerated using open firmware.
- commit 63fc8d3
* Sat Mar  7 2015 jeffm@suse.com
- config: disable DW_WATCHDOG on i386, x86_64, ppc, ppc64, ppc64le
  This hardware used to be ARM-only but is now available on Xtensa, so
  we can disable it everywhere bug ARM.
- commit 93f76a1
* Sat Mar  7 2015 jeffm@suse.com
- config: disable MTD_DOCG3 on i386, x86_64, ppc64, ppc64le
  This generation of DiskOnChip is quite old and found on embedded platforms.
  It's probably ok to disable it for arm64 as well.
  These devices can only be enumerated using open firmware.
- commit fab7c77
* Sat Mar  7 2015 jeffm@suse.com
- config: disable SERIO_APBPS2 on i386
  The hardware enabled by this driver is typically only found on LEON
  SPARC systems. Since it enables an IP library that could potentially
  be found on any embedded board, I've left it enabled for ARM and PPC.
- commit fef75ab
* Sat Mar  7 2015 jeffm@suse.com
- config: disable APPLE_AIRPORT on ppc64le
  Apple Airport is only found on Apple ppc/ppc64 hardware.
- commit aee645c
* Sat Mar  7 2015 jeffm@suse.com
- Update to 4.0-rc2.
- commit 18418ca
* Wed Mar  4 2015 matwey.kornilov@gmail.com
- config: armv7hl: Reenable for armv7hl
- commit 931159a
* Tue Mar  3 2015 jeffm@suse.com
- config: revert changes to i386/pv
  The i386/pv config will be resynced when Xen is updated.
- commit 79560ea
* Tue Mar  3 2015 jeffm@suse.com
- config: disable ALTERA_TSE on i386/x86_64
  These devices can only be enumerated using open firmware.
- commit d06ca5a
* Tue Mar  3 2015 jeffm@suse.com
- config: disable FB_OPENCORES on i386/x86_64
  These devices can only be enumerated using open firmware.
- commit 91d918f
* Mon Mar  2 2015 jeffm@suse.com
- Update to 4.0-rc1.
- Eliminated 1 patch.
- Xen needs updating.
- ARM configs need updating.
- Config changes:
  - General:
  - RCU_KTHREAD_PRIO = 0 for default; 1 for desktop
  - X86_INTEL_QUARK=y (32-bit only)
  - X86_AMD_PLATFORM_DEVICE=y
  - ZSMALLOC_STAT=n
  - DEVMEM=y
  - DUMMY_CONSOLE_COLUMNS=80
  - DUMMY_CONSOLE_ROWS=25
  - FS_DAX=y
  - PSTORE_PMSG=n
  - F2FS_IO_TRACE=n
  - NFSD_PNFS=y
  - GDB_SCRIPTS=n (only installs in build dir)
  - LIVEPATCH=y
  - TEST_HEXDUMP=n
  - CRYPTO_USER_API_RNG=m
  - BLK_DEV_RAM_DAX=y
  - PM_DEVFREQ_EVENT=y
  - VIRTIO_PCI_LEGACY=y
  - Networking:
  - IEEE802154_SOCKET=m
  - NET_ACT_BPF=m
  - NET_ACT_CONNMARK=m
  - BT_SELFTEST=n
  - Networking drivers:
  - IXGBE_VXLAN=y
  - AMD_XGBE=m
  - AMD_XGBE_DCB=y
  - Input:
  - MOUSE_PS2_FOCALTECH=y
  - HID_BETOP_FF=m
  - Other drivers, enabled as modules:
  - TCG_CRB
  - I2C_DESIGNWARE_BAYTRAIL
  - SPI_DLN2
  - USB_ISP1760
  - LEDS_CLASS_FLASH
  - FB_SM7XX
  - USB_GSPCA_TOUPTEK
  - SND_USB_POD
  - SND_USB_PODHD
  - SND_USB_TONEPORT
  - SND_USB_VARIAX
  - Disabled drivers:
  - RTC_DRV_DS1685_FAMILY (found on SGI O2/Octane hardware)
  - ACPI-discoverable sensors drivers, enabled as modules:
  - MMA9551
  - MMA9553
  - KMX61
  - JSA1212
  - SX9500
  - x86
  - DEBUG_IMR_SELFTEST=n
  - zSeries:
  - MARCH_Z900
  - TUNE_DEFAULT
  - SCHED_TOPOLOGY=y (renamed from SCHED_BOOK)
  - Device-tree dependent drivers, all disabled:
  - MTD_NAND_HISI504
  - TI_CPSW_ALE
  - INPUT_E3X0_BUTTON
  - INPUT_TPS65218_PWRBUTTON
  - SERIAL_CONEXANT_DIGICOLOR
  - TCG_TIS_I2C_ST33
  - GPIO_XILINX
  - BATTERY_GAUGE_LTC2941
  - POWER_RESET_RESTART
  - MFD_DA9150
  - MFD_RT5033
  - DRM_PANEL_SIMPLE
  - DRM_PANEL_LD9040
  - DRM_PANEL_S6E8AA0
  - DRM_PANEL_SHARP_LQ101R1SX01
  - MMC_SDHCI_F_SDH30
  - RTC_DRV_ABB5ZES3
  - FB_TFT
  - COMMON_CLK_CDCE706
  - ASM9260_TIMER
  - IOMMU_IO_PGTABLE_LPAE
  - CC10001_ADC
  - QCOM_SPMI_VADC
  - IIO_SSP_SENSORHUB
  - CM3232
- commit cdbb520
* Mon Mar  2 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc1-next-20150302
- commit 654a31c
* Fri Feb 27 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc1-next-20150227
- commit ae50017
* Thu Feb 26 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc1-next-20150226
- commit 1279b76
* Wed Feb 25 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc1-next-20150225
- commit 5191f2b
* Tue Feb 24 2015 mmarek@suse.cz
- Automatically updated to 4.0-rc1-next-20150224
- commit 0a8a6a0
* Tue Feb 24 2015 guillaume.gardet@free.fr
- config: armv6hl: Update and re-enable armv6 default config
  Please find an update from 3.18.0 to 3.19.0 for armv6 default config.
  It also enables armv6 default config again.
  [AF: Homogenized module selection, dropped Broadcom Kona support (ARMv7)]
- commit 3d6604d
* Mon Feb 23 2015 mmarek@suse.cz
- Automatically updated to 3.19-next-20150223
- commit d3b9abc
* Sun Feb 22 2015 mmarek@suse.cz
- Automatically updated to 3.19-next-20150222
- commit e42bdb4
* Fri Feb 20 2015 mmarek@suse.cz
- Automatically updated to 3.19-next-20150220
- commit c8252bd
* Thu Feb 19 2015 mmarek@suse.cz
- Automatically updated to 3.19-next-20150219
- commit e07c26e
* Wed Feb 18 2015 mmarek@suse.cz
- Automatically updated to 3.19-next-20150218
- commit 2eb56af
* Tue Feb 17 2015 mmarek@suse.cz
- Automatically updated to 3.19-next-20150217
- commit 97a418f
* Mon Feb 16 2015 mmarek@suse.cz
- Automatically updated to 3.19-next-20150216
- commit 857c70d
* Mon Feb 16 2015 matwey.kornilov@gmail.com
- config: armv7hl: Temporarily disable CONFIG_PCIE_SPEAR13XX
  spear13xx pcie leads to kernel oopses in random places,
  so lets disable it until a proper solution to fix it is found.
  References: bko#92581
- commit cdb7b6d
* Fri Feb 13 2015 jdelvare@suse.de
- Update config files: disable CONFIG_I2C_SLAVE
  Disable CONFIG_I2C_SLAVE on x86 and ppc*. There is currently no known
  use case for this feature on these architectures, and it has a small
  build time and size cost.
- commit 3b0fc1d
* Fri Feb 13 2015 mmarek@suse.cz
- Automatically updated to 3.19-next-20150213
- commit a6de782
* Thu Feb 12 2015 mmarek@suse.cz
- Automatically updated to 3.19-next-20150212
- commit 9de7fbe
* Wed Feb 11 2015 mmarek@suse.cz
- Automatically updated to 3.19-next-20150211
- commit 8c1a546
* Tue Feb 10 2015 mmarek@suse.cz
- Automatically updated to 3.19-next-20150210
- commit 23dfd8a
* Mon Feb  9 2015 jeffm@suse.com
- Update to 3.19-final.
- commit 4e5f389
* Mon Feb  9 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc7-next-20150209
- commit 8bf75ad
* Thu Feb  5 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix build if there is no *.crt file
- commit c5b1275
* Wed Feb  4 2015 jbeulich@suse.com
- Update Xen patches to 3.19-rc7 and c/s 1279.
- Update Xen config files.
- commit fe0ed43
* Wed Feb  4 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc7-next-20150204
- commit 2da02d9
* Tue Feb  3 2015 jeffm@suse.com
- Update to 3.19-rc7.
- commit 316ec1c
* Tue Feb  3 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc7-next-20150203
- commit ff1bf92
* Mon Feb  2 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc6-next-20150202
- commit b151899
* Fri Jan 30 2015 mmarek@suse.cz
- rpm/constraints.in: Lower the requirement to 4 CPUs on POWER
- commit 9e50821
* Fri Jan 30 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc6-next-20150130
- commit 41f80bc
* Thu Jan 29 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc6-next-20150129
- commit 1acd3e3
* Wed Jan 28 2015 jeffm@suse.com
- Update to 3.19-rc6.
- Config changes:
  - SENSORS_I5500=m (i386/x86_64)
- commit add7a41
* Wed Jan 28 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc6-next-20150128
- commit df6955b
* Tue Jan 27 2015 jbeulich@suse.com
- rpm/package-descriptions: Describe kernel-pv (and correct kernel-ec2's).
- commit 6dd25c9
* Tue Jan 27 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc6-next-20150127
- commit 6505b81
* Mon Jan 26 2015 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Do not ignore errors from make
- commit 86ebfa7
* Sat Jan 24 2015 jdelvare@suse.de
- Update x86_64 config files: CONFIG_SENSORS_NCT6683=m
  The nct6683 driver is already enabled on i386 and history suggests
  that it not being enabled on x86_64 is by mistake.
- commit 32c1cf3
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Drop sparse from BuildRequires
- commit 9777c26
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Update the comment about NO_BRP_STALE_LINK_ERROR
  There is no stale symlink in the installed system anymore, but there is
  one during build.
- commit e575cce
* Fri Jan 23 2015 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Own the modules directory in the devel
  package (bnc#910322)
- commit d89b963
* Fri Jan 23 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc5-next-20150123
- commit c9b1008
* Thu Jan 22 2015 jbeulich@suse.com
- Add x86 PV config files.
- commit 4c2e561
* Thu Jan 22 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc5-next-20150122
- commit b2b0d9a
* Thu Jan 22 2015 jbeulich@suse.com
- Update Xen patches to 3.19-rc5 and c/s 1276.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 5102b91
* Wed Jan 21 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc5-next-20150121
- commit 4aa2e2d
* Wed Jan 21 2015 jeffm@suse.com
- Update to 3.19-rc5.
- Config changes:
  - I40E_FCOE=y
- commit 6ff60ce
* Tue Jan 20 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc5-next-20150120
- commit 94640fc
* Mon Jan 19 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc5-next-20150119
- commit 732df12
* Fri Jan 16 2015 matwey.kornilov@gmail.com
- config: armv7hl: Update config files for 3.19-rc6
  [AF: Updated for -rc6, enabled some more default options,
    enabled/disabled lpae options, regenerated vanilla from default]
- commit a50555e
* Fri Jan 16 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc4-next-20150116
- commit becfee2
* Thu Jan 15 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc4-next-20150115
- commit bd7c6de
* Wed Jan 14 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc4-next-20150114
- commit 2dfa457
* Tue Jan 13 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc4-next-20150113
- commit a7e0910
* Mon Jan 12 2015 jeffm@suse.com
- Update to 3.19-rc4.
- Config changes:
  - KDB_DEFAULT_ENABLE=0x1 (default, no change)
- commit 54642a5
* Mon Jan 12 2015 jeffm@suse.com
- config: fixed re-enabling of CFG80211_WEXT
- Note: CFG80211_WEXT was disabled in 3.19-rc1, not 3.17.
  * git describe and git name-rev show different things.
- IPW2200_DEBUG=y was set prior to 3.19-rc1, restore it
- Re-sync arm64 config to match pre-rc1 values.
- commit 1da43cd
* Mon Jan 12 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc4-next-20150112
- commit 57721cb
* Fri Jan  9 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc3-next-20150109
- commit 27465fb
* Thu Jan  8 2015 jeffm@suse.com
- Update to 3.19-rc3.
- Config changes are repairing fallout from the removal of
  wireless extensions in 3.17. They were restored in 3.19-rc3.
- commit 3d46b64
* Thu Jan  8 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc3-next-20150108
- commit 6bc4524
* Wed Jan  7 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc3-next-20150107
- commit 9e95797
* Tue Jan  6 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc2-next-20150106
- commit 961149f
* Tue Jan  6 2015 agraf@suse.de
- arm64: Enable DRM
- commit 6fbf188
* Mon Jan  5 2015 agraf@suse.de
- arm64: Disable CRC32 accelerator again, doesn't build
- commit dacd84d
* Mon Jan  5 2015 agraf@suse.de
- arm64: Enable generic PHB driver (bnc#911732).
- commit b9f6136
* Mon Jan  5 2015 agraf@suse.de
- Update config files for arm64
- commit 4c5fcb6
* Mon Jan  5 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc2-next-20150105
- commit 5788788
* Sat Jan  3 2015 mmarek@suse.cz
- Automatically updated to 3.19-rc2-next-20150103
- commit d7a6bdf
* Wed Dec 31 2014 mmarek@suse.cz
- Automatically updated to 3.19-rc2-next-20141231
- commit 32fa667
* Tue Dec 30 2014 mmarek@suse.cz
- Automatically updated to 3.19-rc1-next-20141226
- commit 86055f6
* Tue Dec 23 2014 matwey.kornilov@gmail.com
- config: Introduce vanilla configs for armv6l, armv7l and aarch64
- commit 7926012
* Mon Dec 22 2014 jeffm@suse.com
- Update to 3.19-rc1.
- Eliminated 5 patches.
- Xen needs updating.
- ARM configs need updating.
- Config changes:
  - General
  - INIT_FALLBACK (y, default, consistent with old default)
  - PAGE_EXTENSION=n (overhead)
  - PAGE_OWNER=n (overhead)
  - Networking:
  - NET_FOU_IP_TUNNELS=y
  - NFT_REDIR=m
  - NFT_REDIR_IPV4=m
  - NFT_REDIR_IPV6=m
  - NET_DSA_HWMON=y
  - NET_ACT_VLAN=m
  - NET_SWITCHDEV=y (only impact is a slightly bigger ndo)
  - BT_BREDR=y
  - BT_LE=y
  - IPVLAN=m
  - NET_DSA_MV88E6352=m
  - ROCKER=m
  - BCMGENET=m
  - Driver options:
  - CONFIG_MAC80211_RC_MINSTREL_VHT=y
  - ATH9K_PCOEM=y
  - RTC_DRV_DS1374_WDT=y
  - INFINIBAND_ON_DEMAND_PAGING=y
  - SQUASHFS_LZ4=y
  - Drivers:
  - SCSI_AM53C974=m
  - SCSI_WD719X=m
  - KEYBOARD_CAP11XX=m
  - MOUSE_ELAN_I2C=m
  - TOUCHSCREEN_GOODIX=m
  - TOUCHSCREEN_ELAN=m
  - IPMI_SSIF=m
  - I2C_SLAVE=y (does nothing; only here for future additions)
  - GPIO_74XX_MMIO=m
  - SENSORS_NCT7802=m
  - MFD_DLN2=m
  - I2C_DLN2=m
  - GPIO_DLN2
  - IR_IGORPLUGUSB=m
  - DVB_SMIPCIE=m
  - DVB_MN88472=m
  - DVB_MN88473=m
  - VIDEO_SAA7191=n (staging/deprecated)
  - VIDEO_VIM2M=m
  - DRM_I2C_ADV7511=m
  - SND_OXFW=m
  - HID_PLANTRONICS=m
  - MMC_TOSHIBA_PCI=m
  - LEDS_LP8860=m
  - x86
  - X86_INTEL_MPX=y (default n, little kernel overhead for potential security gains)
  - RCU_KTHREAD_PRIO=1 (default)
  - X86_VSYSCALL_EMULATION=y
  - HSA_AMD=m
  - EDAC_AMD64=m
  - EDAC_AMD64_ERROR_INJECTION=y
  - ppc
  - OF_UNITTEST=n
  - IPMI_POWERNV=m
  - I2C_OPAL=m
  - RTC_DRV_OPAL=m
  - s390x
  - SCLP_ASYNC_ID=000000000 (default)
  - SoC
  - PINCTRL_CHERRYVIEW=n
  - ARM?: (all n)
  - PMIC
  - MFD_ATMEL_HLCDC
  - COMMON_CLK_XLNX_CLKWZRD
  - QCOM_SPMI_IADC
  - Mobile sensors: (all n)
  - SI7020
  - BMP280
- commit 911f5d9
* Sun Dec 21 2014 mmarek@suse.cz
- Automatically updated to 3.19-rc1-next-20141221
- commit 49813fe
* Fri Dec 19 2014 mmarek@suse.cz
- Automatically updated to 3.18-next-20141219
- commit 3bba0e3
* Thu Dec 18 2014 mmarek@suse.cz
- Automatically updated to 3.18-next-20141218
- commit a45668e
* Wed Dec 17 2014 mmarek@suse.cz
- Automatically updated to 3.18-next-20141217
- commit c79113e
* Tue Dec 16 2014 mmarek@suse.cz
- Automatically updated to 3.18-next-20141216
- commit 83c02e3
* Mon Dec 15 2014 mmarek@suse.cz
- Automatically updated to 3.18-next-20141215
- commit 3fc4805
* Fri Dec 12 2014 mmarek@suse.cz
- Automatically updated to 3.18-next-20141212
- commit 1fc71ee
* Thu Dec 11 2014 mmarek@suse.cz
- Automatically updated to 3.18-next-20141211
- commit 63dfff4
* Wed Dec 10 2014 mmarek@suse.cz
- Automatically updated to 3.18-next-20141210
- commit a9e18e8
* Tue Dec  9 2014 jeffm@suse.com
- Update to 3.18-final.
- commit 9706845
* Sat Dec  6 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc7-next-20141205
- commit 6ebc594
* Fri Dec  5 2014 agraf@suse.de
- arm64: Enable 64k page size (bnc#908468)
- commit 428ead9
* Thu Dec  4 2014 agraf@suse.de
- ARMv7: Bump NR_CPUs to 16, the HIP04D01 has that many
- commit de5c040
* Thu Dec  4 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc7-next-20141204
- commit c10f230
* Tue Dec  2 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc6-next-20141201
- commit d1e9d3d
* Mon Dec  1 2014 jbeulich@suse.com
- Update Xen config files (restore RTC_DRV_EFI).
- commit 5b7e818
* Thu Nov 27 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc6-next-20141126
- commit 4d89802
* Thu Nov 27 2014 mmarek@suse.cz
- rpm/constraints.in: Require 10GB of disk space also on 32bit POWER
- commit 33a282b
* Wed Nov 26 2014 jeffm@suse.com
- Update to 3.18-rc6.
- commit d33363f
* Wed Nov 26 2014 mmarek@suse.cz
- rpm/constraints.in: Require 10GB disk space on POWER
  A debuginfo build currently requires about 8.5 GB on POWER. Also,
  require at least 8 CPUs, so that builds do not get accidentally
  scheduled on slow machines.
- commit 596d9cf
* Wed Nov 26 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc6-next-20141125
- commit 3b95049
* Mon Nov 24 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc5-next-20141124
- commit bc4fd61
* Fri Nov 21 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc5-next-20141121
- commit e862acc
* Thu Nov 20 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc5-next-20141120
- commit 8200612
* Wed Nov 19 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc5-next-20141119
- commit d674ac7
* Wed Nov 19 2014 jeffm@suse.com
- Update to 3.18-rc5.
- commit 1866934
* Tue Nov 18 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc5-next-20141118
- commit 83ac95c
* Mon Nov 17 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc4-next-20141117
- commit 85e1d7d
* Fri Nov 14 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Provide name-version-release for kgraft
  packages (bnc#901925)
- commit c9157ee
* Fri Nov 14 2014 agraf@suse.de
- PPC: Update config files: Enable HV KVM as module
- commit b1fc93a
* Fri Nov 14 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc4-next-20141114
- commit 24e4762
* Thu Nov 13 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc4-next-20141113
- commit fde2522
* Wed Nov 12 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc4-next-20141112
- commit 6ac2326
* Tue Nov 11 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc4-next-20141111
- commit d0bc404
* Mon Nov 10 2014 jeffm@suse.com
- Update to 3.18-rc4.
- commit 3b300d5
* Mon Nov 10 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc3-next-20141110
- commit 7c4e666
* Thu Nov  6 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc3-next-20141106
- commit 2af2e06
* Wed Nov  5 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc3-next-20141105
- commit 93c8408
* Tue Nov  4 2014 jbeulich@suse.com
- Update Xen patches to 3.18-rc3.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 33fb499
* Mon Nov  3 2014 matwey.kornilov@gmail.com
- config: armv7hl: temporarily disable KEYSTONE_NAVIGATOR_QMSS
  KEYSTONE_NAVIGATOR_QMSS leads to the following module dependency cycle.
  Disable it until it will be fixed in upstream.
  [24907s] depmod: ERROR: Found 2 modules in dependency cycles!
  [24907s] depmod: ERROR: Cycle detected: knav_qmss_queue -> knav_qmss_acc -> knav_qmss_queue
- commit a4e3ee3
* Mon Nov  3 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc3-next-20141103
- commit 8e75925
* Mon Nov  3 2014 jeffm@suse.com
- Update to 3.18-rc3.
- Eliminated 3 patches.
- commit 69ca48a
* Sun Nov  2 2014 agraf@suse.de
- usb: Add support for Synopsis H20AHB EHCI host controller
  (bnc#902632).
- usb: fix hcd h20ahb driver depends (bnc#902632).
- KVM: ARM: Add "arm,gic-400" compatible support (bnc#902632).
- net/xgbe: Add A0 silicon support (bnc#902632).
- arm64: dts: Add X-Gene reboot driver dts node (bnc#902632).
- arm64: Select reboot driver for X-Gene platform (bnc#902632).
- arm64: Do not call enable PCI resources when specify
  PCI_PROBE_ONLY (bnc#902632).
- ARM/ARM64: arch-timer: fix arch_timer_probed logic (bnc#902632).
- Documentation: Restrict TSC test code to x86 (bnc#902632).
- KVM: ARM: Hack to enable VGIC mapping on 64k PAGE_SIZE kernels
  (bnc#902633).
- Update config files.
- commit d1596ef
* Fri Oct 31 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc2-next-20141031
- commit 94fa159
* Thu Oct 30 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix including the secure boot cert in /etc/uefi/certs
- commit 72255c9
* Thu Oct 30 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc2-next-20141030
- commit 8b04d68
* Wed Oct 29 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc2-next-20141029
- commit 75d4f17
* Mon Oct 27 2014 jeffm@suse.com
- Update to 3.18-rc2.
- Config changes:
  * ACPI_THERMAL_REL=m
  * DA9063_WATCHDOG=m
  * INT340X_THERMAL=m
  * OVERLAYFS_FS=m (vanilla only, we've been carrying these patches)
  * PWM_LPSS_PCI=m
  * PWM_LPSS_PLATFORM=m
  * TCM_USER=m
  * THERMAL_GOV_BANG_BANG=y
- commit 303e0b4
* Fri Oct 24 2014 matwey.kornilov@gmail.com
- config: armv6hl: Compile KGDB serial console into kernel
  A serial console is the major communication for ARM devices.
  Having CONFIG_KGDB_SERIAL_CONSOLE=m makes it impossible to debug the kernel
  at early boot stages.
- commit 017716f
* Fri Oct 24 2014 matwey.kornilov@gmail.com
- config: armv7hl: Compile KGDB serial console into kernel
  A serial console is the major communication for ARM devices.
  Having CONFIG_KGDB_SERIAL_CONSOLE=m makes it impossible to debug the kernel
  at early boot stages.
- commit 7cba380
* Fri Oct 24 2014 matwey.kornilov@gmail.com
- config: armv7hl: Disable CONFIG_USB_MUSB_TUSB6010
  TUSB6010 is not used by any of our JeOSes*, but introduces issues
  with USB on BeagleBone (and all other boards utilizing musb_hdrc).
  The way to resolve the issues is currently unknown, so temporarily
  disable it.
  See for details: http://marc.info/?l=linux-usb&m=141088564307331&w=2
- commit 3e3e42b
* Fri Oct 24 2014 agraf@suse.de
- ARM: Update config files: Move closer to x86_64 config
- commit a4b08eb
* Fri Oct 24 2014 afaerber@suse.de
- config: arm64: Update to v3.18-rc1
  Generic options as x86_64/armv7hl.
  Enabled PCI, enabling lots of devices.
  When in doubt, left miscellaneous drivers disabled.
- commit a09c425
* Fri Oct 24 2014 afaerber@suse.de
- config: armv6hl: Update to v3.18-rc1
  Generic options as for x86_64/armv7hl.
  When in doubt, disabled SoC level and PMIC drivers.
- commit 33c7f23
* Fri Oct 24 2014 afaerber@suse.de
- config: armv7hl: Update to v3.18-rc1
  Generic options like x86_64.
  Meson6 and BCM SoCs for default only.
- commit 4b665ee
* Thu Oct 23 2014 jeffm@suse.com
- Update to 3.18-rc1
- Eliminated 6 patches.
- ARM is disabled.
- Xen is disabled.
- Config changes:
  - Generic config options:
  * TASKS_RCU=n (default)
  * ADVISE_SYSCALLS=y (default)
  * MODULE_COMPRESS=n (default)
  * DISABLE_DEV_COREDUMP=n (default)
  * MTD_SPI_NOR_USE_4K_SECTORS=y (default)
  * SCSI_MQ_DEFAULT=y
  * SCHED_STACK_END_CHECK=y (good protection, may need to reevaluate)
  * HMC_DRV=m
  * DEVFREQ_GOV_SIMPLE_ONDEMAND=m
  * DEVFREQ_GOV_PERFORMANCE=m
  * DEVFREQ_GOV_POWERSAVE=m
  * DEVFREQ_GOV_USERSPACE=m
  * CPUFREQ_DT=n (default)
  - Security:
  * INTEGRITY=y
  - INTEGRITY_SIGNATURE=y
  - INTEGRITY_ASYMMETRIC_KEYS=y
  - INTEGRITY_AUDIT=y
  * CRYPTO_MCRYPTD=m
  * CRYPTO_SHA1_MB=m (x86_64)
  - Networking options:
  * NET_FOU=m
  * GENEVE=m
  * OPENVSWITCH_GENEVE=y
  * TCP_CONG_DCTCP=m
  * NFT_MASQ=m
  * IP_SET_HASH_MAC=m
  * IP_VS_FO=m
  * NF_REJECT_IPV4=y
  * NF_REJECT_IPV6=
  * NFT_MASQ_IPV4=m
  * NFT_MASQ_IPV6=m
  * CAN_M_CAN=m
  - New modules:
  * NET_DSA_MV88E6171=m
  * NET_DSA_BCM_SF2=m
  * FM10K=m
  * - FM10K_VXLAN=y
  * QCA7000=m
  * IWLWIFI_UAPSD=n (default, possible interop problems)
  * RTL8192EE=m
  * RTL8821AE=m
  * TOUCHSCREEN_AR1021_I2C=m
  * INPUT_DRV260X_HAPTICS=m
  * INPUT_DRV2667_HAPTICS=m
  * SERIAL_8250_FINTEK=m
  * HID_PENMOUNT=m
  * IR_HIX5HD2=m
  * DVB_USB_DVBSKY=m
  * USB_HACKRF=m
  * VIDEO_TW68=m
  * VIDEO_SAA7134_GO7007=m
  * DVB_PT3=m
  * USB_LED_TRIG=y
  * LEDS_SYSCON=y
  * BMC150_ACCEL=m
  * VIDEO_PCI_SKELETON=n
  * VIDEO_VIVID=m
  * POWER_RESET_GPIO_RESTART=n (default)
  * POWER_RESET_LTC2952=n
  * POWER_RESET_SYSCON=n
  * ATH9K_DYNACK=n (experimental)
  * ATH9K_CHANNEL_CONTEXT=y (needed for multi-channel concurrency)
  - New options specific to ARM (I think, all disabled):
  * MFD_HI6421_PMIC
  * MFD_RK808
  * MFD_RN5T618
  * SOC_TI
  * EXTCON_RT8973A
  * TI_ADC128S052
  * MAX5821
  * BMG160
  * AL3320A
  * GPIO_DWAPB
  * GPIO_MCP23S08
  - x86/x86_64:
  * IOSF_MBI_DEBUG=n (default)
  - Power:
  * GENERIC_CPU=y (ppc64)
  * POWER7_CPU=y (ppc64le)
  * CXL=m
  - System Z:
  * UPROBE_EVENT=y
- commit 5268106
* Thu Oct 23 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc1-next-20141023
- commit c44620e
* Wed Oct 22 2014 tiwai@suse.de
- Use fop for creating PDF files in kernel-docs package
  As some files still cannot be built with the default backend.
- commit 0de03e2
* Wed Oct 22 2014 tiwai@suse.de
- Fix build of PDF files in kernel-docs package
  Double the spaces for tex, and fix buildrequires for docbook.
- commit 9e1f511
* Wed Oct 22 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc1-next-20141022
- commit 8cab6ed
* Tue Oct 21 2014 mmarek@suse.cz
- Automatically updated to 3.18-rc1-next-20141021
- commit 5b18a4c
* Mon Oct 20 2014 tiwai@suse.de
- Enable some IIO drivers for xen flavors too (bnc#898828)
- commit 7d5305c
* Mon Oct 20 2014 tiwai@suse.de
- Enable some IIO drivers on x86 for Tablet sensors (bnc#898828)
  Only a limited number of drivers are enabled as of now.  If more other
  device-specific drivers are needed, enable appropriately later.
- commit 7b8f64c
* Mon Oct 20 2014 mmarek@suse.cz
- Automatically updated to 3.17-next-20141020
- commit 81ad4cc
* Fri Oct 17 2014 mmarek@suse.cz
- Automatically updated to 3.17-next-20141017
- commit 4262d73
* Thu Oct 16 2014 mmarek@suse.cz
- Automatically updated to 3.17-next-20141016
- commit 07cdd5a
* Wed Oct 15 2014 mmarek@suse.cz
- Automatically updated to 3.17-next-20141015
- commit 176262b
* Tue Oct 14 2014 mmarek@suse.cz
- Automatically updated to 3.17-next-20141014
- commit 9eb8a2c
* Mon Oct 13 2014 mmarek@suse.cz
- Automatically updated to 3.17-next-20141013
- commit 3358272
* Fri Oct 10 2014 mmarek@suse.cz
- Automatically updated to 3.17-next-20141010
- commit 5f4db3a
* Thu Oct  9 2014 mmarek@suse.cz
- Automatically updated to 3.17-next-20141009
- commit 6283c88
* Wed Oct  8 2014 mmarek@suse.cz
- Automatically updated to 3.17-next-20141008
- commit a2451c9
* Tue Oct  7 2014 mmarek@suse.cz
- Automatically updated to 3.17-next-20141007
- commit 3867815
* Mon Oct  6 2014 jeffm@suse.com
- Update to 3.17-final.
- commit 423560e
* Fri Oct  3 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc7-next-20141003
- commit e29cfaf
* Wed Oct  1 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc7-next-20141001
- commit 5541b45
* Mon Sep 29 2014 jeffm@suse.com
- Update to 3.17-rc7.
- commit ec7f4ce
* Sat Sep 27 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc6-next-20140926
- commit 407dee0
* Thu Sep 25 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc6-next-20140925
- commit 5b94ad6
* Wed Sep 24 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc6-next-20140924
- commit afcc3b7
* Tue Sep 23 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc6-next-20140923
- commit cd1d379
* Mon Sep 22 2014 jeffm@suse.com
- Update to 3.17-rc6.
- commit 847fe9e
* Mon Sep 22 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc6-next-20140922
- commit 4254fd5
* Fri Sep 19 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc5-next-20140919
- commit 13ee589
* Thu Sep 18 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc5-next-20140918
- commit 3f18084
* Thu Sep 18 2014 jbeulich@suse.com
- Update EC2 config files again (adding DEBUG_INFO_DWARF4).
- commit cd1ea3d
* Wed Sep 17 2014 jbeulich@suse.com
- Update EC2 config files (re-enable DEBUG_INFO).
- commit c169b20
* Wed Sep 17 2014 jbeulich@suse.com
- Update Xen patches to 3.17-rc5.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 80c0730
* Wed Sep 17 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc5-next-20140917
- commit ee37d55
* Tue Sep 16 2014 jdelvare@suse.de
- Update s390x config files: disable CONFIG_EXTCON_SM5502
  Enabling CONFIG_EXTCON_SM5502 broke the build, because this option
  should depend on CONFIG_I2C which is not enabled on s390x. So disable
  CONFIG_EXTCON_SM5502 on s390x, and also disable CONFIG_EXTCON as
  there is no point in enabling it when no extcon device driver is
  selected.
- commit 954df51
* Tue Sep 16 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc5-next-20140916
- commit c25e852
* Mon Sep 15 2014 jeffm@suse.com
- Update to 3.17-rc5.
- Config changes:
  - NAT config option splitout, no real change:
  - CONFIG_IP6_NF_NAT=m
  - CONFIG_IP_NF_NAT=m
  - CONFIG_NETFILTER_XT_NAT=m
  - CONFIG_NF_NAT_H323=m
  - CONFIG_NF_NAT_IPV4=m
  - CONFIG_NF_NAT_IPV6=m
  - CONFIG_NF_NAT_PPTP=m
  - CONFIG_NF_NAT_PROTO_GRE=m
  - CONFIG_NF_NAT_SNMP_BASIC=m
- commit e4ddd38
* Mon Sep 15 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc4-next-20140915
- commit 6d9ec79
* Sun Sep 14 2014 jdelvare@suse.de
- Update s390x config files: Disable CONFIG_WATCHDOG_NOWAYOUT
  It's already disabled on all other architectures for a long time and
  has been causing problems on s390x (bnc#756585, bnc#895103.)
- commit db1fb88
* Fri Sep 12 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc4-next-20140912
- commit 2f4bdbf
* Thu Sep 11 2014 mmarek@suse.cz
- Disable MODULE_COMPRESS
  It makes little sense for openSUSE and it breaks debuginfo packaging.
- commit 8d461c1
* Thu Sep 11 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc4-next-20140911
- commit 0ca9674
* Wed Sep 10 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc4-next-20140910
- commit e24ed5e
* Tue Sep  9 2014 agraf@suse.de
- ARM: Update config files: Enable DRM
- commit 489c985
* Tue Sep  9 2014 matwey.kornilov@gmail.com
- config: armv7hl/default: Disable DMA for MUSB
  Hi, this is both for stable and master.
  An issue is the following. We can not have multiple DMA modes in the same kernel due to current musb design.
  So, it will work only for specific hardware (OMAP DMA). Current configuration leads to OOPS at BeaglBone Black (CPI41 DMA which is disabled), because it tries to use wrong DMA functions (from OMAP DMA).
  The fairest way to fix it is to disable DMA for all hardware until fix in upstream.
  [agraf: copy changes to lpae flavor as well]
- commit 2e60b62
* Tue Sep  9 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc4-next-20140909
- commit 73c21dc
* Mon Sep  8 2014 jeffm@suse.com
- Update to 3.17-rc4.
- No config changes.
- commit d82155a
* Mon Sep  8 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc4-next-20140908
- commit 1872bad
* Mon Sep  8 2014 agraf@suse.de
- kernel-obs-build: Force load kernel modules
  - fixes QEMU kiwi builds
- commit 9a27fc1
* Mon Sep  8 2014 agraf@suse.de
- rpm/kernel-obs-build.spec.in: Enable 32bit ARM builds
- commit 3ccdab2
* Sun Sep  7 2014 agraf@suse.de
- ARM: Update config files.
  - armv7: Increase CMA size to 64MB
  - arm64: Switch to 4k pages, enables KVM on more systems and 32bit compat
- commit 106ec7c
* Sat Sep  6 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc3-next-20140905
- commit 24dc09e
* Sat Sep  6 2014 dmueller@suse.com
- config: armv7hl/lpae: Reenable support for Hugepages
  This was apparently accidentally disabled, but we need
  hugepages support for improved performance and stability
  of the KVM build workers.
- commit 628d06e
* Fri Sep  5 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc3-next-20140904
- commit 3f45c08
* Fri Sep  5 2014 agraf@suse.de
- rpm/kernel-binary.spec.in: Always build zImage for ARM
- commit 14e56cc
* Thu Sep  4 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc3-next-20140903
- commit 7bbc077
* Wed Sep  3 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Create a kernel-macros package with the KMP macros
  This package does not have multiversion(kernel) and is not built in the
  - rt tree (bnc#867595).
- commit 9b6a6fe
* Wed Sep  3 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc3-next-20140902
- commit 14b0a9e
* Wed Sep  3 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Install doc files in a versioned directory (bnc#867595)
- commit deb25bc
* Tue Sep  2 2014 jeffm@suse.com
- Update to 3.17-rc3.
- Config changes:
  - x86_64: KEXEC_FILE=y
- commit c7e0570
* Tue Sep  2 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc3-next-20140901
- commit 1017b4e
* Mon Sep  1 2014 agraf@suse.de
- ARM: Update config files: Disable NFC, it results in endless depmod loops
- commit 460b329
* Fri Aug 29 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc2-next-20140829
- commit 5157a25
* Thu Aug 28 2014 matwey.kornilov@gmail.com
- config: armv7hl/default: Disable pcie-spear13xx and gpio-zynq
  This is for master (Kernel:HEAD) to fix build:
  [30000s] ERROR: "dw_pcie_host_init" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_handle_msi_irq" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_pcie_msi_init" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_pcie_cfg_write" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_pcie_cfg_read" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_pcie_setup_rc" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30000s] ERROR: "dw_pcie_link_up" [drivers/pci/host/pcie-spear13xx.ko] undefined!
  [30003s] ERROR: "handle_fasteoi_irq" [drivers/gpio/gpio-zynq.ko] undefined!
- commit a061ee1
* Thu Aug 28 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc2-next-20140828
- commit d7fce39
* Wed Aug 27 2014 jslaby@suse.cz
- Update config files.
  Turn off udev firmware loading as udev does not provide this service
  anymore and it causes delays. This kernel on older distros still
  should load the fw on its own. (bnc#891645)
- commit 21b9f10
* Wed Aug 27 2014 jeffm@suse.com
- Update to 3.17-rc2.
- Config changes:
  - PCI_DRA7XX=n on ARM
  - I2C_ACPI renamed to ACPI_I2C_OPREGION.
- commit dfb8ab0
* Wed Aug 27 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc2-next-20140827
- commit a1029fa
* Tue Aug 26 2014 schwab@suse.de
- config: arm64/default: reenable ARM64_CRYPTO
- commit 0e25358
* Tue Aug 26 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc2-next-20140826
- commit 27426c7
* Mon Aug 25 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc1-next-20140825
- commit fe0a8cd
* Mon Aug 25 2014 agraf@suse.de
- Update armv6hl config file
- commit 9890575
* Mon Aug 25 2014 agraf@suse.de
- Update armv7l config files
- commit d4dbc90
* Mon Aug 25 2014 agraf@suse.de
- Update arm64 config file
- commit 682bf29
* Fri Aug 22 2014 jeffm@suse.com
- config: disable COMMON_CLK_QCOM on non-ARM architectures
- commit e035e67
* Fri Aug 22 2014 jeffm@suse.com
- Update to 3.17-rc1
- Eliminated 8 patches.
- ARM is disabled.
- Xen is disabled.
- Config changes:
  - Generic config options:
  * LOG_CPU_MAX_BUF_SHIFT=15 (32kb, only used with ncpus > 64)
  * KEXEC_VERIFY_SIG=y (needed for secure boot to not get our keys revoked)
  * FW_LOADER_USER_HELPER_FALLBACK=y (we use udev)
  * MESSAGE_LOGLEVEL_DEFAULT=4 (default)
  * DEBUG_INFO_SPLIT=n (would be nice to do =y, but do our tools support it?)
  * DEBUG_INFO_DWARF4=y
  * TEST_RHASHTABLE=n
  * TEST_FIRMWARE=n
  * TEST_UDELAY=n
  * FENCE_TRACE=n
  * GLOB_SELFTEST=n
  * CONFIG_SPI=y
  - USB_MSI2500 depends on SPI
  - Every other SPI driver is disabled
  - New modules:
  * NF_LOG_ARP=m
  * NF_LOG_IPV4=m
  * NF_LOG_IPV6=m
  * NFT_BRIDGE_REJECT=m
  * NF_LOG_BRIDGE=m
  * 6LOWPAN=m
  * TABLET_SERIAL_WACOM4=m
  * I2C_ACPI=y
  * W1_SLAVE_DS2406=m
  * SENSORS_POWR1220=m
  * SENSORS_TPS40422=m
  * SENSORS_TMP103=m
  * IR_XMP_DECODER=m
  * USB_MSI2500=m
  * USB_AIRSPY=m
  * VIDEO_SOLO6X10=m
  * HID_GT683R=m
  * HID_LENOVO=m
  * USB_LINK_LAYER_TEST=m
  * EDAC_IE31200=m
  * RTC_DRV_PCF85063=m
  * MFD_MAX8907=m
  * VIDEO_SOLO6X10=m
  * TOSHIBA_HAPS=m
  * EXTCON_SM5502=m
  * PHY_ST_SPEAR1310_MIPHY=m
  * PHY_ST_SPEAR1340_MIPHY=m
  * THUNDERBOLT=m
  * CRYPTO_DRBG_MENU=m
  - CRYPTO_DRBG_HMAC=y
  - CRYPTO_DRBG_HASH=y
  - CRYPTO_DRBG_CTR=y
  * CRYPTO_DEV_QAT_DH895xCC=m
  * CRYPTO_DES3_EDE_X86_64=m
  * INTEL_MIC_BUS=m
  * INTEL_MIC_X100_DMA=m
  * UNISYS_VISORUTIL=m
  - UNISYS_VISORCHANNEL=m
  - UNISYS_VISORCHIPSET=m
  - UNISYS_CHANNELSTUB=m
  - UNISYS_UISLIB=m
  - UNISYS_VIRTPCI=m
  - UNISYS_VIRTHBA=m
  - ppc64/ppc64le:
  * SENSORS_IBMPOWERNV=m
  * KVM_BOOK3S_64_HV=m
  * CMA_DEBUG=n
  * CMA_AREAS=7 (default)
  - s390x:
  * IRQ_DOMAIN_DEBUG=n
- commit 70faf9b
* Fri Aug 22 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc1-next-20140822
- commit 1243fb9
* Thu Aug 21 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix the version variables in the generated
  Makefile (bnc#892973)
- commit 8331f47
* Wed Aug 20 2014 mmarek@suse.cz
- rpm/compress-vmlinux.sh: Do not duplicate the job of brp-99-compress-vmlinux
- commit e561498
* Wed Aug 20 2014 afaerber@suse.de
- config: arm64: Enable RTC_DRV_HID_SENSOR_TIME
  For consistency across ARM configs.
  This drags in IIO. For consistency, in turn use:
  CONFIG_IIO_SIMPLE_DUMMY=m
  CONFIG_HID_SENSOR_IIO_TRIGGER=m
  CONFIG_IIO_PERIODIC_RTC_TRIGGER=m
  CONFIG_IIO_INTERRUPT_TRIGGER=m
  CONFIG_IIO_SYSFS_TRIGGER=m
  CONFIG_IIO_BUFFER=y
  CONFIG_IIO_KFIFO_BUF=m
  CONFIG_HID_SENSOR_*=m
- commit 063ce91
* Wed Aug 20 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc1-next-20140820
- commit 130d06a
* Wed Aug 20 2014 afaerber@suse.de
- config: armv6hl: Re-enable DWC2 USB support
  The config update/cleanup for v3.16-rc3 mistakenly disabled USB_DWC2,
  which is needed for the Raspberry Pi.
  Fixes: d2f49e165ca3 ("config: armv6hl: Update config for 3.16-rc3")
- commit 7bfc961
* Wed Aug 20 2014 afaerber@suse.de
- config: ARM: Change RTC drivers to built-in
  Consistently do not build RTC drivers as modules. This fixes subtle
  differences between armv7hl default and lpae flavors and avoids any
  timing-related driver initialization issues.
  To make RTC_DRV_88PM80X built-in, make MFD_88PM800 built-in, too.
  To make RTC_DRV_PM8XXX built-in, make MFD_PM8921_CORE built-in, too.
- commit 469cc7f
* Mon Aug 18 2014 schwab@suse.de
- rpm/kernel-binary.spec.in: Fix missing quotes around %%build_flavor
  %%build_flavor can be an arbitrary string, so it needs to be quoted for
  string comparison.
- commit 0134440
* Mon Aug 18 2014 dvaleev@suse.com
- rpm/kernel-obs-build.spec.in: Use dracut for SLE12
- commit ec64eaf
* Mon Aug 18 2014 mmarek@suse.cz
- Automatically updated to 3.17-rc1-next-20140818
- commit c07f575
* Mon Aug 18 2014 afaerber@suse.de
- config: armv6hl: Enable DMA_BCM2835
  Only bcm2835 option missing.
- commit 6da1105
* Mon Aug 18 2014 afaerber@suse.de
- config: armv7hl: Enable DWMAC_SUNXI for lpae flavor as well
  Without this, the Cubietruck has no network in LPAE mode.
- commit dde37db
* Fri Aug 15 2014 mmarek@suse.cz
- Automatically updated to 3.16-next-20140815
- commit 4ce77f8
* Thu Aug 14 2014 mmarek@suse.cz
- Automatically updated to 3.16-next-20140814
- commit 3f26c9e
* Wed Aug 13 2014 tiwai@suse.de
- Revert "config: armv7hl: Disable OMAP DRM"
  This reverts commit f92487dbd7a305531e4cc54c41609b8f77a1bc30.
  The previous commit should fix the build error of omapdrm.
- commit 6292001
* Wed Aug 13 2014 afaerber@suse.de
- config: armv7hl: Disable OMAP DRM
  To avoid errors such as:
  ../drivers/gpu/drm/omapdrm/omap_plane.c: In function 'omap_plane_pre_apply':
  ../drivers/gpu/drm/omapdrm/omap_plane.c:145:2: error: format '%%x' expects argument of type 'unsigned int', but argument 5 has type 'dma_addr_t' [-Werror=format=]
    DBG("%%d,%%d %%08x %%08x", info->pos_x, info->pos_y,
    ^
  ../drivers/gpu/drm/omapdrm/omap_plane.c:145:2: error: format '%%x' expects argument of type 'unsigned int', but argument 6 has type 'dma_addr_t' [-Werror=format=]
  cc1: all warnings being treated as errors
  disable OMAP DRM for now.
  Two patches were sent upstream by Matwey V. Kornilov but didn't find
  their way into v3.16. Once patches are applied, revert this commit.
- commit f2f74ea
* Wed Aug 13 2014 afaerber@suse.de
- config: arm64: Disable ARM64 crypto extensions
  To avoid build errors such as:
  ld: cannot find arch/arm64/crypto/aes-glue-ce.o: No such file or directory
  ../scripts/Makefile.build:411: recipe for target 'arch/arm64/crypto/aes-ce-blk.o' failed
  disable support for ARM64 crypto extensions for now.
  A patch was submitted upstream by Andreas Schwab but didn't make it into
  v3.16. Once that is available, this commit should be reverted.
- commit cb61536
* Wed Aug 13 2014 mmarek@suse.cz
- Automatically updated to 3.16-next-20140813
- commit 479f92f
* Tue Aug 12 2014 mmarek@suse.cz
- Automatically updated to 3.16-next-20140812
- commit 7940a91
* Tue Aug 12 2014 schwab@suse.de
- config: arm64/default: make rtc-pl03[01] built-in
- commit 150629d
* Mon Aug 11 2014 mmarek@suse.cz
- Automatically updated to 3.16-next-20140811
- commit 80d86a6
* Fri Aug  8 2014 mmarek@suse.cz
- Automatically updated to 3.16-next-20140808
- commit e7df58d
* Thu Aug  7 2014 mmarek@suse.cz
- Automatically updated to 3.16-next-20140807
- commit 4d651a6
* Wed Aug  6 2014 mmarek@suse.cz
- Automatically updated to 3.16-next-20140806
- commit f96b3a9
* Tue Aug  5 2014 mmarek@suse.cz
- Automatically updated to 3.16-next-20140805
- commit 504d074
* Mon Aug  4 2014 jeffm@suse.com
- config: disable CONFIG_PPC_PS3 on ppc64le
  The PS3 hardware is big-endian.
- commit 0e1f9ab
* Mon Aug  4 2014 jeffm@suse.com
- config: resync vanilla configs (no actual changes)
- commit 8f9c221
* Mon Aug  4 2014 jeffm@suse.com
- Update to 3.16.
- commit ccbb81b
* Fri Aug  1 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc7-next-20140801
- commit 20e30d3
* Thu Jul 31 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc7-next-20140730
- commit 555ac0f
* Wed Jul 30 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc7-next-20140729
- commit 6b5cf91
* Wed Jul 30 2014 jdelvare@suse.de
- Revert "config: disable USB_UAS (bnc#888069)."
  This reverts commit f509af67eb3a98665e0134eaadb91e93420d9e04. The uas
  driver works fine since kernel v3.15, the problem was that the
  module was blacklisted so it would not load when needed.
- commit f23efc2
* Tue Jul 29 2014 jeffm@suse.com
- config: disable USB_UAS (bnc#888069).
  uas is already blacklisted in /etc/modprobe.d/50-blacklist.conf as
  being hopelessly broken, but there are parts of usb-storage that are
  ifdef'd around it being configured at all. Let's disable it completely.
- commit dda6ac4
* Tue Jul 29 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc7-next-20140728
- commit 5b375b5
* Tue Jul 29 2014 jeffm@suse.com
- Update to 3.16-rc7.
- commit 3eaa177
* Mon Jul 28 2014 schwab@suse.de
- config: arm64/default: increase LOG_BUF_SHIFT to 18
- commit f334009
* Mon Jul 28 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc6-next-20140725
- commit eed1b4b
* Mon Jul 28 2014 lpechacek@suse.cz
- doc/README.SUSE: update Solid Driver team contacts
- commit a90946c
* Thu Jul 24 2014 jdelvare@suse.de
- Update config files: disable CONFIG_STE_MODEM_RPROC
  I was told by Dmitry Tarnyagin and Linus Walleij that there exists no
  public hardware that needs this driver, so there is no point in
  building it and shipping it.
- commit 7f8b8f6
* Mon Jul 21 2014 jeffm@suse.com
- config: sync vanilla configs
- commit 91ea893
* Mon Jul 21 2014 jeffm@suse.com
- Update to 3.16-rc6.
- Eliminated 1 patch.
- commit 0217e34
* Mon Jul 21 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc5-next-20140721
- commit ba4e5ff
* Mon Jul 21 2014 jdelvare@suse.de
- Update armv7hl config files for 3.16-rc5
  New driver CONFIG_USB_EHCI_MSM=m.
- commit 44aa324
* Fri Jul 18 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not sign firmware files (bnc#867199)
- commit 38f105d
* Fri Jul 18 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc5-next-20140718
- commit 7d5d363
* Thu Jul 17 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc5-next-20140717
- commit 545e2cb
* Wed Jul 16 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc5-next-20140716
- commit cbd2471
* Tue Jul 15 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc5-next-20140715
- commit cdf000e
* Mon Jul 14 2014 jeffm@suse.de
- Update to 3.16-rc5.
- Eliminated 1 patch.
- commit 8173a44
* Mon Jul 14 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc5-next-20140714
- commit 03532fc
* Fri Jul 11 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc4-next-20140711
- commit 8d975c3
* Fri Jul 11 2014 jdelvare@suse.de
- Update ppc config files: Disable ChromeOS drivers
  No Chromebook is based on PowerPC so these drivers are useless on ppc.
- commit d4fe6a6
* Thu Jul 10 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc4-next-20140710
- commit 7c263a0
* Wed Jul  9 2014 mmarek@suse.cz
- rpm/package-descriptions: Drop descriptions for dropped flavors
- commit aa68ae6
* Wed Jul  9 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/post(un).sh: Drop checks for dropped archs/flavors
- commit bd6afed
* Wed Jul  9 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: No scriptlets in kernel-zfcpdump
  The kernel should not be added to the bootloader nor are there any KMPs.
- commit bcca34b
* Wed Jul  9 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc4-next-20140709
- commit 6690b09
* Tue Jul  8 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc4-next-20140708
- commit 1b4f4ce
* Mon Jul  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Delete the build-id links created by vdso_install
- commit ca040af
* Mon Jul  7 2014 jeffm@suse.com
- Update to 3.16-rc4.
- commit 1fca5ba
* Mon Jul  7 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc4-next-20140707
- commit 33f0d21
* Sun Jul  6 2014 afaerber@suse.de
- config: armv7hl: Update configs for 3.16-rc3
  * Samsung Exynos is now in default flavor, drop exynos flavor
  * Enable Freescale/Xilinx for default flavor only
  * Enable Qualcomm/LSI for both default and lpae flavors
  * Enable Allwinner A20+ in lpae flavor, A10+ in default flavor
  * Enable Hisilicon Hi3xxx in default flavor
  * Enable Renesas RZ/A in default flavor
  * Enable big.LITTLE switcher module
  * Enable PCI for Freescale/Marvell/Nvidia/Samsung
  but keep device drivers to minimum, as known boards are mini PCIe only
  * Build in some more serial drivers for console use
  * Enable some missing USB media device driver modules
  * Disable OMAP4 V4L as it cannot be built as module (Matwey K.)
- commit c57fed0
* Sun Jul  6 2014 afaerber@suse.de
- config: arm64: Update config for 3.16-rc3
- commit 21ba34b
* Sun Jul  6 2014 afaerber@suse.de
- config: armv6hl: Update config for 3.16-rc3
- commit cf4ce13
* Fri Jul  4 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_DRM_I2C_NXP_TDA998X
  Disable the TDA998x driver in all flavors where is not needed.
- commit 5078a2c
* Fri Jul  4 2014 mmarek@suse.cz
- kbuild: Do not print the build directory with make -s.
- commit e130902
* Fri Jul  4 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc3-next-20140704
- commit 5a4a204
* Thu Jul  3 2014 jbeulich@suse.com
- Update Xen patches to 3.16-rc3 and c/s 1261.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit 51b2043
* Thu Jul  3 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc3-next-20140703
- commit 4b02a87
* Wed Jul  2 2014 jeffm@suse.com
- Update to 3.16-rc3.
- Eliminated 1 patch.
- commit 546bd75
* Wed Jul  2 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc3-next-20140702
- commit c68d545
* Tue Jul  1 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc3-next-20140701
- commit 12cc82f
* Mon Jun 30 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc3-next-20140630
- commit dadd39b
* Mon Jun 30 2014 schwab@suse.de
- rpm/kernel-obs-build.spec.in: add support for aarch64
  Use Image for kernel_name on aarch64 and add virtio_mmio to KERNEL_MODULES.
- commit 6024dc9
* Fri Jun 27 2014 mmarek@suse.cz
- rpm/compress-vmlinux.sh: Compress vmlinux after find-debuginfo.sh (bnc#884459)
- commit 381a192
* Fri Jun 27 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc2-next-20140627
- commit c23fd75
* Thu Jun 26 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc2-next-20140626
- commit be6f5a4
* Thu Jun 26 2014 mmarek@suse.cz
- rpm/old-flavors: Obsolete kernel-trace-base by kernel-default
  (bnc#884364)
- commit 568f3cc
* Thu Jun 26 2014 mmarek@suse.cz
- rpm/old-flavors: Explicitly list subpackages to obsolete
- commit 5595ce2
* Wed Jun 25 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc2-next-20140625
- commit d3934ce
* Tue Jun 24 2014 jeffm@suse.com
- config: disable X86_GOLDFISH
  It seems to be built-in and generates loads of messages like:
  genirq: Flags mismatch irq 4. 00000000 (serial) vs. 00000080 (goldfish_pdev_bus)
- commit f9b2c78
* Tue Jun 24 2014 jeffm@suse.de
- Update to 3.16-rc2.
- Config changes:
  - Generic config options:
  * RANDOMIZE_BASE=n (default n)
  - With only 9 bits of entropy on 64-bit systems, is it worthwhile?
  - System z:
  * DIAG288_WATCHDOG=m
  - New options specific to ARM (I think), all disabled:
  * I2C_RK3X (SoC)
- commit 5c59017
* Mon Jun 23 2014 mmarek@suse.cz
- rpm/post.sh: Also check for grub2 config
- commit 0844541
* Mon Jun 23 2014 mmarek@suse.cz
- Port ppc64le packaging fixes from 'SLE12' to 'packaging'
- commit c233eb3
* Mon Jun 23 2014 jdelvare@suse.de
- Update config files: Enable Realtek RTL8723AU support
  This wireless network chipset is found in hybrid notebooks/tablets
  such as the first Lenovo Yoga 13.
- commit 6f0cfca
* Mon Jun 23 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc2-next-20140623
- commit 1d03c4c
* Fri Jun 20 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc1-next-20140620
- commit 8352e9e
* Thu Jun 19 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc1-next-20140619
- commit 538627e
* Wed Jun 18 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc1-next-20140618
- commit 56b628d
* Tue Jun 17 2014 mmarek@suse.cz
- Automatically updated to 3.16-rc1-next-20140617
- commit 1f8f4b7
* Mon Jun 16 2014 jeffm@suse.de
- Update to 3.16-rc1.
- Eliminated 10 patches.
- ARM is disabled.
- Xen is disabled.
- Config changes:
  - Generic config options:
  * UEVENT_HELPER=y (default y)
  - It should be obsolete - needs review
  * SGETMASK_SYSCALL=y/n
  - default varies by architecture, used default
  * DEBUG_PI_LIST=n (default n)
  * TRACEPOINT_BENCHMARK=n (default n)
  - Only needed if developing tracepoint infrastructure
  * TEST_BPF=n (default n)
  - New options for existing drivers:
  * QLCNIC_HWMON=y (default y)
  * ISDN_CAPI_CAPIDRV_VERBOSE=y (helpful messages, cost only in capi.ko)
  - New modules:
  * SERIAL_SC16IS7XX (i2c)
  * SENSORS_SHTC1 (i2c)
  * USB_GSPCA_DTCS033 (usb)
  * SND_BCD2000 (firewire)
  * SND_FIREWORKS (firewire)
  * SND_BEBOB (firewire)
  * HID_RMI (usb)
  * MMC_USDHI6ROL0 (usb)
  * MMC_REALTEK_USB (usb)
  * MEMSTICK_REALTEK_USB (usb)
  * R8192EE (pci)
  * INPUT_GPIO_BEEPER (generic gpio)
  * NFT_BRIDGE_META (netfilter)
  * CAN_GS_USB (USB)
  * MTD_SPI_NOR (SPI)
  * AMD_XGBE (PCI)
  - x86/x86_64:
  * DELL_SMO8800=m
  * SENSORS_NCT6683=m (found on Intel DQ87PG motherboards)
  * INTEL_SOC_DTS_THERMAL=m
  * X86_GOLDFISH=y (platform driver, used for virtual Android development)
  - KEYBOARD_GOLDFISH_EVENTS=m
  - GOLDFISH_TTY=m
  - BATTERY_GOLDFISH=m
  - MMC_GOLDFISH=m
  - GOLDFISH_AUDIO=m
  - MTD_GOLDFISH_NAND=m
  - GOLDFISH_PIPE=m
  * CRYPTO_SKEIN=n (default n)
  - staging, only available on 64-bit x86 - usefulness?)
  * CRYPTO_THREEFISH=n (same)
  * I2C_CROS_EC_TUNNEL=m (also available on ARM)
  * X86_16BIT=y (default y, required for wine, minimal runtime savings)
  - ppc64le:
  * VIRTUALIZATION=y
  - KVM_BOOK3S_64=m
  - KVM_BOOK3S_64_PR=m
  - KVM_XICS=y
  - New options specific to ARM (I think), all disabled:
  * NFC_ST21NFCA (datasheet says intended for mobile phone use)
  * USB_DWC2
  * SYSTEMPORT
  * KEYBOARD_OMAP4
  * PINCTRL_APQ8064
  * PINCTRL_IPQ8064
  * GENERIC_CPUFREQ_CPU0
  * RTC_DRV_XGENE
  * MFD_AXP20X
- commit 15e9be8
* Mon Jun 16 2014 mmarek@suse.cz
- Automatically updated to 3.15-next-20140616
- commit a54e0e7
* Mon Jun 16 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_8723AU_P2P
  Disable this as it is reported to be totally broken and can cause
  a kernel oops.
- commit 6bb03f0
* Fri Jun 13 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Build in a subdirectory of the source tree
  So that the build can use relative paths.
- commit 8eb070a
* Fri Jun 13 2014 mmarek@suse.cz
- Automatically updated to 3.15-next-20140613
- commit 69b8f4e
* Thu Jun 12 2014 mmarek@suse.cz
- Automatically updated to 3.15-next-20140612
- commit 776d1db
* Wed Jun 11 2014 mmarek@suse.cz
- Automatically updated to 3.15-next-20140611
- commit 8acbd70
* Tue Jun 10 2014 jbeulich@suse.com
- swiotlb: don't assume PA 0 is invalid (bnc#865882).
- Update Xen patches to 3.15 final.
- Update x86-64 Xen config files.
- commit c705cbb
* Tue Jun 10 2014 mmarek@suse.cz
- Automatically updated to 3.15-next-20140610
- commit 07a0bfd
* Mon Jun  9 2014 jeffm@suse.de
- Update to 3.15.
- commit 1bd2beb
* Fri Jun  6 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc8-next-20140606
- commit 1899cdd
* Thu Jun  5 2014 mmarek@suse.cz
- rpm/package-descriptions: kernel-vmi is gone
- rpm/mkspec: Obsolete $flavor-{devel,extra} $flavor-base is obsolete
  (bnc#881490)
- rpm/kernel-module-subpackage: Obsolete -trace KMPs (bnc#881490)
- rpm/old-flavors: Obsolete also kernel-trace-base (bnc#881490)
- commit 38d4d09
* Thu Jun  5 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require hmaccalc on 13.1 and earlier
- commit d7a84f7
* Thu Jun  5 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc8-next-20140605
- commit 8612dec
* Wed Jun  4 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc8-next-20140604
- commit 94d8975
* Wed Jun  4 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Allow find-debuginfo.sh to create vmlinux.debug
- commit 9b3c48f
* Tue Jun  3 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc8-next-20140603
- commit ebbec3a
* Mon Jun  2 2014 jeffm@suse.de
- Update to 3.15-rc8.
- commit 76d3645
* Mon Jun  2 2014 mmarek@suse.cz
- Obsolete kernel-trace by kernel-default
- commit 1eb3f59
* Mon Jun  2 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc7-next-20140602
- commit d6d9275
* Mon Jun  2 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_XO15_EBOOK
  The xo15-ebook driver is useless without the rest of OLPC support. So
  I left it enabled only in i386/default and i386/vanilla.
- commit 9f99282
* Fri May 30 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc7-next-20140530
- commit 237a9c0
* Thu May 29 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc7-next-20140529
- commit 1448b6d
* Wed May 28 2014 jdelvare@suse.de
- Update config files: Disable gpio-fan and ntc_thermistor drivers
  Disable the gpio-fan and ntc_thermistor hwmon drivers on all
  architectures where they are not used.
- commit cf522e0
* Tue May 27 2014 jeffm@suse.de
- Update to 3.15-rc7.
- Eliminated 1 patch.
- Config changes:
  - CX_ECAT=m (default n) for i386/x86_64
  - The vendor supplying this hardware only uses 32/64-bit Atom CPUs.
    This may need to be revisited if the hardware extends to different
    architectures (ARM, probably).
  - SENSORS_NTC_THERMISTOR=m (default n)
  - Sensor chip that could be found essentially anywhere.
- commit 910d968
* Fri May 23 2014 jeffm@suse.de
- config: sync vanilla configs for 3.15-rc6.
- commit f79934e
* Fri May 23 2014 jeffm@suse.de
- Update to 3.15-rc6.
- Config changes:
  - ACPI_PROCFS_POWER=y (default n)
  - Should eventually be =n once userspace tools have been audited.
- commit 1b75918
* Fri May 23 2014 jdelvare@suse.de
- Update ppc config files: Disable SH_MOBILE media drivers
  These are useless on PowerPC.
- commit 5ae3b30
* Fri May 23 2014 ddiss@suse.de
- Update config files: enable CONFIG_CIFS_SMB2
  cifs.ko is currently built with support for the base SMB1/CIFS dialect
  only. SMB1/CIFS support can be disabled in Windows 8.1 and Windows
  Server 2012 R2, and is completely unsupported with the Microsoft Azure
  File service, leaving cifs.ko users unable to access files on such
  servers without this change (fate#317480).
- commit d73e475
* Fri May 23 2014 jdelvare@suse.de
- Update config files: Disable remaining R-CAR drivers
  These drivers are useless except on arm/shmobile.
- commit cbb3e29
* Wed May 21 2014 jdelvare@suse.de
- Fix a typo in config/ppc/vanilla, sorry
- commit 3a8bbdf
* Wed May 21 2014 jdelvare@suse.de
- Update config files: Disable unused RTC platform drivers
- commit 7ab2564
* Wed May 21 2014 jdelvare@suse.de
- Update config files: Disable the rtc-moxart driver
  This driver is only needed on Moxa ART systems, which we do not
  support.
- commit a688df0
* Tue May 20 2014 jbeulich@suse.com
- Update Xen config files: Set compatibility level back to 4.1
  (bnc#851338).
- commit db7872f
* Mon May 19 2014 jdelvare@suse.de
- Update armv7hl/default config file: CONFIG_DRM_PTN3460=y
  Align on what exynos has, in anticipation of both files being
  merged someday.
- commit 7fdbccd
* Mon May 19 2014 jdelvare@suse.de
- Update config files: Disable DRM_PTN3460
  Currently it's only needed on arm/exynos.
- commit 19f8bd9
* Mon May 19 2014 jdelvare@suse.de
- Update armv7hl/exynos config file: CONFIG_DRM_PTN3460=y
  DRM_EXYNOS_DP depends on DRM_PTN3460, and we have the former built-in,
  so the latter must be built-in as well. Otherwise we get a linker
  failure like:
  .../linux-3.15-rc5/drivers/gpu/drm/exynos/exynos_dp_core.c:1004:
  undefined reference to `ptn3460_init'
- commit b98c3cb
* Fri May 16 2014 jdelvare@suse.de
- Update config files: Disable all EG20T drivers except on i386
  EG20T (aka Topcliff PCH) is a chipset for 32-bit x86 processors, so
  we only need these drivers on i386.
- commit 6fb20b1
* Fri May 16 2014 jdelvare@suse.de
- Update arm64 config file to fix the build
- commit 876c44b
* Fri May 16 2014 afaerber@suse.de
- config: armv6hl: Update config to 3.15-rc5
- commit 0a6bd2a
* Fri May 16 2014 afaerber@suse.de
- config: armv7hl: Update configs to 3.15-rc5
- commit 94fa1ac
* Thu May 15 2014 jdelvare@suse.de
- Update armv7hl/lpae config file: Enable SERIAL_TEGRA
  Despite what the Kconfig text says, the serial-tegra driver works on
  all Tegra platforms.
- commit 97bc755
* Thu May 15 2014 jdelvare@suse.de
- Update ppc64le config files: Disable DA903x support completely
  It makes no sense to support some sub-drivers and not the rest.
- commit 2a243de
* Thu May 15 2014 duwe@suse.de
- Update config files:
  i386/x86_64/ppc64/ppc64le disable:
  timeriomem-rng
  pwm-pca9685
  unsupported RTC drivers
  ssd1307fb/da903x_bl
- commit d8e18c0
* Thu May 15 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc5-next-20140515
- commit 44b5845
* Wed May 14 2014 afaerber@suse.de
- config: arm64: Update config for 3.15
- commit f385138
* Wed May 14 2014 jbeulich@suse.com
- Update Xen patches to 3.15-rc5.
- privcmd: actually batch hypercalls for batch ioctls.
- Refresh patches.xen/xen-blkfront-indirect (bnc#876786).
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit aef56a6
* Wed May 14 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc5-next-20140514
- commit 2675db3
* Tue May 13 2014 jdelvare@suse.de
- Update ec2 config files: Disable CAN support
  It was enabled by accident.
- commit 0bf5288
* Mon May 12 2014 jeffm@suse.de
- Update to 3.15-rc5.
- Eliminated 2 patches.
- Config changes:
  - CAN_C_CAN_STRICT_FRAME_ORDERING=n (default)
- commit a5ae007
* Mon May 12 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc5-next-20140512
- commit b7e4aa7
* Mon May 12 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not keep debug symbols in vmlinux-*.gz
  (bnc#877267)
- commit f928d60
* Fri May  9 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc4-next-20140509
- commit e4c0a2c
* Wed May  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Package .vmlinuz-*.hmac as well
- commit 3375bd7
* Wed May  7 2014 jdelvare@suse.de
- Update x86 config files: Disable unused CAN drivers
  Disable platform, grcan and tscan1 CAN drivers. Disable ISA and EG20T
  CAN drivers on x86_64. These are believed to be useless, and will
  only be enabled upon explicit request.
- commit 98892e0
* Wed May  7 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Exclude /boot/symtypes* from the base/main package
  Also, get rid of the comparison of the base and devel filelist.
- commit f1e303f
* Wed May  7 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc4-next-20140507
- commit 08828dd
* Tue May  6 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix packaging of vmlinux debuginfo
  (bnc#875946)
  Add the uncompressed vmlinux image as ghost file to the main package, so
  that the vmlinux debuginfo generated by rpm natively and put into the
  right package.
- commit 26b7a64
* Tue May  6 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Simplify filelist for files in /boot
- commit ef040ff
* Tue May  6 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc4-next-20140506
- commit 1d0f0fd
* Mon May  5 2014 mmarek@suse.cz
- Enable CONFIG_INTEL_TXT on i586 as well (fate#311820, fate#311962,
  bnc#707666, bnc#875575)
- commit a44f630
* Mon May  5 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc3-next-20140505
- commit 7a8a9cc
* Fri May  2 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc3-next-20140502
- commit 37dda94
* Thu May  1 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc3-next-20140501
- commit 2134fc1
* Wed Apr 30 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc3-next-20140430
- commit d3878b7
* Tue Apr 29 2014 guillaume.gardet@oliseo.fr
- Re-eanble ARM kernel in config.conf file and update all ARM configs:
  * config/arm64/default:
  - Add SATA/PATA support
  - Add voltage and regulator support
  * config/armv6hl/default:
  - Add external I2C controllers
  - Add usermode SPI driver
  * config/armv7hl/default:
  - Add I2C support for Tegra SoC
  - Add external I2C controllers
  - Add SPI, GPIO and watchdog support to Davinci/Keystone SoC
  - Add RTC driver for Tegra and sunxi SoC
  - Enhance nVidia Tegra support with MFD_NVEC and KEYBOARD_TEGRA
  - Add OMAP4 video input support
  - Add IR receiver
  - Add iMX HDMI support
  - Add Serial support for Tegra SoC
  * config/armv7hl/exynos:
  - Trivial update
  * config/armv7hl/lpae:
  - Add I2C support for Tegra SoC
  - Add external I2C controllers
  - Add SPI, GPIO and watchdog support to Davinci/Keystone SoC
  - Remove unused Terga20/Tegra30 SPI support
  - Add RTC driver for Tegra and sunxi SoC
  - Enhance nVidia Tegra supprt with MFD_NVEC and KEYBOARD_TEGRA
  - Add IR receiver
  - Add iMX HDMI support
- commit f193362
* Tue Apr 29 2014 jeffm@suse.com
- Update to 3.15-rc3.
- commit 8ea4d95
* Tue Apr 29 2014 jeffm@suse.com
- config: sync PCI changes to s390x/vanilla
- commit 7057957
* Tue Apr 29 2014 jdelvare@suse.de
- Update arm config files: Enable all USB-to-serial drivers
  Specifically, enable USB_SERIAL_WISHBONE, USB_SERIAL_MXUPORT and
  USB_SERIAL_QT2 on all arm flavors.
- commit e17b903
* Tue Apr 29 2014 jdelvare@suse.de
- Update arm64 config file: Disabled 3 unneeded drivers
  Align the arm64 config file with the rest of the config files:
  CONFIG_ATMEL_SSC is not set
  CONFIG_FB_TMIO is not set
  CONFIG_FB_GOLDFISH is not set
- commit 2cb42be
* Tue Apr 29 2014 jdelvare@suse.de
- Update config files: Enable CONFIG_USB_SERIAL_SIMPLE
  This is a unified driver replacing several drivers we were shipping
  so far, so we should ship it too.
- commit ce0469e
* Tue Apr 29 2014 mmarek@suse.cz
- Enable CONFIG_INTEL_TXT on x86_64 (fate#311820, fate#311962,
  bnc#707666, bnc#875575)
- commit f9ea26f
* Tue Apr 29 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc3-next-20140429
- commit 8a427ea
* Mon Apr 28 2014 mmarek@suse.cz
- Sync config files with master
- commit bc9e8c2
* Mon Apr 28 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc2-next-20140428
- commit 1f57323
* Mon Apr 28 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec.in: Require only perl-Bootloader
- commit 573fc1b
* Mon Apr 28 2014 mmarek@suse.cz
- rpm/kernel-obs-qa.spec.in: Use per-flavor path for the logfile
- commit 717e968
* Sun Apr 27 2014 jeffm@suse.com
- s390: enable PCI to match SLE12 kernel configs
- PCI=y
- HOTPLUG_PCI=y
- HOTPLUG_PCI_S390=y
- PCI_IOV=y
- INFINIBAND=m
- INFINIBAND_USER_ACCESS=m
- MLX4_INFINIBAND=m
- MLX4_EN=m
- RDS_RDMA=m
  New devices since 3.12:
- MLX5_CORE=m
- MLX5_INFINIBAND=m
- SUNRPC_XPRT_RDMA_CLIENT=m
- SUNRPC_XPRT_RDMA=m
- SUNRPC_XPRT_RDMA_SERVER=m
- All others defaulted to No.
- commit 56f4a3f
* Sun Apr 27 2014 jeffm@suse.de
- Update to 3.15-rc2.
- Config changes:
  - Generic config options:
  * IPMI_SI_PROBE_DEFAULTS=y (default=n)
  - older hardware only works with boot option
  - New options specific to ARM:
  * PINCTRL_BCM281XX=n (default)
- commit a68e86f
* Sun Apr 27 2014 jeffm@suse.de
- Update to 3.15-rc1.
- Xen is disabled.
- ARM is disabled.
- Eliminated 3 patches.
- Config changes:
  - Generic config options:
  * USELIB=y (default) - only used for libc5 users, do we care?
  * SYSFS_SYSCALL=y (default) - libc doesn't even supported it anymore,
  do we care?
  * ACPI_REDUCED_HARDWARE_ONLY=n (default)
  * CGROUP_NET_PRIO=y (new feature, do we want it?)
  * LOCK_TORTURE_TEST=n (default)
  * EVM=n (default)
  - New options for existing drivers:
  * BATMAN_ADV_MCAST=y (default=n) -- optimization w/ better reliability
  * BT_6LOWPAN=y (default=n) -- new feature
  * MTD_UBI_BLOCK=n (default -- do we even care about UBI?)
  * ZRAM_LZ4_COMPRESS=y (new feature)
  * BE2NET_VXLAN=y (default)
  * MLX4_EN_VXLAN=y (default)
  * QLCNIC_VXLAN=y (default=n) - enabled for other drivers
  * IWLWIFI_BCAST_FILTERING=n (default)
  - New modules:
  * IP_SET_HASH_IPMARK
  * INTEL_MEI_TXE
  * DM_ERA
  * ALTERA_TSE
  * RTL8723BE
  * RSI_91X
  - RSI_DEBUGFS=n
  - RSI_SDIO=m
  - RSI_USB=m
  * INPUT_PWM_BEEPER
  * SENSORS_LTC2945
  * SENSORS_LTC4222
  * SENSORS_LTC4260
  * SENSORS_ADC128D818
  * MFD_RTSX_USB
  * IR_SHARP_DECODER
  * IR_IMG
  - IR_IMG_RAW=n (documented as performance degrading and for debugging)
  - IR_IMG_NEC=y
  - IR_IMG_JVC=y
  - IR_IMG_SONY=y
  - IR_IMG_SHARP=y
  - IR_IMG_SANYO=y
  * DRM_PTN3460
  * USB_UAS
  * DVB_RTL2832_SDR (USB)
  * ALIENWARE_WMI
  * PWM_LPSS
  * SUNRPC_XPRT_RDMA_CLIENT=m (default)
  * SUNRPC_XPRT_RDMA_SERVER=m (default)
  - x86_64:
  * EFI_MIXED=n (default) -- do we use a bootloader that can support it?
  - ppc/ppc64le:
  * HV_PERF_CTRS=y (default)
  * POWERNV_CPUFREQ=y (default)
  - Probably ARM but looks generic, all modules:
  * SPMI
  * GPIO_DWAPB
  * HID_CP2112
  * MFD_TPS65218
  * GPIO_SYSCON (depends on MFD_SYSCON, which looks to be only used by ARM)
  - New options specific to ARM (I think), all disabled:
  * IMX_THERMAL
  * AHCI_IMX
  * PWM_FSL_FTM
  * OMAP_CONTROL_PHY
  * PHY_SAMSUNG_USB2
  * FSL_EDMA
  * XILINX_WATCHDOG
  * GS_FPGABOOT
  * BCMGENET
  * SXGBE_ETH
  * MFD_BCM590XX
  * BCM7XXX_PHY
  - New options specific to tablets, all disabled:
  * INPUT_SOC_BUTTON_ARRAY (windows tablet)
  * R8723AU (Lenovo Yogi)
  - Other weird hardware:
  * CONFIG_MCB=n (specific to MEN Mikroelektronik FGPA devices)
  - Changes undocumented here were changed automatically.
- commit 369eecd
* Thu Apr 24 2014 jdelvare@suse.de
- Update config files: Disable CONFIG_NFC on s390x and ppc64le
  NFC support makes little sense on server-class hardware.
- commit fa5058c
* Thu Apr 24 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc2-next-20140424
- commit bea9c43
* Thu Apr 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not store the buildroot in the .hmac file
- commit ce5bd7a
* Thu Apr 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add hmaccalc to buildrequires
- commit 9cca2fa
* Wed Apr 23 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Generate a hmac singature for the kernel
  (fate#316930, bnc#856310)
- commit 2659f6f
* Wed Apr 23 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Drop conditionals for -kdump and -ps3
- commit 01fab08
* Wed Apr 23 2014 adrian@suse.de
- require kernel-obs-build
  It must be also configured as VMinstall, but is a build requires
  as well to avoid that qa and build package build parallel after kernel-default
  or kernel-xen have changed.
- commit 7a16a4e
* Wed Apr 23 2014 adrian@suse.de
- improve error logging in case the kernel module could not get loaded
- commit 3811667
* Wed Apr 23 2014 adrian@suse.de
- add block device modules for xen kernel-obs-build image
- commit 04fbb81
* Wed Apr 23 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc2-next-20140423
- commit af6a41c
* Wed Apr 23 2014 jdelvare@suse.de
- Update arm64 config file
  I'm an idiot :-(
- commit 2fe302d
* Wed Apr 23 2014 jdelvare@suse.de
- Update arm64 config file: Disable CONFIG_IIO
  It is disabled in all other non-ARM configuration files.
- commit fbc570a
* Tue Apr 22 2014 jdelvare@suse.de
- Update arm64 config file: Disable CONFIG_RTC_DRV_HID_SENSOR_TIME
  It forcibly selects CONFIG_IIO, which we don't want.
- commit 5e3b1eb
* Tue Apr 22 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc2-next-20140422
- commit 8c70d41
* Thu Apr 17 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc1-next-20140417
- commit ed47c50
* Wed Apr 16 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc1-next-20140416
- commit 7e7ed19
* Tue Apr 15 2014 jdelvare@suse.de
- Update arm config files: Disable Cadence network drivers
  Disable ARM_AT91_ETHER in all arm config files, it is only needed on
  Atmel AT91 which we don't support.
  CONFIG_MACB is useful on armv6hl/default (for ARCH_PICOXCELL) and
  armv7hl/default (for ARCH_ZYNQ.) Disable it in all other config files.
- commit ab922fa
* Tue Apr 15 2014 jdelvare@suse.de
- Disable CONFIG_NET_CADENCE on non-ARM
- commit 37a468e
* Tue Apr 15 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc1-next-20140415
- commit 9766ffc
* Tue Apr 15 2014 guillaume.gardet@opensuse.org
- Update armv7hl configs
  * config/armv7hl/default :
  - Switch CONFIG_PHYLIB from =m to =y (fix Ethernet on iMX6 boards)
  - Enable CONFIG_USB_DWC3* to add USB3 support for keystone SoC only
  - Enable CONFIG_USB_CHIPIDEA* to add USB support for iMX boards
  * config/armv7hl/exynos :
  - Enable CONFIG_USB_DWC3* to add USB3 support for Exynos SoC only
  * config/armv7hl/lpae :
  - Switch CONFIG_PHYLIB from =m to =y (fix Ethernet on iMX6 boards)
  - Enable CONFIG_USB_DWC3* to add USB3 support for keystone boards
  - Enable CONFIG_USB_CHIPIDEA* to add USB support for iMX boards
- commit 1e6049a
* Mon Apr 14 2014 mmarek@suse.cz
- Add kernel-obs-qa-xen.spec
- commit f73cebd
* Mon Apr 14 2014 jslaby@suse.cz
- Update config files.
- commit 6dad34d
* Mon Apr 14 2014 mmarek@suse.cz
- Automatically updated to 3.15-rc1-next-20140414
- commit c440d66
* Fri Apr 11 2014 mmarek@suse.cz
- Automatically updated to 3.14-next-20140411
- commit 57a8901
* Thu Apr 10 2014 jeffm@suse.com
- config: eliminate trace flavor
  With the tracing options synced to the other flavors, we can eliminate
  the trace flavor entirely.
  This implicitly disables the following options that used to be set
  in the trace flavors:
  IRQSOFF_TRACER: carries a substantial runtime overhead
  MMIOTRACE: really only needed for driver development
  FTRACE_SELFTEST: introduces noticible delays during boot
  FTRACE_STARTUP_TEST: introduces noticible delays during tracer startup
- commit 3b01d73
* Thu Apr 10 2014 jeffm@suse.com
- config: sync RING_BUFFER_BENCHMARK=m on s390x configs
  It is enabled as a module on every other config.
- commit b73dcb5
* Thu Apr 10 2014 jeffm@suse.com
- config: enable STACK_TRACER on all flavors
  It carries no runtime overhead when disabled (and it is by default).
- commit 4709110
* Thu Apr 10 2014 jeffm@suse.com
- config: enable FTRACE_SYSCALLS on all flavor files
  It incurs no runtime overhead other than a few KB of memory.
- commit 3fd1238
* Thu Apr 10 2014 jeffm@suse.com
- config: enable SCHED_TRACER on all flavors
  It doesn't have any runtime overhead except for a few KB of memory.
- commit 999e50b
* Thu Apr 10 2014 jeffm@suse.com
- config: enable ftrace features on all flavors
  We enable the following function tracing options:
- FUNCTION_TRACER
- DYNAMIC_FTRACE
- FUNCTION_PROFILER
- FUNCTION_GRAPH_TRACER
  With dynamic ftrace, there is very little runtime overhead.
  FUNCTION_GRAPH_TRACER is disabled only on ARM because it enables
  frame pointers there, so there is a real runtime cost even when it
  is disabled.
- commit 8d8cc04
* Thu Apr 10 2014 mmarek@suse.cz
- Generate kernel-obs-*.spec from templates
- commit b2e5f7c
* Thu Apr 10 2014 mmarek@suse.cz
- Automatically updated to 3.14-next-20140410
- commit 1052fe0
* Wed Apr  9 2014 mmarek@suse.cz
- Automatically updated to 3.14-next-20140409
- commit c978886
* Wed Apr  9 2014 jdelvare@suse.de
- Update debug config files: enable TTY_PRINTK
  Enabled only in debug kernels for now, as it can't be modular yet.
  Once it can be built as a module, we can enable it in other flavors
  as well.
- commit 1882ee8
* Tue Apr  8 2014 jdelvare@suse.de
- Update arm64 config file: disable CONFIG_USB_DWC3_KEYSTONE
  This driver is only needed on Texas Instruments Keystone2 platforms.
- commit 982b6fa
* Tue Apr  8 2014 jdelvare@suse.de
- Update ppc config files: disble HW_RANDOM_ATMEL
  This driver is only needed on Atmel AT91 systems.
- commit 0e28172
* Tue Apr  8 2014 jdelvare@suse.de
- Update arm/exynos config file: disable AHCI_IMX
  This driver is only used on Freescale i.MX systems so it isn't needed
  on Exynos.
- commit 2560636
* Tue Apr  8 2014 jdelvare@suse.de
- Update arm config files: Disable exynos support
  Disable exynos support in all non-exynos configuration files, as we
  have a dedicated kernel flavor for exynos.
- commit cc37534
* Tue Apr  8 2014 mmarek@suse.cz
- Automatically updated to 3.14-next-20140408
- commit 6736de1
* Mon Apr  7 2014 mmarek@suse.cz
- Automatically updated to 3.14-next-20140407
- commit dc5ddfc
* Fri Apr  4 2014 mmarek@suse.cz
- rpm/kernel-module-subpackage: Regenerated the initrd in %%posttrans
  (fate#313506)
- commit c0b6219
* Fri Apr  4 2014 jdelvare@suse.de
- Update x86_64 config files: disable CONFIG_SBC8360_WDT
  The sbc8360 driver is for a Socket 370-based single-board computer,
  so it's useless on x86-64.
- commit 8764a1f
* Fri Apr  4 2014 adrian@suse.de
- fix building initrd for SLE 12
  It does provided and load the critical kernel modules
  for building some kiwi images and cross architecture
  builds like used for aarch64.
  The kernel-obs-build.spec still contains the bits to allow
  to use it also for SLE 11.
- commit e9868b7
* Thu Apr  3 2014 jdelvare@suse.de
- Update config files: disable all of Timberdale support
  Timberdale is a companion chip for Atom CPUs in embedded in-car
  infotainment systems. We don't need that in openSUSE, really.
- commit de2f6be
* Thu Apr  3 2014 mmarek@suse.cz
- Automatically updated to 3.14-next-20140403
- commit 7fcd379
* Wed Apr  2 2014 jdelvare@suse.de
- Update config files: disable CONFIG_I2C_SI470X
  I2C access to the SI470X radio chip is only needed on embedded systems
  so it makes no sense to enable it in most of our kernel configuration
  files.
- commit 6e29852
* Wed Apr  2 2014 mmarek@suse.cz
- rpm/config.sh: Build against 13.1
- commit 3c20896
* Wed Apr  2 2014 mmarek@suse.cz
- Automatically updated to 3.14-next-20140402
- commit 9e17709
* Wed Apr  2 2014 jdelvare@suse.de
- Update config files: re-enable twofish crypto support
  Software twofish crypto support was disabled in several architectures
  since openSUSE 10.3. For i386 and x86_64 it was on purpose, because
  hardware-accelerated alternatives exist. However for all other
  architectures it was by accident.
  Re-enable software twofish crypto support in all configuration files,
  to guarantee that at least one implementation is always available,
  (bnc#871325).
- commit 84156c1
* Wed Apr  2 2014 mmarek@suse.cz
- rpm/kernel-syms.spec.in: Require pesign-obs-integration for signing KMPs
- commit e68d5fc
* Tue Apr  1 2014 jdelvare@suse.de
- Update config files: disable CONFIG_TOUCHSCREEN_W90X900
  The w90p910_ts driver only makes sense on the W90x900 architecture,
  which we do not support.
- commit 98b1cf5
* Tue Apr  1 2014 mmarek@suse.cz
- Automatically updated to 3.14-next-20140401
- commit 8938163
* Tue Apr  1 2014 jdelvare@suse.de
- Update config files: CONFIG_HID_BATTERY_STRENGTH=y
  CONFIG_HID_BATTERY_STRENGTH was already enabled on i386, x86_64 and
  most of arm. Enable this feature on all other architectures which can
  benefit from it.
- commit e032330
* Mon Mar 31 2014 jeffm@suse.de
- Update to 3.14.
- commit 078a925
* Mon Mar 31 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc8-next-20140331
- commit dd9de32
* Fri Mar 28 2014 jdelvare@suse.de
- Update i386/desktop config file: enable CONFIG_RCU_FAST_NO_HZ
  All other x86 kernels have CONFIG_RCU_FAST_NO_HZ enabled so the
  i386/desktop kernel should too.
- commit 13c63b6
* Fri Mar 28 2014 jdelvare@suse.de
- Update ppc config files: adjust filesystems modularity
  Build reiserfs, fat and vfat support as modules as we do on every
  other architecture. Also align the reiserfs debugging features on
  x86_64.
- commit 142798b
* Fri Mar 28 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc8-next-20140328
- commit e1fc3ed
* Thu Mar 27 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc8-next-20140327
- commit 83039d0
* Wed Mar 26 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc8-next-20140326
- commit 9d699f2
* Wed Mar 26 2014 jdelvare@suse.de
- Update ec2 config files: disable HID device drivers
  I don't think the HID drivers for non-standard keyboards and mice
  are needed at all on EC2.
- commit 5054928
* Tue Mar 25 2014 jeffm@suse.com
- Update to 3.14-rc8.
- commit 09ca619
* Tue Mar 25 2014 jdelvare@suse.de
- Update x86 config files: enable CONFIG_HID_BATTERY_STRENGTH
  Looks like a cool feature to support on desktop systems. As it has
  to be built-in, I'm only enabling it on x86 for now, because I don't
  know for sure how useful it would be on other architectures. Feel
  free to enable on any other architecture where it would be useful.
- commit 3e5a279
* Tue Mar 25 2014 jdelvare@suse.de
- Update ec2 config files: disable CONFIG_INPUT_FF_MEMLESS
  This helper module is useless on EC2.
- commit faaea16
* Tue Mar 25 2014 jdelvare@suse.de
- Update i386 config files: Modularize all HID device drivers
  HID device drivers are modularized in all config files except arm*
  and desktop, so i386/pae, i386/trace and i386/xen should do the same.
- commit 27eba98
* Tue Mar 25 2014 jdelvare@suse.de
- Update i386 config files: CONFIG_HID=y
  Align the CONFIG_HID setting of the i386/debug, i386/default and
  i386/vanilla config files with what is done in every other config
  file (but s390x and ec2.)
- commit f7bcd52
* Tue Mar 25 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc7-next-20140325
- commit 57b6833
* Mon Mar 24 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc7-next-20140324
- commit 3d53dc9
* Fri Mar 21 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc7-next-20140321
- commit af57c2a
* Thu Mar 20 2014 jdelvare@suse.de
- Update s390x config files: disable CONFIG_INPUT_FF_MEMLESS
  It was set by mistake, obviously.
- commit b1528a7
* Thu Mar 20 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc7-next-20140320
- commit 450acc8
* Wed Mar 19 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc7-next-20140319
- commit 11eac46
* Wed Mar 19 2014 tiwai@suse.de
- Enable Socketcan again for i386 and x86_64 (bnc#858607)
- commit 08df362
* Tue Mar 18 2014 jdelvare@suse.de
- Update vanilla config files: enable console rotation
  It's enabled in all other kernel flavors so it should be enabled in
  vanilla too.
- commit 25d8d21
* Tue Mar 18 2014 jdelvare@suse.de
- config: set CONFIG_X86_INTEL_LPSS in trace and vanilla
  Trying to keep the trace and vanilla kernels in sync with default.
- commit e96b8cd
* Tue Mar 18 2014 jdelvare@suse.de
- Align the x86_64 debug config file on the default config
  For real this time.
- commit 67fd5fb
* Tue Mar 18 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc7-next-20140318
- commit 0fa17b5
* Mon Mar 17 2014 jeffm@suse.de
- Update to 3.14-rc7.
- Eliminated 1 patch.
- commit fc95709
* Mon Mar 17 2014 jdelvare@suse.de
- Align the x86_64 debug config file on the default config
  This makes it much easier to validate that the debug config file only
  diverges from default by debug and testing options.
- commit f526605
* Mon Mar 17 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc6-next-20140317
- commit 44ed0eb
* Mon Mar 17 2014 jdelvare@suse.de
- config.conf: ia64 is history
- Delete config/ia64/debug.
- Delete config/ia64/default.
- Delete config/ia64/trace.
- Delete config/ia64/vanilla.
- commit b2d5d31
* Mon Mar 17 2014 tiwai@suse.de
- Enable CONFIG_IRDA_FAST_RR=y (bnc#860502)
- commit f3b3714
* Mon Mar 17 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc6-next-20140314
- commit 671d26e
* Sat Mar 15 2014 jdelvare@suse.de
- Update x86_64 config files: Disable AMD Elan SC520 drivers
  The AMD Elan SC520 is a 32-bit x86 processor, related drivers are
  useless on other architectures.
- commit 0de8b16
* Sat Mar 15 2014 jdelvare@suse.de
- Update x86_64 and ia64 config files: Disable SC1200 drivers
  The SC1200 is a SoC based on the Geode GX1 32-bit x86 processor, so
  its drivers are useless on other architectures.
- commit 34c589f
* Fri Mar 14 2014 jdelvare@suse.de
- Update config files: Restore CONFIG_THERMAL_HWMON
  Setting CONFIG_THERMAL=y in commit e60ddcfe had the side effect of
  disabling CONFIG_THERMAL_HWMON in many configs that didn't have
  CONFIG_HWMON=y. So revert that change in all affected config files.
  Sorry for overlooking that originally.
- commit 22678a2
* Fri Mar 14 2014 jdelvare@suse.de
- Update config files: Drop all Geode-related drivers
  The Geode was a 32-bit x86 CPU, so all drivers for its companion
  chips (CS55xx) are useless on other architectures. Same for OT200
  drivers, as the Bachmann OT200 device was based on a Geode CPU.
- commit ac34a52
* Fri Mar 14 2014 jdelvare@suse.de
- Update arm and ppc config files: Drop OLPC-related driver
  OLPC drivers are only useful on i386.
- commit 07440f1
* Fri Mar 14 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc6-next-20140313
- commit c324965
* Thu Mar 13 2014 jdelvare@suse.de
- Update debug config files: mac80211 debug options
  Enable all mac80211 debug options in all debug kernel flavors.
- commit c1ae613
* Thu Mar 13 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc6-next-20140312
- commit 5457b94
* Wed Mar 12 2014 guillaume.gardet@opensuse.org
- config: Fix version string for armv7hl/lpae
- commit ddab49a
* Wed Mar 12 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc6-next-20140311
- commit 613d627
* Wed Mar 12 2014 guillaume.gardet@opensuse.org
- ARM: Re-enable and update configs
- commit 8443843
* Mon Mar 10 2014 jeffm@suse.com
- Update to 3.14-rc6.
- commit 1aaed1c
* Fri Mar  7 2014 mmarek@suse.cz
- rpm/mkspec: Generate a per-architecture per-package _constraints file
- commit 65a07f7
* Fri Mar  7 2014 mmarek@suse.cz
- rpm/mkspec: Remove dead code
- commit 3fc95f5
* Fri Mar  7 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc5-next-20140307
- commit 76b63a5
* Thu Mar  6 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc5-next-20140306
- commit 94e1156
* Thu Mar  6 2014 jdelvare@suse.de
- Update config files: CONFIG_THERMAL=y
  The generic thermal module is used by several ACPI components
  (processor, fan, thermal and video) and a few other drivers. So
  in practice it will end up being loaded on almost all systems
  which support ACPI. It is small so build it into the kernel to
  improve boot speed on all ACPI-enabled architectures (i386,
  x86_64 and ia64.)
- commit ec3b91e
* Wed Mar  5 2014 jeffm@suse.com
- Update to 3.14-rc5.
- commit fb05247
* Wed Mar  5 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc5-next-20140305
- commit 43e6c93
* Tue Mar  4 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc5-next-20140304
- commit 07bbb6f
* Tue Mar  4 2014 jdelvare@suse.de
- Update ppc64le config files: disable STE_MODEM_RPROC
  Disable config option STE_MODEM_RPROC on all ppc64le flavors, because
  it draws dependencies which aren't available on ppc64le:
  warning: (REMOTEPROC && RPMSG) selects VIRTUALIZATION which has unmet direct dependencies (!CPU_LITTLE_ENDIAN)
- commit 8709b33
* Mon Mar  3 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc4-next-20140303
- commit 71378e1
* Sat Mar  1 2014 mmarek@suse.cz
- rpm/mkspec: Fix whitespace in NoSource lines
- commit 6320617
* Sat Mar  1 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not zero modules.dep before using it
  (bnc#866075)
- commit b67b660
* Fri Feb 28 2014 jdelvare@suse.de
- Update config files: modularize BLK_DEV_MD, disable MD_AUTODETECT
  Michal Marek says:
  I think that the reason why BLK_DEV_MD is built in is
  config MD_AUTODETECT
    bool "Autodetect RAID arrays during kernel boot"
    depends on BLK_DEV_MD=y
  but since we compile the raid presonalities as modules, this cannot
  work. Also, we use the initrd even in the trivial cases, so why bother
  about root-on-md.
- commit 275d732
* Fri Feb 28 2014 jdelvare@suse.de
- Update config files.
  Modularize the following helper drivers:
  INET_LRO, NET_CLS_CGROUP, DNS_RESOLVER
  They had to be built-in before due to dependencies, but this is no
  longer the case, so we can modularize them again.
- commit 85f4d8f
* Fri Feb 28 2014 jdelvare@suse.de
- Update x86 config files: CONFIG_X86_MSR=m
  The msr driver creates /dev/cpu/*/msr through which you can poke
  at all the MSRs if you have CAP_SYS_RAWIO. We prefer to be able
  to remove that module if it is not needed.
- commit cea9e52
* Fri Feb 28 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec: Drop useless ExclusiveArch statement
- commit 5cdf1da
* Fri Feb 28 2014 guillaume.gardet@oliseo.fr
- config: Update armv7/exynos
- Add sound support
- Add I2C/SPI support
- commit a77ed84
* Fri Feb 28 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc4-next-20140228
- commit dcb98b0
* Fri Feb 28 2014 jdelvare@suse.de
- Update config files: CONFIG_ISO9660_FS=m
  There is no good reason why isofs would be built into the kernel.
  Most systems don't need it after installation, and reportedly
  mkinitrd etc. can deal with it as a module just fine.
- commit a44ffb1
* Thu Feb 27 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc4-next-20140227
- commit d5fae9a
* Wed Feb 26 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc4-next-20140226
- commit cb2983b
* Tue Feb 25 2014 jdelvare@suse.de
- Update config files: CONFIG_AUTOFS4_FS=y
  systemd requires autofs, so autofs4.ko will always be loaded on boot.
  For performance reasons, it makes sense to build it into the kernel
  (bnc#863771).
- commit 3a6d348
* Tue Feb 25 2014 jbeulich@suse.com
- Update Xen patches to 3.14-rc4 and c/s 1252.
- privcmd: allow preempting long running user-mode originating
  hypercalls (bnc#861093).
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- scripts/check-cvs-add: Disable config checking for now.
- commit 75e87f1
* Tue Feb 25 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc4-next-20140225
- commit 40c5e8b
* Mon Feb 24 2014 tiwai@suse.de
- Obsolete compat-wireless, rts5229 and rts_pstor KMPs
  These are found in SLE11-SP3, now replaced with the upstream drivers.
- commit 37738dd
* Mon Feb 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not obsolete ocfs2-kmp (bnc#865259)865259
- commit c8661b5
* Mon Feb 24 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete the -base package from SLE11 (bnc#865096)
- commit 3f926c3
* Mon Feb 24 2014 jeffm@suse.com
- config: disable PINCTRL_MSM and PINCTRL_MSM8X4
  These options were enable accidentally during the 3.14-rc1 update for
  just the i386/default config.
- commit 3944522
* Mon Feb 24 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc3-next-20140224
- commit eaf2ed3
* Mon Feb 24 2014 jeffm@suse.com
- Update to 3.14-rc4.
- Eliminated 1 patch.
- commit 51e723d
* Wed Feb 19 2014 jeffm@suse.com
- dmraid45: removed driver.
  This functionality should be offered by the dmraid driver.
- commit 3759086
* Mon Feb 17 2014 jeffm@suse.com
- config: CONFIG_BCM_KONA_USB2_PHY=n on s390
- commit 88af7b5
* Mon Feb 17 2014 jeffm@suse.com
- Update to 3.14-rc3.
- commit 8ce76dd
* Mon Feb 17 2014 jeffm@suse.com
- Update vanilla config files.
- commit 7dc1c47
* Fri Feb 14 2014 mmarek@suse.cz
- rpm/kernel-obs-build.spec: Do not mount /sys, the build script does it
- commit f11b02a
* Fri Feb 14 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc2-next-20140214
- commit 9f913e5
* Fri Feb 14 2014 jdelvare@suse.de
- Update config files: Disable TS5500-specific drivers
  These drivers are useless without TS5500 board support: mtd-ts5500,
  gpio-ts5500 and max197.
- commit 631746d
* Fri Feb 14 2014 jslaby@suse.cz
- Linux 3.13.3 (bnc#799216).
- Refresh patches.xen/xen-x86-EFI.
- Refresh patches.xen/xen3-patch-3.12.
- Delete
  patches.drivers/drm-cirrus-Correct-register-values-for-16bpp.
- Update config files.
- commit 644071a
* Thu Feb 13 2014 dvaleev@suse.de
- rpm/kernel-obs-build.spec: Fix for ppc64le
- commit 50c4205
* Thu Feb 13 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc2-next-20140213
- commit ab1705a
* Wed Feb 12 2014 mq@suse.cz
- Scripts: .nosrc.rpm should contain only the specfile (bnc #639379)
- commit afe62e0
* Wed Feb 12 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc2-next-20140212
- commit b0be8c7
* Wed Feb 12 2014 lpechacek@suse.cz
- doc/README.PATCH-POLICY.SUSE: updated links
- commit ac58062
* Tue Feb 11 2014 mq@suse.cz
- Spec: zeroing modules.dep to get identical builds among different machines
- commit a1c5879
* Tue Feb 11 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc2-next-20140211
- commit a2164b5
* Tue Feb 11 2014 mmarek@suse.cz
- rpm/guards: Report which config file has problem in --check mode
- commit b39543d
* Mon Feb 10 2014 jeffm@suse.com
- Update to 3.14-rc2.
- Eliminated 1 patch.
- commit cf40344
* Mon Feb 10 2014 mmarek@suse.cz
- doc/README.SUSE: Update to match the current package layout
- commit f357abb
* Mon Feb 10 2014 mmarek@suse.cz
- Add the README.SUSE file to the packaging branch
- commit 11905ea
* Mon Feb 10 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc1-next-20140210
- commit b439894
* Fri Feb  7 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc1-next-20140207
- commit 0a97f72
* Thu Feb  6 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc1-next-20140206
- commit 360f034
* Wed Feb  5 2014 mmarek@suse.cz
- Change also BuildRequires from module-init-tools to modutils
- commit f650166
* Wed Feb  5 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc1-next-20140205
- commit 000da2f
* Tue Feb  4 2014 jeffm@suse.com
- Update to 3.14-rc1.
- 19 patches eliminated.
- Xen is disabled.
- ARM is disabled.
- commit edcefdd
* Tue Feb  4 2014 mmarek@suse.cz
- Automatically updated to 3.14-rc1-next-20140204
- commit 6b3d745
* Mon Feb  3 2014 mmarek@suse.cz
- Automatically updated to 3.13-next-20140203
- commit 7a2eada
* Fri Jan 31 2014 mmarek@suse.cz
- Automatically updated to 3.13-next-20140131
- commit 36321fe
* Fri Jan 31 2014 adrian@suse.de
- avoid double /sys mounts for kernel-obs-build, OBS is doing this meanwhile
- commit 3ea39a4
* Thu Jan 30 2014 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require 'modutils' also in the subpackages
- commit 91f0a2e
* Thu Jan 30 2014 mmarek@suse.cz
- Reformat the spec files to what the buildservice expects
- commit 0b9e9a1
* Thu Jan 30 2014 mmarek@suse.cz
- Automatically updated to 3.13-next-20140130
- commit 62ab4d1
* Wed Jan 29 2014 mmarek@suse.cz
- Automatically updated to 3.13-next-20140129
- commit be49ae5
* Tue Jan 28 2014 mmarek@suse.cz
- Automatically updated to 3.13-next-20140128
- commit c6d4ca3
* Mon Jan 27 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add README.PATCH-POLICY.SUSE as source file
- commit 9c9ce61
* Mon Jan 27 2014 mmarek@suse.cz
- Drop the _constraints file, we are using the prjconf setting for now
- commit a0aa890
* Fri Jan 24 2014 mmarek@suse.cz
- Automatically updated to 3.13-next-20140124
- commit 9e98e0d
* Thu Jan 23 2014 mmarek@suse.cz
- Automatically updated to 3.13-next-20140123
- commit 576673f
* Wed Jan 22 2014 jbeulich@suse.com
- Update Xen patched to 3.13-final and c/s 1248.
- Update EC2 config files (restore CONFIG_DEBUG_INFO).
- commit 02599db
* Wed Jan 22 2014 mmarek@suse.cz
- Automatically updated to 3.13-next-20140122
- commit 48c5332
* Tue Jan 21 2014 mmarek@suse.cz
- Automatically updated to 3.13-next-20140121
- commit d59da50
* Tue Jan 21 2014 jeffm@suse.de
- Update to 3.13.
- commit 8af008e
* Mon Jan 20 2014 mmarek@suse.cz
- Automatically updated to 3.13-rc8-next-20140120
- commit a08648a
* Fri Jan 17 2014 mmarek@suse.cz
- Automatically updated to 3.13-rc8-next-20140117
- commit 571c196
* Thu Jan 16 2014 mmarek@suse.cz
- Automatically updated to 3.13-rc8-next-20140116
- commit b188ce3
* Wed Jan 15 2014 mmarek@suse.cz
- Automatically updated to 3.13-rc8-next-20140115
- commit 2ad486e
* Tue Jan 14 2014 mmarek@suse.cz
- rpm/kernel-source.spec.in: Require kernel-devel%%variant
- commit 810ea41
* Tue Jan 14 2014 mmarek@suse.cz
- Automatically updated to 3.13-rc8-next-20140114
- commit b0fdc5a
* Tue Jan 14 2014 mhocko@suse.cz
- Update config files.
  Disable CONFIG_MEMCG_SWAP_ENABLED because it got enabled by accident.
  The CONFIG_MEMCG_SWAP is enabled but the accounting has to be explicitly
  allowed by swap_account=1 kernel command line parameter
- commit 4b52d8e
* Mon Jan 13 2014 jeffm@suse.com
- Update to 3.13-rc8.
- commit 096745e
* Mon Jan 13 2014 mmarek@suse.cz
- Automatically updated to 3.13-rc8-next-20140113
- commit 2caeada
* Fri Jan 10 2014 mmarek@suse.cz
- rpm/mkspec: Fix for older Perl
- commit ecf021e
* Fri Jan 10 2014 mmarek@suse.cz
- rpm/mkspec: Add .changes file for kernel-obs-*.spec as well
- commit bd3c299
* Fri Jan 10 2014 ro@suse.de
- rpm/kernel-obs-build.spec: Fix building in chroot instead of Xen
- commit 57e89b6
* Fri Jan 10 2014 mmarek@suse.cz
- Automatically updated to 3.13-rc7-next-20140110
- commit 911b330
* Thu Jan  9 2014 jdelvare@suse.de
- Disable CONFIG_MODULE_FORCE_UNLOAD (bnc#857673)
  Forcing module unloading can't lead to anything good. If reference
  counting is wrong then it should be fixed. If the reference count is
  right and a regular (unforced) unloading doesn't work, then a forced
  unloading can only lead to chaos and ultimately a kernel crash.
- commit 4127d31
* Thu Jan  9 2014 afaerber@suse.de
- config: armv6hl: Extend default config for Raspberry Pi
  Enable CONFIG_FB_SIMPLE as that's what U-Boot exposes in DT.
- commit 84739e1
* Thu Jan  9 2014 mmarek@suse.cz
- Automatically updated to 3.13-rc7-next-20140109
- commit 76aee85
* Wed Jan  8 2014 afaerber@suse.de
- config: armv6hl: Extend default config for Raspberry Pi
  Activate CONFIG_ARM_ATAG_DTB_COMPAT for it to receive U-Boot bootargs.
  Enable BCM2835_{I2C,WDT}, MMC_SDHCI_BCM2835, USB_HCD_BCMA as modules.
- commit dce309f
* Wed Jan  8 2014 jbeulich@suse.com
- Update Xen patches to 3.13-rc7 and c/s 1245.
- netback: bump tx queue length (bnc#849404).
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 7f87e21
* Wed Jan  8 2014 mmarek@suse.cz
- Automatically updated to 3.13-rc7-next-20140108
- commit ff9f9f4
* Tue Jan  7 2014 agraf@suse.de
- Delete config/armv7hl/cubox.
- commit 01020d6
* Tue Jan  7 2014 mmarek@suse.cz
- Automatically updated to 3.13-rc7-next-20140107
- commit 52b7348
* Mon Jan  6 2014 jeffm@suse.com
- Update to 3.13-rc7.
- Eliminated 1 patch.
- commit 9a1f1d6
* Mon Jan  6 2014 jdelvare@suse.de
- Disable CONFIG_I2C_VIA in config/x86_64/desktop too
- commit 1f0c9fb
* Mon Jan  6 2014 jdelvare@suse.de
- Disable CONFIG_I2C_VIA, no 64-bit system would need it
- commit 6bd7148
* Mon Jan  6 2014 mmarek@suse.cz
- Automatically updated to 3.13-rc7-next-20140106
- commit f186d0d
* Fri Jan  3 2014 mmarek@suse.cz
- Switch to linux-*.tar.xz
- commit 27d9f61
* Fri Jan  3 2014 mmarek@suse.cz
- Add support for linux-*.tar.xz to the spec files
- commit d12c880
* Thu Jan  2 2014 agraf@suse.de
- ARM: Reenable and update configs
- commit 520cd7d
* Thu Jan  2 2014 jeffm@suse.de
- Update to 3.13-rc6.
- commit 84f7a6c
* Thu Dec 26 2013 jeffm@suse.de
- Update to 3.13-rc5.
- Eliminated 3 patches.
- commit f90d6df
* Tue Dec 24 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc5-next-20131224
- commit 1cec9f0
* Mon Dec 23 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc5-next-20131223
- commit 71a7e6c
* Sat Dec 21 2013 jeffm@suse.de
- Update to 3.13-rc4.
- ppc64le/vanilla appears to have not been resynced when copied.
- commit a78550f
* Fri Dec 20 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc4-next-20131220
- commit e76292a
* Fri Dec 20 2013 agraf@suse.de
- Update config files: Disable relocation on ppc64le (it's broken)
- commit e6217e9
* Thu Dec 19 2013 agraf@suse.de
- Update config files: Disable kvm for ppc64le (not implemented upstream)
- commit 4bbc90d
* Thu Dec 19 2013 agraf@suse.de
- Add ppc64le support (configs are a copy of the ppc64 ones with LE enabled)
- commit a424835
* Thu Dec 19 2013 agraf@suse.de
- Update config files
  - remove epapr bytechan interface, we don't support booke
- commit 78753b9
* Thu Dec 19 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc4-next-20131219
- commit 07b4df6
* Wed Dec 18 2013 tiwai@suse.de
- Disable simplefb and x86 sysfb due to breakage (bnc#855821)
- commit ce297e4
* Wed Dec 18 2013 adrian@suse.de
- Add kernel-obs-build to use the distribution kernel within OBS VM builds.
  Add kernel-obs-qa to test that the kernel is booting within OBS VMs. It may run also further tests later on.
- commit e9cfd5c
* Wed Dec 18 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc4-next-20131218
- commit a708919
* Tue Dec 17 2013 mmarek@suse.cz
- Port module signing changes from SLE11-SP3 (fate#314508)
- commit 8a264a3
* Tue Dec 17 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc4-next-20131217
- commit e4c5c83
* Mon Dec 16 2013 jkosina@suse.cz
- doc/README.PATCH-POLICY.SUSE: add patch policy / best practices document
- commit 60893d6
* Mon Dec 16 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc4-next-20131216
- commit 86e2b88
* Fri Dec 13 2013 tiwai@suse.de
- Add missing CONFIG_PINCTRL_SINGLE kconfig setups
- commit b0bb087
* Fri Dec 13 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc3-next-20131213
- commit 8556cf1
* Thu Dec 12 2013 jdelvare@suse.de
- config.conf: s390 is history
- Delete config/s390/s390.
- Delete config/s390/trace.
- Delete config/s390/vanilla.
- commit 8dce845
* Thu Dec 12 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc3-next-20131212
- commit 5a6455c
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Spelling fix
- commit 2e074cb
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Delete dead code
- commit 98077a9
* Wed Dec 11 2013 jdelvare@suse.de
- rpm/guards: Typo fix from upstream
- commit ce654f8
* Wed Dec 11 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc3-next-20131211
- commit af8b0cd
* Wed Dec 11 2013 stefan.bruens@rwth-aachen.de
- config: set CONFIG_X86_INTEL_LPSS and CONFIG_I2C_DESIGNWARE_PLATFORM
  Enable INTEL LPSS (Low Power SubSystem) for LynxPoint chipsets (bnc#849125)
  and DesignWare (platform) i2c bus driver (bnc#849338).
  The DesignWare i2c driver depends on the clock subsystem.
- commit ee13b5b
* Tue Dec 10 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc3-next-20131210
- commit 36237c1
* Mon Dec  9 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc3-next-20131209
- commit b38fc47
* Sun Dec  8 2013 jeffm@suse.com
- Update to 3.13-rc3.
- commit 93e11a7
* Fri Dec  6 2013 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add the OBS _constraints file as source
- commit 17282e4
* Fri Dec  6 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc2-next-20131206
- commit 7b76a12
* Thu Dec  5 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc2-next-20131205
- commit d453e9b
* Wed Dec  4 2013 jeffm@suse.de
- config: enable CONFIG_EXPERT
  3.10 introduced Kconfig rules that automatically builds in
  uncommon HID drivers if EXPERT is not set.
  This commit does not introduce any other config changes.
- commit 31061f3
* Wed Dec  4 2013 tiwai@suse.de
- config: CONFIG_CHECKPOINT_RESTORE=y and CONFIG_MEM_SOFT_DIRTY=y on x86_64
- commit 0ed3710
* Wed Dec  4 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc2-next-20131204
- commit ea9531a
* Tue Dec  3 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc2-next-20131203
- commit 9d99d08
* Mon Dec  2 2013 jeffm@suse.com
- Update to 3.13-rc2.
  - Eliminated 1 patch.
- commit 84511e5
* Fri Nov 29 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc1-next-20131129
- commit 099c61b
* Fri Nov 29 2013 tiwai@suse.de
- Build mei and mei_me as modules (bnc#852656)
- commit 06e7f53
* Wed Nov 27 2013 duwe@suse.de
- pstore: automatically dump and clean dmesg entries
  (fate#315232).
- Update config files.
- commit 8e11a7f
* Wed Nov 27 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc1-next-20131127
- commit d45ec7b
* Tue Nov 26 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc1-next-20131126
- commit 4032133
* Mon Nov 25 2013 mmarek@suse.cz
- Automatically updated to 3.13-rc1-next-20131125
- commit 53c4f98
* Sat Nov 23 2013 jeffm@suse.com
- Update to 3.13-rc1.
- Eliminated 7 patches.
- Xen is disabled.
- ARM needs config updates.
- commit 84f5973
* Fri Nov 22 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131122
- commit a47b10d
* Thu Nov 21 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131121
- commit f21ff24
* Thu Nov 21 2013 guillaume.gardet@oliseo.fr
- Add USB PHY support (needed to get USB and Ethernet working on beagle and panda boards) Add CONFIG_PINCTRL_SINGLE=y to be able to use Device tree (at least for beagle and panda boards) Add ARM SoC sound support Add SPI bus support Add user-space access to I2C and SPI
- commit c78b336
* Thu Nov 21 2013 guillaume.gardet@oliseo.fr
- Set CONFIG_GPIO_TWL4030 as built-in (instead of module) as a requirement to boot on SD card on beagleboard xM
- commit 5a6e0d9
* Wed Nov 20 2013 jslaby@suse.cz
- Update config files (fate#315172).
- commit 09a3120
* Wed Nov 20 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131120
- commit 89aaa57
* Tue Nov 19 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131119
- commit e7c1ad8
* Mon Nov 18 2013 mmarek@suse.cz
- Disable CONFIG_MFD_AS3722 as it does not build without builtin i2c
- commit 3af95e3
* Mon Nov 18 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131118
- commit 24205cd
* Sat Nov 16 2013 jeffm@suse.com
- config: build uncommon HID drivers as modules
- commit dbd95bb
* Sat Nov 16 2013 jeffm@suse.com
- config: sync HID=y on x86_64/debug config
- commit 8233d3c
* Fri Nov 15 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131115
- commit 58f6df8
* Fri Nov 15 2013 mmarek@suse.cz
- Disable CONFIG_GPIO_INTEL_MID and CONFIG_ARM_ARCH_TIMER_EVTSTREAM
  As suggested by JeanL GPIO_INTEL_MID cannot be modularized and
  ARM_ARCH_TIMER_EVTSTREAM is a Kconfig bug.
- commit a659b53
* Thu Nov 14 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131114
- commit 9efcd50
* Wed Nov 13 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131113
- commit f37ff74
* Tue Nov 12 2013 jdelvare@suse.de
- armv6hl, armv7hl: Update config files.
  Set CONFIG_BATMAN_ADV_BLA=y as all other kernel configuration files
  have.
- commit 1355b59
* Fri Nov  8 2013 jdelvare@suse.de
- Update config files:
  * CONFIG_BATMAN_ADV_NC=y, because other BATMAN_ADV options are all
  enabled so why not this one.
  * CONFIG_GPIO_SCH=m, CONFIG_GPIO_PCH=m, because we support all other
  features of these pieces of hardware.
  * CONFIG_INTEL_POWERCLAMP=m, because this small driver might be
  useful in specific cases, and there's no obvious reason not to
  include it.
- commit f40d115
* Fri Nov  8 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131108
- commit b2a122c
* Thu Nov  7 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131107
- commit 48a224e
* Wed Nov  6 2013 duwe@suse.de
- fate#316581: CONFIG_IBM_BSR y -> m
- commit 9999bea
* Wed Nov  6 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131106
- commit ab64a5e
* Tue Nov  5 2013 mmarek@suse.cz
- Automatically updated to 3.12-next-20131105
- commit efa9a14
* Mon Nov  4 2013 mmarek@suse.cz
- Automatically updated to 3.12-rc7-next-20131104
- commit de40b42
* Mon Nov  4 2013 jeffm@suse.com
- Update config files.
- commit d92e8b0
* Fri Nov  1 2013 mmarek@suse.cz
- Automatically updated to 3.12-rc7-next-20131101
- commit aa61395
* Thu Oct 31 2013 mmarek@suse.cz
- Automatically updated to 3.12-rc7-next-20131031
- commit e4dc61f
* Wed Oct 30 2013 mmarek@suse.cz
- Automatically updated to 3.12-rc7-next-20131030
- commit 00046e0
* Tue Oct 29 2013 mmarek@suse.cz
- Automatically updated to 3.12-rc7-next-20131029
- commit 53166c5
* Mon Oct 28 2013 jeffm@suse.de
- Update to 3.12-rc7.
- commit 292af54
* Mon Oct 21 2013 jeffm@suse.com
- Update to 3.12-rc6.
- commit 9278298
* Wed Oct 16 2013 jbeulich@suse.com
- Update x86 Xen config files (RTC_DRV_EFI=y).
- commit a14b215
* Wed Oct 16 2013 jbeulich@suse.com
- Update Xen patches to 3.12-rc5.
- config.conf: Re-enable Xen configs.
- Update config files.
- Delete patches.xen/xen3-010-acpi_initrd_override_tables.patch.
- commit 238fae9
* Fri Oct 11 2013 jeffm@suse.com
- Update to 3.12-rc4.
- commit 3e4e98b
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/split-modules: Check module support only if the -extra package is requested
- commit add86bf
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/split-modules: Remove unused options
- commit 3736315
* Fri Oct  4 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix creating the kernel-*-extra package
  CONFIG_ENTERPRISE_SUPPORT has been renamed to CONFIG_SUSE_KERNEL_SUPPORTED
- commit 9e5b6fe
* Thu Oct  3 2013 mmarek@suse.cz
- Enable CONFIG_DRM_QXL and mark qxl.ko as supported (fate#316469)
- commit df2bb0e
* Tue Oct  1 2013 jeffm@suse.com
- Update to 3.12-rc3.
- commit b27ca60
* Tue Oct  1 2013 mmarek@suse.cz
- Disable CONFIG_FB_TMIO (Sharp Zaurus) on non-arm configs.
- commit 0cd3baf
* Tue Oct  1 2013 mmarek@suse.cz
- Disable CONFIG_FB_GEODE, as the individual GEODE options are already disabled
- commit 182d653
* Mon Sep 30 2013 mmarek@suse.cz
- Always include the git commit in KOTD builds
  This allows us not to set it explicitly in builds submitted to the
  official distribution (bnc#821612, bnc#824171).
- commit a80e5ef
* Mon Sep 30 2013 mmarek@suse.cz
- Do not build udlfb, to avoid conflict with udl (fate#316407)
- commit 9f71248
* Mon Sep 30 2013 mmarek@suse.cz
- Disable fb drivers that have been blacklisted for a long time
  via /etc/modprobe.d/50-blacklist.conf.
- commit 4acf19b
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add obsolete KMPs from sle11-sp1
- commit 221133c
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Make sure that all KMP obsoletes are
  versioned (bnc#821465).
- commit d802bf2
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Provide obsoleted KMPs (bnc#753353)
- commit f5449e6
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove unversioned provides/obsoletes
  for packages that were only seen in openSUSE releases up to 11.0.
  (bnc#821465).
- commit 7e1f4b6
* Fri Sep 27 2013 ohering@suse.de
- Input: add a driver to support Hyper-V synthetic keyboard
  (fate#315887).
- Update config files.
- commit ad52630
* Fri Sep 27 2013 jeffm@suse.com
- config: disable DGAP on s390
  It requires ioremap, which isn't available on s390. It's a staging
  driver anyway.
- commit 49808e0
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-flavors, rpm/mkspec: Add version information to obsolete
  flavors (bnc#821465).
- rpm/kernel-binary.spec.in: Move the xenpae obsolete to the
  old-flavors file.
- commit 25c1b0d
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-flavors: Convert the old-packages.conf file to a flat
  list.
- rpm/mkspec: Adjust.
- rpm/old-packages.conf: Delete.
- commit 4037e16
* Fri Sep 27 2013 mmarek@suse.cz
- rpm/old-packages.conf: Drop bogus obsoletes for "smp" (bnc#821465)
- commit 50c4c23
* Fri Sep 27 2013 mmarek@suse.cz
- Automatically updated to 3.12-rc2-next-20130927
- commit 9e1bb02
* Fri Sep 27 2013 jdelvare@suse.de
- config/*/debug: Enable FSCACHE_DEBUG and CACHEFILES_DEBUG.
- commit ed2effc
* Thu Sep 26 2013 jeffm@suse.com
- config.conf: Re-enable s390x and ia64 configs
- commit f3ce157
* Thu Sep 26 2013 mmarek@suse.cz
- Automatically updated to 3.12-rc2-next-20130926
- commit 0f5fd42
* Thu Sep 26 2013 jdelvare@suse.de
- Build gpio-ucb1400 as a module
- commit 4d3e431
* Wed Sep 25 2013 agraf@suse.de
- ARM: Update config files: Use lpae for multiarch, exynos for LPAE exynos5
- commit 5f7d24b
* Wed Sep 25 2013 agraf@suse.de
- config.conf:
- Update config files for ARM on 3.12.
- commit 42cc3a2
* Wed Sep 25 2013 mmarek@suse.cz
- Automatically updated to 3.12-rc2-next-20130925
- commit d3f276b
* Tue Sep 24 2013 jeffm@suse.com
- Update to 3.12-rc2.
- Eliminated 3 patches.
- commit ca91ac5
* Tue Sep 24 2013 jeffm@suse.com
- Update to 3.12-rc1.
- Eliminated 42 patches.
- Xen is disabled.
- ARM is disabled.
- commit e07030b
* Tue Sep 24 2013 mmarek@suse.cz
- Automatically updated to 3.12-rc2-next-20130924
- commit 38a9342
* Mon Sep 23 2013 mmarek@suse.cz
- Automatically updated to 3.12-rc1-next-20130923
- commit 00753a0
* Wed Sep 18 2013 duwe@suse.de
- Increase NR_CPUS on ppc64 to 2048 (fate#315438)
- commit f16637a
* Tue Sep 17 2013 jslaby@suse.cz
- Update config files.
  Fix ZSWAP on vanillas.
- commit 53326c8
* Tue Sep 17 2013 jeffm@suse.com
- config: Update missing ZSWAP configs.
- commit b9c290c
* Thu Sep 12 2013 jeffm@suse.com
- config: Enable CONFIG_ZSWAP (bnc#839064).
  It's built-in but a no-op without zswap.enabled=1 on the kernel
  command line.
- commit 2ee51f4
* Thu Sep 12 2013 mmarek@suse.cz
- Automatically updated to 3.11-next-20130912
- commit 9f04313
* Wed Sep 11 2013 mmarek@suse.cz
- Automatically updated to 3.11-next-20130911
- commit f997bdc
* Tue Sep 10 2013 mmarek@suse.cz
- Automatically updated to 3.11-next-20130910
- commit f1f5c2c
* Mon Sep  9 2013 mmarek@suse.cz
- Automatically updated to 3.11-next-20130909
- commit 778a1c2
* Fri Sep  6 2013 rgoldwyn@suse.de
- Update config files to enable GFS DLM locking.
- commit 2e2b598
* Fri Sep  6 2013 mmarek@suse.cz
- Automatically updated to 3.11-next-20130906
- commit 6b2fc77
* Thu Sep  5 2013 mmarek@suse.cz
- Automatically updated to 3.11-next-20130905
- commit 9e5f629
* Wed Sep  4 2013 mmarek@suse.cz
- Automatically updated to 3.11-next-20130904
- commit 7386611
* Tue Sep  3 2013 jeffm@suse.com
- Update to 3.11-final.
- commit c2b86e8
* Tue Sep  3 2013 mmarek@suse.cz
- Automatically updated to 3.11-next-20130903
- commit 5432aa3
* Mon Sep  2 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc7-next-20130902
- commit a598239
* Fri Aug 30 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc7-next-20130830
- commit 6deb96c
* Thu Aug 29 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc7-next-20130829
- commit c0d2a2a
* Wed Aug 28 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc7-next-20130828
- commit 88c7ac1
* Tue Aug 27 2013 jeffm@suse.com
- rpm/kernel-docs.spec.in: Fix missing whitespace error in description
- commit 280c88e
* Tue Aug 27 2013 jeffm@suse.com
- Update to 3.11-rc7.
- commit 811b92b
* Thu Aug 22 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc6-next-20130822
- commit 4cdd2cd
* Wed Aug 21 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc6-next-20130821
- commit 6cea5ef
* Tue Aug 20 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc6-next-20130820
- commit d41fa33
* Mon Aug 19 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc6-next-20130819
- commit 2f3e3b0
* Fri Aug 16 2013 mmarek@suse.cz
- Disable CONFIG_USB_HCD_TEST_MODE
- commit a2d155a
* Fri Aug 16 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc5-next-20130816
- commit d4b4ebf
* Thu Aug 15 2013 jbeulich@suse.com
- Update Xen patches to 3.11-rc5.
- config.conf: Re-enable Xen configs
- Delete patches.xen/xen-sections.
- commit 92f32d0
* Thu Aug 15 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc5-next-20130815
- commit 2ea9889
* Wed Aug 14 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc5-next-20130814
- commit d0b5f27
* Tue Aug 13 2013 guillaume.gardet@oliseo.fr
- config: update armv6 default config to multi-arch armv6
- commit a4e49ee
* Tue Aug 13 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc5-next-20130813
- commit 1e4d4d2
* Mon Aug 12 2013 jeffm@suse.com
- Update to 3.11-rc5.
- commit 8ed5271
* Mon Aug 12 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc4-next-20130812
- commit 6b250d1
* Fri Aug  9 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc4-next-20130809
- commit 92798b2
* Thu Aug  8 2013 guillaume.gardet@oliseo.fr
- arm: update default config for 3.11.0-rc4
- Add sound modules
- Add TI wifi modules
- commit e351159
* Thu Aug  8 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc4-next-20130808
- commit 741991e
* Thu Aug  8 2013 dmueller@suse.com
- config/arm: update and reenable ARM64 config
- commit 1609117
* Thu Aug  8 2013 dmueller@suse.com
- Reenable ARMv6/ARMv7 configs
- commit fdf48d9
* Wed Aug  7 2013 jeffm@suse.com
- config: disable RCU_USER_QS
  RCU_USER_QS is used for hacking on debugging the full dynticks model,
  which we've disabled.
- commit a8077ee
* Wed Aug  7 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc4-next-20130807
- commit 29e6d29
* Tue Aug  6 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc4-next-20130806
- commit b9d9517
* Mon Aug  5 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Avoid hardcoded runtime dependency on
  module-init-tools.
- commit 2889cef
* Mon Aug  5 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc4-next-20130805
- commit 8a85fd4
* Mon Aug  5 2013 jeffm@suse.com
- Update to 3.11-rc4.
- commit fff9bad
* Fri Aug  2 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc3-next-20130802
- commit 230f5eb
* Thu Aug  1 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc3-next-20130801
- commit 46311c4
* Wed Jul 31 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc3-next-20130731
- commit cc6a1dc
* Tue Jul 30 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc3-next-20130730
- commit 6469714
* Mon Jul 29 2013 jeffm@suse.com
- Update to 3.11-rc3.
- Eliminated 3 patches.
- commit a8c0ef8
* Mon Jul 29 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc2-next-20130729
- commit c4a78f0
* Fri Jul 26 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc2-next-20130726
- commit 14859c4
* Thu Jul 25 2013 jdelvare@suse.de
- Hu, OK, RapidIO can't be fully modularized on PPC (yet.)
- commit 30e79d8
* Thu Jul 25 2013 jdelvare@suse.de
- Update config files: build RapidIO support as modules
- commit 3aac28d
* Thu Jul 25 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc2-next-20130725
- commit fe620b1
* Thu Jul 25 2013 jeffm@suse.com
- rpm/kernel-binary.spec.in: Obsolete microcode_ctl
  The kernel can request CPU microcode itself now and microcode_ctl is
  no longer required.
- commit 43e5ff5
* Thu Jul 25 2013 jeffm@suse.com
- config: enable early CPU microcode loading.
- commit 0ad65c2
* Wed Jul 24 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc2-next-20130724
- commit 2e1c3f4
* Tue Jul 23 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc2-next-20130723
- commit 8f85bd5
* Tue Jul 23 2013 jeffm@suse.com
- config: disable USB_CHIPIDEA
- commit 3065e57
* Tue Jul 23 2013 jeffm@suse.com
- Update to 3.11-rc2.
- Eliminated 1 patch.
- commit 1196e4b
* Mon Jul 22 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc2-next-20130722
- commit 6ecb6b3
* Fri Jul 19 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc1-next-20130719
- commit d21a565
* Thu Jul 18 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc1-next-20130718
- commit c0b1365
* Wed Jul 17 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc1-next-20130717
- commit 4806c54
* Tue Jul 16 2013 jeffm@suse.com
- Update to 3.10-rc1.
- Eliminated 13 patches.
- Xen needs updating and is disabled.
- commit 3a398de
* Tue Jul 16 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc1-next-20130716
- commit 60f5ed3
* Tue Jul 16 2013 jeffm@suse.com
- config: revert NO_HZ_FULL=y to NO_HZ_IDLE=y (bnc#826946)
  NO_HZ_FULL mode was introduced in v3.10 but still has some
  problems to be worked out. Most notably are issues with
  CPU accounting and how it interacts with power states.
  We'll re-enable it when it's been proven to be stable.
- commit d3b17c1
* Mon Jul 15 2013 mmarek@suse.cz
- Automatically updated to 3.11-rc1-next-20130715
- commit 7931094
* Fri Jul 12 2013 mmarek@suse.cz
- Automatically updated to 3.10-next-20130712
- commit b5f9f20
* Thu Jul 11 2013 mmarek@suse.cz
- Automatically updated to 3.10-next-20130711
- commit 9d1b9a9
* Wed Jul 10 2013 mmarek@suse.cz
- Automatically updated to 3.10-next-20130710
- commit e978dc2
* Tue Jul  9 2013 mmarek@suse.cz
- Automatically updated to 3.10-next-20130709
- commit 5260bfe
* Mon Jul  8 2013 mmarek@suse.cz
- Automatically updated to 3.10-next-20130708
- commit d2e8264
* Sat Jul  6 2013 agraf@suse.de
- ARM: Enable xen for lpae target
- arm: introduce psci_smp_ops.
- ARM: Enable selection of SMP operations at boot time.
- ARM: let the ASID allocator handle suspended animation.
- ARM: prevent risks of out-of-bound access in ASID allocator.
- ARM: Cortex-A15: fix erratum 798181 implementation.
- xen/arm: disable cpuidle when linux is running as dom0.
- arm: choose debug/uncompress.h include when uncompress debug
  is disabled.
- xen/arm: enable PV control for ARM.
- Update config files.
- Refresh patches.xen/xen3-fixup-xen.
- commit 8af61d3
* Fri Jul  5 2013 mmarek@suse.cz
- Automatically updated to 3.10-next-20130705
- commit 5d9202d
* Thu Jul  4 2013 mmarek@suse.cz
- Automatically updated to 3.10-next-20130704
- commit 0ea5f62
* Wed Jul  3 2013 agraf@suse.de
- ARM: Enable Arndale board with LPAE config
- ARM: EXYNOS: Set 64-bit DMA mask for EXYNOS5250.
- usb: phy: Fix phy-samsung-usb when built as module.
- USB: ehci-s5p: Fix phy reset.
- ARM: Update config files: Make LPAE Exynos only until Multiarch comes
- commit 685f89d
* Wed Jul  3 2013 mmarek@suse.cz
- Automatically updated to 3.10-next-20130703
- commit 231682f
* Tue Jul  2 2013 mmarek@suse.cz
- Automatically updated to 3.10-next-20130702
- commit 66e3a57
* Mon Jul  1 2013 mmarek@suse.cz
- Automatically updated to 3.10-next-20130701
- commit c130f79
* Mon Jul  1 2013 jeffm@suse.com
- Update to 3.10-final.
- commit 5eca76a
* Sat Jun 29 2013 dmueller@suse.com
- arm: add and reenable armv6hl
  We've recently decided to remove the softfp
  targets from the openSUSE ARM portfolio. Add
  a armv6hl default kernel flavor and remove
  traces of armv5tel.
- commit 51c5edf
* Fri Jun 28 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc7-next-20130628
- commit 8a43800
* Thu Jun 27 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc7-next-20130627
- commit 017b060
* Thu Jun 27 2013 guillaume.gardet@oliseo.fr
- arm: build lpae kernel as zImage
- commit d8f6242
* Wed Jun 26 2013 jeffm@suse.com
- Update to 3.10-rc7.
- Eliminated 1 patch.
- commit 028a021
* Wed Jun 26 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc7-next-20130626
- commit a4b1fce
* Tue Jun 25 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc7-next-20130625
- commit 912f9b9
* Mon Jun 24 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc7-next-20130624
- commit 7bd0820
* Fri Jun 21 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc6-next-20130621
- commit 73e6813
* Thu Jun 20 2013 mmarek@suse.cz
- Update config files: Disable USB_CHIPIDEA.
- commit f1eab5c
* Thu Jun 20 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc6-next-20130620
- commit 4636233
* Wed Jun 19 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc6-next-20130619
- commit 06ae3d8
* Mon Jun 17 2013 jeffm@suse.com
- config: update vanilla configs for -rc6.
- commit e6ce29d
* Mon Jun 17 2013 jeffm@suse.com
- Update to 3.10-rc6.
- commit 867717f
* Mon Jun 17 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc6-next-20130617
- commit f889d8a
* Mon Jun 10 2013 dmueller@suse.com
- Update and reenable armv7hl configs
- commit e96b989
* Mon Jun 10 2013 jeffm@suse.com
- Update to 3.10-rc5.
- commit df6438c
* Mon Jun 10 2013 schwab@suse.de
- Update arm64/default and reenable it
- commit f099e79
* Fri Jun  7 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc4-next-20130607
- commit 1119129
* Thu Jun  6 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc4-next-20130606
- commit e2b4cd9
* Wed Jun  5 2013 jbeulich@suse.com
- Update Xen patches to 3.10-rc4.
- use vCPU time info registration to support vread_pvclock().
- Delete patches.xen/xen-netback-nr-irqs.
- config.conf: Re-enable Xen flavors.
- Update x86 config files.
- commit 6b826d7
* Wed Jun  5 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc4-next-20130605
- commit 98a971f
* Tue Jun  4 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc4-next-20130604
- commit 54987cc
* Mon Jun  3 2013 jeffm@suse.com
- Update to 3.10-rc4.
- Eliminated 4 patches.
- commit c093b9a
* Mon Jun  3 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc4-next-20130603
- commit fe22c09
* Fri May 31 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc3-next-20130531
- commit cea0794
* Thu May 30 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc3-next-20130530
- commit 4fb5de3
* Wed May 29 2013 jdelvare@suse.de
- Update config files: Modularize HID drivers
  Modularize all HID drivers which can easily be. Some couldn't due to
  weird Kconfig dependencies.
- commit 6c9e9f3
* Wed May 29 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc3-next-20130529
- commit 92eaa72
* Wed May 29 2013 jdelvare@suse.de
- Update config files: disable RADIO_SI476X
  RADIO_SI476X selects SND_SOC_SI476X, which depends on SND_SOC which we do
  not have.
- commit cf469da
* Tue May 28 2013 jeffm@suse.com
- Update to 3.10-rc3.
- 2 patches eliminated.
- commit 0b3486e
* Tue May 28 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc3-next-20130528
- commit 49d3b46
* Mon May 27 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc3-next-20130527
- commit 325465f
* Fri May 24 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc2-next-20130523
- commit 37eecfe
* Wed May 22 2013 jeffm@suse.com
- config: remove sparc64 configs
  The sparc64 configs have been completely unmaintained for two years.
  If someone wants to resurrect support, we'll accept patches.
- commit b684066
* Wed May 22 2013 jeffm@suse.com
- sparc64: revert accidental changes during the 3.9-rc2 update
- commit f1af65a
* Wed May 22 2013 schwab@suse.de
- Update group-source-files.pl to handle symlink to directory
  Also add arch/[^/]+/boot/dts/include/dt-bindings to the list of devel
  files and avoid listing README.SUSE twice.
- commit af248e4
* Tue May 21 2013 jeffm@suse.com
- Update to 3.10-rc2.
- commit 9880044
* Tue May 21 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc2-next-20130521
- commit b757a65
* Mon May 20 2013 jslaby@suse.cz
- Linux 3.9.3.
- Update config files.
- Refresh patches.xen/xen3-patch-2.6.21.
- Refresh patches.xen/xen3-patch-2.6.24.
- Refresh patches.xen/xen3-patch-2.6.36.
- commit 1efefb1
* Fri May 17 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Avoid duplicates in the certifiate list.
- commit 9d687ad
* Fri May 17 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do an exit 0 at the end of each scriptlet
  (bnc#809617).
- commit 7d1a48f
* Fri May 17 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc1-next-20130517
- commit f2a2d71
* Thu May 16 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc1-next-20130516
- commit 1c70995
* Thu May 16 2013 jdelvare@suse.de
- Update config files: CONFIG_ZSMALLOC=y
  Zsmalloc support can no longer be built as a module, so change
  CONFIG_ZSMALLOC=m to =y in all configuration files to fix the build.
- commit 4ff86b9
* Wed May 15 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc1-next-20130515
- commit 17e7727
* Tue May 14 2013 jeffm@suse.com
- Update to 3.10-rc1.
- Eliminated 10 patches.
- Xen is disabled.
- ARM configs are disabled pending updates.
- In-kernel Bootsplash has been removed.
- EXT4 rich acls are re-enabled after having the index officially reserved.
- commit f19bb8a
* Tue May 14 2013 jdelvare@suse.de
- Change CONFIG_OF_MDIO from y to m as needed
  Fix build after my previous commit, OF_MDIO depends on PHYLIB so when
  turning the latter into a module I should have done so with the former
  as well.
- commit 1c3067f
* Tue May 14 2013 jdelvare@suse.de
- Update config files : build PHYLIB as a module.
  All but armv7hl/cubox: make PHYLIB modular. Most systems don't
  need it, and it registers a mdio_bus driver. As a side effect,
  we have to disable PHY emulation support, as it is only availble
  when PHYLIB is built-in. This driver is rather weird anyway and
  hopefully no system we want to support needs it, so it should be
  OK.
  - CONFIG_PHYLIB=m
  - CONFIG_FIXED_PHY=n
- commit 28cada8
* Tue May 14 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc1-next-20130514
- commit 52cff32
* Mon May 13 2013 mmarek@suse.cz
- Automatically updated to 3.10-rc1-next-20130513
- commit ee6029c
* Fri May 10 2013 mmarek@suse.cz
- Automatically updated to 3.9-next-20130510
- commit 887cf5c
* Thu May  9 2013 mmarek@suse.cz
- Automatically updated to 3.9-next-20130509
- commit b5ac825
* Wed May  8 2013 mmarek@suse.cz
- Automatically updated to 3.9-next-20130508
- commit 5b7cf67
* Tue May  7 2013 dmueller@suse.com
- Fix -devel package for armv7hl
  armv7hl kernel flavors in the non-multiplatform configuration
  (which is the default for our openSUSE 12.3 release), needs
  more header files from the machine specific directories to
  be included in kernel-devel.
- commit 882120e
* Tue May  7 2013 mmarek@suse.cz
- Automatically updated to 3.9-next-20130507
- commit 806a046
* Mon May  6 2013 mmarek@suse.cz
- Automatically updated to 3.9-next-20130506
- commit 26919f7
* Mon May  6 2013 jdelvare@suse.de
- S390: Disable CONFIG_PHYLIB on 32-bit kernels
  libphy depends on irq code which is only available on 64-bit S390,
  so disable it on 32-bit kernels.
- commit abfb82b
* Sun May  5 2013 jdelvare@suse.de
- Update config files: enable CC_STACKPROTECTOR
  All other major Linux distributions are building their kernel
  with -fstack-protector, so do the same. See the discussion at:
  http://lists.opensuse.org/opensuse-kernel/2012-06/msg00088.html
  http://lists.opensuse.org/opensuse-kernel/2012-07/msg00000.html
  http://lists.opensuse.org/opensuse-kernel/2013-05/msg00013.html
  - CONFIG_CC_STACKPROTECTOR=y
- commit bccca80
* Fri May  3 2013 mmarek@suse.cz
- rpm/mkspec: Stop generating the get_release_number.sh file
  It was only needed for the old KOTD.
- commit ee71b69
* Fri May  3 2013 mmarek@suse.cz
- Automatically updated to 3.9-next-20130503
- commit 5804d71
* Thu May  2 2013 mmarek@suse.cz
- Automatically updated to 3.9-next-20130502
- commit 31f2e2d
* Thu May  2 2013 mmarek@suse.cz
- rpm/kernel-spec-macros: Properly handle KOTD release numbers with
  .g<commit> suffix
- commit ccb20c3
* Thu May  2 2013 mmarek@suse.cz
- rpm/kernel-spec-macros: Drop the %%release_num macro
  We no longer put the -rcX tag into the release string.
- commit b88e78f
* Wed May  1 2013 mmarek@suse.cz
- Automatically updated to 3.9-next-20130501
- commit 9df8591
* Tue Apr 30 2013 mmarek@suse.cz
- Automatically updated to 3.9-next-20130430
- commit 14ee2d6
* Tue Apr 30 2013 jeffm@suse.de
- Update to 3.9-final.
- commit 09687b7
* Mon Apr 29 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc8-next-20130429
- commit 3deb0e2
* Fri Apr 26 2013 mmarek@suse.cz
- Revert "kconfig: fix randomising choice entries in presence
  of KCONFIG_ALLCONFIG".
- commit 6087a14
* Fri Apr 26 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc8-next-20130426
- commit 1822cf5
* Wed Apr 24 2013 jeffm@suse.com
- config: disable SCSI_UFSHCD on s390/x
  It depends on PCI and can be re-enabled when PCI is enabled
  on s390/x. I expect eventually another module will be added to use
  a different bus technology so adding a depends PCI on SCSI_UFSHCD
  won't really help.
- commit 08373ce
* Wed Apr 24 2013 jeffm@suse.com
- Update to 3.9-rc8.
  Eliminated 2 patches.
- commit 2c76852
* Wed Apr 24 2013 mmarek@suse.cz
- rpm/macros.kernel-source: Fix the -c option if -n is not given
- commit d704806
* Wed Apr 24 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc8-next-20130424
- commit 269a559
* Tue Apr 23 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc8-next-20130423
- commit de0de47
* Mon Apr 22 2013 mmarek@suse.cz
- Delete
  patches.rpmify/DT-export-of_get_next_parent-for-use-by-modules-fix-modular-V4L2.patch.
- commit 197bd1a
* Mon Apr 22 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc8-next-20130422
- commit 4ced92b
* Fri Apr 19 2013 mmarek@suse.cz
- DT: export of_get_next_parent() for use by modules: fix
  modular V4L2.
- commit 89ad032
* Fri Apr 19 2013 mmarek@suse.cz
- Disable CONFIG_MFD_TPS65912
- commit 195d84a
* Fri Apr 19 2013 mmarek@suse.cz
- Delete
  patches.rpmify/0001-input-Export-matrix_keypad_parse_of_params.patch.
- commit 51be776
* Fri Apr 19 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc7-next-20130419
- commit 0adada8
* Thu Apr 18 2013 mmarek@suse.cz
- Remove set -x and set +e statements in KMP scripts
- commit 5575c3c
* Thu Apr 18 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc7-next-20130418
- commit 2e2f5d3
* Tue Apr 16 2013 mmarek@suse.cz
- [media] em28xx: Put remaining .vidioc_g_chip_info instance
  under ADV_DEBUG.
- input: Export matrix_keypad_parse_of_params().
- commit 54b5959
* Tue Apr 16 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc7-next-20130416
- commit a22d05d
* Mon Apr 15 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc6-next-20130415
- commit 2b29c6f
* Sat Apr 13 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc6-next-20130412
- commit 7f10310
* Fri Apr 12 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc6-next-20130411
- commit 57d937c
* Thu Apr 11 2013 sleep_walker@suse.cz
- Enable FRAMEBUFFER_CONSOLE_ROTATION in our kernels
  More and more monitors have insane aspect ratio and can be better used when
  rotated. This may help when X.org is not running and for boot.
- commit 7cd9100
* Wed Apr 10 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc6-next-20130410
- commit f00003c
* Wed Apr 10 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc6-next-20130409
- commit 54bf169
* Tue Apr  9 2013 jeffm@suse.com
- Update to 3.9-rc6.
  Eliminated 1 patch.
- commit dad3321
* Tue Apr  9 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc5-next-20130408
- commit 778b462
* Mon Apr  8 2013 agraf@suse.de
- ARM: Exynos: Update config files: Use DRM instead of FB
- commit 70e2691
* Sun Apr  7 2013 agraf@suse.de
- rpm/package-descriptions: add lpae config for ARM
- ARM: Update config files (fix default, split out lpae).
- ARM: xen: Add missing define.
- config.conf: add lpae config for ARM
- rpm/package-descriptions: add lpae config for ARM
- commit 958fe54
* Fri Apr  5 2013 jbeulich@suse.com
- Update Xen patches to 3.9-rc5.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 773d688
* Fri Apr  5 2013 jdelvare@suse.de
- Update config files: enable ViperBoard drivers
  All kernels which include core (MFD) support for the ViperBoard
  should also include the actual drivers for its functions:
  - CONFIG_I2C_VIPERBOARD=m
  - CONFIG_GPIO_VIPERBOARD=m
- commit ef110b7
* Fri Apr  5 2013 jdelvare@suse.de
- Update config files: disable UCB1400 on all but ARM
  Currently UCB1400 is only used on ARM OMAP systems, and part of the
  code is dead code that can't even be modularized.
  - CONFIG_UCB1400_CORE=n
  - CONFIG_TOUCHSCREEN_UCB1400=n
  - CONFIG_GPIO_UCB1400=n
- commit cd60801
* Fri Apr  5 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc5-next-20130405
- commit d3dd1b3
* Wed Apr  3 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc5-next-20130403
- commit 6b30cb8
* Wed Apr  3 2013 jeffm@suse.com
- Update to 3.9-rc5.
  EFI_VARS_PSTORE is disabled. It is potentially useful but can brick
  certain models of notebooks. Until it's been confirmed as safe, we
  should keep this disabled.
- commit 2f926bd
* Sat Mar 30 2013 jdelvare@suse.de
- Update config files: Build DSA drivers as modules
  DSA drivers can be built as modules since kernel v3.3, so do that:
  - CONFIG_NET_DSA=m
  - CONFIG_NET_DSA_MV88E6XXX=m
  - CONFIG_NET_DSA_MV88E6060=m
  - CONFIG_NET_DSA_MV88E6131=m
  - CONFIG_NET_DSA_MV88E6123_61_65=m
- commit 9786e80
* Fri Mar 29 2013 jdelvare@suse.de
- Update config file config/sparc64/default: drop X86-only GPIO drivers
- commit f097807
* Fri Mar 29 2013 jeffm@suse.com
- config: enable GPIO_[PS]CH, disable INTEL_MID_DMAC
- commit ae6a57a
* Fri Mar 29 2013 jdelvare@suse.de
- Update config files: CONFIG_I2C_COMPAT
  Disable compatibility with lm-sensors <= 3.1.1, version 3.1.2 was
  released 3 years ago.
- commit 53f9d94
* Thu Mar 28 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc4-next-20130328
- commit 318dde8
* Wed Mar 27 2013 mmarek@suse.cz
- rpm/kernel-cert-subpackage: Fix description and summary.
- commit a4cd5e1
* Wed Mar 27 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc4-next-20130327
- commit ce10105
* Tue Mar 26 2013 agraf@suse.de
- Delete config/armv7hl/u8500.
- commit b9fe3d9
* Tue Mar 26 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc4-next-20130326
- commit 366bef3
* Mon Mar 25 2013 jeffm@suse.com
- Updated to 3.9-rc4.
  Eliminated 2 patches.
- commit 4d0ddee
* Mon Mar 25 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc4-next-20130325
- commit 764e231
* Fri Mar 22 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc3-next-20130322
- commit cc2e360
* Thu Mar 21 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc3-next-20130321
- commit 681e55f
* Thu Mar 21 2013 agraf@suse.de
- ARM: FEC: Fix module compilation.
- ARM: kvm: fix IOMMU dependency check.
- omap3isp: fix miscompile.
- VT8500: fix miscompile in clk driver.
- config.conf: Remove imx51 and omap2plus, reenable arm
- Update config files.
- Delete config/armv7hl/imx51.
- Delete config/armv7hl/omap2plus.
- commit 6170f9d
* Wed Mar 20 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc3-next-20130320
- commit 3e90b55
* Tue Mar 19 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc3-next-20130319
- commit 09ed2d7
* Mon Mar 18 2013 jeffm@suse.com
- Update to 3.9-rc3.
- 2 patches were eliminated
  CONFIG_EXPERIMENTAL was eliminated, so I've updated the Xen patches for
  that. DMRAID45 and Rich ACLs also needed updating.
- commit 1c39b52
* Mon Mar 18 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc2-next-20130318
- commit 49a4cb4
* Mon Mar 18 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix sed command with multiple certificates
- commit 59405a2
* Fri Mar 15 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Install the used certificates below
  /etc/uefi/certs (fate#314507).
- commit 19b4300
* Fri Mar 15 2013 mmarek@suse.cz
- rpm/kernel-cert-subpackage: Make the template work with multiple
  certificates.
- commit 3bf5898
* Thu Mar 14 2013 jeffm@suse.com
- Updated to 3.9-rc2.
- Eliminated 52 patches.
- Xen is disabled.
- ARM configs need updating and are disabled.
- commit f10ab2f
* Thu Mar 14 2013 jeffm@suse.com
- supported-flag: clean up patches and merge into one
  The config option is renamed to CONFIG_SUSE_KERNEL_SUPPORTED and
  the text has been updated to reflect that SUSE is no longer a
  unit of Novell.
- commit 83d0c50
* Wed Mar 13 2013 jeffm@suse.com
- config: disabled CONFIG_SPI and CONFIG_IIO on non-ARM architectures
  These devices are found almost entirely on embedded platforms and
  end up adding hundreds of drivers for hardware that most users won't
  have. On systems using them, they are more likely to be embedded
  systems that should probably have a specialized kernel anyway.
- commit 1807abc
* Wed Mar 13 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc2-next-20130313
- commit b2c5158
* Tue Mar 12 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc2-next-20130312
- commit 7cb2a62
* Sun Mar 10 2013 mmarek@suse.cz
- KMP: Add -c <cert> option to the %%kernel_module_package macro
  This produces an -ueficert subpackage that imports the certificate into
  the MokList when installed (fate#314511)
- commit d8f177c
* Fri Mar  8 2013 mmarek@suse.cz
- KMP: Add the -kmp suffix inside the subpackage definition
- commit 7c6395d
* Thu Mar  7 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc1-next-20130307
- commit 4ad873c
* Wed Mar  6 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc1-next-20130306
- commit 94ba970
* Tue Mar  5 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not require new mkinitrd in kernel-vanilla
- commit 26431d8
* Tue Mar  5 2013 mmarek@suse.cz
- Automatically updated to 3.9-rc1-next-20130305
- commit 2a43c39
* Mon Mar  4 2013 mmarek@suse.cz
- Automatically updated to 3.8-next-20130304
- commit 15baf3c
* Fri Mar  1 2013 mmarek@suse.cz
- Automatically updated to 3.8-next-20130301
- commit d1b6f4d
* Thu Feb 28 2013 agraf@suse.de
- Add AArch64 support
- commit 09220ef
* Thu Feb 28 2013 jslaby@suse.cz
- Update config files.
- commit d85872b
* Thu Feb 28 2013 mmarek@suse.cz
- rpm/config.sh: Build against 12.3.
- commit 84aba74
* Thu Feb 28 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Copy kernel signing changes from 12.3 to the
  packaging branch
- commit 59d2acf
* Thu Feb 28 2013 mmarek@suse.cz
- rpm/kernel-binary.spec.in: 'bc' is required since v3.9-rc1
- commit 4a9a926
* Thu Feb 28 2013 mmarek@suse.cz
- Copy packaging changes from master to the packaging branch
- commit dd227e2
* Thu Feb 28 2013 mmarek@suse.cz
- Automatically updated to 3.8-next-20130228
- commit d3299d8
* Wed Feb 27 2013 mmarek@suse.cz
- Automatically updated to 3.8-next-20130227
- commit 4b1e961
* Tue Feb 26 2013 agraf@suse.de
- ARM: Update config files: Drop mmap min addr to at most 32k
- commit 282ad40
* Tue Feb 26 2013 agraf@suse.de
- ARM: default: Update config file: Compile RTC drivers =y
- commit 0275d83
* Tue Feb 26 2013 mmarek@suse.cz
- Automatically updated to 3.8-next-20130226
- commit 8b9a050
* Mon Feb 25 2013 mmarek@suse.cz
- Automatically updated to 3.8-next-20130225
- commit 1896e3a
* Fri Feb 22 2013 mmarek@suse.cz
- Automatically updated to 3.8-next-20130222
- commit a2acaac
* Thu Feb 21 2013 mmarek@suse.cz
- Automatically updated to 3.8-next-20130221
- commit af8c150
* Wed Feb 20 2013 mmarek@suse.cz
- Automatically updated to 3.8-next-20130220
- commit dd13139
* Wed Feb 20 2013 jeffm@suse.com
- config: disable ACPI_BGRT on ia64
  bgrt_image is only defined on x86.
- commit b76784d
* Wed Feb 20 2013 jeffm@suse.com
- config: disable ACPI_INITRD_TABLE_OVERRIDE on ia64
  It requires max_low_pfn_mapped, which is x86 only.
- commit 543cab1
* Wed Feb 20 2013 jeffm@suse.com
- Update to 3.8-final.
- commit cb6aa93
* Tue Feb 19 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc7-next-20130219
- commit 330a5f1
* Mon Feb 18 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc7-next-20130218
- commit 29347d4
* Sun Feb 17 2013 ohering@suse.de
- video: Add Hyper-V Synthetic Video Frame Buffer Driver
- Update config files.
- commit 7c8d9da
* Sat Feb 16 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc7-next-20130215
- commit cc7fa15
* Thu Feb 14 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc7-next-20130214
- commit b45b1a9
* Tue Feb 12 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc7-next-20130212
- commit f14b5af
* Mon Feb 11 2013 jeffm@suse.de
- Update to 3.8-rc7.
  Eliminated 1 patch.
- commit 844f33d
* Fri Feb  8 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc6-next-20130208
- commit 1f694ec
* Thu Feb  7 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc6-next-20130207
- commit f8ff183
* Tue Feb  5 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc6-next-20130205
- commit a719e37
* Sun Feb  3 2013 jeffm@suse.com
- Update to 3.8-rc6.
- commit 346f877
* Sun Feb  3 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc6-next-20130202
- commit 347cb8f
* Wed Jan 30 2013 jeffm@suse.com
- ptp: PTP_1588_CLOCK_PCH depends on x86.
- commit 295abb5
* Wed Jan 30 2013 jeffm@suse.com
- config: disable CONFIG_MVMDIO on s390/x
  CONFIG_MVMDIO is only used by a few ARM SoCs, so we don't need to build
  it everywhere else. Not sure why s390 got skipped in the previous commit.
- commit e7b01fc
* Wed Jan 30 2013 jeffm@suse.com
- config: disable CONFIG_MVMDIO on non-ARM arches
  CONFIG_MVMDIO is only used by a few ARM SoCs, so we don't need to build
  it everywhere else.
- commit 0f82cda
* Wed Jan 30 2013 jeffm@suse.com
- Update to 3.8-rc5.
  Eliminated 4 patches.
- commit 448693e
* Tue Jan 29 2013 jeffm@suse.com
- sysctl: Fixed vm.dirty_ratio sysctl name for desktop flavors
- commit 92907c0
* Tue Jan 29 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc5-next-20130128
- commit 5bd1c27
* Fri Jan 25 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc4-next-20130125
- commit bf5cff1
* Thu Jan 24 2013 jeffm@suse.com
- Updated to 3.8-rc2.
  Eliminated 1 patch.
- commit a86d063
* Thu Jan 24 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc4-next-20130124
- commit fb7dc6e
* Wed Jan 23 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc4-next-20130123
- commit d0f62ff
* Tue Jan 22 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc4-next-20130122
- commit acecada
* Mon Jan 21 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc4-next-20130121
- commit 429c98e
* Sun Jan 20 2013 agraf@suse.de
- Delete config/armv7hl/highbank (included in default now)
- commit c001d45
* Sun Jan 20 2013 agraf@suse.de
- ARM: Default: Update config file (enable multiarch)
- commit 5e5b5ce
* Sat Jan 19 2013 agraf@suse.de
- Delete config/armv7hl/tegra
- commit 8c4868f
* Sat Jan 19 2013 agraf@suse.de
- ARM: IMX51: Update config file (enable drm)
- commit 6f8e127
* Sat Jan 19 2013 agraf@suse.de
- ARM: Exynos: Update config file (set drm+video =y)
- commit b2a30f8
* Fri Jan 18 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc3-next-20130118
- commit 8e32833
* Thu Jan 17 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc3-next-20130117
- commit 867fb5d
* Wed Jan 16 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc3-next-20130116
- commit 9065fcc
* Tue Jan 15 2013 dmueller@suse.com
- reenable armv7hl configs
- commit 3656db8
* Tue Jan 15 2013 jbeulich@suse.com
- Update Xen patches to 3.8-rc3.
- config.conf: Re-enable Xen flavors.
- Update x86 config files.
- commit a0970bf
* Tue Jan 15 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc3-next-20130115
- commit 7b38b2d
* Mon Jan 14 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc3-next-20130114
- commit d178aa6
* Fri Jan 11 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc3-next-20130111
- commit 5baa569
* Thu Jan 10 2013 jeffm@suse.com
- Update to 3.8-rc3.
- commit 52ccea9
* Thu Jan 10 2013 dmueller@suse.com
- config: update armv5tel config for 3.8-rc2
- commit 24bae31
* Thu Jan 10 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc2-next-20130110
- commit 2a90d79
* Wed Jan  9 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc2-next-20130109
- commit 4d91e9d
* Tue Jan  8 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc2-next-20130108
- commit 1ace09b
* Mon Jan  7 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc2-next-20130107
- commit 32dbfb0
* Fri Jan  4 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc2-next-20130104
- commit e40488b
* Thu Jan  3 2013 jeffm@suse.com
- config: Update vanilla configs.
- commit 75de638
* Thu Jan  3 2013 jeffm@suse.com
- Updated to 3.8-rc2.
- commit 5ccb84f
* Thu Jan  3 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc1-next-20130103
- commit e584d62
* Wed Jan  2 2013 mmarek@suse.cz
- Automatically updated to 3.8-rc1-next-20130102
- commit 04bba45
* Tue Dec 25 2012 jeffm@suse.com
- Updated to 3.8-rc1.
- Eliminated 13 patches.
- Xen is disabled.
- ARM configs need updating.
- ext4 richacls are disabled until the upstream index can be reserved.
- commit a66c8fb
* Mon Dec 24 2012 mmarek@suse.cz
- Automatically updated to 3.8-rc1-next-20121224
- commit 99d1a9b
* Fri Dec 21 2012 mmarek@suse.cz
- Automatically updated to 3.7-next-20121221
- commit 90f9d53
* Thu Dec 20 2012 mmarek@suse.cz
- Automatically updated to 3.7-next-20121220
- commit 0dabd99
* Wed Dec 19 2012 mmarek@suse.cz
- Automatically updated to 3.7-next-20121219
- commit 165e15f
* Tue Dec 18 2012 mmarek@suse.cz
- Automatically updated to 3.7-next-20121218
- commit a31b652
* Mon Dec 17 2012 mmarek@suse.cz
- Automatically updated to 3.7-next-20121217
- commit 597e529
* Sat Dec 15 2012 mmarek@suse.cz
- Automatically updated to 3.7-next-20121214
- commit ba1c807
* Thu Dec 13 2012 mmarek@suse.cz
- Automatically updated to 3.7-next-20121213
- commit 860c5a6
* Wed Dec 12 2012 jeffm@suse.com
- ezusb: add dependency to USB.
  This prevents build failures by making it depend on the value of CONFIG_USB.
  Commit 36e0f0bd did this for architectures other than ARM manually.
- commit 63b6c48
* Tue Dec 11 2012 jeffm@suse.com
- Update to 3.7-final.
- commit 20873a0
* Tue Dec 11 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc8-next-20121211
- commit 3cbf8f7
* Tue Dec 11 2012 jack@suse.cz
- Disable ext3 driver in all kernels and use ext4 driver instead. Eventually
  ext3 will be removed upstream so let's do the transition.
- commit e256219
* Sat Dec  8 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc8-next-20121207
- commit 7d4074b
* Fri Dec  7 2012 guillaume.gardet@oliseo.fr
- Update omap2plus (armv7) config: Enable TWL* USB drivers
- commit 20c352d
* Fri Dec  7 2012 jbeulich@suse.com
- Update Xen config files (enable XEN_BZIMAGE and EFI_STUB).
- commit 9607a80
* Thu Dec  6 2012 ohering@suse.de
- fate#314663 hyper-v memory ballooning support
- mm: Export a function to get vm committed memory.
- Drivers: hv: Add Hyper-V balloon driver.
- Drivers: hv: balloon: Fix a bug in the definition of struct
  dm_info_msg.
- Update config files.
  fate#314665 hyper-v: Update the Vmbus protocol
- Drivers: hv: Implement routines for read side signaling
  optimization.
- Drivers: hv: Add state to manage batched reading.
- Drivers: hv: Turn off batched reading for util drivers.
- Drivers: hv: Optimize signaling in the read path.
- Drivers: hv: Optimize the signaling on the write path.
- Drivers: hv: Get rid of hv_get_ringbuffer_interrupt_mask().
- Drivers: hv: Support handling multiple VMBUS versions.
- Drivers: hv: Update the ring buffer structure to match win8
  functionality.
- Drivers: hv: Extend/modify vmbus_channel_offer_channel for
  win7 and beyond.
- Drivers: hv: Save and export negotiated vmbus version.
- Drivers: hv: Change the signature for hv_signal_event().
- Drivers: hv: Change the signature of vmbus_set_event().
- Drivers: hv: Move vmbus version definitions to hyperv.h.
- Drivers: hv: Manage signaling state on a per-connection basis.
- Drivers: hv: Cleanup vmbus_set_event() to support win7 and
  beyond.
- Drivers: hv: Setup a mapping for Hyper-V's notion cpu ID.
- Drivers: hv: Add state to manage incoming channel interrupt
  load.
- Drivers: hv: Modify the interrupt handling code to support
  win8 and beyond.
- Drivers: hv: Add code to distribute channel interrupt load.
- Drivers: hv: Get rid of the unused global signaling state.
- Drivers: hv: Get rid of unnecessary request for offers.
- Drivers: hv: Manage event tasklets on per-cpu basis.
- Drivers: hv: Handle vmbus interrupts concurrently on all cpus.
- Drivers: hv: Add a check to deal with spurious interrupts.
- Drivers: hv: Enable protocol negotiation with win8 hosts.
- Drivers: hv: Implement flow management on the send side.
- Drivers: hv: Capture the host build information.
- Drivers: hv: Cleanup and consolidate reporting of build/version
  info.
- commit 362423f
* Thu Dec  6 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc8-next-20121206
- commit ec80bf6
* Wed Dec  5 2012 jeffm@suse.com
- Update to 3.7-rc8.
- Delete patches.rpmify/net-fix-build-failure-in-xilinx.
- commit 4cd69dc
* Wed Dec  5 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc8-next-20121205
- commit 2c97a35
* Tue Dec  4 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc8-next-20121204
- commit f783be7
* Fri Nov 30 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc7-next-20121130
- commit c67d161
* Thu Nov 29 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc7-next-20121129
- commit 753f086
* Wed Nov 28 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc7-next-20121128
- commit a5bb48f
* Tue Nov 27 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc7-next-20121127
- commit bb53b4c
* Fri Nov 23 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not remove fillup from the buildsystem
  (bnc#781327)
- commit 841d864
* Tue Nov 20 2012 sjayaraman@suse.com
- Update config files. Enable CONFIG_SMB2 to 'y'.
- commit 645522d
* Fri Nov 16 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc5-next-20121115
- commit 1707486
* Wed Nov 14 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc5-next-20121114
- commit e6ff593
* Tue Nov 13 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc5-next-20121113
- commit 8165406
* Mon Nov 12 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc5-next-20121112
- commit 063010a
* Fri Nov  9 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc4-next-20121109
- commit 04aaa8f
* Thu Nov  8 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc4-next-20121108
- commit 69456d5
* Wed Nov  7 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc4-next-20121107
- commit c338495
* Tue Nov  6 2012 jeffm@suse.com
- config: sync x86_64 configs for NR_UARTS
  This commit sets both CONFIG_SERIAL_8250_RUNTIME_UARTS and
  CONFIG_SERIAL_8250_NR_UARTS to 32.
- commit 3600626
* Tue Nov  6 2012 jeffm@suse.com
- config: sync ppc64 configs for LIB80211, NET_SDA_MV*
  This commit changes the following options to be modular:
  LIB80211
  NET_DSA_MV88E6XXX
  NET_DSA_MV88E6060
- commit 7f06759
* Tue Nov  6 2012 jeffm@suse.com
- config: sync ppc64/debug with ppc64/default
  The debug config should be identical to default with the exception of
  the debug options. This patch brings ppc64/debug in line with ppc64/default
  with the exception of a few things that are modular in debug that should
  also be modular in default.
- commit 786826a
* Tue Nov  6 2012 jeffm@suse.com
- config: sync kvm options between ppc64 flavors.
- commit c03f540
* Tue Nov  6 2012 jeffm@suse.com
- config: disable HW_RANDOM_AMD on ppc64
  This chip is only on AMD hardware and an old ppc64 eval board. We can skip
  it on ppc64.
- commit 61b99aa
* Tue Nov  6 2012 jeffm@suse.com
- config: Eliminate unused ppc/ppc64 configs.
  The history of the ppc/ppc64 configs is a convoluted one that started
  before the kernel source could support multiple machine types with a
  single image and before there was a usable 64-bit userspace.
  In the subsequent years, the powerpc code has been unified and we've
  released a 64-bit powerpc userspace. The "default" and "ppc64" configs
  on ppc64 are essentially identical and just waste space. The "ppc64"
  config on 32-bit ppc address a long since unnecessary corner case. Users
  who still want a 32-bit userspace with a 64-bit kernel can install and
  update it themselves using the 64-bit repository like i386/x86_64 users
  can do.
  This commit can be summarized thusly:
  rm config/ppc/ppc64
  rm config/ppc/ps3 (already unused)
  mv config/ppc64/ppc64 config/ppc64/default
- commit f13f865
* Tue Nov  6 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc4-next-20121106
- commit 8bdf790
* Mon Nov  5 2012 jeffm@suse.com
- config: sync vanilla flavor with default flavor for each platform
  The vanilla configs have drifted away from the default configuration
  for each platform. This patch brings them back in sync.
- commit 3ee29f6
* Mon Nov  5 2012 jeffm@suse.com
- config: -ec2 still had CONFIG_ENTERPRISE_SUPPORT enabled.
- commit 9a95847
* Mon Nov  5 2012 jeffm@suse.com
- Updated to 3.7-rc4.
  Eliminated 1 patch.
- commit a68ddc2
* Mon Nov  5 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc4-next-20121105
- commit 3033c3d
* Fri Nov  2 2012 jbeulich@novell.com
- Update Xen patches to 3.7-rc3 and c/s 1202.
- extend base interfaces to support multi-page rings for
  frontend/backend communication.
- blkback: allow using multiple page frontend communication ring.
- blkfront: allow using multiple page backend communication ring.
- ACPI: Store valid ACPI tables passed via early initrd in
  reserved memblock areas.
- ACPI: Fix build when disabled.
- ACPI: Cleanup acpi_initrd_override declaration and remove
  ifdefs.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- Delete patches.xen/xen3-acpi_override_2_2.patch.
- commit f7f2e5e
* Fri Nov  2 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc3-next-20121102
- commit ff09440
* Thu Nov  1 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc3-next-20121101
- commit 31be598
* Wed Oct 31 2012 guillaume.gardet@oliseo.fr
- Add support to armv5 versatile kernel
- commit bee1c22
* Wed Oct 31 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc3-next-20121031
- commit 0d73a1e
* Wed Oct 31 2012 jeffm@suse.com
- Update to 3.7-rc3.
- commit d6607a5
* Tue Oct 30 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require coreutils in kernel-*-devel (bnc#783615)
- commit 2520563
* Tue Oct 30 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc3-next-20121030
- commit b1041d0
* Tue Oct 30 2012 agraf@suse.de
- ARM: Update config files: Fix vexpress (default) config
- commit 7ff1620
* Mon Oct 29 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc3-next-20121029
- commit bba8910
* Fri Oct 26 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc2-next-20121026
- commit db6d963
* Thu Oct 25 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc2-next-20121025
- commit 4ae5c53
* Tue Oct 23 2012 agraf@suse.de
- ARM: Update config files: Exynos: Disable 8bit sd mode to support wifi
- commit a6863b1
* Mon Oct 22 2012 agraf@suse.de
- Revert "disable non-compiling irrelevant I2C module"
- commit 481a0be
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files.
- commit b6b574b
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files.
- commit ff6e580
* Mon Oct 22 2012 agraf@suse.de
- ARM: Exynos: Fix MMC driver
- ARM: Exynos: Update configs
- commit f34b850
* Mon Oct 22 2012 jeffm@suse.com
- config: change CONFIG_USB_EZUSB_FX2 to module
- commit e5e7986
* Mon Oct 22 2012 jeffm@suse.com
- Updated to 3.7-rc2.
- commit ec174c0
* Mon Oct 22 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc2-next-20121022
- commit 4b55b13
* Mon Oct 22 2012 agraf@suse.de
- ARM: Update config files: Exynos: Enable gfx and highmem
- commit 5e66bc3
* Fri Oct 19 2012 mmarek@suse.cz
- Disable MODULE_SIG for now.
- commit 375041b
* Fri Oct 19 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc1-next-20121019
- commit 6558fe8
* Thu Oct 18 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Use a macro instead of /etc/IGNORE-KABI-BADNESS
- commit 19e7e54
* Thu Oct 18 2012 agraf@suse.de
- ARM: Update config files: Fix exynos uart
- commit a8020fc
* Thu Oct 18 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc1-next-20121018
- commit 829ecef
* Wed Oct 17 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Also check for /etc/IGNORE-KABI-BADNESS file
  This allows to control the kabi checker from outside of the package.
- commit 0a0900c
* Wed Oct 17 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc1-next-20121017
- commit 66de085
* Wed Oct 17 2012 jeffm@suse.com
- Update to 3.7-rc1.
- Eliminated 38 patches.
- Xen is disabled.
- ARM configs need updating.
- Module signing is disabled until the build infrastructure can support it.
- commit a6503f9
* Tue Oct 16 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc1-next-20121016
- commit b655845
* Mon Oct 15 2012 mmarek@suse.cz
- Automatically updated to 3.7-rc1-next-20121015
- commit 27ffc86
* Fri Oct 12 2012 mmarek@suse.cz
- Automatically updated to 3.6-next-20121012
- commit 1029883
* Thu Oct 11 2012 guillaume.gardet@oliseo.fr
- ARM (omap2plus) : re-enable OMAP DRM module
- commit eb5b90a
* Thu Oct 11 2012 mmarek@suse.cz
- Automatically updated to 3.6-next-20121011
- commit 42eca8a
* Wed Oct 10 2012 mmarek@suse.cz
- Automatically updated to 3.6-next-20121010
- commit c90bb32
* Tue Oct  9 2012 mmarek@suse.cz
- Automatically updated to 3.6-next-20121009
- commit 015e923
* Mon Oct  8 2012 dmueller@suse.com
- Remove noncompiling modules
- commit 57219e0
* Mon Oct  8 2012 agraf@suse.de
- ARM: Update config files: Exynos: Enable serial console
- commit ec60d23
* Fri Oct  5 2012 mmarek@suse.cz
- Automatically updated to 3.6-next-20121005
- commit e6c9077
* Thu Oct  4 2012 ohering@suse.de
- rpm/kernel-binary.spec.in: enable Conflicts for
  apparmor, udev and lvm2 also for vanilla kernel
- commit a24206f
* Thu Oct  4 2012 ohering@suse.de
- rpm/kernel-binary.spec.in: add Conflicht: hyper-v < 4
  to make sure the daemon is in sync with the kernel
  (bnc#770763 , fate#314441)
- commit 86f9ba3
* Thu Oct  4 2012 jbeulich@novell.com
- Update Xen patches to 3.6-final and c/s 1197.
- Update Xen config files.
- commit 5be6bae
* Thu Oct  4 2012 mmarek@suse.cz
- Automatically updated to 3.6-next-20121004
- commit cdcbcc4
* Wed Oct  3 2012 mmarek@suse.cz
- Automatically updated to 3.6-next-20121002
- commit fd25c09
* Tue Oct  2 2012 mmarek@suse.cz
- Automatically updated to 3.6-next-20121001
- commit c8a6065
* Mon Oct  1 2012 agraf@suse.de
- ARM: Update config files: Exynos: Disable broken config options
- commit 467f144
* Mon Oct  1 2012 agraf@suse.de
- ARM: Update config files: Exynos: disable VFIO
- commit 9c06679
* Mon Oct  1 2012 jeffm@suse.com
- Update to 3.6-final.
- commit 6be64f1
* Sat Sep 29 2012 dmueller@suse.com
- disable non-compiling irrelevant I2C module
- commit 7c87bf7
* Sat Sep 29 2012 dmueller@suse.com
- ARM/tegra: Remove optional parts to fix build
- commit e1021dd
* Sat Sep 29 2012 dmueller@suse.com
- ARM: enable zcache support
- commit b5bece4
* Sat Sep 29 2012 dmueller@suse.com
- ARM/cubox: set cachefilesd to module
- commit 664d6e9
* Sat Sep 29 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc7-next-20120928
- commit 22e6960
* Fri Sep 28 2012 mszeredi@suse.cz
- Update config files to enable building overlayfs as a module.
- commit ec3335b
* Fri Sep 28 2012 trenn@suse.de
- Update config files.
  Enable ACPI table override capability via initrd for
  all i386/x86_64 flavors:
  +CONFIG_ACPI_INITRD_TABLE_OVERRIDE=y
- commit 4865802
* Fri Sep 28 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc7-next-20120927
- commit 478ffae
* Thu Sep 27 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc7-next-20120926
- commit e36d83e
* Thu Sep 27 2012 agraf@suse.de
- Update config files: Disable JTAG HVC, when enabled the kernel hangs on access
- commit 3bcca46
* Wed Sep 26 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc7-next-20120925
- commit 48fed13
* Tue Sep 25 2012 jeffm@suse.com
- Update to 3.6-rc7.
  Eliminated one patch.
- commit ab3a8ff
* Tue Sep 25 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc6-next-20120924
- commit d96c7cd
* Sat Sep 22 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc6-next-20120921
- commit affefc4
* Thu Sep 20 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc6-next-20120920
- commit 9b93994
* Wed Sep 19 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc6-next-20120918
- commit c5a96bc
* Tue Sep 18 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc6-next-20120917
- commit 2d04931
* Mon Sep 17 2012 jeffm@suse.com
- Update to 3.6-rc6.
- Eliminated 1 patch.
  patches.arch/arm-phys-offset.patch needs review.
- commit a944109
* Sat Sep 15 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc5-next-20120914
- commit c609954
* Thu Sep 13 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc5-next-20120913
- commit 74e39a2
* Tue Sep 11 2012 dmueller@suse.com
- (ARM/tegra) remove non-building module from config
- commit a9bde8a
* Tue Sep 11 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc5-next-20120911
- commit 722b617
* Tue Sep 11 2012 jeffm@suse.com
- config: disabled MFD drivers that aren't buildable as modules
  This allows MFD_CORE to be modular on all arch/flavors except for
  ARM and the non-PAE flavors on i386, since it's used with the OLPC XO-1.
- commit 83d5ac4
* Mon Sep 10 2012 jeffm@suse.com
- Update to 3.6-rc5.
- commit a83424c
* Sat Sep  8 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc4-next-20120907
- commit 3c73744
* Fri Sep  7 2012 dmueller@suse.com
- fix build of imx51 flavor by removing irrelevant drivers
- commit c4165b4
* Fri Sep  7 2012 dmueller@suse.com
- remove drivers that do not exist and do not build on ARM (default)
- commit 072e984
* Fri Sep  7 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc4-next-20120906
- commit d240f5e
* Thu Sep  6 2012 jbeulich@novell.com
- Update Xen patches to 3.6-rc4 and c/s 1188.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit f337259
* Thu Sep  6 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc4-next-20120905
- commit c42722b
* Wed Sep  5 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc4-next-20120904
- commit 09b15b4
* Tue Sep  4 2012 mmarek@suse.cz
- Disable CONFIG_KMSG_IDS on s390x, because it is currently broken
- commit 3bdd3b6
* Mon Sep  3 2012 jslaby@suse.cz
- Update config files. (vanilla ones)
- commit da9da13
* Fri Aug 31 2012 dmueller@suse.com
- ARM(omap2plus): Remove optional parts that don't compile
- commit 6dae1d1
* Thu Aug 30 2012 agraf@suse.de
- Update config files: Add highbank (forgot in last patch)
- commit 594863f
* Thu Aug 30 2012 agraf@suse.de
- config.conf: Enable ARM
- Update ARM config files.
- Add highbank definition
- commit 734ba0e
* Tue Aug 28 2012 jeffm@suse.com
- config: Update -vanilla for ChipIdea fix
- commit fdf68c3
* Tue Aug 28 2012 jeffm@suse.com
- chipidea: Allow user to select PCI/IMX options.
  This allows us to disable the ChipIdea IMX code on powerpc,
  where it was causing build problems.
- commit c478b2e
* Tue Aug 28 2012 jeffm@suse.com
- config: Disable EXYNOS_VIDEO and HW_RANDOM_EXYNOS on all configs except exynos
  This hardware is only found on the Samsung EXYNOS boards.
- commit f1eabb2
* Sat Aug 25 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc3-next-20120824
- commit af03b47
* Thu Aug 23 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc3-next-20120823
- commit d03dd6a
* Wed Aug 22 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc2-next-20120822
- commit e11978c
* Tue Aug 21 2012 jeffm@suse.com
- config: update vanilla configs for 3.6-rc2.
- commit 88d289a
* Tue Aug 21 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc2-next-20120820
- commit a91a01f
* Fri Aug 17 2012 jeffm@suse.com
- Update to 3.6-rc2.
  - Eliminated 1 patch.
- commit ea6ece6
* Fri Aug 17 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc2-next-20120817
- commit 9206f5b
* Thu Aug 16 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc1-next-20120816
- commit 543ce9f
* Tue Aug 14 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc1-next-20120814
- commit 6aa3207
* Mon Aug 13 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc1-next-20120813
- commit baaf672
* Fri Aug 10 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc1-next-20120810
- commit c1a2c69
* Thu Aug  9 2012 mmarek@suse.cz
- Disable CONFIG_DRM_NOUVEAU on ia64 due to build errors
- commit 77696c1
* Thu Aug  9 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc1-next-20120809
- commit 3e83480
* Wed Aug  8 2012 mmarek@suse.cz
- Update config files to fix build.
- commit f1b5063
* Wed Aug  8 2012 dmueller@suse.com
- config: enable various ARM errata workarounds to improve stability
- commit 0292bdc
* Tue Aug  7 2012 mmarek@suse.cz
- rpm/config.sh: Build the KOTD against 12.2
- commit 4099be6
* Tue Aug  7 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc1-next-20120807
- commit 3f9c512
* Mon Aug  6 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc1-next-20120806
- commit 9a12ff1
* Fri Aug  3 2012 jeffm@suse.com
- Updated and re-enabled DMRAID45.
- commit dd7fcb9
* Fri Aug  3 2012 jeffm@suse.com
- Updated and re-enabled richacl support.
- commit 07a5ea0
* Fri Aug  3 2012 mmarek@suse.cz
- Automatically updated to 3.6-rc1-next-20120803
- commit 00bae27
* Fri Aug  3 2012 jeffm@suse.com
- Update to 3.6-rc1.
  - Eliminated 11 patches.
  - Rich ACLs are disabled.
  - Xen is disabled.
  - ARM is disabled.
  - DMRAID45 is disabled.
- commit 473a005
* Thu Aug  2 2012 mmarek@suse.cz
- Automatically updated to 3.5-next-20120802
- commit 26b0dae
* Tue Jul 31 2012 mmarek@suse.cz
- Automatically updated to 3.5-next-20120731
- commit 93d5ad1
* Mon Jul 30 2012 jeffm@suse.com
- Update config files: HID_GENERIC=y where USBHID=y (bnc#773559).
  On flavors where USBHID is built-in statically, we want HID_GENERIC to
  be built statically as well. This, notably, includes i386/x86_64's desktop
  flavors.
- commit ee350da
* Mon Jul 30 2012 jeffm@suse.com
- Synced configs after commit 940e57e2 (Delete patches.drivers/input-Add-LED-support-to-Synaptics-device.)
- commit c7a1b25
* Mon Jul 30 2012 dmueller@suse.com
- Enable RTL8150 for omap2plus
  Generic USB Network device that also works fine on ARM, so enable it
- commit f5d960c
* Mon Jul 30 2012 mmarek@suse.cz
- Automatically updated to 3.5-next-20120730
- commit 272c1e4
* Fri Jul 27 2012 mmarek@suse.cz
- Automatically updated to 3.5-next-20120727
- commit 686c2a0
* Thu Jul 26 2012 mmarek@suse.cz
- Automatically updated to 3.5-next-20120726
- commit d789ae5
* Wed Jul 25 2012 mmarek@suse.cz
- Automatically updated to 3.5-next-20120725
- commit 47e2d4d
* Tue Jul 24 2012 jeffm@suse.com
- Update to 3.5-final.
  patches.suse/dm-raid45-26-Nov-2009.patch needs updating to new kmsg
  interface but, since powerpc isn't officially supported by opensuse, the
  update can happen later.
- commit 41a31d2
* Tue Jul 24 2012 mmarek@suse.cz
- Automatically updated to 3.5-next-20120724
- commit 1b4b9ca
* Mon Jul 23 2012 mmarek@suse.cz
- Automatically updated to 3.5-next-20120722
- commit b368f09
* Fri Jul 20 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc7-next-20120720
- commit 41e65a2
* Tue Jul 17 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc7-next-20120717
- commit e8fed88
* Fri Jul 13 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc6-next-20120713
- commit 4eea079
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Updates vanilla config files to include NFS_DEBUG implied by SUNRPC_DEBUG
- commit 37cfaba
* Fri Jul 13 2012 neilb@suse.de
- Update config files.
  Add SUNRPC_DEBUG - a new option for functionality that was
  previously always present.
  Without this, "rpcdebug" doesn't work.
  We often request customers enable this to analyse problems.
- commit 708cd64
* Thu Jul 12 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc6-next-20120712
- commit 0c9fd6a
* Thu Jul 12 2012 mmarek@suse.cz
- Update vanilla config files.
- commit da358b1
* Tue Jul 10 2012 jeffm@suse.com
- Enable VMWGFX as module (bnc#769534).
  This option affects GNOME performance in VMware virtual machines.
- commit 3effe7e
* Mon Jul  9 2012 sjayaraman@suse.com
- Update config files: CONFIG_CIFS_FSCACHE=y.
- commit 66ef05e
* Mon Jul  9 2012 sjayaraman@suse.com
- Update config files: CONFIG_CIFS_FSCACHE=m.
- commit 79aea40
* Mon Jul  9 2012 jeffm@suse.com
- Updated to 3.5-rc5.
- Eliminated 2 patches.
- commit b6f66c6
* Sat Jul  7 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc5-next-20120706
- commit 54daf11
* Fri Jul  6 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc5-next-20120705
- commit 5824d85
* Thu Jul  5 2012 agraf@suse.de
- Update config files: use PR KVM on ppc/ppc64
- commit bf641de
* Wed Jul  4 2012 hare@suse.de
- mach-dove: define TIMER_PHYS_BASE.
- Update config files.
- commit 2e6041f
* Tue Jul  3 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc5-next-20120703
- commit 5a2d0ac
* Sat Jun 30 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc4-next-20120629
- commit b9e981b
* Fri Jun 29 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc4-next-20120628
- commit 9876d20
* Wed Jun 27 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc4-next-20120627
- commit 965c3bd
* Tue Jun 26 2012 vojtech@suse.com
- Update post.sh to make the RT kernel default in the bootloader
  after installation.
- commit 3c10ce7
* Tue Jun 26 2012 guillaume.gardet@oliseo.fr
- Update omap2plus (ARM) config
- commit 751830a
* Tue Jun 26 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc4-next-20120625
- commit 3a0c1ac
* Sun Jun 24 2012 awafaa@opensuse.org
- Add support for Samsung Exynos SoC
- commit 6b5955f
* Sun Jun 24 2012 awafaa@opensuse.org
- Update configs for cubox/default/imx51/tegra/u8500
- commit 5117d60
* Sat Jun 23 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc3-next-20120622
- commit d6fcd12
* Fri Jun 22 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc3-next-20120621
- commit 60762de
* Thu Jun 21 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc3-next-20120620
- commit 02e1623
* Wed Jun 20 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc3-next-20120619
- commit 2e4dc5f
* Tue Jun 19 2012 jbeulich@novell.com
- Update Xen patches to 3.5-rc3 and c/s 1182.
- Update x86 config files.
- Delete patches.xen/add-console-use-vt.
- commit e79f21d
* Mon Jun 18 2012 jeffm@suse.com
- Updated to 3.5-rc3.
- commit 0596699
* Fri Jun 15 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc2-next-20120615
- commit 08c3bae
* Thu Jun 14 2012 jeffm@suse.com
- CONFIG_RTC_DRV_CMOS=y on all x86/x86_64 flavors (bnc#755525).
  When rtc_cmos is module, hctosys fails to set the clock on boot, issuing
  ominious error messages to the console.
- commit f190e27
* Thu Jun 14 2012 jbeulich@novell.com
- Update x86 config files (ATA_PIIX=m, bnc#766284).
- commit 56e051f
* Wed Jun 13 2012 hare@suse.de
- Add SolidRun Cubox configuration
- Update config files.
- Add separate cubox configuration.
- mach-dove: Fixup ge00 initialisation.
- spi-orion: convert to new infrastructure.
- config.conf: Add cubox configuration
- rpm/package-descriptions: Add cubox description
- commit 48ad4d6
* Wed Jun 13 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc2-next-20120613
- commit e123a06
* Tue Jun 12 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc2-next-20120612
- commit 7342ac8
* Mon Jun 11 2012 jeffm@suse.com
- Update to 3.5-rc2.
  - Xen needs update.
  - ARM needs update.
  - Eliminated 13 patches.
- commit 421e73d
* Fri Jun  8 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc1-next-20120608
- commit 0e5a603
* Thu Jun  7 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc1-next-20120607
- commit 15cd59f
* Tue Jun  5 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc1-next-20120605
- commit 71d1f49
* Mon Jun  4 2012 mmarek@suse.cz
- Automatically updated to 3.5-rc1-next-20120604
- commit 3e089c0
* Fri Jun  1 2012 tiwai@suse.de
- Update config files: Use CONFIG_SND_HDA_INPUT_BEEP=1 instead of 2
  The mode 2 was an ugly hack and shouldn't have been set, but it was so
  changed since some time ago...
- commit a5e6e4c
* Fri Jun  1 2012 guillaume.gardet@oliseo.fr
- Update ARM configs
- commit f847717
* Fri Jun  1 2012 mmarek@suse.cz
- Automatically updated to 3.4-next-20120601
- commit e08aec5
* Thu May 31 2012 mmarek@suse.cz
- Automatically updated to 3.4-next-20120531
- commit b5a4d36
* Tue May 29 2012 jbeulich@novell.com
- Update Xen config files (XEN_SPINLOCK_ACQUIRE_NESTING=1).
- commit 56f8939
* Tue May 29 2012 mmarek@suse.cz
- Automatically updated to 3.4-next-20120529
- commit 5868eea
* Mon May 28 2012 mmarek@suse.cz
- Automatically updated to 3.4-next-20120528
- commit 35894e6
* Fri May 25 2012 jeffm@suse.com
- Renamed armv7l to armv7hl, following %%_cpu_target convention.
- commit 54f7adb
* Fri May 25 2012 mmarek@suse.cz
- Automatically updated to 3.4-next-20120524
- commit b4b62d9
* Thu May 24 2012 mmarek@suse.cz
- Automatically updated to 3.4-next-20120523
- commit 402bde7
* Wed May 23 2012 mmarek@suse.cz
- Automatically updated to 3.4-next-20120522
- commit 89003e3
* Tue May 22 2012 mmarek@suse.cz
- Automatically updated to 3.4-next-20120521
- commit 487276a
* Sat May 19 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc7-next-20120518
- commit 80b1aab
* Fri May 18 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc7-next-20120517
- commit 5f91e1b
* Thu May 17 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc7-next-20120516
- commit 2c47b8e
* Tue May 15 2012 agraf@suse.de
- Update config files: ppc64: use PR instead of HV KVM which is usable by more people
- commit 1f811d7
* Tue May 15 2012 jeffm@suse.com
- Make CRYPTO_CRC32C modular (bnc#762344)
  It was pulled in =y via CEPH_LIB=y, so we change the
  following options to =m:
- CONFIG_CEPH_LIB
- CONFIG_CRYPTO_CRC32C
- CONFIG_LIBCRC32C
  Making it modular allows the Intel-optimized crc32c implementation
  to be loaded, improving performance of things like btrfs.
- commit 5a78d5f
* Tue May 15 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc7-next-20120514
- commit 0887101
* Mon May 14 2012 jeffm@suse.com
- Disabled more Intel embedded drivers.
  Disabled:
- CONFIG_GPIO_LANGWELL
- CONFIG_GPIO_PCH
- CONFIG_GPIO_SCH
- commit a45bdb5
* Mon May 14 2012 jeffm@suse.com
- USB storage on -desktop should be modular.
- commit 54e63d5
* Mon May 14 2012 jeffm@suse.com
- Disabled more testing options.
  Disables:
  - CONFIG_TEST_POWER
  - CONFIG_VIDEO_MEM2MEM_TESTDEV
- commit daac446
* Mon May 14 2012 jeffm@suse.com
- Update to 3.4-rc7.
  - Eliminated 1 patch.
- commit 03d6d8e
* Sat May 12 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc6-next-20120511
- commit 8e82bfd
* Thu May 10 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc6-next-20120510
- commit 11cbf12
* Wed May  9 2012 jeffm@suse.com
- geodefb: Depend on X86_32.
  Disables:
- CONFIG_FB_GEODE_GX1
- CONFIG_FB_GEODE_GX
- CONFIG_FB_GEODE_LX
- CONFIG_FB_GEODE
- commit 54e841d
* Wed May  9 2012 jeffm@suse.com
- Disabled testing config options on !debug
- CONFIG_CRYPTO_TEST
- CONFIG_DMATEST
- CONFIG_RTC_DRV_TEST
- commit 4bd27ae
* Wed May  9 2012 guillaume.gardet@opensuse.org
- Update ARM configs
- commit 62e14ad
* Wed May  9 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc6-next-20120508
- commit fab52c2
* Tue May  8 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc6-next-20120507
- commit 442b6db
* Sun May  6 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc5-next-20120504
- commit 5e976d4
* Sat May  5 2012 jeffm@suse.com
- Disabled MMC_TEST (bnc#760077).
- commit 798d696
* Fri May  4 2012 jeffm@suse.com
- sysctl/defaults: kernel.hung_task_timeout -> kernel.hung_task_timeout_secs (bnc#700174)
- commit 3571127
* Fri May  4 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc5-next-20120503
- commit eab51d3
* Thu May  3 2012 guillaume.gardet@opensuse.org
- Update config/armv7l/omap2plus
- commit 947b9c5
* Wed May  2 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc5-next-20120501
- commit b146f3d
* Mon Apr 30 2012 jeffm@suse.com
- Updated and re-enabled armv7l.
  Thanks to Guillaume GARDET <guillaume.gardet@opensuse.org>
- commit c19358b
* Mon Apr 30 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc5-next-20120430
- commit 4b461b5
* Mon Apr 30 2012 neilb@suse.de
- Update config files.
  Add CONFIG options for NFSv4v1 support.
  bnc#730444
- commit 2034b94
* Fri Apr 27 2012 jeffm@suse.com
- Disabled more Moorestown/Medfield drivers.
  Specific options disabled:
  I2C_INTEL_MID
  CONFIG_SFI
  MTD_NAND_DENALI
  SERIAL_MRST_MAX3110
  DRM_GMA600
  SPI_DW_MID_DMA
  APDS9802ALS
- commit 16dc1b2
* Thu Apr 26 2012 jeffm@suse.com
- Disabled DECNet and ARCNet.
  Specific config options disabled:
  CONFIG_ARCNET
  CONFIG_ARCNET_1051
  CONFIG_ARCNET_1201
  CONFIG_ARCNET_CAP
  CONFIG_ARCNET_COM20020_CS
  CONFIG_ARCNET_COM20020
  CONFIG_ARCNET_COM20020_PCI
  CONFIG_ARCNET_COM90xxIO
  CONFIG_ARCNET_COM90xx
  CONFIG_ARCNET_RAW
  CONFIG_ARCNET_RIM_I
  CONFIG_DECNET
  CONFIG_DECNET_NF_GRABULATOR
- commit b3b71bf
* Thu Apr 26 2012 jeffm@suse.com
- Disabled embedded hardware on all architectures except armv7l.
  Regulator drivers, except those needed by Via vx885/875 and OLPC
  are disabled.  IIO drivers are disabled.  SPI drivers are disabled.
  Drivers used only with Intel Medfield or Moorestown have been disabled.
  Specific options disabled:
  CONFIG_AD2S1200, CONFIG_AD2S1210, CONFIG_AD2S90, CONFIG_AD5064,
  CONFIG_AD5360, CONFIG_AD5380, CONFIG_AD5421, CONFIG_AD5446, CONFIG_AD5504,
  CONFIG_AD5624R_SPI, CONFIG_AD5686, CONFIG_AD5764, CONFIG_AD5791,
  CONFIG_AD5930, CONFIG_AD5933, CONFIG_AD7150, CONFIG_AD7152, CONFIG_AD7192,
  CONFIG_AD7280, CONFIG_AD7291, CONFIG_AD7298, CONFIG_AD7476,
  CONFIG_AD7606_IFACE_PARALLEL, CONFIG_AD7606_IFACE_SPI, CONFIG_AD7606,
  CONFIG_AD7746, CONFIG_AD7780, CONFIG_AD7793, CONFIG_AD7816, CONFIG_AD7887,
  CONFIG_AD799X, CONFIG_AD799X_RING_BUFFER, CONFIG_AD9832, CONFIG_AD9834,
  CONFIG_AD9850, CONFIG_AD9852, CONFIG_AD9910, CONFIG_AD9951,
  CONFIG_ADE7753, CONFIG_ADE7754, CONFIG_ADE7758, CONFIG_ADE7759,
  CONFIG_ADE7854_I2C, CONFIG_ADE7854, CONFIG_ADE7854_SPI, CONFIG_ADIS16060,
  CONFIG_ADIS16080, CONFIG_ADIS16130, CONFIG_ADIS16201, CONFIG_ADIS16203,
  CONFIG_ADIS16204, CONFIG_ADIS16209, CONFIG_ADIS16220, CONFIG_ADIS16240,
  CONFIG_ADIS16260, CONFIG_ADIS16400, CONFIG_ADT7310, CONFIG_ADT7316_I2C,
  CONFIG_ADT7316, CONFIG_ADT7316_SPI, CONFIG_ADT7410, CONFIG_ADXRS450,
  CONFIG_BACKLIGHT_WM831X, CONFIG_CAN_JANZ_ICAN3, CONFIG_FB_SM501,
  CONFIG_GPIO_JANZ_TTL, CONFIG_GPIO_RDC321X, CONFIG_GPIO_STMPE,
  CONFIG_GPIO_TIMBERDALE, CONFIG_GPIO_WM831X, CONFIG_IIO_BUFFER,
  CONFIG_IIO_CONSUMERS_PER_TRIGGER=2, CONFIG_IIO_GPIO_TRIGGER,
  CONFIG_IIO_KFIFO_BUF, CONFIG_IIO, CONFIG_IIO_PERIODIC_RTC_TRIGGER,
  CONFIG_IIO_SIMPLE_DUMMY, CONFIG_IIO_ST_HWMON, CONFIG_IIO_SW_RING,
  CONFIG_IIO_SYSFS_TRIGGER, CONFIG_IIO_TRIGGER,
  CONFIG_INPUT_MC13783_PWRBUTTON, CONFIG_INPUT_WM831X_ON,
  CONFIG_KEYBOARD_STMPE, CONFIG_KXSD9, CONFIG_LEDS_MC13783,
  CONFIG_LEDS_REGULATOR, CONFIG_LEDS_WM831X_STATUS,
  CONFIG_LIS3L02DQ_BUF_KFIFO, CONFIG_LIS3L02DQ, CONFIG_MAX1363,
  CONFIG_MAX1363_RING_BUFFER, CONFIG_MAX517, CONFIG_MFD_CORE,
  CONFIG_MFD_JANZ_CMODIO, CONFIG_MFD_MC13783, CONFIG_MFD_MC13XXX,
  CONFIG_MFD_RDC321X, CONFIG_MFD_SM501_GPIO, CONFIG_MFD_SM501,
  CONFIG_MFD_STMPE, CONFIG_MFD_TIMBERDALE, CONFIG_MFD_TPS65217,
  CONFIG_MFD_WM831X_SPI, CONFIG_MFD_WM831X, CONFIG_MFD_WM8400,
  CONFIG_RADIO_TIMBERDALE, CONFIG_REGMAP_I2C, CONFIG_REGMAP_SPI,
  CONFIG_REGMAP, CONFIG_REGULATOR_AD5398, CONFIG_REGULATOR_DA903X,
  CONFIG_REGULATOR_DEBUG, CONFIG_REGULATOR_DUMMY,
  CONFIG_REGULATOR_FIXED_VOLTAGE, CONFIG_REGULATOR_GPIO,
  CONFIG_REGULATOR_ISL6271A, CONFIG_REGULATOR_LP3971,
  CONFIG_REGULATOR_LP3972, CONFIG_REGULATOR_MAX1586,
  CONFIG_REGULATOR_MAX8649, CONFIG_REGULATOR_MAX8660,
  CONFIG_REGULATOR_MAX8952, CONFIG_REGULATOR_MC13783,
  CONFIG_REGULATOR_MC13892, CONFIG_REGULATOR_MC13XXX_CORE,
  CONFIG_REGULATOR_PCAP, CONFIG_REGULATOR_TPS6105X,
  CONFIG_REGULATOR_TPS62360, CONFIG_REGULATOR_TPS65023,
  CONFIG_REGULATOR_TPS6507X, CONFIG_REGULATOR_TPS65217,
  CONFIG_REGULATOR_TPS6524X, CONFIG_REGULATOR_USERSPACE_CONSUMER,
  CONFIG_REGULATOR_VIRTUAL_CONSUMER, CONFIG_REGULATOR_WM831X,
  CONFIG_REGULATOR_WM8400, CONFIG_REGULATOR, CONFIG_RFKILL_REGULATOR,
  CONFIG_RTC_DRV_MC13XXX, CONFIG_RTC_DRV_WM831X, CONFIG_SCA3000,
  CONFIG_SENSORS_AK8975, CONFIG_SENSORS_HMC5843, CONFIG_SENSORS_ISL29018,
  CONFIG_SENSORS_MC13783_ADC, CONFIG_SENSORS_TSL2563, CONFIG_SENSORS_WM831X,
  CONFIG_SERIAL_MFD_HSU, CONFIG_SERIAL_UARTLITE, CONFIG_STMPE_I2C,
  CONFIG_STMPE_SPI, CONFIG_TOUCHSCREEN_MC13783, CONFIG_TOUCHSCREEN_STMPE,
  CONFIG_TOUCHSCREEN_WM831X, CONFIG_TPS6105X, CONFIG_TSL2583,
  CONFIG_WM831X_BACKUP, CONFIG_WM831X_POWER, CONFIG_WM831X_WATCHDOG
- commit 60e1dd7
* Thu Apr 26 2012 jeffm@suse.com
- Disabled CONFIG_COPS and CONFIG_LTPC: Ancient ISA LocalTalk hardware.
- commit 5fd070c
* Wed Apr 25 2012 jeffm@suse.com
- Update to 3.4-rc4.
- commit 47dcd83
* Tue Apr 24 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc4-next-20120424
- commit 23749eb
* Sun Apr 22 2012 jeffm@suse.com
- Update config files: Merged omap2plus changes.
- commit 6742196
* Fri Apr 20 2012 jbeulich@novell.com
- Update Xen patches to 3.4-rc3 and c/s 1172.
- config.conf: Re-enabled Xen configs.
- Update config files.
- commit 34bb2c2
* Fri Apr 20 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc3-next-20120420
- commit 86c0da5
* Wed Apr 18 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc3-next-20120418
- commit 6347479
* Tue Apr 17 2012 jeffm@suse.com
- Update to 3.4-rc3.
  - Eliminated 1 patch.
- commit 1cdec0c
* Tue Apr 17 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc3-next-20120417
- commit 403711c
* Fri Apr 13 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc2-next-20120413
- commit b858a28
* Thu Apr 12 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc2-next-20120412
- commit 2c805cc
* Wed Apr 11 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc2-next-20120411
- commit 5207c52
* Mon Apr  9 2012 jeffm@suse.com
- Update to 3.4-rc2.
- commit 2d0834c
* Thu Apr  5 2012 jeffm@suse.com
- Update richacl patchset for 3.4.
- commit 1820194
* Thu Apr  5 2012 jeffm@suse.com
- Updated to 3.4-rc1.
  - Eliminated 121 patches.
  - Xen is unavailable.
  - ACPI overrides are unavailable.
  - AppArmor network feature are unavailable.
- commit b87f45c
* Thu Apr  5 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc1-next-20120405
- commit 2175f93
* Wed Apr  4 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc1-next-20120404
- commit 73a9fe5
* Tue Apr  3 2012 mmarek@suse.cz
- Automatically updated to 3.4-rc1-next-20120403
- commit dbb767a
* Mon Apr  2 2012 jeffm@suse.de
- armv7l: Disable CONFIG_TOUCHSCREEN_EGALAX on default and u8500 due to missing infrastructure.
- commit 91d2885
* Fri Mar 30 2012 mmarek@suse.cz
- Automatically updated to 3.3-next-20120330
- commit fa785ad
* Thu Mar 29 2012 mmarek@suse.cz
- Automatically updated to 3.3-next-20120329
- commit 20e124c
* Tue Mar 27 2012 mmarek@suse.cz
- Automatically updated to 3.3-next-20120327
- commit cef0e7b
* Mon Mar 26 2012 mmarek@suse.cz
- Automatically updated to 3.3-next-20120326
- commit 206e7d7
* Fri Mar 23 2012 mmarek@suse.cz
- Automatically updated to 3.3-next-20120323
- commit a1b77b6
* Thu Mar 22 2012 mmarek@suse.cz
- Automatically updated to 3.3-next-20120322
- commit 36e8a01
* Thu Mar 22 2012 jeffm@suse.com
- Update config files: Disable CONFIG_INTEL_IOMMU_DEFAULT_ON (bnc#740102 and others)
- commit 842c4d7
* Thu Mar 22 2012 jeffm@suse.de
- Update config files: Disabled CONFIG_COMPAT_BRK and CONFIG_COMPAT_VDSO (FATE#313171)
- commit 62108b4
* Wed Mar 21 2012 mmarek@suse.cz
- Automatically updated to 3.3-next-20120321
- commit a070d37
* Mon Mar 19 2012 jeffm@suse.com
- Update vanilla config files.
- commit 1feb084
* Mon Mar 19 2012 jeffm@suse.com
- Update to 3.3-final.
- commit f59d863
* Sat Mar 17 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc7-next-20120316
- commit 50228e7
* Fri Mar 16 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc7-next-20120315
- commit 7f57195
* Thu Mar 15 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc7-next-20120314
- commit c21d945
* Wed Mar 14 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc7-next-20120313
- commit 9fec1f5
* Mon Mar 12 2012 jeffm@suse.com
- Update to 3.3-rc7.
- commit ec992f9
* Sat Mar 10 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc6-next-20120309
- commit 05afd72
* Fri Mar  9 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc6-next-20120308
- commit a620ea6
* Thu Mar  8 2012 mmarek@suse.cz
- Fix vanilla config files.
- commit 67a1d7d
* Thu Mar  8 2012 mmarek@suse.cz
- Delete patches.rpmify/nvme-broken, nvme builds again on 32bit.
- commit d944890
* Thu Mar  8 2012 mmarek@suse.cz
- rpm/config.sh: Build against 12.1
- commit 608c374
* Thu Mar  8 2012 mmarek@suse.cz
- Delete patches.rpmify/nvme-broken, nvme builds on 32bit again
- commit 73d8ebb
* Thu Mar  8 2012 agraf@suse.de
- armv7l: config: omap: disable HDMI output (breaks build)
- commit bc8cbe6
* Thu Mar  8 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc6-next-20120307
- commit 01c2dc5
* Wed Mar  7 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc6-next-20120306
- commit 2c445c2
* Tue Mar  6 2012 agraf@suse.de
- armv7l: omap2plus: Enable TIDSPBRIDGE and SND codecs
- commit dea4b8a
* Mon Mar  5 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc6-next-20120305
- commit 0f59e96
* Mon Mar  5 2012 jeffm@suse.com
- Update to 3.3-rc6.
- commit b0274ee
* Sun Mar  4 2012 jslaby@suse.cz
- Update config files.
  Enable RT2800USB_RT35XX and RT2800USB_RT53XX.
- commit 01d45cd
* Fri Mar  2 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc5-next-20120302
- commit 11c8e6e
* Thu Mar  1 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc5-next-20120301
- commit 7732786
* Wed Feb 29 2012 jbeulich@novell.com
- Update Xen patches to 3.3-rc5 and c/s 1157.
- config.conf: Re-enable Xen configs.
- Update config files.
- commit 023fbdf
* Wed Feb 29 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc5-next-20120229
- commit 6f1ffc5
* Tue Feb 28 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc5-next-20120228
- commit d855486
* Fri Feb 24 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc4-next-20120224
- commit 98f485e
* Thu Feb 23 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc4-next-20120223
- commit 4d95298
* Wed Feb 22 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc4-next-20120222
- commit 7046fca
* Tue Feb 21 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc4-next-20120221
- commit 8df5794
* Mon Feb 20 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc4-next-20120220
- commit dbc1b18
* Sun Feb 19 2012 jeffm@suse.com
- Updated to 3.3-rc4.
- commit 36ab62b
* Fri Feb 17 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc3-next-20120217
- commit 0d327f2
* Thu Feb 16 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc3-next-20120216
- commit aa6d2f9
* Wed Feb 15 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc3-next-20120215
- commit f6ee89a
* Tue Feb 14 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc3-next-20120214
- commit 3d37f5a
* Mon Feb 13 2012 mmarek@suse.cz
- nvme: Mark as broken on x86_32.
- commit 3408530
* Mon Feb 13 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc3-next-20120213
- commit e0b5fa0
* Sun Feb 12 2012 trenn@suse.de
- Add driver auto probing for x86 features v4
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86/cpu: Fix overrun check in arch_print_cpu_modalias()
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- crypto: Add support for x86 cpuid
  auto loading for x86 crypto drivers
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86/cpu: Clean up modalias feature matching
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel-idle: convert to x86_cpu_id auto probing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel_idle: Fix ID for Nehalem-EX Xeon in device ID table
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- HWMON: Convert via-cputemp to x86 cpuid autoprobing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- powernow-k7: Fix CPU family number
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- ACPI: Load acpi-cpufreq from processor driver automatically
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- intel_idle: Revert change of auto_demotion_flags for Nehalem
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- HWMON: Convert coretemp to x86 cpuid autoprobing
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- powernow-k6: Really enable auto-loading
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- X86: Introduce HW-Pstate scattered cpuid feature
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- cpufreq: Add support for x86 cpuinfo auto loading v4
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- x86: autoload microcode driver on Intel and AMD systems v2
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- CPU: Introduce ARCH_HAS_CPU_AUTOPROBE and X86 parts
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- ACPI: remove duplicated lines of merging
  problems with acpi_processor_start
  (http://lists.opensuse.org/opensuse-kernel/2011-11/msg00075.html).
- Update config files.
- commit 24191d0
* Fri Feb 10 2012 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Build x86 packages as i686, except for
  - default (bnc#745632). KMPs are still built as i586.
- commit 88a632b
* Fri Feb 10 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc3-next-20120210
- commit 3ed273c
* Thu Feb  9 2012 agraf@suse.de
- armv7l: Update config files.
- commit b00a12e
* Thu Feb  9 2012 agraf@suse.de
- armv7l: config: integrate bmwiedemann's updates to make it usable
- commit a1b9e7f
* Thu Feb  9 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc2-next-20120209
- commit d77da42
* Thu Feb  9 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc2-next-20120208
- commit 246830b
* Tue Feb  7 2012 jeffm@suse.com
- Update vanilla config files.
- commit 2de2e2a
* Tue Feb  7 2012 jeffm@suse.com
- Update to 3.3-rc2.
  - Eliminated 5 patches.
  - Xen is disabled.
- commit 4c9206f
* Tue Feb  7 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc2-next-20120207
- commit 7cb88b2
* Mon Feb  6 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc2-next-20120206
- commit 1a25f5c
* Fri Feb  3 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc2-next-20120203
- commit 1ea4c48
* Thu Feb  2 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc2-next-20120202
- commit df20145
* Wed Feb  1 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc2-next-20120201
- commit c37560b
* Tue Jan 31 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc1-next-20120131
- commit 0e73f8c
* Mon Jan 30 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc1-next-20120130
- commit ba083b5
* Fri Jan 27 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc1-next-20120127
- commit bc395d1
* Wed Jan 25 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc1-next-20120125
- commit eb1abfc
* Tue Jan 24 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc1-next-20120124
- commit 8d166ee
* Mon Jan 23 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc1-next-20120123
- commit 73a4f95
* Fri Jan 20 2012 mmarek@suse.cz
- Automatically updated to 3.3-rc1-next-20120120
- commit 54fbf55
* Thu Jan 19 2012 mmarek@suse.cz
- Automatically updated to 3.2-next-20120119
- commit 83f5bd7
* Wed Jan 18 2012 mmarek@suse.cz
- Automatically updated to 3.2-next-20120118
- commit 2dd522c
* Tue Jan 17 2012 mmarek@suse.cz
- Automatically updated to 3.2-next-20120117
- commit 6404248
* Mon Jan 16 2012 mmarek@suse.cz
- Automatically updated to 3.2-next-20120116
- commit f48a17d
* Fri Jan 13 2012 agraf@suse.de
- ARM: Update config files: Enable highmem everywhere
- commit 759f64a
* Fri Jan 13 2012 mmarek@suse.cz
- Automatically updated to 3.2-next-20120113
- commit 0574f3b
* Thu Jan 12 2012 mmarek@suse.cz
- Automatically updated to 3.2-next-20120112
- commit 66fd259
* Wed Jan 11 2012 mmarek@suse.cz
- Automatically updated to 3.2-next-20120111
- commit e60abc2
* Tue Jan 10 2012 mmarek@suse.cz
- Automatically updated to 3.2-next-20120110
- commit 7e5bac1
* Mon Jan  9 2012 mmarek@suse.cz
- Set CONFIG_LOCALVERSION for armv7l/u8500.
- commit 5b2d652
* Mon Jan  9 2012 mmarek@suse.cz
- Automatically updated to 3.2-next-20120109
- commit a4c2bc8
* Sat Jan  7 2012 mmarek@suse.cz
- Automatically updated to 3.2-next-20120106
- commit aaafcec
* Fri Jan  6 2012 awafaa@opensuse.org
- add support for ST-Ericsson Nova based SoCs
- commit 58b8258
* Fri Jan  6 2012 mmarek@suse.cz
- Automatically updated to 3.2-rc7-next-20120105
- commit 63a5bcd
* Thu Jan  5 2012 jeffm@suse.com
- Update to 3.2-final.
- commit 6872828
* Thu Jan  5 2012 mmarek@suse.cz
- Automatically updated to 3.2-rc7-next-20120104
- commit 2cdc781
* Wed Jan  4 2012 mmarek@suse.cz
- Automatically updated to 3.2-rc7-next-20120103
- commit be24a61
* Thu Dec 29 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc7-next-20111228
- commit d931293
* Thu Dec 22 2011 jeffm@suse.com
- Update config files.
- CONFIG_X86_INTEL_MID -> CONFIG_X86_WANT_INTEL_MID
- commit 7e3e6d7
* Thu Dec 22 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc6-next-20111222
- commit b009923
* Wed Dec 21 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc6-next-20111221
- commit 4d7ad96
* Tue Dec 20 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc6-next-20111219
- commit fffa396
* Sun Dec 18 2011 aj@suse.de
- rpm/kernel-source.rpmlintrc: The hidden files are fine, silence rpmlint.
- commit a7813dd
* Fri Dec 16 2011 aj@suse.de
- rpm/kernel-binary.spec.in: Add provides and make most obsoletes versioned.
  This silences rpmlint warnings.
- commit e3023c7
* Fri Dec 16 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc5-next-20111216
- commit b9ab827
* Thu Dec 15 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc5-next-20111214
- commit c70ad3a
* Wed Dec 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: Fix tarball URL for -rcX and
  do not generate any URL for linux-next and vanilla snapshots.
- commit 1548daf
* Wed Dec 14 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc5-next-20111213
- commit 7473ecb
* Wed Dec 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: Fix linux tarball URL
- commit 5453f99
* Tue Dec 13 2011 agraf@suse.de
- PPC: Update config files: disable CONFIG_DEBUG_STACKOVERFLOW
- commit 705c502
* Mon Dec 12 2011 aj@suse.de
- Silence missing defattr warning.
- commit e7e3743
* Mon Dec 12 2011 aj@suse.de
- Silence warning about dangling symlink and vdsos
- commit 701c5c7
* Mon Dec 12 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc5-next-20111212
- commit e714b3a
* Fri Dec  9 2011 aj@suse.de
- No self-obsoletions.
- commit 1d2e747
* Fri Dec  9 2011 aj@suse.de
- Do not show rpmlint warnings.
- commit bb45b41
* Fri Dec  9 2011 aj@suse.de
- Use versioned provides/obsoletes.
- commit cf4f296
* Fri Dec  9 2011 aj@suse.de
- Adjust kernel-source.rpmlintrc for Linux 3.x
- commit bc1534e
* Fri Dec  9 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc4-next-20111209
- commit 3fef93b
* Thu Dec  8 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not package the vmlinux image in the devel
  package.
- commit 02bb976
* Thu Dec  8 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc4-next-20111208
- commit c7aabb3
* Wed Dec  7 2011 aj@suse.de
- Use GPL-2.0 as license tag (from http://spdx.org/licenses/)
  Only have one licenses line per file, the rest was just duplicated.
- commit f7c443c
* Wed Dec  7 2011 aj@suse.de
- Fix typo: Base package should not conflict with itself but with main package.
- commit e961ef0
* Wed Dec  7 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc4-next-20111207
- commit 241b78a
* Tue Dec  6 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc4-next-20111206
- commit 4ab73f9
* Tue Dec  6 2011 jeffm@suse.com
- Update to 3.2-rc4.
  - Eliminated 1 patch.
- commit a371aa2
* Mon Dec  5 2011 agraf@suse.de
- ARM: Update config files: omap: enable power management
- commit 5832939
* Mon Dec  5 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc4-next-20111205
- commit 620f519
* Fri Dec  2 2011 mmarek@suse.cz
- Disable CONFIG_ANDROID, it can't be built as module and use of little
  use outside Android.
- commit 16403cc
* Fri Dec  2 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc3-next-20111202
- commit c61cf83
* Thu Dec  1 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc3-next-20111201
- commit 8ec8788
* Wed Nov 30 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc3-next-20111130
- commit e01f21b
* Tue Nov 29 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Make the -base package conflict with the main
  one.
- commit 45ada0d
* Tue Nov 29 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc3-next-20111129
- commit e61ca86
* Mon Nov 28 2011 jeffm@suse.com
- Fix kernel-source spec to give ownership of the /usr/src/linux link
  to kernel-devel. kernel-source depends on kernel-devel, so this is correct.
- commit 7160a9c
* Mon Nov 28 2011 jbeulich@novell.com
- Update Xen patches to 3,2-rc3 and c/s 1127.
- Update frontswap patches to v10.
- config.conf: Re-enable Xen.
- Update config files.
- commit 5a64fb5
* Mon Nov 28 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Ignore staging failures only in vanilla only
  branches.
- commit eeaaaf1
* Mon Nov 28 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc3-next-20111128
- commit f6eccb9
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: set omap_fb=y
- commit 10cf6dc
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: disable OMAP2 to fix reboots
- commit d247631
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable DVI
- commit 2ea05c2
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable ehci
- commit 47f78d4
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable pandaboard usb
- commit e39d076
* Fri Nov 25 2011 agraf@suse.de
- ARM: config: omap: enable pandaboard LAN
- commit 39b016d
* Fri Nov 25 2011 agraf@suse.de
- ARM: configs: Align with non-arm configs
- commit 9bacb92
* Fri Nov 25 2011 agraf@suse.de
- ARM: configs: enable devtmpfs on all targets
- commit 96496dc
* Fri Nov 25 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc3-next-20111125
- commit 8e316ca
* Fri Nov 25 2011 jeffm@suse.com
- Update config files for vanilla.
- commit f158a8a
* Fri Nov 25 2011 jeffm@suse.com
- Update to 3.2-rc3.
  - stack unwind: cfi_ignore takes more arguments.
  - iio: Fix build error in industrialio-core.c.
- commit c5d389f
* Thu Nov 24 2011 mmarek@suse.cz
- rpm/try-disable-staging-driver: Script to disable failing staging
  driver and restart make.
- commit 819d1fa
* Thu Nov 24 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not have a separate make invocation for
  s390 and the rest.
- commit d72f6c1
* Thu Nov 24 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc2-next-20111124
- commit 0b18fe8
* Thu Nov 24 2011 agraf@suse.de
- ARM: Update config file file i.MX51 (disable i.MX53)
- commit ffe896f
* Wed Nov 23 2011 agraf@suse.de
- ARM: create uImage, not zImage, so we can boot with u-boot
- commit 63a7b2c
* Wed Nov 23 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc2-next-20111123
- commit fc54d2c
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: fix several issues in 3.2
- commit cfe50b9
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: disable broken eth driver
- commit f6e44d3
* Tue Nov 22 2011 agraf@suse.de
- ARM: Update config files: run_oldconfig.sh
- commit b2d101c
* Tue Nov 22 2011 agraf@suse.de
- ARM: Use zImage, not vmlinux
  On ARM we use the arch/arm/boot/zImage file similar to x86 to boot systems.
  Put that into the rpm as vmlinuz instead of the vmlinux ELF binary.
- commit 4c08eb0
* Tue Nov 22 2011 agraf@suse.de
- ARM: Dont generalize the target
  On ARM we can not build generic kernels that work through different generations,
  such as armv5 and armv7. So we better list them explicitly and not export an rpm
  that wouldn't even work on the respective architecture :).
- commit 854928d
* Mon Nov 21 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc2-next-20111121
- commit e420b4e
* Thu Nov 17 2011 bpoirier@suse.de
- dm-raid45: split region hash and log, used by mirror and raid45.
- Update config files.
- commit 1cb7291
* Wed Nov 16 2011 jeffm@suse.com
- Update to 3.2-rc2.
  - Eliminated 1 patch.
- commit 2ee84e4
* Wed Nov 16 2011 jeffm@suse.com
- Update to 3.2-rc1.
  - Eliminate 212 patches.
- commit 68cad9f
* Tue Nov 15 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc1-next-20111115
- commit 3969294
* Mon Nov 14 2011 awafaa@opensuse.org
- Add package descriptions for ARM kernels
- Add ARM support for iMX51, OMAP2plus & Tegra SoC
- commit 51ebb2d
* Mon Nov 14 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc1-next-20111114
- commit dc619fd
* Sat Nov 12 2011 adrian@suse.de
- initial armv7l default kernel config, everything enable except the non compiling modules
- commit 6d159bb
* Fri Nov 11 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc1-next-20111111
- commit b797bb7
* Thu Nov 10 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc1-next-20111110
- commit a542929
* Wed Nov  9 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc1-next-20111109
- commit e29675f
* Tue Nov  8 2011 mmarek@suse.cz
- Automatically updated to 3.2-rc1-next-20111108
- commit 6fba090
* Sun Oct 30 2011 mmarek@suse.cz
- rpm/{arch-symbols,mkspec}: Add support for ARM
  The various ARM families need similar handling like i?86.
- commit 0c6be6b
* Fri Oct 14 2011 mmarek@suse.cz
- rpm/*.spec.in, rpm/mkspec: Generate specfiles according to Factory
  requirements.
- commit aebe2d9
* Wed Sep 28 2011 jbeulich@novell.com
- Update Xen config files.
- commit 77bf04b
* Mon Sep 26 2011 mmarek@suse.cz
- rpm/host-memcpy-hack.h: Hack to use older version of the memcpy symbol
  in userspace programs, so that they keep working on older systems.
- rpm/kernel-binary.spec.in: Pass -include
  %%_sourcedir/host-memcpy-hack.h to the compiler when compiling
  userspace programs.
- commit e3c78cf
* Thu Sep 22 2011 mmarek@suse.cz
- rpm/split-modules: Print the full path for modules missing in supported.conf
- commit e55e4c6
* Wed Sep 21 2011 mmarek@suse.cz
- Add support for wildcards in supported.conf
- rpm/kernel-binary.spec.in: Generate Module.supported with all
  lines from supported conf, unsupported modules are marked as "no"
- rpm/split-modules: Use the supported flag in modules, instead of
  parsing the Module.supported file and report modules that have no
  supported marking.
- rpm/check-supported-list: Delete, this is done by split-modules
  now.
- commit edfdc2a
* Wed Sep 21 2011 mhocko@suse.cz
- Provide memory controller swap extension.
  Keep the feature disabled by default. Use swapaccount=1 kernel
  boot parameter for enabling it.
- commit a89ce59
* Wed Sep 21 2011 mhocko@suse.cz
- Update config files.
  Clean run_oldconfig.sh run to get configs into sync
- commit acdc10a
* Tue Sep 20 2011 trenn@suse.de
- ACPI: Implement overriding of arbitrary ACPI tables via initrd
  (none).
- ACPICA: Fix wrongly mapped acpi table header when overriding
  via initrd (none).
- ACPICA: Introduce acpi_os_phys_table_override function (none).
- x86: allow NVS can be accessed by driver (none).
- Update config files:
  CONFIG_ACPI_INITRD_TABLE_OVERRIDE=y
  on i386 and x86_64 flavors
- commit 4671392
* Thu Sep 15 2011 jeffm@suse.de
- Update to 3.1-rc6.
- commit 77688b8
* Mon Sep 12 2011 jbeulich@novell.com
- Update Xen patches to 3.1-rc5 and c/s 1104.
- mm: frontswap: config and doc files.
- mm: frontswap: core code.
- mm: frontswap: add swap hooks and extend try_to_unuse.
- mm: frontswap: swap data structure changes.
- In HVM guests do not take over the CDROM device (bnc#645893).
- x86: report ACPI-reserved state of PCI MMCONFIG region to
  hypervisor.
- config.conf: Re-enable Xen flavors.
- Update config files.
- commit 574ae35
* Sun Sep 11 2011 agraf@suse.de
- Update config files (disable EHCA on PPC - gcc bug)
- commit abe205f
* Sun Sep 11 2011 agraf@suse.de
- Update config files (enable KVM on PPC64 for OBS)
- commit 180afd2
* Mon Sep  5 2011 mmarek@suse.cz
- Update to 3.1-rc5 from https://github.com/torvalds/linux.git.
- commit de74a23
* Wed Aug 31 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc4-next-20110831
- commit f979764
* Mon Aug 29 2011 jeffm@suse.com
- Update to 3.1-rc4.
- commit ae12eae
* Mon Aug 29 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc3-next-20110829
- commit 0b09889
* Wed Aug 24 2011 jeffm@suse.com
- PTI: depends on X86 && PCI.
- commit 945119d
* Wed Aug 24 2011 jeffm@suse.com
- Update to 3.1-rc3.
  - Eliminated 8 patches.
  - Xen is disabled.
- commit 8948499
* Tue Aug 23 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc3-next-20110823
- commit a203272
* Fri Aug 19 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc2-next-20110819
- commit 3132880
* Thu Aug 18 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc2-next-20110817
- commit 3ea94e0
* Wed Aug 17 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc2-next-20110816
- commit 6d05089
* Tue Aug 16 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc2-next-20110815
- commit 84fa5fc
* Sat Aug 13 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc1-next-20110812
- commit 856afff
* Sat Aug 13 2011 gregkh@suse.de
- Update config files, enabling CONFIG_RT2800PCI as requested.
- commit e2f3061
* Fri Aug 12 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc1-next-20110811
- commit c4aa215
* Wed Aug 10 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc1-next-20110810
- commit 52b41c7
* Tue Aug  9 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc1-next-20110809
- commit 7f62fb1
* Tue Aug  9 2011 trenn@suse.de
- Update config files:
  bnc#674988, change:
  - CONFIG_ACPI_CUSTOM_METHOD=m
  +# CONFIG_ACPI_CUSTOM_METHOD is not set
  for all flavors
- commit b3a0ea1
* Mon Aug  8 2011 mmarek@suse.cz
- Automatically updated to 3.1-rc1-next-20110808
- commit 953fbda
* Sat Aug  6 2011 mmarek@suse.cz
- Automatically updated to 3.0-next-20110805
- commit 5aec63d
* Thu Aug  4 2011 mmarek@suse.cz
- Update config files: Disable ZCACHE on x86, as it doesn't build.
- commit f7a02ac
* Thu Aug  4 2011 mmarek@suse.cz
- Automatically updated to 3.0-next-20110804
- commit 2b2db8b
* Wed Aug  3 2011 mmarek@suse.cz
- Automatically updated to 3.0-next-20110803
- commit dee9fb1
* Tue Aug  2 2011 mmarek@suse.cz
- Automatically updated to 3.0-next-20110802
- commit f2e79ac
* Mon Aug  1 2011 mmarek@suse.cz
- rpm/modversions: Support for new genksyms format with E# tags for enum
  constants.
- commit ee6da8c
* Mon Aug  1 2011 mmarek@suse.cz
- Automatically updated to 3.0-next-20110801
- commit 0c66860
* Sat Jul 30 2011 mmarek@suse.cz
- Automatically updated to 3.0-next-20110729
- commit 2dea032
* Thu Jul 28 2011 mmarek@suse.cz
- Automatically updated to 3.0-next-20110728
- commit 61ab895
* Wed Jul 27 2011 mmarek@suse.cz
- Automatically updated to 3.0-next-20110727
- commit 8065669
* Tue Jul 26 2011 mmarek@suse.cz
- Automatically updated to 3.0-next-20110725
- commit cbdd075
* Mon Jul 25 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc7-next-20110722
- commit 7da4e67
* Mon Jul 25 2011 meissner@suse.de
- Powerpc config adjustments
  This makes CONFIG_POWER_SUPPLY=y like in the other architectures,
  it also disables the EHCA driver as gcc 4.6 currently fails to compile
  it correctly.
- commit f29bb11
* Fri Jul 22 2011 mmarek@suse.cz
- Update to 3.0.
- commit c6eed25
* Fri Jul 22 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc7-next-20110721
- commit 211bd08
* Thu Jul 21 2011 jbeulich@novell.com
- Update Xen patches to 3.0-rc7 and c/s 1098.
- Update Xen config files.
- commit 3adad2c
* Thu Jul 21 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc7-next-20110720
- commit 6b52ba3
* Tue Jul 19 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc7-next-20110718
- commit 1c96340
* Sun Jul 17 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc7-next-20110716
- commit 777a403
* Thu Jul 14 2011 tiwai@suse.de
- ALSA: hda - Add Kconfig for the default buffer size
  (bnc#682725).
- Update config files.
- Delete, replaced with the new upstream patch
  patches.drivers/alsa-hda-0019-Increase-default-buffer-size.
- commit d12543f
* Wed Jul 13 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc6-next-20110707
- commit 7b8d542
* Wed Jul 13 2011 jeffm@suse.com
- Update to 3.0-rc7.
- commit 8b7c20a
* Thu Jul  7 2011 jeffm@suse.com
- Update to 3.0-rc6.
  - Eliminated 1 patch.
- commit 61dda6b
* Wed Jul  6 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc6-next-20110705
- commit 44f2d8b
* Tue Jul  5 2011 jbeulich@novell.com
- Update Xen patches to 3.0-rc5 and c/s 1095.
- xen: prepare tmem shim to handle frontswap.
- support booting Xen from EFI (fate#311376, fate#311529,
  bnc#578927, bnc#628554).
- config.conf: Re-enabled Xen flavors.
- Update x86 config files.
- Delete patches.xen/xen-blkback-bimodal-suse.
- commit c0d5d39
* Mon Jul  4 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc5-next-20110704
- commit b08d40b
* Sat Jul  2 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc5-next-20110701
- commit 0927713
* Fri Jul  1 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc5-next-20110630
- commit 675952d
* Thu Jun 30 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc5-next-20110629
- commit a6c942f
* Wed Jun 29 2011 jeffm@suse.com
- Update to 3.0-rc5.
- commit af9784d
* Wed Jun 29 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc4-next-20110628
- commit 2b029b7
* Tue Jun 28 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc4-next-20110627
- commit a8c2b7d
* Fri Jun 24 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc4-next-20110624
- commit ad67ef8
* Fri Jun 24 2011 jeffm@suse.com
- Enable TOMOYO (FATE#310292, bnc#668381).
- commit 13b36d0
* Thu Jun 23 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc4-next-20110623
- commit 114d92c
* Wed Jun 22 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc3-next-20110621
- commit a3c4a4b
* Tue Jun 21 2011 mmarek@suse.cz
- Update vanilla configs.
- commit a6ccbe2
* Tue Jun 21 2011 mmarek@suse.cz
- Update to 3.0-rc4
- commit 656b198
* Mon Jun 20 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc3-next-20110620
- commit c409a54
* Fri Jun 17 2011 mmarek@suse.cz
- rpm/post.sh: Touch /boot/do_purge_kernels on package install
  (fate#312018).
- rpm/postun.sh: Remove it again if it still exists on package
  uninstall.
- commit 82f4a5d
* Fri Jun 17 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc3-next-20110617
- commit cf5628a
* Thu Jun 16 2011 ohering@suse.de
- Update vanilla config files.
- commit d2fa559
* Thu Jun 16 2011 ohering@suse.de
- rpm/kernel-binary.spec.in:
  jobs is not defined for home: projects, use the new _smp_mflags to enable parallel build
- commit 1009eaf
* Thu Jun 16 2011 ohering@suse.de
- rpm/kernel-binary.spec.in:
  Update comment, get the number of cpus from /proc/stat
- commit b4cf18c
* Thu Jun 16 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc3-next-20110616
- commit f40cffe
* Wed Jun 15 2011 jeffm@suse.com
- Update config files: Disable BRCMSMAC on ppc/ppc64.
- commit 6347281
* Wed Jun 15 2011 jeffm@suse.com
- Update to 3.0-rc3.
  - Eliminated 2 patches.
- commit 9fd545d
* Wed Jun 15 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc3-next-20110615
- commit 14aa7ef
* Tue Jun 14 2011 mmarek@suse.cz
- Automatically updated to 3.0-rc3-next-20110614
- commit 734b0a0
* Mon Jun 13 2011 jeffm@suse.com
- Update config files.
- commit 778fdea
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Call gzip with -n.
- commit 9a65e48
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/mkspec: Put the -rcX tag into the rpm version instead of the
  trailing zero. Rpm considers "rc" older than "0", so this will sort
  properly.
- commit 8d9b2b9
* Mon Jun 13 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Set default PATCHLEVEL and SUBLEVEL to 0.
  The package version will thus always match the Makefile version and
  the SRCVERSION variable will only be used to determine the tarball
  version.
- commit 95c9977
* Fri Jun 10 2011 mmarek@suse.cz
- Automatically updated to 3.0.0-rc2-next-20110609
- commit e375f21
* Thu Jun  9 2011 mmarek@suse.cz
- Automatically updated to 3.0.0-rc2-next-20110608
- commit b268928
* Wed Jun  8 2011 jeffm@suse.com
- Revert "Revert "- Updated to 3.0-rc1.""
  This reverts commit b2d9e72dc9cd8e62d49e0565babd76332f7c2114.
  Conflicts:
  rpm/config.sh
  series.conf
- commit af3cb42
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix for empty EXTRAVERSION
- commit a0a1386
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix for 3.0
- commit dca1465
* Tue Jun  7 2011 mmarek@suse.cz
- rpm/mkspec: Fix perl warning
- commit 395d7d8
* Tue Jun  7 2011 mmarek@suse.cz
- Automatically updated to 3.0.0-rc2-next-20110607
- commit e7d673e
* Mon Jun  6 2011 mmarek@suse.cz
- README.BRANCH: Update information about linux-next
- commit 8e56c60
* Mon Jun  6 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Loosen the mkinitrd requirement, this was
  only a workaround for a 11.3 update problem (cf bnc#615680).
- commit 05ade7d
* Mon Jun  6 2011 mmarek@suse.cz
- Automatically updated to 3.0.0-rc1-next-20110606
- commit 476c4a9
* Sat Jun  4 2011 mmarek@suse.cz
- Automatically updated to 3.0.0-rc1-next-20110603
- commit d59a25a
* Fri Jun  3 2011 mmarek@suse.cz
- Temporarily set PPC_DISABLE_WERROR=y in power to fix build
- commit dfa5ab8
* Fri Jun  3 2011 mmarek@suse.cz
- rpm/macros.kernel-source: Add -b option to %%kernel_module_package
  to unconditionally call mkinitrd on kmp install (fate#309400).
- rpm/kernel-module-subpackage: Pass KMP_NEEDS_MKINITRD=1 to
  weak-modules2 if the -b option is used.
- commit 83331f5
* Thu Jun  2 2011 mmarek@suse.cz
- Automatically updated to 3.0.0-rc1-next-20110602
- commit 761991b
* Wed Jun  1 2011 mmarek@suse.cz
- Automatically updated to 3.0.0-rc1-next-20110601
- commit da915a8
* Tue May 31 2011 jeffm@suse.com
- Revert "- Updated to 3.0-rc1."
  This reverts commit 5710413eb834b0f215f6f4249d6ff7c3f7673eb7.
  Should have been committed to the merge-v3.0 branch.
- commit 2ca3a35
* Tue May 31 2011 jeffm@suse.com
- Updated to 3.0-rc1.
  - Eliminated 9 patches.
- commit 0676207
* Mon May 30 2011 mmarek@suse.cz
- Automatically updated to 3.0.0-rc1-next-20110530
- commit eae976b
* Fri May 27 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Set KBUILD_BUILD_{USER,HOST} to
  geeko@buildhost, obsoleting the patch to scripts/mkcompile_h.
- commit b4b7255
* Fri May 27 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-next-20110527
- commit 14524f6
* Wed May 25 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-next-20110525
- commit 0a8194c
* Tue May 24 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-next-20110524
- commit 4f041e0
* Mon May 23 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-next-20110523
- commit 7683d41
* Sat May 21 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-next-20110520
- commit 3c0dbb7
* Fri May 20 2011 jeffm@suse.com
- Updated to 2.6.39-final.
- commit 5423d95
* Thu May 19 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc7-next-20110519
- commit f9083d5
* Wed May 18 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc7-next-20110518
- commit 845bc42
* Tue May 17 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc7-next-20110517
- commit a69a175
* Mon May 16 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Add the commit hash to uname -v, cleanup.
- commit f3bdb4c
* Mon May 16 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc7-next-20110516
- commit ca3e01c
* Fri May 13 2011 jeffm@suse.com
- Update to 2.6.39-rc7.
  - Eliminated 5 patches.
- commit bc966f5
* Fri May 13 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc7-next-20110513
- commit 0340532
* Thu May 12 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc7-next-20110512
- commit c762443
* Wed May 11 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc7-next-20110511
- commit fdf4967
* Tue May 10 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc6-next-20110510
- commit 751253f
* Sat May  7 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc6-next-20110506
- commit 6a619fb
* Fri May  6 2011 jeffm@suse.com
- sysctl: Increase IPC defaults (bnc#146656)
  - Delete patches.suse/shmall-bigger.
- commit 777a380
* Fri May  6 2011 jeffm@suse.com
- sysctl/i386/desktop, sysctl/x86_64/desktop: Add vm.dirty_ratio = 20
  for desktop flavors (bnc#552883)
  - Delete patches.suse/mm-tune-dirty-limits.patch.
- commit 53d5648
* Fri May  6 2011 jeffm@suse.com
- sysctl/defaults: Added kernel.hung_task_timeout=0
  - Delete patches.suse/hung_task_timeout-configurable-default.
- commit eabe698
* Fri May  6 2011 mmarek@suse.cz
- rpm/kernel-{binary,source}.spec.in: Install per-kernel /boot/sysctl-*
  files (patch from Jeff Mahoney).
- commit 473f2d1
* Thu May  5 2011 jeffm@suse.com
- Update config files for -vanilla.
- commit 3008d73
* Thu May  5 2011 jeffm@suse.com
- Updated to 2.6.39-rc6.
  - 2 patches eliminated.
- commit bd72594
* Thu May  5 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc6-next-20110505
- commit 9b9043a
* Tue May  3 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc5-next-20110503
- commit 4fa156a
* Mon May  2 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc5-next-20110502
- commit 154c02e
* Fri Apr 29 2011 jeffm@suse.com
- rpm/compute-PATCHVERSION.sh: Replace ^+++ with ^\+\+\+ as an
    awk regex. It's technically invalid.
- commit 52dd0f0
* Fri Apr 29 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc5-next-20110429
- commit d287142
* Thu Apr 28 2011 jbeulich@novell.com
- Update i386 Xen config files.
- commit 5b68cfd
* Wed Apr 27 2011 jeffm@suse.com
- Update to 2.6.39-rc5.
  - Eliminated 2 patches.
- commit 8fcb89b
* Wed Apr 27 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc4-next-20110427
- commit 40645d5
* Fri Apr 22 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc4-next-20110421
- commit c1624fe
* Tue Apr 19 2011 jack@suse.cz
- Revert changes to sparc configs to not make life harder for Jan Engelhardt
  maintaining sparc architecture.
- commit d936b77
* Tue Apr 19 2011 jack@suse.cz
- Update vanilla config files.
- commit f78056e
* Tue Apr 19 2011 jeffm@suse.com
- Updated to 2.6.39-rc4.
  - Eliminated 1 patch.
- commit 1e380f4
* Tue Apr 19 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc3-next-20110419
- commit f0ff903
* Mon Apr 18 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc3-next-20110418
- commit fdf71e4
* Sat Apr 16 2011 jack@suse.cz
- Disable ext2, use ext4 instead as a driver
- Update config files.
- commit 4472410
* Fri Apr 15 2011 jeffm@suse.com
- Enabled CONFIG_GIGASET_CAPI (bnc#686008).
  - This results in automatically disabling CONFIG_GIGASET_I4L.
- commit 51aadf9
* Fri Apr 15 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc3-next-20110415
- commit ea9b00b
* Fri Apr 15 2011 jbeulich@novell.com
- Update Xen patches to 2.6.39-rc3 and c/s 1079.
- blktap2: replace hard-coded limit of tap devices with
  configurable one.
- config.conf: Re-enable Xen configs.
- Update x86 config files.
- commit a4de524
* Tue Apr 12 2011 jeffm@suse.com
- Updated to 2.6.39-rc3.
  - Eliminated 2 patches.
- commit 827feed
* Tue Apr 12 2011 jeffm@suse.com
- Update config files for -vanilla.
- commit 11dfe34
* Tue Apr 12 2011 jeffm@suse.com
- Update to 2.6.39-rc2.
  - Eliminated 18 patches.
  - Added 3 patches.
  - hv_mouse: needs <linux/delay.h>.
  - dm-raid45: Remove blk_unplug calls.
  - novfs: 2.6.39 API update.
  - Xen, Swap-over-NFS, and certain SCSI multipath features are disabled.
  - patches.kernel.org is no longer used to contain upstream patches
    for -rc releases. Users planning on building their own kernel should
    have a copy of the tarball corresponding to the -rc releases.
- commit 7d4f459
* Tue Apr 12 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc3-next-20110412
- commit fbbb8c7
* Mon Apr 11 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc2-next-20110411
- commit b6c17a1
* Sat Apr  9 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc2-next-20110408
- commit d69f4c8
* Thu Apr  7 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc2-next-20110407
- commit 4630426
* Tue Apr  5 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc1-next-20110405
- commit 4c9902d
* Mon Apr  4 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc1-next-20110404
- commit 1b1b79b
* Fri Apr  1 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc1-next-20110401
- commit c3ee5bc
* Thu Mar 31 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc1-next-20110331
- commit 2fab579
* Wed Mar 30 2011 mmarek@suse.cz
- Automatically updated to 2.6.39-rc1-next-20110330
- commit 791e5e9
* Tue Mar 29 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-next-20110329
- commit fba646e
* Mon Mar 28 2011 trenn@suse.de
- Update config files, remove CONFIG_X86_MCE_XEON75XX=m
  - >driver got reverted with previous commit
- Refresh patches.xen/xen3-auto-arch-x86.diff.
- commit 4051735
* Mon Mar 28 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not install unneeded packages in the
  build chroot.
- commit 7f4c49d
* Mon Mar 28 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-next-20110328
- commit 79d10e0
* Fri Mar 25 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-next-20110325
- commit 452695b
* Thu Mar 24 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-next-20110324
- commit 83ef783
* Wed Mar 23 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-next-20110323
- commit 8f06d4e
* Tue Mar 22 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-next-20110322
- commit f78c8d4
* Mon Mar 21 2011 mmarek@suse.cz
- Delete config/i386/vmi, it was an artifact from SLE11-SP1 development.
- commit 9c7b60b
* Mon Mar 21 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-next-20110321
- commit a841d95
* Sat Mar 19 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-next-20110318
- commit fefbec9
* Thu Mar 17 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-next-20110317
- commit da524ce
* Wed Mar 16 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-next-20110316
- commit d63a970
* Tue Mar 15 2011 jeffm@suse.com
- Update to 2.6.38.
- commit 9e83eee
* Tue Mar 15 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc8-next-20110314
- commit e0df894
* Sat Mar 12 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc8-next-20110311
- commit 5b5e150
* Fri Mar 11 2011 jbeulich@novell.com
- Update Xen patches to 2.6.38-rc7 and c/s 1072
- pv-ops blktap2.
- adjust xen build after addition of pv-ops' blktap2.
- blktap: Fix reference to freed struct request.
- cleanup to blkback and blktap.
- apply xen specific patch to the Chelsio ethernet drivers.
- Update Xen config files.
- commit d210453
* Fri Mar 11 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc8-next-20110310
- commit 45a75a7
* Thu Mar 10 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc8-next-20110309
- commit 8b31b21
* Wed Mar  9 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc7-next-20110308
- commit fbc08ac
* Tue Mar  8 2011 mmarek@suse.cz
- tty: Move remaining headers to drivers/staging.
- commit cea6351
* Tue Mar  8 2011 mmarek@suse.cz
- staging: gma500: Fix compilation error.
- commit 449a4ba
* Tue Mar  8 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc7-next-20110307
- commit 7f88de0
* Mon Mar  7 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not abort build because of
  supported.conf inconsistency if %%supported_modules_check == 0.
- commit 88d5daa
* Sat Mar  5 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc7-next-20110304
- commit 1075eef
* Fri Mar  4 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc7-next-20110303
- commit 31d0fa1
* Thu Mar  3 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc7-next-20110302
- commit b4d8bdd
* Wed Mar  2 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc6-next-20110301
- commit ffc8a78
* Tue Mar  1 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc6-next-20110228
- commit e562754
* Sat Feb 26 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc6-next-20110225
- commit 9d83bf9
* Fri Feb 25 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc6-next-20110224
- commit f8ce52a
* Thu Feb 24 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove unused code.
- commit dacbc44
* Wed Feb 23 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc6-next-20110223
- commit d37010b
* Tue Feb 22 2011 jeffm@suse.com
- Update to 2.6.38-rc6.
  - Eliminated 1 patch.
- commit 11b889d
* Tue Feb 22 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc5-next-20110222
- commit 4b4c151
* Tue Feb 22 2011 mmarek@suse.cz
- rpm/mkspec: Do not create kernel-syms.spec on vanilla-only branches
- commit eb17bba
* Tue Feb 22 2011 mmarek@suse.cz
- spi: fix build of OpenCores tiny driver.
- spi: Fix Altera SPI build.
- commit 7bea08e
* Mon Feb 21 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc5-next-20110221
- commit a20d13d
* Fri Feb 18 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc5-next-20110218
- commit db538df
* Thu Feb 17 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc5-next-20110217
- commit 3973340
* Thu Feb 17 2011 jeffm@suse.de
- Update to 2.6.38-rc5.
- commit 1eab7b2
* Thu Feb 17 2011 gregkh@suse.de
- Update config files.
  - disable CONFIG_DRM_VMWGFX (bnc#606458)
  - update sparc configs to at least be able to run "make oldconfig"
- commit 86217cc
* Wed Feb 16 2011 mmarek@suse.cz
- Update config files: CONFIG_XVMALLOC=y, which the automatic script
  somehow forgot.
- commit 12a044a
* Wed Feb 16 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc4-next-20110216
- commit 71f20c6
* Tue Feb 15 2011 mmarek@suse.cz
- Allow sharing xvmalloc for zram and zcache.
- commit c58c702
* Tue Feb 15 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc4-next-20110215
- commit caa2518
* Mon Feb 14 2011 mmarek@suse.cz
- Move spec file templates and helper scripts to a separate branch, to
  ease synchronizing these files among master, vanilla and linux-next.
- commit 411abb8
* Mon Feb 14 2011 mmarek@suse.cz
- Delete a couple of obsolete kabi and other scripts from misc/:
- Delete misc/checkmod.
- Delete misc/collect_ksyms.
- Delete misc/diff-the-xfs-cvs.
- Delete misc/ksyms.py.
- Delete misc/mangle-ifdef.py.
- Delete misc/obsolete-module-aliases.
- Delete misc/testmodule.
- commit 71cfa19
* Mon Feb 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Delete misc/extract-modaliases, the code
  was merged into rpm's find-supplements script.
- Delete rpm/check-build.sh, not needed anymore.
- commit 4f60862
* Fri Feb 11 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc4-next-20110211
- commit 3e80d07
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Set timestamp of sources to the commit
  timestamp, so that they are always older than generated files in
  /usr/src/linux-obj (bnc#669669).
- commit 84695cd
* Wed Feb  9 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc4-next-20110209
- commit 02b0e53
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not run fdupes in /usr/src/linux-obj, to
  keep timestamps intact.
- commit a263252
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Remove .gitignore files after applying patches
  (fix last change).
- commit bf3f40b
* Tue Feb  8 2011 jbeulich@novell.com
- Update Xen patches to 2.6.38-rc4 and c/s 1066.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit 2b3a840
* Tue Feb  8 2011 jbeulich@novell.com
- Update config files.
- Refresh and re-enable patches.arch/x86_64-unwind-annotations.
- Refresh and re-enable patches.suse/stack-unwind.
- commit 2401b1e
* Tue Feb  8 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc4-next-20110208
- commit 7f165e3
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/{config.sh,kernel-source.spec.in,mkspec}: Generate only
  kernel-source-vanilla in the linux-next and vanilla branches.
- commit 87e0101
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Remove dead code.
- commit f43baea
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-spec-macros: Fix the definition
  of %%release_major and rename it to %%release_num to better describe
  what it does. Add some comments to explain how the versioning works.
- commit 785e4e2
* Mon Feb  7 2011 mmarek@suse.cz
- Automatically updated to 2.6.38-rc3-next-20110207
- commit 8bdb892
* Fri Feb  4 2011 mmarek@suse.cz
- rpm/config.sh, scripts/wd-functions.sh: Change the SRCVERSION format
  for linux-next to 2.6.<version>-next-<date>
- rpm/compute-PATCHVERSION.sh: Fix sed regexp
- commit d028aa3
* Fri Feb  4 2011 mmarek@suse.cz
- Automatically updated to next-20110204
- commit e1d42e9
* Fri Feb  4 2011 jeffm@suse.com
- Updated to 2.6.38-rc3.
  - Eliminated 2 patches.
- commit d28caeb
* Thu Feb  3 2011 mmarek@suse.cz
- Automatically updated to next-20110203
- commit 4b2f9ed
* Wed Feb  2 2011 mmarek@suse.cz
- Automatically updated to next-20110202
- commit 8ba402f
* Tue Feb  1 2011 mmarek@suse.cz
- Automatically updated to next-20110201
- commit 4bd4afe
* Mon Jan 31 2011 mmarek@suse.cz
- Automatically updated to next-20110131
- commit e6c6bfb
* Sun Jan 23 2011 jeffm@suse.com
- Update config files.
  - CONFIG_EXPERT=n on all but ps3
  - Vanilla configs updated.
- commit f9e6809
* Sun Jan 23 2011 jeffm@suse.com
- Revert "- Update config files: CONFIG_EXPERT=n except ps3"
  This reverts commit 3f2c93d6a0593b2cc0c40f5ffee426eef27cc400.
  This was a bad commit. I have no idea where all the changes came from.
- commit cd1894b
* Sun Jan 23 2011 jeffm@suse.com
- Update config files: CONFIG_EXPERT=n except ps3
- commit a64f6f2
* Sat Jan 22 2011 jeffm@suse.de
- Update to 2.6.38-rc1.
  - Removed 12 patches.
  - Xen is disabled.
  - Quite a few patches need updating.
- commit e3c456e
* Fri Jan 21 2011 mmarek@suse.cz
- Automatically updated to next-20110121
- commit bb85681
* Fri Jan 21 2011 trenn@suse.de
- perf: Do not export power_frequency, but power_start event
  (bnc#665153).
- cpuidle/x86/perf: fix power:cpu_idle double end events and
  throw cpu_idle events from the cpuidle layer (bnc#665153).
- perf: Clean up power events by introducing new, more generic
  ones (bnc#665153).
- cpuidle: Rename X86 specific idle poll state from C0 to POLL
  (bnc#665153).
- perf timechart: Adjust perf timechart to the new power events
  (bnc#665153).
- Fix display of idle boxes (none).
- Fix huge and wronge C-state drawings due to uninitialized
  start/end timestamps (none).
- Update config files.
- doc/config-options.changes:
  CONFIG_EVENT_POWER_TRACING_DEPRECATED=y
- commit 7e54309
* Thu Jan 20 2011 mmarek@suse.cz
- Automatically updated to next-20110120
- commit 472fa1d
* Tue Jan 18 2011 mmarek@suse.cz
- Automatically updated to next-20110118
- commit b76c2d3
* Mon Jan 17 2011 mmarek@suse.cz
- Automatically updated to next-20110117
- commit 724ad2e
* Mon Jan 17 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-7768-gf8b1808
- commit 6e6f3fd
* Sun Jan 16 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-7733-g1b59be2
- commit c37bb9b
* Sat Jan 15 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-7475-g6ab8219
- commit 1c70c15
* Fri Jan 14 2011 mmarek@suse.cz
- Revert %%kernelrelease changes originally made on the vanilla branch,
  they break on master and must be done differently.
- commit 47f524a
* Fri Jan 14 2011 mmarek@suse.cz
- Disable CONFIG_MMC_SDHCI_OF as it does not build on x86
- commit 88dc665
* Fri Jan 14 2011 mmarek@suse.cz
- ecryptfs: fix broken build.
- commit e793d92
* Fri Jan 14 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-6858-g581548d
- commit ec297e9
* Thu Jan 13 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-5761-gf878133
- commit 9daf5c6
* Wed Jan 12 2011 mmarek@suse.cz
- fs/btrfs: Fix build of ctree.
- commit 333c141
* Wed Jan 12 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-5292-g7bc4a4c
- commit 664dd3e
* Tue Jan 11 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-4043-ge0e736f
- commit 955681d
* Mon Jan 10 2011 jeffm@suse.com
- Enabled AGP modules as parts of the static kernel on i386 (bnc#609607)
- commit e2b28ea
* Sun Jan  9 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-3737-g0c21e3a
- commit 595b23e
* Sat Jan  8 2011 jengelh@medozas.de
- config: run oldconfig on sparc64/default
- commit 8e28dab
* Sat Jan  8 2011 jengelh@medozas.de
- config: update sparc64/net and throw out unworthy options
- commit 3cb63f7
* Sat Jan  8 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-3551-g128283a
- commit b90b8b1
* Fri Jan  7 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-337-gcb600d2
- commit 4f03386
* Thu Jan  6 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Move the source tree if %%kernelrelease is
  different from the tarball version.
- commit a54b85b
* Thu Jan  6 2011 jeffm@suse.com
- rpm/kernel-source.spec.in: Remove the relocation of the source tree.
  It's expanded in-place.
- commit 6d9f15d
* Thu Jan  6 2011 jeffm@suse.com
- Update to 2.6.37-final.
- commit a994f3d
* Thu Jan  6 2011 mmarek@suse.cz
- Automatically updated to 2.6.37
- commit 541c6ed
* Wed Jan  5 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-rc8-64-g989d873
- commit 5ca1633
* Tue Jan  4 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-rc8-46-g03ed6a3
- commit 68bb9d8
* Mon Jan  3 2011 mmarek@suse.cz
- Automatically updated to 2.6.37-rc8-32-g9109f4e
- commit 8c0f776
* Fri Dec 31 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc8-14-g3643e0e
- commit 8da1438
* Thu Dec 30 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc8
- commit 4f87762
* Wed Dec 29 2010 jeffm@suse.com
- Update to 2.6.37-rc8.
  - Eliminated 1 patch.
- commit eeea62c
* Wed Dec 29 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc7-184-gb52e2a6
- commit 816f63c
* Tue Dec 28 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc7-174-gffc96d6
- commit 991f75d
* Tue Dec 28 2010 jeffm@suse.com
- Update to 2.6.37-rc7.
  - Eliminated 9 patches.
- commit 2fd3f23
* Mon Dec 27 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc7-154-gd7c1255
- commit 0ee1cf9
* Wed Dec 22 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc7
- commit 5dd550d
* Tue Dec 21 2010 mmarek@suse.cz
- Delete patches.rpmify/easycap-buildfix which is already in mainline.
- commit f3ee1ac
* Tue Dec 21 2010 mmarek@suse.cz
- cciss: Fix build.
- commit 4299084
* Tue Dec 21 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc6-168-g8cad7f0
- commit ae416c0
* Mon Dec 20 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc6-132-g55ec86f
- commit 6344d65
* Sun Dec 19 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc6-109-g0a59228
- commit 2771402
* Sat Dec 18 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc6-93-gc15524a
- commit f37eae4
* Fri Dec 17 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc6-51-ga3383e8
- commit 34cf949
* Fri Dec 17 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc6-9-gb3444d1
- commit 223c932
* Fri Dec 17 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Define %%kernelrelease
- commit e23be74
* Thu Dec 16 2010 jeffm@suse.com
- Linux: 2.6.37-rc6.
- Update config files.
- Refresh patches.suse/SoN-23-mm-swapfile.patch.
- Refresh patches.suse/SoN-26-nfs-swapper.patch.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.24.
- commit e94c2ff
* Thu Dec 16 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc6
- commit 1c11dc9
* Thu Dec 16 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc5-338-ga4851d8
- commit 7f38ae6
* Mon Dec 13 2010 jbeulich@novell.com
- Update Xen config files (XEN_NETDEV_LOOPBACK=n).
- supported.conf: Update.
- commit 26d0c04
* Fri Dec 10 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc5-62-g6313e3c
- commit a494c89
* Fri Dec 10 2010 jbeulich@novell.com
- Update Xen config files (CONFIG_XEN_COMPAT=0x040000).
- commit 16a42ab
* Thu Dec  9 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix timestamp of /usr/src/linux-obj/.../.config
- commit 22ecd26
* Wed Dec  8 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Allow to build against any version of
  kernel-source
- commit bf9797f
* Tue Dec  7 2010 jeffm@suse.com
- Update vanilla config files.
- commit 2df42ee
* Tue Dec  7 2010 jeffm@suse.com
- Update to 2.6.37-rc5.
- commit 1539849
* Tue Dec  7 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc4-219-g771f8bc
- commit aaaa469
* Mon Dec  6 2010 jeffm@suse.de
- Update to 2.6.37-rc4.
- commit 2213601
* Sat Dec  4 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc4-201-g11e8896
- commit 5ceb1d1
* Fri Dec  3 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc4-137-g94c35de
- commit 16d240a
* Thu Dec  2 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc4-12-g22a5b56
- commit 41a681b
* Wed Dec  1 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc4
- commit dad78e7
* Tue Nov 30 2010 mmarek@suse.cz
- staging: easycap: fix build failure.
- commit 58057d2
* Mon Nov 29 2010 jeffm@suse.com
- Merge 2.6.37-rc3-git6 with Xen.
- commit 6f111eb
* Mon Nov 29 2010 jeffm@suse.com
- Update to 2.6.37-rc3-git6.
- commit dc489aa
* Mon Nov 29 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc3-324-g7208364
- commit 6df7f60
* Fri Nov 26 2010 jbeulich@novell.com
- Update Xen patches to 2.6.37-rc3-git1 and c/s 1055.
- xen/acpi: Add memory hotadd to pvops dom0 (bnc#651066).
- xen/acpi: Export host physical CPU information to dom0
  (bnc#651066).
- Xen: para-virtual watchdog driver.
- introduce {rd,wr}msr_safe_on_pcpu() and add/enable users.
- eliminate scalability issues from initrd handling.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit 2e37199
* Wed Nov 24 2010 jeffm@suse.com
- Update to 2.6.37-rc3-git1.
- commit 1f2163d
* Tue Nov 23 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc3
- commit ac2caab
* Mon Nov 22 2010 jeffm@suse.com
- Update to 2.6.37-rc3.
  - Eliminated 1 patch.
- commit f4b5b54
* Sun Nov 21 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc2-181-gb86db47
- commit 13003b7
* Sat Nov 20 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc2-124-g6656b3f
- commit 03f5d25
* Fri Nov 19 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc2-56-g2811036
- commit 6b06c25
* Thu Nov 18 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc2-36-g460781b
- commit b9bbb1f
* Wed Nov 17 2010 jeffm@suse.com
- sched: automated per tty task groups.
  - Enabled in -desktop flavors for better interactivity.
- commit e72f812
* Wed Nov 17 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc2
- commit 60b4ccc
* Tue Nov 16 2010 jeffm@suse.com
- Update to 2.6.37-rc2.
- commit 0cad819
* Tue Nov 16 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc1-609-g6800e4c
- commit a2932d6
* Mon Nov 15 2010 jeffm@suse.com
- Update vanilla config files.
- commit c6bcee0
* Mon Nov 15 2010 jeffm@suse.com
- Update to 2.6.37-rc1-git11.
  - Eliminated 2 patches.
- commit caf4431
* Sun Nov 14 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc1-542-g0143832
- commit 5c374c0
* Sat Nov 13 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc1-345-ga0a6da1
- commit 47e8390
* Fri Nov 12 2010 jeffm@suse.de
- Update to 2.6.37-rc1.
  - Eliminated 26 patches.
  - Xen is disabled.
- commit 67b83ed
* Thu Nov 11 2010 gregkh@suse.de
- Update config files. (bnc#652954) increase the number of possible and
  default uarts for users with multi-port serial cards for the i386 and
  x86-64 default configs.
- commit 318ead5
* Wed Nov 10 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc1-170-gf6614b7
- commit 94c91b1
* Tue Nov  9 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc1-163-ga7bcf21
- commit 07c27bb
* Sun Nov  7 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc1-116-g151f52f
- commit 06f3f42
* Sat Nov  6 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc1-103-g4b4a270
- commit ebab771
* Thu Nov  4 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc1-27-gff8b16d
- commit 7f3066d
* Wed Nov  3 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc1-5-gd88c092
- commit e8108f5
* Tue Nov  2 2010 mmarek@suse.cz
- Automatically updated to 2.6.37-rc1-1-ge99d11d
- commit b9613ea
* Mon Nov  1 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-9871-g3985c7c
- commit 37006d8
* Sun Oct 31 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-9848-g1792f17
- commit e917f1b
* Sat Oct 30 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-9410-gb7bdcc4
- commit 0cd27f1
* Fri Oct 29 2010 trenn@suse.de
- Update config files.
  Forgot to enable ACPI_EC_DEBUGFS on i386/pae
- commit c537afc
* Fri Oct 29 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-8965-g2d3b07c
- commit 1943fe5
* Thu Oct 28 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-6794-g12ba8d1e
- commit 18179b2
* Wed Oct 27 2010 jslaby@suse.cz
- aha152x: enable PCMCIA on 64bit (bnc#630652).
- Update config files.
- commit e0e5450
* Wed Oct 27 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-5857-gf9ba537
- commit 9bab858
* Tue Oct 26 2010 trenn@suse.de
- Update config files.
  Enable CONFIG_ACPI_EC_DEBUGFS=m on supported archs.
- commit 09658e1
* Tue Oct 26 2010 jbeulich@novell.com
- Update Xen config files (restore options accidentally deleted
  by 1b1584fccbfdc42e6e8b35c3c207ca65feb0c7d5).
- commit 66a7723
* Tue Oct 26 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-5279-g72e5806
- commit 1e255ec
* Mon Oct 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36 and c/s 1043.
- xen: netback: take net_schedule_list_lock when removing entry
  from net_schedule_list.
- Update Xen config files.
- commit 85d7698
* Mon Oct 25 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-4464-g229aebb
- commit 78422af
* Sun Oct 24 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-3963-g35da7a3
- commit 29b4c76
* Sat Oct 23 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-1431-gf5d9d24
- commit 5cef133
* Fri Oct 22 2010 jeffm@suse.de
- Update to 2.6.36-final.
- commit 4ebb1ab
* Fri Oct 22 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-531-g5fe8321
- commit 65ee29d
* Wed Oct 20 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc8-45-g51ea8a8
- commit 1fbcdc6
* Tue Oct 19 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc8-22-g2b666ca
- commit f547461
* Sun Oct 17 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc8-20-g2d01971
- commit 8292f40
* Sat Oct 16 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc8-13-g5a2b3ef
- commit 1048598
* Fri Oct 15 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc7-200-g3aa0ce8
- commit 1cdc3a5
* Wed Oct 13 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc7-153-g0acc1b2
- commit af3ab16
* Tue Oct 12 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc7-149-g29979aa
- commit 0824f5c
* Mon Oct 11 2010 mmarek@suse.cz
- Generate per-symbol provides again (fate#305945).
  11.4 will do incremental downloads of repository metadata
  (fate#309561), so there should be no problem with the update
  repository anymore.
- commit 2083a6a
* Sun Oct 10 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc7-124-g85a3318
- commit 9f29183
* Fri Oct  8 2010 jeffm@suse.de
- Update to 2.6.36-rc7.
- commit be4e347
* Fri Oct  8 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc7-69-g6b0cd00
- commit 556f9e1
* Thu Oct  7 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc7
- commit 31747de
* Wed Oct  6 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc6-136-ge1d9694
- commit 5c1d8b9
* Tue Oct  5 2010 jeffm@suse.de
- Enable SECURITY_APPARMOR_COMPAT_24
- commit 7dee26e
* Tue Oct  5 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc6-119-g3c06806
- commit 2a74b8e
* Sun Oct  3 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc6-84-gc6ea21e
- commit 8a78f00
* Sat Oct  2 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc6-76-g18ffe4b
- commit 7512c56
* Fri Oct  1 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc6-6-g4193d91
- commit c001f86
* Wed Sep 29 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc6
- commit c52fb02
* Wed Sep 29 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc5-284-g0f44fbd
- commit 3ed1f3f
* Mon Sep 27 2010 mmarek@suse.cz
- README.BRANCH: Update.
- commit 5d6a9e0
* Mon Sep 27 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc5-151-g32163f4
- commit 445c0e0
* Sun Sep 26 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc5-149-g56162ba
- commit 72b1d28
* Sat Sep 25 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc5-112-gcb9cae0
- commit 2559032
* Fri Sep 24 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc5-79-g91e71c1
- commit a26a09b
* Thu Sep 23 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix for kernel release strings like
  2.6.36-rc5-73-g57aebd7-vanilla.
- rpm/kernel-spec-macros: Cleanup.
- commit abada62
* Thu Sep 23 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc5-73-g57aebd7
- commit fb99565
* Thu Sep 23 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc5-49-gc79bd89
- commit 69a6d28
* Wed Sep 22 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc5-33-g1ce1e41
- commit 7b27c54
* Tue Sep 21 2010 mmarek@suse.cz
- Automatically updated to 2.6.36-rc5
- commit 937777f
* Tue Sep 21 2010 mmarek@suse.cz
- Start a branch tracking the latest upstream git.
- commit ae53d59
* Tue Sep 21 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: BuildRequire proper version of kernel-source
- commit c33d773
* Tue Sep 21 2010 jeffm@suse.de
- Linux: 2.6.36-rc5.
  - Eliminated 6 patches (all security backports).
- commit 77852e5
* Mon Sep 20 2010 jeffm@suse.de
- Revert "- make SCSI and ATA drivers modules again. (bnc#564357)."
  This reverts commit 75e8e5eae2c1e8dd279370f2c7650835ee821deb.
  - make SCSI and ATA drivers modules again.
    (bnc#564357)
  This change only applies to enterprise releases and should have been
  reverted prior to the release of openSUSE 11.3.
- commit 8d19a5c
* Mon Sep 20 2010 jeffm@suse.de
- Set LSM_MMAP_MIN_ADDR=0 to allow tools like DOSemu to work properly. The
  default is still set to 64k.
- commit 41fc57e
* Tue Sep 14 2010 jslaby@suse.cz
- Update to Linux 2.6.36-rc4.
  - Obsoletes:
  - patches.fixes/bonding-jiffies2.patch.
  - patches.fixes/irda-correctly-clean-up-self-ias_obj-on-irda_bind-failure.
  - patches.fixes/net-sched-fix-kernel-leak-in-act_police.
  - patches.rpmify/spectra-depends-on-moorestown.
- fix build on s390 as of 2.6.36-rc4.
- Refresh patches.suse/SoN-08-mm-page_alloc-emerg.patch.
- Refresh patches.suse/reiser4-set_page_dirty_notag.
- Refresh patches.xen/pci-guestdev.
- Update config files.
- commit 6915057
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, rpm/old-packages.conf:
  Obsolete kernel-vmi-base by kernel-pae-base (bnc#594271).
- commit a48fbdf
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/mkspec, rpm/old-packages.conf: Explicitly list ppc64 flavors that
  obsolete kernel-kdump.
- commit 0a4f75b
* Fri Apr 16 2010 mmarek@suse.cz
- rpm/old-packages.conf: s390(x) provides/obsoletes not needed anymore.
- commit 0e039b7
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/old-packages.conf: Obsolete kernel-vmi by kernel-default.
- rpm/kernel-module-subpackage: Also obsolete vmi KMPs.
- commit bf55479
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.KSYMS: Add to repo.
- commit 04ec451
